import { GraphWidget, HorizontalAnnotation, IWidget } from "monocdk/aws-cloudwatch";
import { AlarmFactory, BaseMonitoringProps, ErrorAlarmFactory, ErrorCountThreshold, ErrorRateThreshold, HighTpsThreshold, LatencyAlarmFactory, LatencyThreshold, LowTpsThreshold, MetricWithAlarmSupport, Monitoring, MonitoringScope, TpsAlarmFactory } from "../../common";
import { MonitoringHeaderWidget } from "../../dashboard";
import { ApiGatewayV2HttpApiMetricFactoryProps } from "./ApiGatewayV2HttpApiMetricFactory";
export interface ApiGatewayV2HttpApiMonitoringProps extends ApiGatewayV2HttpApiMetricFactoryProps, BaseMonitoringProps {
    readonly add4xxCountAlarm?: Record<string, ErrorCountThreshold>;
    readonly add4xxRateAlarm?: Record<string, ErrorRateThreshold>;
    readonly add5xxCountAlarm?: Record<string, ErrorCountThreshold>;
    readonly add5xxRateAlarm?: Record<string, ErrorRateThreshold>;
    readonly addLatencyP50Alarm?: Record<string, LatencyThreshold>;
    readonly addLatencyP90Alarm?: Record<string, LatencyThreshold>;
    readonly addLatencyP99Alarm?: Record<string, LatencyThreshold>;
    readonly addIntegrationLatencyP50Alarm?: Record<string, LatencyThreshold>;
    readonly addIntegrationLatencyP90Alarm?: Record<string, LatencyThreshold>;
    readonly addIntegrationLatencyP99Alarm?: Record<string, LatencyThreshold>;
    readonly addLowTpsAlarm?: Record<string, LowTpsThreshold>;
    readonly addHighTpsAlarm?: Record<string, HighTpsThreshold>;
}
export declare class ApiGatewayV2HttpApiMonitoring extends Monitoring {
    protected readonly title: string;
    protected readonly alarmFactory: AlarmFactory;
    protected readonly errorAlarmFactory: ErrorAlarmFactory;
    protected readonly tpsAlarmFactory: TpsAlarmFactory;
    protected readonly latencyAlarmFactory: LatencyAlarmFactory;
    protected readonly tpsAnnotations: HorizontalAnnotation[];
    protected readonly latencyAnnotations: HorizontalAnnotation[];
    protected readonly errorCountAnnotations: HorizontalAnnotation[];
    protected readonly errorRateAnnotations: HorizontalAnnotation[];
    protected readonly tpsMetric: MetricWithAlarmSupport;
    protected readonly error4xxCountMetric: MetricWithAlarmSupport;
    protected readonly error4xxRateMetric: MetricWithAlarmSupport;
    protected readonly error5xxCountMetric: MetricWithAlarmSupport;
    protected readonly error5xxRateMetric: MetricWithAlarmSupport;
    protected readonly p50LatencyMetric: MetricWithAlarmSupport;
    protected readonly p90LatencyMetric: MetricWithAlarmSupport;
    protected readonly p99LatencyMetric: MetricWithAlarmSupport;
    protected readonly p50IntegrationLatencyMetric: MetricWithAlarmSupport;
    protected readonly p90IntegrationLatencyMetric: MetricWithAlarmSupport;
    protected readonly p99IntegrationLatencyMetric: MetricWithAlarmSupport;
    constructor(scope: MonitoringScope, props: ApiGatewayV2HttpApiMonitoringProps);
    summaryWidgets(): IWidget[];
    widgets(): IWidget[];
    protected createTitleWidget(): MonitoringHeaderWidget;
    protected createTpsWidget(width: number, height: number): GraphWidget;
    protected createLatencyWidget(width: number, height: number): GraphWidget;
    protected createErrorCountWidget(width: number, height: number): GraphWidget;
    protected createErrorRateWidget(width: number, height: number): GraphWidget;
}
