import { IAutoScalingGroup } from "monocdk/aws-autoscaling";
import { MetricFactory } from "../../common";
export declare class EC2MetricFactory {
    protected readonly metricFactory: MetricFactory;
    protected readonly autoScalingGroup?: IAutoScalingGroup;
    constructor(metricFactory: MetricFactory, autoScalingGroup?: IAutoScalingGroup);
    /**
     * The percentage of allocated EC2 compute units that are currently in use on the instance.
     * This metric identifies the processing power required to run an application on a selected instance.
     * Depending on the instance type, tools in your operating system can show a lower percentage than
     * CloudWatch when the instance is not allocated a full processor core.
     */
    metricAverageCpuUtilisationPercent(): import("monocdk/aws-cloudwatch").IMetric;
    /**
     * Bytes read from all instance store volumes available to the instance.
     * This metric is used to determine the volume of the data the application reads from the hard disk of the instance.
     * This can be used to determine the speed of the application.
     */
    metricAverageDiskReadBytes(): import("monocdk/aws-cloudwatch").IMetric;
    /**
     * Bytes written to all instance store volumes available to the instance.
     * This metric is used to determine the volume of the data the application writes onto the hard disk of the instance.
     * This can be used to determine the speed of the application.
     */
    metricAverageDiskWriteBytes(): import("monocdk/aws-cloudwatch").IMetric;
    /**
     * Completed read operations from all instance store volumes available to the instance in a specified period of time.
     */
    metricAverageDiskReadOps(): import("monocdk/aws-cloudwatch").IMetric;
    /**
     * Completed write operations to all instance store volumes available to the instance in a specified period of time.
     */
    metricAverageDiskWriteOps(): import("monocdk/aws-cloudwatch").IMetric;
    /**
     * The number of bytes received on all network interfaces by the instance.
     * This metric identifies the volume of incoming network traffic to a single instance.
     */
    metricAverageNetworkInRateBytes(): import("monocdk/aws-cloudwatch").IMetric;
    /**
     * The number of bytes sent out on all network interfaces by the instance.
     * This metric identifies the volume of outgoing network traffic from a single instance.
     */
    metricAverageNetworkOutRateBytes(): import("monocdk/aws-cloudwatch").IMetric;
    private createMetric;
    private metricForAutoScalingGroup;
    private metricForAllInstances;
}
