'''
# CDK Monitoring Constructs

⚠️ This package isn't ready for use yet! ⚠️

[![Gitpod Ready-to-Code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/cdklabs/cdk-monitoring-constructs)
[![NPM version](https://badge.fury.io/js/cdk-monitoring-constructs.svg)](https://badge.fury.io/js/cdk-monitoring-constructs)
[![PyPI version](https://badge.fury.io/py/cdk-monitoring-constructs.svg)](https://badge.fury.io/py/cdk-monitoring-constructs)
[![NuGet version](https://badge.fury.io/nu/Cdklabs.CdkMonitoringConstructs.svg)](https://badge.fury.io/nu/Cdklabs.CdkMonitoringConstructs)
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/io.github.cdklabs/cdkmonitoringconstructs/badge.svg)](https://maven-badges.herokuapp.com/maven-central/io.github.cdklabs/cdkmonitoringconstructs)
[![Mergify](https://img.shields.io/endpoint.svg?url=https://gh.mergify.io/badges/cdklabs/cdk-monitoring-constructs&style=flat)](https://mergify.io)

Easy-to-use CDK constructs for monitoring your AWS infrastructure.

* Easily add commonly-used alarms using predefined properties
* Generate concise Cloudwatch dashboards that indicate your alarms
* Extend the library with your own extensions or custom metrics
* Consume the library in multiple languages (see below)

## Usage

### TypeScript (NPM)

> https://www.npmjs.com/package/cdk-monitoring-constructs

Add the dependency to your `package.json`:

```json
{
  "dependencies": {
    "cdk-monitoring-constructs": "^0.0.11",

    // peer dependencies
    "constructs": "^3.3.69",
    "monocdk": "^1.123.0",

    // (your other dependencies)
  }
}
```

### Java

> https://mvnrepository.com/artifact/io.github.cdklabs/cdkmonitoringconstructs

#### Maven

Add the following Maven project to your `pom.xml`:

```xml
<dependency>
    <groupId>io.github.cdklabs</groupId>
    <artifactId>cdkmonitoringconstructs</artifactId>
    <version>0.0.11</version>
</dependency>
```

#### Gradle

```kotlin
implementation("io.github.cdklabs:cdkmonitoringconstructs:0.0.11")
```

### Python (PyPi)

> https://pypi.org/project/cdk-monitoring-constructs/

TODO: describe usage

### C# (Nuget)

> https://www.nuget.org/packages/Cdklabs.CdkMonitoringConstructs/

TODO: describe usage

## Features

See [API](API.md) for complete auto-generated documentation.

You can also browse the documentation at https://constructs.dev/packages/cdk-monitoring-constructs/

| Item | Monitoring | Alarms | Notes |
| ---- | ---------- | ------ | ----- |
| AWS API Gateway (REST API) (`.monitorApiGateway()`) | TPS, latency, errors | Latency, error count/rate |  To see metrics, you have to enable Advanced Monitoring |
| AWS API Gateway V2 (HTTP API) (`.monitorApiGatewayV2HttpApi()`) | TPS, latency, errors | Latency, error count/rate | To see route level metrics, you have to enable Advanced Monitoring|
| AWS AppSync (GraphQL API) (`.monitorAppSyncApi()`) | TPS, latency, errors | Latency, error count/rate, low/high TPS | |
| AWS Billing (`.monitorBilling()`) | AWS account cost | | [Requires enabling](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/gs_monitor_estimated_charges_with_cloudwatch.html#gs_turning_on_billing_metrics) the **Receive Billing Alerts** option in AWS Console / Billing Preferences |
| AWS Certificate Manager (`.monitorCertificate()`) | Certificate expiration | Days until expiration | |
| AWS CloudFront (`.monitorCloudFrontDistribution()`) | TPS, traffic, latency, errors | | |
| AWS CodeBuild (`.monitorCodeBuildProject()`) | Build counts (total, successful, failed), failed rate, duration | Failed build count/rate, duration | |
| AWS DynamoDB (`.monitorDynamoTable()`) | Read and write capacity provisioned / used | Consumed capacity, throttling, latency, errors | |
| AWS DynamoDB Global Secondary Index (`.monitorDynamoTableGlobalSecondaryIndex()`) | Read and write capacity, indexing progress, throttled events | | |
| AWS EC2 (`.monitorEC2Instances()`) | CPU, disk operations, network | | |
| AWS EC2 Auto Scaling Groups (`.monitorAutoScalingGroup()`) | Group size, instance status | | |
| AWS ECS (`.monitorFargateService()`, `.monitorEc2Service()`, `.monitorSimpleFargateService()`, `monitorSimpleEc2Service()`, `.monitorQueueProcessingFargateService()`, `.monitorQueueProcessingEc2Service()`) | System resources and task health | Unhealthy task count, running tasks count, CPU/memory usage, and bytes processed by load balancer (if any) | Use for ecs-patterns load balanced ec2/fargate constructs (NetworkLoadBalancedEc2Service, NetworkLoadBalancedFargateService, ApplicationLoadBalancedEc2Service, ApplicationLoadBalancedFargateService) |
| AWS ElastiCache (`.monitorElastiCacheCluster()`) | CPU/memory usage, evictions and connections | | |
| AWS Glue (`.monitorGlueJob()`) | Traffic, job status, memory/CPU usage | | |
| AWS Kinesis Data Analytics (`.monitorKinesisDataAnalytics`) | Up/Downtime, CPU/memory usage, KPU usage, checkpoint metrics, and garbage collection metrics | Downtime | |
| AWS Kinesis Data Stream (`.monitorKinesisDataStream()`) | Put/Get/Incoming Record/s and Throttling | Iterator max age | |
| AWS Kinesis Firehose (`.monitorKinesisFirehose()`) | Number of records, requests, latency | | |
| AWS Lambda (`.monitorLambdaFunction()`) | Latency, errors, iterator max age | Latency, errors, throttles, iterator max age | Optional Lambda Insights metrics (opt-in) support |
| AWS Load Balancing (`.monitorNetworkLoadBalancer()`, `.monitorFargateApplicationLoadBalancer()`, `.monitorFargateNetworkLoadBalancer()`, `.monitorEc2ApplicationLoadBalancer()`, `.monitorEc2NetworkLoadBalancer()`) | System resources and task health | Unhealthy task count, running tasks count, (for Fargate/Ec2 apps) CPU/memory usage | Use for FargateService or Ec2Service backed by a NetworkLoadBalancer or ApplicationLoadBalancer |
| AWS OpenSearch/Elasticsearch (`.monitorOpenSearchCluster()`, `.monitorElasticsearchCluster()`) | Indexing and search latency, disk/memory/CPU usage | Indexing and search latency, disk/memory/CPU usage, cluster status | |
| AWS RDS (`.monitorRdsCluster()`) | Query duration, connections, latency, disk/CPU usage | Disk and CPU usage | |
| AWS Redshift (`.monitorRedshiftCluster()`) | Query duration, connections, latency, disk/CPU usage | Disk and CPU usage | |
| AWS S3 Bucket (`.monitorS3Bucket()`) | Bucket size and number of objects | | |
| AWS SecretsManager (`.monitorSecretsManagerSecret()`) | Days since last rotation | Days since last rotation | Requires the `@aws-cdk/aws-secretsmanager:parseOwnedSecretName` [feature flag](https://docs.aws.amazon.com/cdk/latest/guide/featureflags.html) |
| AWS SNS Topic (`.monitorSnsTopic()`) | Message count, size, failed notifications | Failed notifications | |
| AWS SQS Queue (`.monitorSqsQueue()`, `.monitorSqsQueueWithDlq()`) | Message count, age, size | Message count, age, DLQ incoming messages | |
| AWS Step Functions (`.monitorStepFunction()`, `.monitorStepFunctionActivity()`, `monitorStepFunctionLambdaIntegration()`, `.monitorStepFunctionServiceIntegration()`) | Execution count and breakdown per state | Duration, failed, failed rate, aborted, throttled, timed out executions | |
| CloudWatch Logs (`.monitorLog()`) | Patterns present in the log group | | |
| Custom metrics (`.monitorCustom()`) | Addition of custom metrics into the dashboard (each group is a widget) | | Supports anomaly detection |

## Contributing/Security

See [CONTRIBUTING](CONTRIBUTING.md) for more information.

## License

This project is licensed under the Apache-2.0 License.
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from ._jsii import *

import constructs
import monocdk
import monocdk.aws_apigateway
import monocdk.aws_apigatewayv2
import monocdk.aws_appsync
import monocdk.aws_autoscaling
import monocdk.aws_certificatemanager
import monocdk.aws_cloudfront
import monocdk.aws_cloudwatch
import monocdk.aws_codebuild
import monocdk.aws_dynamodb
import monocdk.aws_ecs
import monocdk.aws_ecs_patterns
import monocdk.aws_elasticloadbalancingv2
import monocdk.aws_elasticsearch
import monocdk.aws_lambda
import monocdk.aws_opensearchservice
import monocdk.aws_s3
import monocdk.aws_secretsmanager
import monocdk.aws_sns
import monocdk.aws_sqs
import monocdk.aws_stepfunctions


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AddAlarmProps",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_description": "alarmDescription",
        "alarm_name_suffix": "alarmNameSuffix",
        "comparison_operator": "comparisonOperator",
        "threshold": "threshold",
        "treat_missing_data": "treatMissingData",
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_dedupe_string_suffix": "alarmDedupeStringSuffix",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "disambiguator": "disambiguator",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
    },
)
class AddAlarmProps:
    def __init__(
        self,
        *,
        alarm_description: builtins.str,
        alarm_name_suffix: builtins.str,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        threshold: jsii.Number,
        treat_missing_data: monocdk.aws_cloudwatch.TreatMissingData,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Properties necessary to create a single alarm and configure it.

        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique.
        :param comparison_operator: (experimental) Comparison operator used to compare actual value against the threshold.
        :param threshold: (experimental) Threshold to alarm on.
        :param treat_missing_data: (experimental) Behaviour in case the metric data is missing.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state.
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones. Default: undefined (no disambiguator)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: {number} Same as datapointsToAlarm.
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarm_description": alarm_description,
            "alarm_name_suffix": alarm_name_suffix,
            "comparison_operator": comparison_operator,
            "threshold": threshold,
            "treat_missing_data": treat_missing_data,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_dedupe_string_suffix is not None:
            self._values["alarm_dedupe_string_suffix"] = alarm_dedupe_string_suffix
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if disambiguator is not None:
            self._values["disambiguator"] = disambiguator
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link

    @builtins.property
    def alarm_description(self) -> builtins.str:
        '''(experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible.

        :stability: experimental
        '''
        result = self._values.get("alarm_description")
        assert result is not None, "Required property 'alarm_description' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_name_suffix(self) -> builtins.str:
        '''(experimental) Suffix added to base alarm name.

        Alarm names need to be unique.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_suffix")
        assert result is not None, "Required property 'alarm_name_suffix' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def comparison_operator(self) -> monocdk.aws_cloudwatch.ComparisonOperator:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :stability: experimental
        '''
        result = self._values.get("comparison_operator")
        assert result is not None, "Required property 'comparison_operator' is missing"
        return typing.cast(monocdk.aws_cloudwatch.ComparisonOperator, result)

    @builtins.property
    def threshold(self) -> jsii.Number:
        '''(experimental) Threshold to alarm on.

        :stability: experimental
        '''
        result = self._values.get("threshold")
        assert result is not None, "Required property 'threshold' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def treat_missing_data(self) -> monocdk.aws_cloudwatch.TreatMissingData:
        '''(experimental) Behaviour in case the metric data is missing.

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data")
        assert result is not None, "Required property 'treat_missing_data' is missing"
        return typing.cast(monocdk.aws_cloudwatch.TreatMissingData, result)

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default action strategy.

        :default: default action will be used

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_dedupe_string_suffix(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix.

        This allows you to specify the same dedupe string for a family of alarms.
        Cannot be defined at the same time as alarmDedupeStringOverride.

        :default: undefined (no suffix)

        :stability: experimental
        '''
        result = self._values.get("alarm_dedupe_string_suffix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disambiguator(self) -> typing.Optional[builtins.str]:
        '''(experimental) Disambiguator is a string that differentiates this alarm from other similar ones.

        :default: undefined (no disambiguator)

        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: {number} Same as datapointsToAlarm.

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AddAlarmProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AddCompositeAlarmProps",
    jsii_struct_bases=[],
    name_mapping={
        "disambiguator": "disambiguator",
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_dedupe_string_suffix": "alarmDedupeStringSuffix",
        "alarm_description": "alarmDescription",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "alarm_name_suffix": "alarmNameSuffix",
        "composite_operator": "compositeOperator",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "fill_alarm_range": "fillAlarmRange",
        "runbook_link": "runbookLink",
    },
)
class AddCompositeAlarmProps:
    def __init__(
        self,
        *,
        disambiguator: builtins.str,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        alarm_name_suffix: typing.Optional[builtins.str] = None,
        composite_operator: typing.Optional["CompositeAlarmOperator"] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Properties necessary to create a composite alarm and configure it.

        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible. Default: no description
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique. Default: no suffix
        :param composite_operator: (experimental) Logical operator used to aggregate the status individual alarms. Default: OR
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "disambiguator": disambiguator,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_dedupe_string_suffix is not None:
            self._values["alarm_dedupe_string_suffix"] = alarm_dedupe_string_suffix
        if alarm_description is not None:
            self._values["alarm_description"] = alarm_description
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if alarm_name_suffix is not None:
            self._values["alarm_name_suffix"] = alarm_name_suffix
        if composite_operator is not None:
            self._values["composite_operator"] = composite_operator
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link

    @builtins.property
    def disambiguator(self) -> builtins.str:
        '''(experimental) Disambiguator is a string that differentiates this alarm from other similar ones.

        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        assert result is not None, "Required property 'disambiguator' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default action strategy.

        :default: default action will be used

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_dedupe_string_suffix(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix.

        This allows you to specify the same dedupe string for a family of alarms.
        Cannot be defined at the same time as alarmDedupeStringOverride.

        :default: undefined (no suffix)

        :stability: experimental
        '''
        result = self._values.get("alarm_dedupe_string_suffix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_description(self) -> typing.Optional[builtins.str]:
        '''(experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible.

        :default: no description

        :stability: experimental
        '''
        result = self._values.get("alarm_description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_suffix(self) -> typing.Optional[builtins.str]:
        '''(experimental) Suffix added to base alarm name.

        Alarm names need to be unique.

        :default: no suffix

        :stability: experimental
        '''
        result = self._values.get("alarm_name_suffix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def composite_operator(self) -> typing.Optional["CompositeAlarmOperator"]:
        '''(experimental) Logical operator used to aggregate the status individual alarms.

        :default: OR

        :stability: experimental
        '''
        result = self._values.get("composite_operator")
        return typing.cast(typing.Optional["CompositeAlarmOperator"], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AddCompositeAlarmProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AgeAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AgeAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: "AlarmFactory") -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addDaysSinceUpdateAlarm")
    def add_days_since_update_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "DaysSinceUpdateThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> "AlarmWithAnnotation":
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast("AlarmWithAnnotation", jsii.invoke(self, "addDaysSinceUpdateAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addDaysToExpiryAlarm")
    def add_days_to_expiry_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "DaysToExpiryThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> "AlarmWithAnnotation":
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast("AlarmWithAnnotation", jsii.invoke(self, "addDaysToExpiryAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addIteratorMaxAgeAlarm")
    def add_iterator_max_age_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MaxAgeThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> "AlarmWithAnnotation":
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast("AlarmWithAnnotation", jsii.invoke(self, "addIteratorMaxAgeAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> "AlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("AlarmFactory", jsii.get(self, "alarmFactory"))


class AlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        alarm_scope: monocdk.Construct,
        *,
        global_alarm_defaults: "AlarmFactoryDefaults",
        global_metric_defaults: "MetricFactoryDefaults",
        local_alarm_name_prefix: builtins.str,
    ) -> None:
        '''
        :param alarm_scope: -
        :param global_alarm_defaults: 
        :param global_metric_defaults: 
        :param local_alarm_name_prefix: 

        :stability: experimental
        '''
        props = AlarmFactoryProps(
            global_alarm_defaults=global_alarm_defaults,
            global_metric_defaults=global_metric_defaults,
            local_alarm_name_prefix=local_alarm_name_prefix,
        )

        jsii.create(self.__class__, self, [alarm_scope, props])

    @jsii.member(jsii_name="addAlarm")
    def add_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        *,
        alarm_description: builtins.str,
        alarm_name_suffix: builtins.str,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        threshold: jsii.Number,
        treat_missing_data: monocdk.aws_cloudwatch.TreatMissingData,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> "AlarmWithAnnotation":
        '''
        :param metric: -
        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique.
        :param comparison_operator: (experimental) Comparison operator used to compare actual value against the threshold.
        :param threshold: (experimental) Threshold to alarm on.
        :param treat_missing_data: (experimental) Behaviour in case the metric data is missing.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state.
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones. Default: undefined (no disambiguator)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: {number} Same as datapointsToAlarm.
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        props = AddAlarmProps(
            alarm_description=alarm_description,
            alarm_name_suffix=alarm_name_suffix,
            comparison_operator=comparison_operator,
            threshold=threshold,
            treat_missing_data=treat_missing_data,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            custom_params=custom_params,
            custom_tags=custom_tags,
            datapoints_to_alarm=datapoints_to_alarm,
            dedupe_string_override=dedupe_string_override,
            disambiguator=disambiguator,
            documentation_link=documentation_link,
            evaluate_low_sample_count_percentile=evaluate_low_sample_count_percentile,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            period=period,
            runbook_link=runbook_link,
        )

        return typing.cast("AlarmWithAnnotation", jsii.invoke(self, "addAlarm", [metric, props]))

    @jsii.member(jsii_name="addCompositeAlarm")
    def add_composite_alarm(
        self,
        alarms: typing.Sequence["AlarmWithAnnotation"],
        *,
        disambiguator: builtins.str,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        alarm_name_suffix: typing.Optional[builtins.str] = None,
        composite_operator: typing.Optional["CompositeAlarmOperator"] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.CompositeAlarm:
        '''
        :param alarms: -
        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible. Default: no description
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique. Default: no suffix
        :param composite_operator: (experimental) Logical operator used to aggregate the status individual alarms. Default: OR
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        props = AddCompositeAlarmProps(
            disambiguator=disambiguator,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_description=alarm_description,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            alarm_name_suffix=alarm_name_suffix,
            composite_operator=composite_operator,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string_override=dedupe_string_override,
            documentation_link=documentation_link,
            fill_alarm_range=fill_alarm_range,
            runbook_link=runbook_link,
        )

        return typing.cast(monocdk.aws_cloudwatch.CompositeAlarm, jsii.invoke(self, "addCompositeAlarm", [alarms, props]))

    @jsii.member(jsii_name="createAnnotation")
    def _create_annotation(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: "IAlarmActionStrategy",
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''
        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmAnnotationStrategyProps(
            alarm=alarm,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            metric=metric,
            threshold=threshold,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.HorizontalAnnotation, jsii.invoke(self, "createAnnotation", [props]))

    @jsii.member(jsii_name="determineActionsEnabled")
    def _determine_actions_enabled(
        self,
        actions_enabled: typing.Optional[builtins.bool] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> builtins.bool:
        '''
        :param actions_enabled: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.invoke(self, "determineActionsEnabled", [actions_enabled, disambiguator]))

    @jsii.member(jsii_name="determineCompositeAlarmRule")
    def _determine_composite_alarm_rule(
        self,
        alarms: typing.Sequence["AlarmWithAnnotation"],
        *,
        disambiguator: builtins.str,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        alarm_name_suffix: typing.Optional[builtins.str] = None,
        composite_operator: typing.Optional["CompositeAlarmOperator"] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.IAlarmRule:
        '''
        :param alarms: -
        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible. Default: no description
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique. Default: no suffix
        :param composite_operator: (experimental) Logical operator used to aggregate the status individual alarms. Default: OR
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        props = AddCompositeAlarmProps(
            disambiguator=disambiguator,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_description=alarm_description,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            alarm_name_suffix=alarm_name_suffix,
            composite_operator=composite_operator,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string_override=dedupe_string_override,
            documentation_link=documentation_link,
            fill_alarm_range=fill_alarm_range,
            runbook_link=runbook_link,
        )

        return typing.cast(monocdk.aws_cloudwatch.IAlarmRule, jsii.invoke(self, "determineCompositeAlarmRule", [alarms, props]))

    @jsii.member(jsii_name="generateDescription")
    def _generate_description(
        self,
        alarm_description: builtins.str,
        alarm_description_override: typing.Optional[builtins.str] = None,
        runbook_link_override: typing.Optional[builtins.str] = None,
        documentation_link_override: typing.Optional[builtins.str] = None,
    ) -> builtins.str:
        '''
        :param alarm_description: -
        :param alarm_description_override: -
        :param runbook_link_override: -
        :param documentation_link_override: -

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "generateDescription", [alarm_description, alarm_description_override, runbook_link_override, documentation_link_override]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmNamingStrategy")
    def _alarm_naming_strategy(self) -> "AlarmNamingStrategy":
        '''
        :stability: experimental
        '''
        return typing.cast("AlarmNamingStrategy", jsii.get(self, "alarmNamingStrategy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmScope")
    def _alarm_scope(self) -> monocdk.Construct:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.Construct, jsii.get(self, "alarmScope"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalAlarmDefaults")
    def _global_alarm_defaults(self) -> "AlarmFactoryDefaults":
        '''
        :stability: experimental
        '''
        return typing.cast("AlarmFactoryDefaults", jsii.get(self, "globalAlarmDefaults"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalMetricDefaults")
    def _global_metric_defaults(self) -> "MetricFactoryDefaults":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactoryDefaults", jsii.get(self, "globalMetricDefaults"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shouldUseDefaultDedupeForError")
    def should_use_default_dedupe_for_error(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "shouldUseDefaultDedupeForError"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shouldUseDefaultDedupeForLatency")
    def should_use_default_dedupe_for_latency(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "shouldUseDefaultDedupeForLatency"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmFactoryDefaults",
    jsii_struct_bases=[],
    name_mapping={
        "actions_enabled": "actionsEnabled",
        "alarm_name_prefix": "alarmNamePrefix",
        "action": "action",
        "annotation_strategy": "annotationStrategy",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_processor": "dedupeStringProcessor",
        "documentation_link": "documentationLink",
        "evaluation_periods": "evaluationPeriods",
        "runbook_link": "runbookLink",
        "use_default_dedupe_for_error": "useDefaultDedupeForError",
        "use_default_dedupe_for_latency": "useDefaultDedupeForLatency",
    },
)
class AlarmFactoryDefaults:
    def __init__(
        self,
        *,
        actions_enabled: typing.Union[builtins.bool, typing.Mapping[builtins.str, builtins.bool]],
        alarm_name_prefix: builtins.str,
        action: typing.Optional["IAlarmActionStrategy"] = None,
        annotation_strategy: typing.Optional["IAlarmAnnotationStrategy"] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_processor: typing.Optional["IAlarmDedupeStringProcessor"] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        use_default_dedupe_for_error: typing.Optional[builtins.bool] = None,
        use_default_dedupe_for_latency: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions for either all severities, or per severity.
        :param alarm_name_prefix: (experimental) Global prefix for all alarm names. This should be something unique to avoid collisions with other CTIs. This is ignored if an alarm's dedupeStringOverride is declared.
        :param action: (experimental) Default alarm action used for each alarm, unless it is overridden. If you do not want any actions to be created, just use NoAlarmActionStrategy.
        :param annotation_strategy: (experimental) Custom strategy to create annotations for alarms. Default: default annotations
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: 3
        :param dedupe_string_processor: (experimental) Custom strategy to process dedupe strings of the alarms. Default: default behaviour (no change)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body.
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: {number} Same as datapointsToAlarm.
        :param runbook_link: (experimental) An optional link included in the generated ticket description body.
        :param use_default_dedupe_for_error: (experimental) If this is defined as false and dedupeStringOverride is undefined, the alarm prefix will be part of the dedupe string. This essentially stops the dedupe of different errors together. Default: undefined (true)
        :param use_default_dedupe_for_latency: (experimental) If this is defined as false and dedupeStringOverride is undefined, the alarm prefix will be part of the dedupe string. This essentially stops the dedupe of different latency issues together. Default: undefined (true)

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "actions_enabled": actions_enabled,
            "alarm_name_prefix": alarm_name_prefix,
        }
        if action is not None:
            self._values["action"] = action
        if annotation_strategy is not None:
            self._values["annotation_strategy"] = annotation_strategy
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_processor is not None:
            self._values["dedupe_string_processor"] = dedupe_string_processor
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if use_default_dedupe_for_error is not None:
            self._values["use_default_dedupe_for_error"] = use_default_dedupe_for_error
        if use_default_dedupe_for_latency is not None:
            self._values["use_default_dedupe_for_latency"] = use_default_dedupe_for_latency

    @builtins.property
    def actions_enabled(
        self,
    ) -> typing.Union[builtins.bool, typing.Mapping[builtins.str, builtins.bool]]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions for either all severities, or per severity.

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        assert result is not None, "Required property 'actions_enabled' is missing"
        return typing.cast(typing.Union[builtins.bool, typing.Mapping[builtins.str, builtins.bool]], result)

    @builtins.property
    def alarm_name_prefix(self) -> builtins.str:
        '''(experimental) Global prefix for all alarm names.

        This should be something unique to avoid collisions with other CTIs.
        This is ignored if an alarm's dedupeStringOverride is declared.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_prefix")
        assert result is not None, "Required property 'alarm_name_prefix' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def action(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Default alarm action used for each alarm, unless it is overridden.

        If you do not want any actions to be created, just use NoAlarmActionStrategy.

        :stability: experimental
        '''
        result = self._values.get("action")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def annotation_strategy(self) -> typing.Optional["IAlarmAnnotationStrategy"]:
        '''(experimental) Custom strategy to create annotations for alarms.

        :default: default annotations

        :stability: experimental
        '''
        result = self._values.get("annotation_strategy")
        return typing.cast(typing.Optional["IAlarmAnnotationStrategy"], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: 3

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_processor(self) -> typing.Optional["IAlarmDedupeStringProcessor"]:
        '''(experimental) Custom strategy to process dedupe strings of the alarms.

        :default: default behaviour (no change)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_processor")
        return typing.cast(typing.Optional["IAlarmDedupeStringProcessor"], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: {number} Same as datapointsToAlarm.

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def use_default_dedupe_for_error(self) -> typing.Optional[builtins.bool]:
        '''(experimental) If this is defined as false and dedupeStringOverride is undefined, the alarm prefix will be part of the dedupe string.

        This essentially stops the dedupe of different errors together.

        :default: undefined (true)

        :stability: experimental
        '''
        result = self._values.get("use_default_dedupe_for_error")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_default_dedupe_for_latency(self) -> typing.Optional[builtins.bool]:
        '''(experimental) If this is defined as false and dedupeStringOverride is undefined, the alarm prefix will be part of the dedupe string.

        This essentially stops the dedupe of different latency issues together.

        :default: undefined (true)

        :stability: experimental
        '''
        result = self._values.get("use_default_dedupe_for_latency")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmFactoryDefaults(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "global_alarm_defaults": "globalAlarmDefaults",
        "global_metric_defaults": "globalMetricDefaults",
        "local_alarm_name_prefix": "localAlarmNamePrefix",
    },
)
class AlarmFactoryProps:
    def __init__(
        self,
        *,
        global_alarm_defaults: AlarmFactoryDefaults,
        global_metric_defaults: "MetricFactoryDefaults",
        local_alarm_name_prefix: builtins.str,
    ) -> None:
        '''
        :param global_alarm_defaults: 
        :param global_metric_defaults: 
        :param local_alarm_name_prefix: 

        :stability: experimental
        '''
        if isinstance(global_alarm_defaults, dict):
            global_alarm_defaults = AlarmFactoryDefaults(**global_alarm_defaults)
        if isinstance(global_metric_defaults, dict):
            global_metric_defaults = MetricFactoryDefaults(**global_metric_defaults)
        self._values: typing.Dict[str, typing.Any] = {
            "global_alarm_defaults": global_alarm_defaults,
            "global_metric_defaults": global_metric_defaults,
            "local_alarm_name_prefix": local_alarm_name_prefix,
        }

    @builtins.property
    def global_alarm_defaults(self) -> AlarmFactoryDefaults:
        '''
        :stability: experimental
        '''
        result = self._values.get("global_alarm_defaults")
        assert result is not None, "Required property 'global_alarm_defaults' is missing"
        return typing.cast(AlarmFactoryDefaults, result)

    @builtins.property
    def global_metric_defaults(self) -> "MetricFactoryDefaults":
        '''
        :stability: experimental
        '''
        result = self._values.get("global_metric_defaults")
        assert result is not None, "Required property 'global_metric_defaults' is missing"
        return typing.cast("MetricFactoryDefaults", result)

    @builtins.property
    def local_alarm_name_prefix(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix")
        assert result is not None, "Required property 'local_alarm_name_prefix' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlarmMatrixWidget(
    monocdk.aws_cloudwatch.AlarmStatusWidget,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AlarmMatrixWidget",
):
    '''(experimental) Wrapper of Alarm Status Widget which auto-calcultes height based on the number of alarms.

    Always takes the maximum width.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        alarms: typing.Sequence[monocdk.aws_cloudwatch.IAlarm],
        height: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarms: (experimental) list of alarms to show.
        :param height: (experimental) desired height. Default: auto calculated based on alarm number (3 to 8)
        :param title: (experimental) widget title. Default: no title

        :stability: experimental
        '''
        props = AlarmMatrixWidgetProps(alarms=alarms, height=height, title=title)

        jsii.create(self.__class__, self, [props])


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmMatrixWidgetProps",
    jsii_struct_bases=[],
    name_mapping={"alarms": "alarms", "height": "height", "title": "title"},
)
class AlarmMatrixWidgetProps:
    def __init__(
        self,
        *,
        alarms: typing.Sequence[monocdk.aws_cloudwatch.IAlarm],
        height: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarms: (experimental) list of alarms to show.
        :param height: (experimental) desired height. Default: auto calculated based on alarm number (3 to 8)
        :param title: (experimental) widget title. Default: no title

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarms": alarms,
        }
        if height is not None:
            self._values["height"] = height
        if title is not None:
            self._values["title"] = title

    @builtins.property
    def alarms(self) -> typing.List[monocdk.aws_cloudwatch.IAlarm]:
        '''(experimental) list of alarms to show.

        :stability: experimental
        '''
        result = self._values.get("alarms")
        assert result is not None, "Required property 'alarms' is missing"
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IAlarm], result)

    @builtins.property
    def height(self) -> typing.Optional[jsii.Number]:
        '''(experimental) desired height.

        :default: auto calculated based on alarm number (3 to 8)

        :stability: experimental
        '''
        result = self._values.get("height")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''(experimental) widget title.

        :default: no title

        :stability: experimental
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmMatrixWidgetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmMetadata",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "dedupe_string": "dedupeString",
        "disambiguator": "disambiguator",
    },
)
class AlarmMetadata:
    def __init__(
        self,
        *,
        action: "IAlarmActionStrategy",
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Metadata of an alarm.

        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
        }
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if dedupe_string is not None:
            self._values["dedupe_string"] = dedupe_string
        if disambiguator is not None:
            self._values["disambiguator"] = disambiguator

    @builtins.property
    def action(self) -> "IAlarmActionStrategy":
        '''
        :stability: experimental
        '''
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return typing.cast("IAlarmActionStrategy", result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dedupe_string(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dedupe_string")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disambiguator(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmMetadata(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmNamingInput",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_name_suffix": "alarmNameSuffix",
        "alarm_dedupe_string_suffix": "alarmDedupeStringSuffix",
        "alarm_name_override": "alarmNameOverride",
        "dedupe_string_override": "dedupeStringOverride",
        "disambiguator": "disambiguator",
    },
)
class AlarmNamingInput:
    def __init__(
        self,
        *,
        alarm_name_suffix: builtins.str,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm_name_suffix: 
        :param alarm_dedupe_string_suffix: 
        :param alarm_name_override: 
        :param dedupe_string_override: 
        :param disambiguator: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarm_name_suffix": alarm_name_suffix,
        }
        if alarm_dedupe_string_suffix is not None:
            self._values["alarm_dedupe_string_suffix"] = alarm_dedupe_string_suffix
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if disambiguator is not None:
            self._values["disambiguator"] = disambiguator

    @builtins.property
    def alarm_name_suffix(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_name_suffix")
        assert result is not None, "Required property 'alarm_name_suffix' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_dedupe_string_suffix(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_dedupe_string_suffix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disambiguator(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmNamingInput(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlarmNamingStrategy(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AlarmNamingStrategy",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        global_prefix: builtins.str,
        local_prefix: builtins.str,
        dedupe_string_strategy: typing.Optional["IAlarmDedupeStringProcessor"] = None,
    ) -> None:
        '''
        :param global_prefix: -
        :param local_prefix: -
        :param dedupe_string_strategy: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [global_prefix, local_prefix, dedupe_string_strategy])

    @jsii.member(jsii_name="getDedupeString")
    def get_dedupe_string(
        self,
        *,
        alarm_name_suffix: builtins.str,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> typing.Optional[builtins.str]:
        '''(experimental) Dedupe string resolved like this: - If "dedupeStringOverride" is defined for an alarm, it will be used as a dedupe string.

        - If "alarmDedupeStringSuffix" from the alarm factory is defined, "GlobalPrefix-LocalPrefix-AlarmDedupeStringSuffix" will be used as a dedupe string.
        - Otherwise, the alarm dedupe string will not be set.
          If a dedupe string strategy is set, it will be used to process the final string.

        :param alarm_name_suffix: 
        :param alarm_dedupe_string_suffix: 
        :param alarm_name_override: 
        :param dedupe_string_override: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmNamingInput(
            alarm_name_suffix=alarm_name_suffix,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_name_override=alarm_name_override,
            dedupe_string_override=dedupe_string_override,
            disambiguator=disambiguator,
        )

        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getDedupeString", [props]))

    @jsii.member(jsii_name="getName")
    def get_name(
        self,
        *,
        alarm_name_suffix: builtins.str,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> builtins.str:
        '''(experimental) Alarm name is resolved like this: - If "alarmNameOverride" is defined for an alarm, it will be used as alarm name.

        - Otherwise, the alarm name will be generated by joining: global prefix, local prefix, alarm name suffix, disambiguator.

        :param alarm_name_suffix: 
        :param alarm_dedupe_string_suffix: 
        :param alarm_name_override: 
        :param dedupe_string_override: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmNamingInput(
            alarm_name_suffix=alarm_name_suffix,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_name_override=alarm_name_override,
            dedupe_string_override=dedupe_string_override,
            disambiguator=disambiguator,
        )

        return typing.cast(builtins.str, jsii.invoke(self, "getName", [props]))

    @jsii.member(jsii_name="getWidgetLabel")
    def get_widget_label(
        self,
        *,
        alarm_name_suffix: builtins.str,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> builtins.str:
        '''
        :param alarm_name_suffix: 
        :param alarm_dedupe_string_suffix: 
        :param alarm_name_override: 
        :param dedupe_string_override: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmNamingInput(
            alarm_name_suffix=alarm_name_suffix,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_name_override=alarm_name_override,
            dedupe_string_override=dedupe_string_override,
            disambiguator=disambiguator,
        )

        return typing.cast(builtins.str, jsii.invoke(self, "getWidgetLabel", [props]))

    @jsii.member(jsii_name="joinDistinct")
    def _join_distinct(
        self,
        parts: typing.Sequence[builtins.str],
        separator: builtins.str,
    ) -> builtins.str:
        '''
        :param parts: -
        :param separator: -

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "joinDistinct", [parts, separator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dedupeStringStrategy")
    def _dedupe_string_strategy(self) -> "IAlarmDedupeStringProcessor":
        '''
        :stability: experimental
        '''
        return typing.cast("IAlarmDedupeStringProcessor", jsii.get(self, "dedupeStringStrategy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalPrefix")
    def _global_prefix(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "globalPrefix"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localPrefix")
    def _local_prefix(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "localPrefix"))


class AlarmSummaryMatrixWidget(
    monocdk.aws_cloudwatch.ConcreteWidget,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AlarmSummaryMatrixWidget",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        alarm_arns: typing.Sequence[builtins.str],
        height: typing.Optional[jsii.Number] = None,
        region: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        width: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param alarm_arns: 
        :param height: (experimental) Height of the widget. Default: - 6 for Alarm and Graph widgets. 3 for single value widgets where most recent value of a metric is displayed.
        :param region: (experimental) The region the metrics of this graph should be taken from. Default: - Current region
        :param title: (experimental) Title for the graph. Default: - None
        :param width: (experimental) Width of the widget, in a grid of 24 units wide. Default: 6

        :stability: experimental
        '''
        props = AlarmSummaryMatrixWidgetProps(
            alarm_arns=alarm_arns,
            height=height,
            region=region,
            title=title,
            width=width,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toJson")
    def to_json(self) -> typing.List[typing.Any]:
        '''(experimental) (experimental) Return the widget JSON for use in the dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[typing.Any], jsii.invoke(self, "toJson", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="props")
    def _props(self) -> "AlarmSummaryMatrixWidgetProps":
        '''
        :stability: experimental
        '''
        return typing.cast("AlarmSummaryMatrixWidgetProps", jsii.get(self, "props"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmSummaryMatrixWidgetPropertiesJson",
    jsii_struct_bases=[],
    name_mapping={"alarms": "alarms", "title": "title"},
)
class AlarmSummaryMatrixWidgetPropertiesJson:
    def __init__(
        self,
        *,
        alarms: typing.Sequence[builtins.str],
        title: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarms: 
        :param title: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarms": alarms,
        }
        if title is not None:
            self._values["title"] = title

    @builtins.property
    def alarms(self) -> typing.List[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarms")
        assert result is not None, "Required property 'alarms' is missing"
        return typing.cast(typing.List[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmSummaryMatrixWidgetPropertiesJson(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmSummaryMatrixWidgetProps",
    jsii_struct_bases=[monocdk.aws_cloudwatch.MetricWidgetProps],
    name_mapping={
        "height": "height",
        "region": "region",
        "title": "title",
        "width": "width",
        "alarm_arns": "alarmArns",
    },
)
class AlarmSummaryMatrixWidgetProps(monocdk.aws_cloudwatch.MetricWidgetProps):
    def __init__(
        self,
        *,
        height: typing.Optional[jsii.Number] = None,
        region: typing.Optional[builtins.str] = None,
        title: typing.Optional[builtins.str] = None,
        width: typing.Optional[jsii.Number] = None,
        alarm_arns: typing.Sequence[builtins.str],
    ) -> None:
        '''
        :param height: (experimental) Height of the widget. Default: - 6 for Alarm and Graph widgets. 3 for single value widgets where most recent value of a metric is displayed.
        :param region: (experimental) The region the metrics of this graph should be taken from. Default: - Current region
        :param title: (experimental) Title for the graph. Default: - None
        :param width: (experimental) Width of the widget, in a grid of 24 units wide. Default: 6
        :param alarm_arns: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarm_arns": alarm_arns,
        }
        if height is not None:
            self._values["height"] = height
        if region is not None:
            self._values["region"] = region
        if title is not None:
            self._values["title"] = title
        if width is not None:
            self._values["width"] = width

    @builtins.property
    def height(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Height of the widget.

        :default:

        - 6 for Alarm and Graph widgets.
        3 for single value widgets where most recent value of a metric is displayed.

        :stability: experimental
        '''
        result = self._values.get("height")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def region(self) -> typing.Optional[builtins.str]:
        '''(experimental) The region the metrics of this graph should be taken from.

        :default: - Current region

        :stability: experimental
        '''
        result = self._values.get("region")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''(experimental) Title for the graph.

        :default: - None

        :stability: experimental
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def width(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Width of the widget, in a grid of 24 units wide.

        :default: 6

        :stability: experimental
        '''
        result = self._values.get("width")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def alarm_arns(self) -> typing.List[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_arns")
        assert result is not None, "Required property 'alarm_arns' is missing"
        return typing.cast(typing.List[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmSummaryMatrixWidgetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmWithAnnotation",
    jsii_struct_bases=[AlarmMetadata],
    name_mapping={
        "action": "action",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "dedupe_string": "dedupeString",
        "disambiguator": "disambiguator",
        "alarm": "alarm",
        "alarm_description": "alarmDescription",
        "alarm_label": "alarmLabel",
        "alarm_name": "alarmName",
        "alarm_name_suffix": "alarmNameSuffix",
        "alarm_rule_when_alarming": "alarmRuleWhenAlarming",
        "alarm_rule_when_insufficient_data": "alarmRuleWhenInsufficientData",
        "alarm_rule_when_ok": "alarmRuleWhenOk",
        "annotation": "annotation",
    },
)
class AlarmWithAnnotation(AlarmMetadata):
    def __init__(
        self,
        *,
        action: "IAlarmActionStrategy",
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
        alarm: monocdk.aws_cloudwatch.Alarm,
        alarm_description: builtins.str,
        alarm_label: builtins.str,
        alarm_name: builtins.str,
        alarm_name_suffix: builtins.str,
        alarm_rule_when_alarming: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_insufficient_data: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_ok: monocdk.aws_cloudwatch.IAlarmRule,
        annotation: monocdk.aws_cloudwatch.HorizontalAnnotation,
    ) -> None:
        '''(experimental) Representation of an alarm with additional information.

        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 
        :param alarm: 
        :param alarm_description: 
        :param alarm_label: 
        :param alarm_name: 
        :param alarm_name_suffix: 
        :param alarm_rule_when_alarming: 
        :param alarm_rule_when_insufficient_data: 
        :param alarm_rule_when_ok: 
        :param annotation: 

        :stability: experimental
        '''
        if isinstance(annotation, dict):
            annotation = monocdk.aws_cloudwatch.HorizontalAnnotation(**annotation)
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "alarm": alarm,
            "alarm_description": alarm_description,
            "alarm_label": alarm_label,
            "alarm_name": alarm_name,
            "alarm_name_suffix": alarm_name_suffix,
            "alarm_rule_when_alarming": alarm_rule_when_alarming,
            "alarm_rule_when_insufficient_data": alarm_rule_when_insufficient_data,
            "alarm_rule_when_ok": alarm_rule_when_ok,
            "annotation": annotation,
        }
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if dedupe_string is not None:
            self._values["dedupe_string"] = dedupe_string
        if disambiguator is not None:
            self._values["disambiguator"] = disambiguator

    @builtins.property
    def action(self) -> "IAlarmActionStrategy":
        '''
        :stability: experimental
        '''
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return typing.cast("IAlarmActionStrategy", result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dedupe_string(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dedupe_string")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disambiguator(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm(self) -> monocdk.aws_cloudwatch.Alarm:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm")
        assert result is not None, "Required property 'alarm' is missing"
        return typing.cast(monocdk.aws_cloudwatch.Alarm, result)

    @builtins.property
    def alarm_description(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_description")
        assert result is not None, "Required property 'alarm_description' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_label(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_label")
        assert result is not None, "Required property 'alarm_label' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_name")
        assert result is not None, "Required property 'alarm_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_name_suffix(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_name_suffix")
        assert result is not None, "Required property 'alarm_name_suffix' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_rule_when_alarming(self) -> monocdk.aws_cloudwatch.IAlarmRule:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_rule_when_alarming")
        assert result is not None, "Required property 'alarm_rule_when_alarming' is missing"
        return typing.cast(monocdk.aws_cloudwatch.IAlarmRule, result)

    @builtins.property
    def alarm_rule_when_insufficient_data(self) -> monocdk.aws_cloudwatch.IAlarmRule:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_rule_when_insufficient_data")
        assert result is not None, "Required property 'alarm_rule_when_insufficient_data' is missing"
        return typing.cast(monocdk.aws_cloudwatch.IAlarmRule, result)

    @builtins.property
    def alarm_rule_when_ok(self) -> monocdk.aws_cloudwatch.IAlarmRule:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_rule_when_ok")
        assert result is not None, "Required property 'alarm_rule_when_ok' is missing"
        return typing.cast(monocdk.aws_cloudwatch.IAlarmRule, result)

    @builtins.property
    def annotation(self) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''
        :stability: experimental
        '''
        result = self._values.get("annotation")
        assert result is not None, "Required property 'annotation' is missing"
        return typing.cast(monocdk.aws_cloudwatch.HorizontalAnnotation, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmWithAnnotation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AnomalyDetectingAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AnomalyDetectingAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addAlarmWhenOutOfBand")
    def add_alarm_when_out_of_band(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        alarm_name_suffix: builtins.str,
        disambiguator: builtins.str,
        *,
        alarm_when_above_the_band: builtins.bool,
        alarm_when_below_the_band: builtins.bool,
        standard_deviation_for_alarm: jsii.Number,
        additional_description: typing.Optional[builtins.str] = None,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param alarm_name_suffix: -
        :param disambiguator: -
        :param alarm_when_above_the_band: 
        :param alarm_when_below_the_band: 
        :param standard_deviation_for_alarm: 
        :param additional_description: 
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default

        :stability: experimental
        '''
        props = AnomalyDetectionThreshold(
            alarm_when_above_the_band=alarm_when_above_the_band,
            alarm_when_below_the_band=alarm_when_below_the_band,
            standard_deviation_for_alarm=standard_deviation_for_alarm,
            additional_description=additional_description,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            comparison_operator_override=comparison_operator_override,
            custom_params=custom_params,
            custom_tags=custom_tags,
            datapoints_to_alarm=datapoints_to_alarm,
            dedupe_string_override=dedupe_string_override,
            documentation_link=documentation_link,
            evaluate_low_sample_count_percentile=evaluate_low_sample_count_percentile,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            period=period,
            runbook_link=runbook_link,
            treat_missing_data_override=treat_missing_data_override,
        )

        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addAlarmWhenOutOfBand", [metric, alarm_name_suffix, disambiguator, props]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class AnomalyDetectionMathExpression(
    monocdk.aws_cloudwatch.MathExpression,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AnomalyDetectionMathExpression",
):
    '''(experimental) Captures specific MathExpression for anomaly detection, for which alarm generation is different.

    Added to overcome certain CDK limitations at the time of writing.

    :see: https://github.com/aws/aws-cdk/issues/10540
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        expression: builtins.str,
        using_metrics: typing.Mapping[builtins.str, monocdk.aws_cloudwatch.IMetric],
        color: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> None:
        '''
        :param expression: (experimental) The expression defining the metric.
        :param using_metrics: (experimental) The metrics used in the expression, in a map. The key is the identifier that represents the given metric in the expression, and the value is the actual Metric object.
        :param color: (experimental) Color for this metric when added to a Graph in a Dashboard. Default: - Automatic color
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - Expression value is used as label
        :param period: (experimental) The period over which the expression's statistics are applied. This period overrides all periods in the metrics used in this math expression. Default: Duration.minutes(5)

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MathExpressionProps(
            expression=expression,
            using_metrics=using_metrics,
            color=color,
            label=label,
            period=period,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="createAlarm")
    def create_alarm(
        self,
        scope: monocdk.Construct,
        id: builtins.str,
        *,
        evaluation_periods: jsii.Number,
        threshold: jsii.Number,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description: typing.Optional[builtins.str] = None,
        alarm_name: typing.Optional[builtins.str] = None,
        comparison_operator: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        statistic: typing.Optional[builtins.str] = None,
        treat_missing_data: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
    ) -> monocdk.aws_cloudwatch.Alarm:
        '''(experimental) (experimental) Make a new Alarm for this metric.

        Combines both properties that may adjust the metric (aggregation) as well
        as alarm properties.

        :param scope: -
        :param id: -
        :param evaluation_periods: (experimental) The number of periods over which data is compared to the specified threshold.
        :param threshold: (experimental) The value against which the specified statistic is compared.
        :param actions_enabled: (experimental) Whether the actions for this alarm are enabled. Default: true
        :param alarm_description: (experimental) Description for the alarm. Default: No description
        :param alarm_name: (experimental) Name of the alarm. Default: Automatically generated name
        :param comparison_operator: (experimental) Comparison to use to check if metric is breaching. Default: GreaterThanOrEqualToThreshold
        :param datapoints_to_alarm: (experimental) The number of datapoints that must be breaching to trigger the alarm. This is used only if you are setting an "M out of N" alarm. In that case, this value is the M. For more information, see Evaluating an Alarm in the Amazon CloudWatch User Guide. Default: ``evaluationPeriods``
        :param evaluate_low_sample_count_percentile: (experimental) Specifies whether to evaluate the data and potentially change the alarm state if there are too few data points to be statistically significant. Used only for alarms that are based on percentiles. Default: - Not configured.
        :param period: (deprecated) The period over which the specified statistic is applied. Cannot be used with ``MathExpression`` objects. Default: - The period from the metric
        :param statistic: (deprecated) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Cannot be used with ``MathExpression`` objects. Default: - The statistic from the metric
        :param treat_missing_data: (experimental) Sets how this alarm is to handle missing data points. Default: TreatMissingData.Missing

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.CreateAlarmOptions(
            evaluation_periods=evaluation_periods,
            threshold=threshold,
            actions_enabled=actions_enabled,
            alarm_description=alarm_description,
            alarm_name=alarm_name,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluate_low_sample_count_percentile=evaluate_low_sample_count_percentile,
            period=period,
            statistic=statistic,
            treat_missing_data=treat_missing_data,
        )

        return typing.cast(monocdk.aws_cloudwatch.Alarm, jsii.invoke(self, "createAlarm", [scope, id, props]))

    @jsii.member(jsii_name="with")
    def with_(
        self,
        *,
        color: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> monocdk.aws_cloudwatch.MathExpression:
        '''(experimental) (experimental) Return a copy of Metric with properties changed.

        All properties except namespace and metricName can be changed.

        :param color: (experimental) Color for this metric when added to a Graph in a Dashboard. Default: - Automatic color
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - Expression value is used as label
        :param period: (experimental) The period over which the expression's statistics are applied. This period overrides all periods in the metrics used in this math expression. Default: Duration.minutes(5)

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MathExpressionOptions(
            color=color, label=label, period=period
        )

        return typing.cast(monocdk.aws_cloudwatch.MathExpression, jsii.invoke(self, "with", [props]))


class ApiGatewayMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ApiGatewayMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        api: monocdk.aws_apigateway.RestApiBase,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param api: (experimental) API to monitor (cannot use IRestApi, since it does not provide API name).
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: prod
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = ApiGatewayMetricFactoryProps(
            api=api,
            api_method=api_method,
            api_resource=api_resource,
            api_stage=api_stage,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metric4XXErrorCount")
    def metric4_xx_error_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4XXErrorCount", []))

    @jsii.member(jsii_name="metric4XXErrorRate")
    def metric4_xx_error_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4XXErrorRate", []))

    @jsii.member(jsii_name="metric5XXFaultCount")
    def metric5_xx_fault_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5XXFaultCount", []))

    @jsii.member(jsii_name="metric5XXFaultRate")
    def metric5_xx_fault_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5XXFaultRate", []))

    @jsii.member(jsii_name="metricInvocationCount")
    def metric_invocation_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricInvocationCount", []))

    @jsii.member(jsii_name="metricLatencyP50InMillis")
    def metric_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricLatencyP90InMillis")
    def metric_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricLatencyP99InMillis")
    def metric_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricTps")
    def metric_tps(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTps", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fillTpsWithZeroes")
    def _fill_tps_with_zeroes(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "fillTpsWithZeroes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> "RateComputationMethod":
        '''
        :stability: experimental
        '''
        return typing.cast("RateComputationMethod", jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ApiGatewayMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "api": "api",
        "api_method": "apiMethod",
        "api_resource": "apiResource",
        "api_stage": "apiStage",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "rate_computation_method": "rateComputationMethod",
    },
)
class ApiGatewayMetricFactoryProps:
    def __init__(
        self,
        *,
        api: monocdk.aws_apigateway.RestApiBase,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param api: (experimental) API to monitor (cannot use IRestApi, since it does not provide API name).
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: prod
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "api": api,
        }
        if api_method is not None:
            self._values["api_method"] = api_method
        if api_resource is not None:
            self._values["api_resource"] = api_resource
        if api_stage is not None:
            self._values["api_stage"] = api_stage
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def api(self) -> monocdk.aws_apigateway.RestApiBase:
        '''(experimental) API to monitor (cannot use IRestApi, since it does not provide API name).

        :stability: experimental
        '''
        result = self._values.get("api")
        assert result is not None, "Required property 'api' is missing"
        return typing.cast(monocdk.aws_apigateway.RestApiBase, result)

    @builtins.property
    def api_method(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_method")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_resource(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_resource")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_stage(self) -> typing.Optional[builtins.str]:
        '''
        :default: prod

        :stability: experimental
        '''
        result = self._values.get("api_stage")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional["RateComputationMethod"]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional["RateComputationMethod"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayV2HttpApiMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ApiGatewayV2HttpApiMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        api: monocdk.aws_apigatewayv2.IHttpApi,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param api: 
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: $default
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = ApiGatewayV2HttpApiMetricFactoryProps(
            api=api,
            api_method=api_method,
            api_resource=api_resource,
            api_stage=api_stage,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metric4xxCount")
    def metric4xx_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4xxCount", []))

    @jsii.member(jsii_name="metric4xxRate")
    def metric4xx_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4xxRate", []))

    @jsii.member(jsii_name="metric5xxCount")
    def metric5xx_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5xxCount", []))

    @jsii.member(jsii_name="metric5xxRate")
    def metric5xx_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5xxRate", []))

    @jsii.member(jsii_name="metricIntegrationLatencyP50InMillis")
    def metric_integration_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIntegrationLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricIntegrationLatencyP90InMillis")
    def metric_integration_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIntegrationLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricIntegrationLatencyP99InMillis")
    def metric_integration_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIntegrationLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricInvocationCount")
    def metric_invocation_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricInvocationCount", []))

    @jsii.member(jsii_name="metricLatencyP50InMillis")
    def metric_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricLatencyP90InMillis")
    def metric_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricLatencyP99InMillis")
    def metric_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricTps")
    def metric_tps(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTps", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fillTpsWithZeroes")
    def _fill_tps_with_zeroes(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "fillTpsWithZeroes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> "RateComputationMethod":
        '''
        :stability: experimental
        '''
        return typing.cast("RateComputationMethod", jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ApiGatewayV2HttpApiMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "api": "api",
        "api_method": "apiMethod",
        "api_resource": "apiResource",
        "api_stage": "apiStage",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "rate_computation_method": "rateComputationMethod",
    },
)
class ApiGatewayV2HttpApiMetricFactoryProps:
    def __init__(
        self,
        *,
        api: monocdk.aws_apigatewayv2.IHttpApi,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param api: 
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: $default
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "api": api,
        }
        if api_method is not None:
            self._values["api_method"] = api_method
        if api_resource is not None:
            self._values["api_resource"] = api_resource
        if api_stage is not None:
            self._values["api_stage"] = api_stage
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def api(self) -> monocdk.aws_apigatewayv2.IHttpApi:
        '''
        :stability: experimental
        '''
        result = self._values.get("api")
        assert result is not None, "Required property 'api' is missing"
        return typing.cast(monocdk.aws_apigatewayv2.IHttpApi, result)

    @builtins.property
    def api_method(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_method")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_resource(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_resource")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_stage(self) -> typing.Optional[builtins.str]:
        '''
        :default: $default

        :stability: experimental
        '''
        result = self._values.get("api_stage")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional["RateComputationMethod"]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional["RateComputationMethod"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayV2HttpApiMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppSyncMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AppSyncMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        api: monocdk.aws_appsync.GraphqlApi,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param api: (experimental) the GraphQL API to monitor.
        :param fill_tps_with_zeroes: (experimental) whether the TPS should be filled with zeroes. Default: true
        :param rate_computation_method: (experimental) method to compute TPS. Default: average

        :stability: experimental
        '''
        props = AppSyncMetricFactoryProps(
            api=api,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metric4XXErrorCount")
    def metric4_xx_error_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4XXErrorCount", []))

    @jsii.member(jsii_name="metric4XXErrorRate")
    def metric4_xx_error_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4XXErrorRate", []))

    @jsii.member(jsii_name="metric5XXFaultCount")
    def metric5_xx_fault_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5XXFaultCount", []))

    @jsii.member(jsii_name="metric5XXFaultRate")
    def metric5_xx_fault_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5XXFaultRate", []))

    @jsii.member(jsii_name="metricLatencyP50InMillis")
    def metric_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricLatencyP90InMillis")
    def metric_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricLatencyP99InMillis")
    def metric_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricRequestCount")
    def metric_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricRequestCount", []))

    @jsii.member(jsii_name="metricTps")
    def metric_tps(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTps", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fillTpsWithZeroes")
    def _fill_tps_with_zeroes(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "fillTpsWithZeroes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> "RateComputationMethod":
        '''
        :stability: experimental
        '''
        return typing.cast("RateComputationMethod", jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AppSyncMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "api": "api",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "rate_computation_method": "rateComputationMethod",
    },
)
class AppSyncMetricFactoryProps:
    def __init__(
        self,
        *,
        api: monocdk.aws_appsync.GraphqlApi,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param api: (experimental) the GraphQL API to monitor.
        :param fill_tps_with_zeroes: (experimental) whether the TPS should be filled with zeroes. Default: true
        :param rate_computation_method: (experimental) method to compute TPS. Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "api": api,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def api(self) -> monocdk.aws_appsync.GraphqlApi:
        '''(experimental) the GraphQL API to monitor.

        :stability: experimental
        '''
        result = self._values.get("api")
        assert result is not None, "Required property 'api' is missing"
        return typing.cast(monocdk.aws_appsync.GraphqlApi, result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''(experimental) whether the TPS should be filled with zeroes.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional["RateComputationMethod"]:
        '''(experimental) method to compute TPS.

        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional["RateComputationMethod"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppSyncMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ApplicationLoadBalancerMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "application_load_balancer": "applicationLoadBalancer",
        "application_target_group": "applicationTargetGroup",
    },
)
class ApplicationLoadBalancerMetricFactoryProps:
    def __init__(
        self,
        *,
        application_load_balancer: monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
        application_target_group: monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup,
    ) -> None:
        '''(experimental) Props to create ApplicationLoadBalancerMetricFactory.

        :param application_load_balancer: 
        :param application_target_group: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "application_load_balancer": application_load_balancer,
            "application_target_group": application_target_group,
        }

    @builtins.property
    def application_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("application_load_balancer")
        assert result is not None, "Required property 'application_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, result)

    @builtins.property
    def application_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("application_target_group")
        assert result is not None, "Required property 'application_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApplicationLoadBalancerMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutoScalingGroupMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AutoScalingGroupMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        auto_scaling_group: monocdk.aws_autoscaling.IAutoScalingGroup,
    ) -> None:
        '''
        :param metric_factory: -
        :param auto_scaling_group: 

        :stability: experimental
        '''
        props = AutoScalingGroupMetricFactoryProps(
            auto_scaling_group=auto_scaling_group
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricGroupDesiredCapacity")
    def metric_group_desired_capacity(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The number of instances that the Auto Scaling group attempts to maintain.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupDesiredCapacity", []))

    @jsii.member(jsii_name="metricGroupInServiceInstances")
    def metric_group_in_service_instances(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The number of instances that are running as part of the Auto Scaling group.

        This metric does not include instances that are pending or terminating.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupInServiceInstances", []))

    @jsii.member(jsii_name="metricGroupMaxSize")
    def metric_group_max_size(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The maximum size of the Auto Scaling group.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupMaxSize", []))

    @jsii.member(jsii_name="metricGroupMinSize")
    def metric_group_min_size(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The minimum size of the Auto Scaling group.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupMinSize", []))

    @jsii.member(jsii_name="metricGroupPendingInstances")
    def metric_group_pending_instances(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The number of instances that are pending.

        A pending instance is not yet in service.
        This metric does not include instances that are in service or terminating.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupPendingInstances", []))

    @jsii.member(jsii_name="metricGroupStandbyInstances")
    def metric_group_standby_instances(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The number of instances that are in a Standby state.

        Instances in this state are still running but are not actively in service.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupStandbyInstances", []))

    @jsii.member(jsii_name="metricGroupTerminatingInstances")
    def metric_group_terminating_instances(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The number of instances that are in the process of terminating.

        This metric does not include instances that are in service or pending.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupTerminatingInstances", []))

    @jsii.member(jsii_name="metricGroupTotalInstances")
    def metric_group_total_instances(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) The total number of instances in the Auto Scaling group.

        This metric identifies the number of instances that are in service, pending, and terminating.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGroupTotalInstances", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AutoScalingGroupMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"auto_scaling_group": "autoScalingGroup"},
)
class AutoScalingGroupMetricFactoryProps:
    def __init__(
        self,
        *,
        auto_scaling_group: monocdk.aws_autoscaling.IAutoScalingGroup,
    ) -> None:
        '''
        :param auto_scaling_group: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "auto_scaling_group": auto_scaling_group,
        }

    @builtins.property
    def auto_scaling_group(self) -> monocdk.aws_autoscaling.IAutoScalingGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("auto_scaling_group")
        assert result is not None, "Required property 'auto_scaling_group' is missing"
        return typing.cast(monocdk.aws_autoscaling.IAutoScalingGroup, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoScalingGroupMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AwsConsoleUrlFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AwsConsoleUrlFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        aws_account_region: builtins.str,
    ) -> None:
        '''
        :param aws_account_id: 
        :param aws_account_region: 

        :stability: experimental
        '''
        props = AwsConsoleUrlFactoryProps(
            aws_account_id=aws_account_id, aws_account_region=aws_account_region
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="getApiGatewayUrl")
    def get_api_gateway_url(
        self,
        rest_api_id: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param rest_api_id: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getApiGatewayUrl", [rest_api_id]))

    @jsii.member(jsii_name="getAwsConsoleUrl")
    def get_aws_console_url(
        self,
        destination_url: typing.Optional[builtins.str] = None,
    ) -> typing.Optional[builtins.str]:
        '''
        :param destination_url: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getAwsConsoleUrl", [destination_url]))

    @jsii.member(jsii_name="getCloudFrontDistributionUrl")
    def get_cloud_front_distribution_url(
        self,
        distribution_id: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param distribution_id: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getCloudFrontDistributionUrl", [distribution_id]))

    @jsii.member(jsii_name="getCloudWatchLogGroupUrl")
    def get_cloud_watch_log_group_url(
        self,
        log_group_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param log_group_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getCloudWatchLogGroupUrl", [log_group_name]))

    @jsii.member(jsii_name="getCodeBuildProjectUrl")
    def get_code_build_project_url(
        self,
        project_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param project_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getCodeBuildProjectUrl", [project_name]))

    @jsii.member(jsii_name="getDynamoTableUrl")
    def get_dynamo_table_url(
        self,
        table_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param table_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getDynamoTableUrl", [table_name]))

    @jsii.member(jsii_name="getElastiCacheClusterUrl")
    def get_elasti_cache_cluster_url(
        self,
        cluster_id: builtins.str,
        cluster_type: "ElastiCacheClusterType",
    ) -> typing.Optional[builtins.str]:
        '''
        :param cluster_id: -
        :param cluster_type: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getElastiCacheClusterUrl", [cluster_id, cluster_type]))

    @jsii.member(jsii_name="getKinesisAnalyticsUrl")
    def get_kinesis_analytics_url(
        self,
        application: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param application: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getKinesisAnalyticsUrl", [application]))

    @jsii.member(jsii_name="getKinesisDataStreamUrl")
    def get_kinesis_data_stream_url(
        self,
        stream_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param stream_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getKinesisDataStreamUrl", [stream_name]))

    @jsii.member(jsii_name="getKinesisFirehoseDeliveryStreamUrl")
    def get_kinesis_firehose_delivery_stream_url(
        self,
        stream_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param stream_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getKinesisFirehoseDeliveryStreamUrl", [stream_name]))

    @jsii.member(jsii_name="getLambdaFunctionUrl")
    def get_lambda_function_url(
        self,
        function_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param function_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getLambdaFunctionUrl", [function_name]))

    @jsii.member(jsii_name="getOpenSearchClusterUrl")
    def get_open_search_cluster_url(
        self,
        domain_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param domain_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getOpenSearchClusterUrl", [domain_name]))

    @jsii.member(jsii_name="getRdsClusterUrl")
    def get_rds_cluster_url(
        self,
        cluster_id: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param cluster_id: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getRdsClusterUrl", [cluster_id]))

    @jsii.member(jsii_name="getRedshiftClusterUrl")
    def get_redshift_cluster_url(
        self,
        cluster_id: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param cluster_id: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getRedshiftClusterUrl", [cluster_id]))

    @jsii.member(jsii_name="getResolvedDestinationUrl")
    def _get_resolved_destination_url(
        self,
        context: monocdk.IResolveContext,
        destination_url: builtins.str,
    ) -> builtins.str:
        '''(experimental) Resolves a destination URL within a resolution context.

        :param context: The resolution context.
        :param destination_url: The destination URL to resolve since it may contain CDK tokens.

        :see: https://docs.aws.amazon.com/cdk/latest/guide/tokens.html
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "getResolvedDestinationUrl", [context, destination_url]))

    @jsii.member(jsii_name="getS3BucketUrl")
    def get_s3_bucket_url(
        self,
        bucket_name: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param bucket_name: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getS3BucketUrl", [bucket_name]))

    @jsii.member(jsii_name="getSnsTopicUrl")
    def get_sns_topic_url(
        self,
        topic_arn: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param topic_arn: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getSnsTopicUrl", [topic_arn]))

    @jsii.member(jsii_name="getSqsQueueUrl")
    def get_sqs_queue_url(
        self,
        queue_url: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param queue_url: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getSqsQueueUrl", [queue_url]))

    @jsii.member(jsii_name="getStateMachineUrl")
    def get_state_machine_url(
        self,
        state_machine_arn: builtins.str,
    ) -> typing.Optional[builtins.str]:
        '''
        :param state_machine_arn: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getStateMachineUrl", [state_machine_arn]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="awsAccountId")
    def _aws_account_id(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="awsAccountRegion")
    def _aws_account_region(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountRegion"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AwsConsoleUrlFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "aws_account_region": "awsAccountRegion",
    },
)
class AwsConsoleUrlFactoryProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        aws_account_region: builtins.str,
    ) -> None:
        '''
        :param aws_account_id: 
        :param aws_account_region: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "aws_account_region": aws_account_region,
        }

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aws_account_region(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("aws_account_region")
        assert result is not None, "Required property 'aws_account_region' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AwsConsoleUrlFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.AxisPosition")
class AxisPosition(enum.Enum):
    '''
    :stability: experimental
    '''

    LEFT = "LEFT"
    '''
    :stability: experimental
    '''
    RIGHT = "RIGHT"
    '''
    :stability: experimental
    '''


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.BaseDlqAlarms",
    jsii_struct_bases=[],
    name_mapping={
        "add_dead_letter_queue_max_incoming_messages_alarm": "addDeadLetterQueueMaxIncomingMessagesAlarm",
        "add_dead_letter_queue_max_message_age_alarm": "addDeadLetterQueueMaxMessageAgeAlarm",
        "add_dead_letter_queue_max_size_alarm": "addDeadLetterQueueMaxSizeAlarm",
    },
)
class BaseDlqAlarms:
    def __init__(
        self,
        *,
        add_dead_letter_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxIncomingMessagesCountThreshold"]] = None,
        add_dead_letter_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxMessageAgeThreshold"]] = None,
        add_dead_letter_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxMessageCountThreshold"]] = None,
    ) -> None:
        '''
        :param add_dead_letter_queue_max_incoming_messages_alarm: 
        :param add_dead_letter_queue_max_message_age_alarm: 
        :param add_dead_letter_queue_max_size_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if add_dead_letter_queue_max_incoming_messages_alarm is not None:
            self._values["add_dead_letter_queue_max_incoming_messages_alarm"] = add_dead_letter_queue_max_incoming_messages_alarm
        if add_dead_letter_queue_max_message_age_alarm is not None:
            self._values["add_dead_letter_queue_max_message_age_alarm"] = add_dead_letter_queue_max_message_age_alarm
        if add_dead_letter_queue_max_size_alarm is not None:
            self._values["add_dead_letter_queue_max_size_alarm"] = add_dead_letter_queue_max_size_alarm

    @builtins.property
    def add_dead_letter_queue_max_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxIncomingMessagesCountThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_max_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxIncomingMessagesCountThreshold"]], result)

    @builtins.property
    def add_dead_letter_queue_max_message_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxMessageAgeThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_max_message_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxMessageAgeThreshold"]], result)

    @builtins.property
    def add_dead_letter_queue_max_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxMessageCountThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_max_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxMessageCountThreshold"]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BaseDlqAlarms(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.BaseEc2ServiceAlarms",
    jsii_struct_bases=[],
    name_mapping={
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
    },
)
class BaseEc2ServiceAlarms:
    def __init__(
        self,
        *,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, "RunningTaskCountThreshold"]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "RunningTaskCountThreshold"]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "RunningTaskCountThreshold"]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BaseEc2ServiceAlarms(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.BaseFargateServiceAlarms",
    jsii_struct_bases=[],
    name_mapping={
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
    },
)
class BaseFargateServiceAlarms:
    def __init__(
        self,
        *,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, "RunningTaskCountThreshold"]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "RunningTaskCountThreshold"]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "RunningTaskCountThreshold"]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BaseFargateServiceAlarms(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BaseServiceMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.BaseServiceMetricFactory",
):
    '''(experimental) Metric factory for a base service (parent class for e.g. Fargate and EC2 services).

    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        service: monocdk.aws_ecs.BaseService,
    ) -> None:
        '''
        :param metric_factory: -
        :param service: 

        :stability: experimental
        '''
        props = BaseServiceMetricFactoryProps(service=service)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricClusterCpuUtilisationInPercent")
    def metric_cluster_cpu_utilisation_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricClusterCpuUtilisationInPercent", []))

    @jsii.member(jsii_name="metricClusterMemoryUtilisationInPercent")
    def metric_cluster_memory_utilisation_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricClusterMemoryUtilisationInPercent", []))

    @jsii.member(jsii_name="metricRunningTaskCount")
    def metric_running_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricRunningTaskCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="service")
    def _service(self) -> monocdk.aws_ecs.BaseService:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_ecs.BaseService, jsii.get(self, "service"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.BaseServiceMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"service": "service"},
)
class BaseServiceMetricFactoryProps:
    def __init__(self, *, service: monocdk.aws_ecs.BaseService) -> None:
        '''(experimental) Props to create BaseServiceMetricFactory.

        :param service: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "service": service,
        }

    @builtins.property
    def service(self) -> monocdk.aws_ecs.BaseService:
        '''
        :stability: experimental
        '''
        result = self._values.get("service")
        assert result is not None, "Required property 'service' is missing"
        return typing.cast(monocdk.aws_ecs.BaseService, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BaseServiceMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.BaseSqsQueueAlarms",
    jsii_struct_bases=[],
    name_mapping={
        "add_queue_max_incoming_messages_alarm": "addQueueMaxIncomingMessagesAlarm",
        "add_queue_max_message_age_alarm": "addQueueMaxMessageAgeAlarm",
        "add_queue_max_size_alarm": "addQueueMaxSizeAlarm",
        "add_queue_max_time_to_drain_messages_alarm": "addQueueMaxTimeToDrainMessagesAlarm",
        "add_queue_min_incoming_messages_alarm": "addQueueMinIncomingMessagesAlarm",
        "add_queue_min_size_alarm": "addQueueMinSizeAlarm",
    },
)
class BaseSqsQueueAlarms:
    def __init__(
        self,
        *,
        add_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxIncomingMessagesCountThreshold"]] = None,
        add_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxMessageAgeThreshold"]] = None,
        add_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxMessageCountThreshold"]] = None,
        add_queue_max_time_to_drain_messages_alarm: typing.Optional[typing.Mapping[builtins.str, "MaxTimeToDrainThreshold"]] = None,
        add_queue_min_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, "MinIncomingMessagesCountThreshold"]] = None,
        add_queue_min_size_alarm: typing.Optional[typing.Mapping[builtins.str, "MinMessageCountThreshold"]] = None,
    ) -> None:
        '''
        :param add_queue_max_incoming_messages_alarm: 
        :param add_queue_max_message_age_alarm: 
        :param add_queue_max_size_alarm: 
        :param add_queue_max_time_to_drain_messages_alarm: 
        :param add_queue_min_incoming_messages_alarm: 
        :param add_queue_min_size_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if add_queue_max_incoming_messages_alarm is not None:
            self._values["add_queue_max_incoming_messages_alarm"] = add_queue_max_incoming_messages_alarm
        if add_queue_max_message_age_alarm is not None:
            self._values["add_queue_max_message_age_alarm"] = add_queue_max_message_age_alarm
        if add_queue_max_size_alarm is not None:
            self._values["add_queue_max_size_alarm"] = add_queue_max_size_alarm
        if add_queue_max_time_to_drain_messages_alarm is not None:
            self._values["add_queue_max_time_to_drain_messages_alarm"] = add_queue_max_time_to_drain_messages_alarm
        if add_queue_min_incoming_messages_alarm is not None:
            self._values["add_queue_min_incoming_messages_alarm"] = add_queue_min_incoming_messages_alarm
        if add_queue_min_size_alarm is not None:
            self._values["add_queue_min_size_alarm"] = add_queue_min_size_alarm

    @builtins.property
    def add_queue_max_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxIncomingMessagesCountThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxIncomingMessagesCountThreshold"]], result)

    @builtins.property
    def add_queue_max_message_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxMessageAgeThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_message_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxMessageAgeThreshold"]], result)

    @builtins.property
    def add_queue_max_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxMessageCountThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxMessageCountThreshold"]], result)

    @builtins.property
    def add_queue_max_time_to_drain_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MaxTimeToDrainThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_time_to_drain_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MaxTimeToDrainThreshold"]], result)

    @builtins.property
    def add_queue_min_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MinIncomingMessagesCountThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_min_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MinIncomingMessagesCountThreshold"]], result)

    @builtins.property
    def add_queue_min_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "MinMessageCountThreshold"]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_min_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "MinMessageCountThreshold"]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BaseSqsQueueAlarms(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BillingMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.BillingMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="metricSearchTopCostByServiceInUsd")
    def metric_search_top_cost_by_service_in_usd(
        self,
    ) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricSearchTopCostByServiceInUsd", []))

    @jsii.member(jsii_name="metricTotalCostInUsd")
    def metric_total_cost_in_usd(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricTotalCostInUsd", []))


class BitmapDashboard(
    monocdk.aws_cloudwatch.Dashboard,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.BitmapDashboard",
):
    '''(experimental) Specific subtype of dashboard that renders supported widgets as bitmaps, while preserving the overall layout.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: monocdk.Construct,
        id: builtins.str,
        *,
        dashboard_name: typing.Optional[builtins.str] = None,
        end: typing.Optional[builtins.str] = None,
        period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        start: typing.Optional[builtins.str] = None,
        widgets: typing.Optional[typing.Sequence[typing.Sequence[monocdk.aws_cloudwatch.IWidget]]] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param dashboard_name: (experimental) Name of the dashboard. If set, must only contain alphanumerics, dash (-) and underscore (_) Default: - automatically generated name
        :param end: (experimental) The end of the time range to use for each widget on the dashboard when the dashboard loads. If you specify a value for end, you must also specify a value for start. Specify an absolute time in the ISO 8601 format. For example, 2018-12-17T06:00:00.000Z. Default: When the dashboard loads, the end date will be the current time.
        :param period_override: (experimental) Use this field to specify the period for the graphs when the dashboard loads. Specifying ``Auto`` causes the period of all graphs on the dashboard to automatically adapt to the time range of the dashboard. Specifying ``Inherit`` ensures that the period set for each graph is always obeyed. Default: Auto
        :param start: (experimental) The start of the time range to use for each widget on the dashboard. You can specify start without specifying end to specify a relative time range that ends with the current time. In this case, the value of start must begin with -P, and you can use M, H, D, W and M as abbreviations for minutes, hours, days, weeks and months. For example, -PT8H shows the last 8 hours and -P3M shows the last three months. You can also use start along with an end field, to specify an absolute time range. When specifying an absolute time range, use the ISO 8601 format. For example, 2018-12-17T06:00:00.000Z. Default: When the dashboard loads, the start time will be the default time range.
        :param widgets: (experimental) Initial set of widgets on the dashboard. One array represents a row of widgets. Default: - No widgets

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.DashboardProps(
            dashboard_name=dashboard_name,
            end=end,
            period_override=period_override,
            start=start,
            widgets=widgets,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="addWidgets")
    def add_widgets(self, *widgets: monocdk.aws_cloudwatch.IWidget) -> None:
        '''(experimental) (experimental) Add a widget to the dashboard.

        Widgets given in multiple calls to add() will be laid out stacked on
        top of each other.

        Multiple widgets added in the same call to add() will be laid out next
        to each other.

        :param widgets: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "addWidgets", [*widgets]))

    @jsii.member(jsii_name="asBitmap")
    def _as_bitmap(
        self,
        widget: monocdk.aws_cloudwatch.IWidget,
    ) -> monocdk.aws_cloudwatch.IWidget:
        '''
        :param widget: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IWidget, jsii.invoke(self, "asBitmap", [widget]))

    @jsii.member(jsii_name="asBitmaps")
    def _as_bitmaps(
        self,
        *widgets: monocdk.aws_cloudwatch.IWidget,
    ) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''
        :param widgets: -

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "asBitmaps", [*widgets]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bitmapRenderingSupport")
    def _bitmap_rendering_support(self) -> "BitmapWidgetRenderingSupport":
        '''
        :stability: experimental
        '''
        return typing.cast("BitmapWidgetRenderingSupport", jsii.get(self, "bitmapRenderingSupport"))


class BitmapWidgetRenderingSupport(
    monocdk.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.BitmapWidgetRenderingSupport",
):
    '''(experimental) Support for rendering bitmap widgets on the server side.

    It is a custom widget lambda with some additional roles and helper methods.

    :stability: experimental
    '''

    def __init__(self, scope: monocdk.Construct, id: builtins.str) -> None:
        '''
        :param scope: -
        :param id: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [scope, id])

    @jsii.member(jsii_name="asBitmap")
    def as_bitmap(self, widget: monocdk.aws_cloudwatch.IWidget) -> "CustomWidget":
        '''
        :param widget: -

        :stability: experimental
        '''
        return typing.cast("CustomWidget", jsii.invoke(self, "asBitmap", [widget]))

    @jsii.member(jsii_name="getWidgetProperties")
    def _get_widget_properties(
        self,
        widget: monocdk.aws_cloudwatch.IWidget,
    ) -> typing.Any:
        '''
        :param widget: -

        :stability: experimental
        '''
        return typing.cast(typing.Any, jsii.invoke(self, "getWidgetProperties", [widget]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="handler")
    def handler(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_lambda.IFunction, jsii.get(self, "handler"))


@jsii.enum(jsii_type="cdk-monitoring-constructs.CapacityType")
class CapacityType(enum.Enum):
    '''
    :stability: experimental
    '''

    READ = "READ"
    '''
    :stability: experimental
    '''
    WRITE = "WRITE"
    '''
    :stability: experimental
    '''


class CertificateManagerMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CertificateManagerMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        certificate: monocdk.aws_certificatemanager.ICertificate,
    ) -> None:
        '''
        :param metric_factory: -
        :param certificate: 

        :stability: experimental
        '''
        props = CertificateManagerMetricFactoryProps(certificate=certificate)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricDaysToExpiry")
    def metric_days_to_expiry(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDaysToExpiry", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CertificateManagerMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"certificate": "certificate"},
)
class CertificateManagerMetricFactoryProps:
    def __init__(
        self,
        *,
        certificate: monocdk.aws_certificatemanager.ICertificate,
    ) -> None:
        '''
        :param certificate: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "certificate": certificate,
        }

    @builtins.property
    def certificate(self) -> monocdk.aws_certificatemanager.ICertificate:
        '''
        :stability: experimental
        '''
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return typing.cast(monocdk.aws_certificatemanager.ICertificate, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CertificateManagerMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudFrontDistributionMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CloudFrontDistributionMetricFactory",
):
    '''(experimental) To get the CloudFront metrics from the CloudWatch API, you must use the US East (N.

    Virginia) Region (us-east-1).
    https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/programming-cloudwatch-metrics.html

    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        distribution: monocdk.aws_cloudfront.IDistribution,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param distribution: 
        :param fill_tps_with_zeroes: Default: true

        :stability: experimental
        '''
        props = CloudFrontDistributionMetricFactoryProps(
            distribution=distribution, fill_tps_with_zeroes=fill_tps_with_zeroes
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metric4xxErrorRateAverage")
    def metric4xx_error_rate_average(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric4xxErrorRateAverage", []))

    @jsii.member(jsii_name="metric5xxErrorRateAverage")
    def metric5xx_error_rate_average(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metric5xxErrorRateAverage", []))

    @jsii.member(jsii_name="metricCacheHitRateAverageInPercent")
    def metric_cache_hit_rate_average_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricCacheHitRateAverageInPercent", []))

    @jsii.member(jsii_name="metricRequestCount")
    def metric_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricRequestCount", []))

    @jsii.member(jsii_name="metricRequestTps")
    def metric_request_tps(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricRequestTps", []))

    @jsii.member(jsii_name="metricTotalBytesDownloaded")
    def metric_total_bytes_downloaded(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalBytesDownloaded", []))

    @jsii.member(jsii_name="metricTotalBytesUploaded")
    def metric_total_bytes_uploaded(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalBytesUploaded", []))

    @jsii.member(jsii_name="metricTotalErrorRateAverage")
    def metric_total_error_rate_average(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalErrorRateAverage", []))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CloudFrontDistributionMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "distribution": "distribution",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
    },
)
class CloudFrontDistributionMetricFactoryProps:
    def __init__(
        self,
        *,
        distribution: monocdk.aws_cloudfront.IDistribution,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param distribution: 
        :param fill_tps_with_zeroes: Default: true

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "distribution": distribution,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes

    @builtins.property
    def distribution(self) -> monocdk.aws_cloudfront.IDistribution:
        '''
        :stability: experimental
        '''
        result = self._values.get("distribution")
        assert result is not None, "Required property 'distribution' is missing"
        return typing.cast(monocdk.aws_cloudfront.IDistribution, result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudFrontDistributionMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodeBuildProjectMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CodeBuildProjectMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        project: monocdk.aws_codebuild.IProject,
    ) -> None:
        '''
        :param metric_factory: -
        :param project: 

        :stability: experimental
        '''
        props = CodeBuildProjectMetricFactoryProps(project=project)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricBuildCount")
    def metric_build_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricBuildCount", []))

    @jsii.member(jsii_name="metricDurationP50InSeconds")
    def metric_duration_p50_in_seconds(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDurationP50InSeconds", []))

    @jsii.member(jsii_name="metricDurationP90InSeconds")
    def metric_duration_p90_in_seconds(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDurationP90InSeconds", []))

    @jsii.member(jsii_name="metricDurationP99InSeconds")
    def metric_duration_p99_in_seconds(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDurationP99InSeconds", []))

    @jsii.member(jsii_name="metricFailedBuildCount")
    def metric_failed_build_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFailedBuildCount", []))

    @jsii.member(jsii_name="metricFailedBuildRate")
    def metric_failed_build_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFailedBuildRate", []))

    @jsii.member(jsii_name="metricSucceededBuildCount")
    def metric_succeeded_build_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSucceededBuildCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="project")
    def _project(self) -> monocdk.aws_codebuild.IProject:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_codebuild.IProject, jsii.get(self, "project"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CodeBuildProjectMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"project": "project"},
)
class CodeBuildProjectMetricFactoryProps:
    def __init__(self, *, project: monocdk.aws_codebuild.IProject) -> None:
        '''
        :param project: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "project": project,
        }

    @builtins.property
    def project(self) -> monocdk.aws_codebuild.IProject:
        '''
        :stability: experimental
        '''
        result = self._values.get("project")
        assert result is not None, "Required property 'project' is missing"
        return typing.cast(monocdk.aws_codebuild.IProject, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodeBuildProjectMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.CompositeAlarmOperator")
class CompositeAlarmOperator(enum.Enum):
    '''
    :stability: experimental
    '''

    AND = "AND"
    '''(experimental) trigger only if all the alarms are triggered.

    :stability: experimental
    '''
    OR = "OR"
    '''(experimental) trigger if any of the alarms is triggered.

    :stability: experimental
    '''


class CustomAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CustomAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addCustomAlarm")
    def add_custom_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        alarm_name_suffix: builtins.str,
        disambiguator: builtins.str,
        *,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        threshold: jsii.Number,
        additional_description: typing.Optional[builtins.str] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param alarm_name_suffix: -
        :param disambiguator: -
        :param comparison_operator: 
        :param threshold: 
        :param additional_description: 
        :param dedupe_string: 
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default

        :stability: experimental
        '''
        props = CustomThreshold(
            comparison_operator=comparison_operator,
            threshold=threshold,
            additional_description=additional_description,
            dedupe_string=dedupe_string,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            comparison_operator_override=comparison_operator_override,
            custom_params=custom_params,
            custom_tags=custom_tags,
            datapoints_to_alarm=datapoints_to_alarm,
            dedupe_string_override=dedupe_string_override,
            documentation_link=documentation_link,
            evaluate_low_sample_count_percentile=evaluate_low_sample_count_percentile,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            period=period,
            runbook_link=runbook_link,
            treat_missing_data_override=treat_missing_data_override,
        )

        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addCustomAlarm", [metric, alarm_name_suffix, disambiguator, props]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomAlarmThreshold",
    jsii_struct_bases=[],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
    },
)
class CustomAlarmThreshold:
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
    ) -> None:
        '''(experimental) Common customization that can be attached to each alarm.

        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomAlarmThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomMetricGroup",
    jsii_struct_bases=[],
    name_mapping={
        "metrics": "metrics",
        "title": "title",
        "graph_widget_axis": "graphWidgetAxis",
        "graph_widget_right_axis": "graphWidgetRightAxis",
        "graph_widget_type": "graphWidgetType",
        "horizontal_annotations": "horizontalAnnotations",
        "horizontal_right_annotations": "horizontalRightAnnotations",
        "important": "important",
    },
)
class CustomMetricGroup:
    def __init__(
        self,
        *,
        metrics: typing.Sequence[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression, "CustomMetricWithAlarm", "CustomMetricWithAnomalyDetection", "CustomMetricSearch"]],
        title: builtins.str,
        graph_widget_axis: typing.Optional[monocdk.aws_cloudwatch.YAxisProps] = None,
        graph_widget_right_axis: typing.Optional[monocdk.aws_cloudwatch.YAxisProps] = None,
        graph_widget_type: typing.Optional["GraphWidgetType"] = None,
        horizontal_annotations: typing.Optional[typing.Sequence[monocdk.aws_cloudwatch.HorizontalAnnotation]] = None,
        horizontal_right_annotations: typing.Optional[typing.Sequence[monocdk.aws_cloudwatch.HorizontalAnnotation]] = None,
        important: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''(experimental) Custom metric group represents a single widget.

        :param metrics: (experimental) list of metrics in the group (can be defined in different ways, see the type documentation).
        :param title: (experimental) title of the whole group.
        :param graph_widget_axis: (experimental) optional axis. Default: undefined
        :param graph_widget_right_axis: (experimental) optional right axis default: undefined.
        :param graph_widget_type: (experimental) type of the widget. Default: line
        :param horizontal_annotations: (experimental) optional custom horizontal annotations which will be displayed over the metrics on the left axis (if there are any alarms, any existing annotations will be merged together).
        :param horizontal_right_annotations: (experimental) optional custom horizontal annotations which will be displayed over the metrics on the right axis (if there are any alarms, any existing annotations will be merged together).
        :param important: (experimental) Flag indicating, whether this is an important metric group that should be included in the summary as well. Default: false

        :stability: experimental
        '''
        if isinstance(graph_widget_axis, dict):
            graph_widget_axis = monocdk.aws_cloudwatch.YAxisProps(**graph_widget_axis)
        if isinstance(graph_widget_right_axis, dict):
            graph_widget_right_axis = monocdk.aws_cloudwatch.YAxisProps(**graph_widget_right_axis)
        self._values: typing.Dict[str, typing.Any] = {
            "metrics": metrics,
            "title": title,
        }
        if graph_widget_axis is not None:
            self._values["graph_widget_axis"] = graph_widget_axis
        if graph_widget_right_axis is not None:
            self._values["graph_widget_right_axis"] = graph_widget_right_axis
        if graph_widget_type is not None:
            self._values["graph_widget_type"] = graph_widget_type
        if horizontal_annotations is not None:
            self._values["horizontal_annotations"] = horizontal_annotations
        if horizontal_right_annotations is not None:
            self._values["horizontal_right_annotations"] = horizontal_right_annotations
        if important is not None:
            self._values["important"] = important

    @builtins.property
    def metrics(
        self,
    ) -> typing.List[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression, "CustomMetricWithAlarm", "CustomMetricWithAnomalyDetection", "CustomMetricSearch"]]:
        '''(experimental) list of metrics in the group (can be defined in different ways, see the type documentation).

        :stability: experimental
        '''
        result = self._values.get("metrics")
        assert result is not None, "Required property 'metrics' is missing"
        return typing.cast(typing.List[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression, "CustomMetricWithAlarm", "CustomMetricWithAnomalyDetection", "CustomMetricSearch"]], result)

    @builtins.property
    def title(self) -> builtins.str:
        '''(experimental) title of the whole group.

        :stability: experimental
        '''
        result = self._values.get("title")
        assert result is not None, "Required property 'title' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def graph_widget_axis(self) -> typing.Optional[monocdk.aws_cloudwatch.YAxisProps]:
        '''(experimental) optional axis.

        :default: undefined

        :stability: experimental
        '''
        result = self._values.get("graph_widget_axis")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.YAxisProps], result)

    @builtins.property
    def graph_widget_right_axis(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.YAxisProps]:
        '''(experimental) optional right axis default: undefined.

        :stability: experimental
        '''
        result = self._values.get("graph_widget_right_axis")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.YAxisProps], result)

    @builtins.property
    def graph_widget_type(self) -> typing.Optional["GraphWidgetType"]:
        '''(experimental) type of the widget.

        :default: line

        :stability: experimental
        '''
        result = self._values.get("graph_widget_type")
        return typing.cast(typing.Optional["GraphWidgetType"], result)

    @builtins.property
    def horizontal_annotations(
        self,
    ) -> typing.Optional[typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]]:
        '''(experimental) optional custom horizontal annotations which will be displayed over the metrics on the left axis (if there are any alarms, any existing annotations will be merged together).

        :stability: experimental
        '''
        result = self._values.get("horizontal_annotations")
        return typing.cast(typing.Optional[typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]], result)

    @builtins.property
    def horizontal_right_annotations(
        self,
    ) -> typing.Optional[typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]]:
        '''(experimental) optional custom horizontal annotations which will be displayed over the metrics on the right axis (if there are any alarms, any existing annotations will be merged together).

        :stability: experimental
        '''
        result = self._values.get("horizontal_right_annotations")
        return typing.cast(typing.Optional[typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]], result)

    @builtins.property
    def important(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating, whether this is an important metric group that should be included in the summary as well.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("important")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomMetricGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomMetricGroupWithAnnotations",
    jsii_struct_bases=[],
    name_mapping={
        "annotations": "annotations",
        "metric_group": "metricGroup",
        "right_annotations": "rightAnnotations",
        "title_addons": "titleAddons",
    },
)
class CustomMetricGroupWithAnnotations:
    def __init__(
        self,
        *,
        annotations: typing.Sequence[monocdk.aws_cloudwatch.HorizontalAnnotation],
        metric_group: CustomMetricGroup,
        right_annotations: typing.Sequence[monocdk.aws_cloudwatch.HorizontalAnnotation],
        title_addons: typing.Sequence[builtins.str],
    ) -> None:
        '''
        :param annotations: 
        :param metric_group: 
        :param right_annotations: 
        :param title_addons: 

        :stability: experimental
        '''
        if isinstance(metric_group, dict):
            metric_group = CustomMetricGroup(**metric_group)
        self._values: typing.Dict[str, typing.Any] = {
            "annotations": annotations,
            "metric_group": metric_group,
            "right_annotations": right_annotations,
            "title_addons": title_addons,
        }

    @builtins.property
    def annotations(self) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        result = self._values.get("annotations")
        assert result is not None, "Required property 'annotations' is missing"
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], result)

    @builtins.property
    def metric_group(self) -> CustomMetricGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("metric_group")
        assert result is not None, "Required property 'metric_group' is missing"
        return typing.cast(CustomMetricGroup, result)

    @builtins.property
    def right_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        result = self._values.get("right_annotations")
        assert result is not None, "Required property 'right_annotations' is missing"
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], result)

    @builtins.property
    def title_addons(self) -> typing.List[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("title_addons")
        assert result is not None, "Required property 'title_addons' is missing"
        return typing.cast(typing.List[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomMetricGroupWithAnnotations(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomMetricSearch",
    jsii_struct_bases=[],
    name_mapping={
        "dimensions": "dimensions",
        "search_query": "searchQuery",
        "statistic": "statistic",
        "label": "label",
        "namespace": "namespace",
        "period": "period",
        "position": "position",
    },
)
class CustomMetricSearch:
    def __init__(
        self,
        *,
        dimensions: typing.Mapping[builtins.str, typing.Any],
        search_query: builtins.str,
        statistic: "MetricStatistic",
        label: typing.Optional[builtins.str] = None,
        namespace: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        position: typing.Optional[AxisPosition] = None,
    ) -> None:
        '''(experimental) Custom metric search.

        :param dimensions: (experimental) search dimensions (can be empty).
        :param search_query: (experimental) search query (can be empty).
        :param statistic: (experimental) metric statistic.
        :param label: (experimental) custom label for the metrics. Default: " "
        :param namespace: (experimental) metric namespace. Default: none
        :param period: (experimental) metric period. Default: global default
        :param position: (experimental) axis (right or left) on which to graph metric default: AxisPosition.LEFT.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "dimensions": dimensions,
            "search_query": search_query,
            "statistic": statistic,
        }
        if label is not None:
            self._values["label"] = label
        if namespace is not None:
            self._values["namespace"] = namespace
        if period is not None:
            self._values["period"] = period
        if position is not None:
            self._values["position"] = position

    @builtins.property
    def dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''(experimental) search dimensions (can be empty).

        :stability: experimental
        '''
        result = self._values.get("dimensions")
        assert result is not None, "Required property 'dimensions' is missing"
        return typing.cast(typing.Mapping[builtins.str, typing.Any], result)

    @builtins.property
    def search_query(self) -> builtins.str:
        '''(experimental) search query (can be empty).

        :stability: experimental
        '''
        result = self._values.get("search_query")
        assert result is not None, "Required property 'search_query' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def statistic(self) -> "MetricStatistic":
        '''(experimental) metric statistic.

        :stability: experimental
        '''
        result = self._values.get("statistic")
        assert result is not None, "Required property 'statistic' is missing"
        return typing.cast("MetricStatistic", result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''(experimental) custom label for the metrics.

        :default: " "

        :stability: experimental
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def namespace(self) -> typing.Optional[builtins.str]:
        '''(experimental) metric namespace.

        :default: none

        :stability: experimental
        '''
        result = self._values.get("namespace")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) metric period.

        :default: global default

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def position(self) -> typing.Optional[AxisPosition]:
        '''(experimental) axis (right or left) on which to graph metric default: AxisPosition.LEFT.

        :stability: experimental
        '''
        result = self._values.get("position")
        return typing.cast(typing.Optional[AxisPosition], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomMetricSearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomMetricWithAlarm",
    jsii_struct_bases=[],
    name_mapping={
        "add_alarm": "addAlarm",
        "alarm_friendly_name": "alarmFriendlyName",
        "metric": "metric",
        "position": "position",
    },
)
class CustomMetricWithAlarm:
    def __init__(
        self,
        *,
        add_alarm: typing.Mapping[builtins.str, "CustomThreshold"],
        alarm_friendly_name: builtins.str,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        position: typing.Optional[AxisPosition] = None,
    ) -> None:
        '''(experimental) Custom metric with an alarm defined.

        :param add_alarm: (experimental) alarm definitions.
        :param alarm_friendly_name: (experimental) alarm friendly name.
        :param metric: (experimental) metric to alarm on.
        :param position: (experimental) axis (right or left) on which to graph metric default: AxisPosition.LEFT.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "add_alarm": add_alarm,
            "alarm_friendly_name": alarm_friendly_name,
            "metric": metric,
        }
        if position is not None:
            self._values["position"] = position

    @builtins.property
    def add_alarm(self) -> typing.Mapping[builtins.str, "CustomThreshold"]:
        '''(experimental) alarm definitions.

        :stability: experimental
        '''
        result = self._values.get("add_alarm")
        assert result is not None, "Required property 'add_alarm' is missing"
        return typing.cast(typing.Mapping[builtins.str, "CustomThreshold"], result)

    @builtins.property
    def alarm_friendly_name(self) -> builtins.str:
        '''(experimental) alarm friendly name.

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        assert result is not None, "Required property 'alarm_friendly_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) metric to alarm on.

        :stability: experimental
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], result)

    @builtins.property
    def position(self) -> typing.Optional[AxisPosition]:
        '''(experimental) axis (right or left) on which to graph metric default: AxisPosition.LEFT.

        :stability: experimental
        '''
        result = self._values.get("position")
        return typing.cast(typing.Optional[AxisPosition], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomMetricWithAlarm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomMetricWithAnomalyDetection",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "anomaly_detection_standard_deviation_to_render": "anomalyDetectionStandardDeviationToRender",
        "metric": "metric",
        "add_alarm_on_anomaly": "addAlarmOnAnomaly",
        "period": "period",
    },
)
class CustomMetricWithAnomalyDetection:
    def __init__(
        self,
        *,
        alarm_friendly_name: builtins.str,
        anomaly_detection_standard_deviation_to_render: jsii.Number,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        add_alarm_on_anomaly: typing.Optional[typing.Mapping[builtins.str, "AnomalyDetectionThreshold"]] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> None:
        '''(experimental) Custom metric with anomaly detection.

        :param alarm_friendly_name: (experimental) alarm friendly name.
        :param anomaly_detection_standard_deviation_to_render: (experimental) standard deviation for the anomaly detection to be rendered on the graph widget.
        :param metric: (experimental) metric to alarm on.
        :param add_alarm_on_anomaly: (experimental) adds alarm on a detected anomaly.
        :param period: (experimental) anomaly detection period. Default: metric period (if defined) or global default

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarm_friendly_name": alarm_friendly_name,
            "anomaly_detection_standard_deviation_to_render": anomaly_detection_standard_deviation_to_render,
            "metric": metric,
        }
        if add_alarm_on_anomaly is not None:
            self._values["add_alarm_on_anomaly"] = add_alarm_on_anomaly
        if period is not None:
            self._values["period"] = period

    @builtins.property
    def alarm_friendly_name(self) -> builtins.str:
        '''(experimental) alarm friendly name.

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        assert result is not None, "Required property 'alarm_friendly_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def anomaly_detection_standard_deviation_to_render(self) -> jsii.Number:
        '''(experimental) standard deviation for the anomaly detection to be rendered on the graph widget.

        :stability: experimental
        '''
        result = self._values.get("anomaly_detection_standard_deviation_to_render")
        assert result is not None, "Required property 'anomaly_detection_standard_deviation_to_render' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) metric to alarm on.

        :stability: experimental
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], result)

    @builtins.property
    def add_alarm_on_anomaly(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, "AnomalyDetectionThreshold"]]:
        '''(experimental) adds alarm on a detected anomaly.

        :stability: experimental
        '''
        result = self._values.get("add_alarm_on_anomaly")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, "AnomalyDetectionThreshold"]], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) anomaly detection period.

        :default: metric period (if defined) or global default

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomMetricWithAnomalyDetection(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "comparison_operator": "comparisonOperator",
        "threshold": "threshold",
        "additional_description": "additionalDescription",
        "dedupe_string": "dedupeString",
    },
)
class CustomThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        threshold: jsii.Number,
        additional_description: typing.Optional[builtins.str] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param comparison_operator: 
        :param threshold: 
        :param additional_description: 
        :param dedupe_string: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "comparison_operator": comparison_operator,
            "threshold": threshold,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override
        if additional_description is not None:
            self._values["additional_description"] = additional_description
        if dedupe_string is not None:
            self._values["dedupe_string"] = dedupe_string

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def comparison_operator(self) -> monocdk.aws_cloudwatch.ComparisonOperator:
        '''
        :stability: experimental
        '''
        result = self._values.get("comparison_operator")
        assert result is not None, "Required property 'comparison_operator' is missing"
        return typing.cast(monocdk.aws_cloudwatch.ComparisonOperator, result)

    @builtins.property
    def threshold(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("threshold")
        assert result is not None, "Required property 'threshold' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def additional_description(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("additional_description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dedupe_string(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dedupe_string")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CustomWidget(
    monocdk.aws_cloudwatch.ConcreteWidget,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CustomWidget",
):
    '''(experimental) A dashboard widget that can be customized using a Lambda.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        handler: monocdk.aws_lambda.IFunction,
        handler_params: typing.Any = None,
        height: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
        update_on_refresh: typing.Optional[builtins.bool] = None,
        update_on_resize: typing.Optional[builtins.bool] = None,
        update_on_time_range_change: typing.Optional[builtins.bool] = None,
        width: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param handler: (experimental) Lambda providing the widget contents. The Lambda function should return HTML with widget code. The simplest Lambda example:: exports.handler = function (event, context, callback) { return callback(null, "<h1>Hello! This is a custom widget.</h1><pre>" + JSON.stringify(event, null, 2) + "</pre>"); };
        :param handler_params: (experimental) Arguments to pass to the Lambda. These arguments will be available in the Lambda context.
        :param height: (experimental) Height of the widget. Default: 6
        :param title: (experimental) Title for the graph.
        :param update_on_refresh: (experimental) Whether the widget should be updated (by calling the Lambda again) on refresh. Default: true
        :param update_on_resize: (experimental) Whether the widget should be updated (by calling the Lambda again) on resize. Default: true
        :param update_on_time_range_change: (experimental) Whether the widget should be updated (by calling the Lambda again) on time range change. Default: true
        :param width: (experimental) Width of the widget, in a grid of 24 units wide. Default: 6

        :stability: experimental
        '''
        props = CustomWidgetProps(
            handler=handler,
            handler_params=handler_params,
            height=height,
            title=title,
            update_on_refresh=update_on_refresh,
            update_on_resize=update_on_resize,
            update_on_time_range_change=update_on_time_range_change,
            width=width,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toJson")
    def to_json(self) -> typing.List[typing.Any]:
        '''(experimental) (experimental) Return the widget JSON for use in the dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[typing.Any], jsii.invoke(self, "toJson", []))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomWidgetProps",
    jsii_struct_bases=[],
    name_mapping={
        "handler": "handler",
        "handler_params": "handlerParams",
        "height": "height",
        "title": "title",
        "update_on_refresh": "updateOnRefresh",
        "update_on_resize": "updateOnResize",
        "update_on_time_range_change": "updateOnTimeRangeChange",
        "width": "width",
    },
)
class CustomWidgetProps:
    def __init__(
        self,
        *,
        handler: monocdk.aws_lambda.IFunction,
        handler_params: typing.Any = None,
        height: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
        update_on_refresh: typing.Optional[builtins.bool] = None,
        update_on_resize: typing.Optional[builtins.bool] = None,
        update_on_time_range_change: typing.Optional[builtins.bool] = None,
        width: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''(experimental) Properties of a custom widget.

        :param handler: (experimental) Lambda providing the widget contents. The Lambda function should return HTML with widget code. The simplest Lambda example:: exports.handler = function (event, context, callback) { return callback(null, "<h1>Hello! This is a custom widget.</h1><pre>" + JSON.stringify(event, null, 2) + "</pre>"); };
        :param handler_params: (experimental) Arguments to pass to the Lambda. These arguments will be available in the Lambda context.
        :param height: (experimental) Height of the widget. Default: 6
        :param title: (experimental) Title for the graph.
        :param update_on_refresh: (experimental) Whether the widget should be updated (by calling the Lambda again) on refresh. Default: true
        :param update_on_resize: (experimental) Whether the widget should be updated (by calling the Lambda again) on resize. Default: true
        :param update_on_time_range_change: (experimental) Whether the widget should be updated (by calling the Lambda again) on time range change. Default: true
        :param width: (experimental) Width of the widget, in a grid of 24 units wide. Default: 6

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "handler": handler,
        }
        if handler_params is not None:
            self._values["handler_params"] = handler_params
        if height is not None:
            self._values["height"] = height
        if title is not None:
            self._values["title"] = title
        if update_on_refresh is not None:
            self._values["update_on_refresh"] = update_on_refresh
        if update_on_resize is not None:
            self._values["update_on_resize"] = update_on_resize
        if update_on_time_range_change is not None:
            self._values["update_on_time_range_change"] = update_on_time_range_change
        if width is not None:
            self._values["width"] = width

    @builtins.property
    def handler(self) -> monocdk.aws_lambda.IFunction:
        '''(experimental) Lambda providing the widget contents.

        The Lambda function should return HTML with widget code.
        The simplest Lambda example::

           exports.handler = function (event, context, callback) {
              return callback(null, "<h1>Hello! This is a custom widget.</h1><pre>" + JSON.stringify(event, null, 2) + "</pre>");
           };

        :stability: experimental
        '''
        result = self._values.get("handler")
        assert result is not None, "Required property 'handler' is missing"
        return typing.cast(monocdk.aws_lambda.IFunction, result)

    @builtins.property
    def handler_params(self) -> typing.Any:
        '''(experimental) Arguments to pass to the Lambda.

        These arguments will be available in the Lambda context.

        :stability: experimental
        '''
        result = self._values.get("handler_params")
        return typing.cast(typing.Any, result)

    @builtins.property
    def height(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Height of the widget.

        :default: 6

        :stability: experimental
        '''
        result = self._values.get("height")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''(experimental) Title for the graph.

        :stability: experimental
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def update_on_refresh(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Whether the widget should be updated (by calling the Lambda again) on refresh.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("update_on_refresh")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def update_on_resize(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Whether the widget should be updated (by calling the Lambda again) on resize.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("update_on_resize")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def update_on_time_range_change(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Whether the widget should be updated (by calling the Lambda again) on time range change.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("update_on_time_range_change")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def width(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Width of the widget, in a grid of 24 units wide.

        :default: 6

        :stability: experimental
        '''
        result = self._values.get("width")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomWidgetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.DashboardRenderingPreference")
class DashboardRenderingPreference(enum.Enum):
    '''(experimental) Preferred way of rendering the widgets.

    :stability: experimental
    '''

    INTERACTIVE_ONLY = "INTERACTIVE_ONLY"
    '''(experimental) create standard set of dashboards with interactive widgets only.

    :stability: experimental
    '''
    BITMAP_ONLY = "BITMAP_ONLY"
    '''(experimental) create standard set of dashboards with bitmap widgets only.

    :stability: experimental
    '''
    INTERACTIVE_AND_BITMAP = "INTERACTIVE_AND_BITMAP"
    '''(experimental) create a two sets of dashboards: standard set (interactive) and a copy (bitmap).

    :stability: experimental
    '''


class DashboardWithBitmapCopy(
    monocdk.aws_cloudwatch.Dashboard,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DashboardWithBitmapCopy",
):
    '''(experimental) Composite dashboard which keeps a normal dashboard with its bitmap copy.

    The bitmap copy name will be derived from the primary dashboard name, if specified.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: monocdk.Construct,
        id: builtins.str,
        *,
        dashboard_name: typing.Optional[builtins.str] = None,
        end: typing.Optional[builtins.str] = None,
        period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        start: typing.Optional[builtins.str] = None,
        widgets: typing.Optional[typing.Sequence[typing.Sequence[monocdk.aws_cloudwatch.IWidget]]] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param dashboard_name: (experimental) Name of the dashboard. If set, must only contain alphanumerics, dash (-) and underscore (_) Default: - automatically generated name
        :param end: (experimental) The end of the time range to use for each widget on the dashboard when the dashboard loads. If you specify a value for end, you must also specify a value for start. Specify an absolute time in the ISO 8601 format. For example, 2018-12-17T06:00:00.000Z. Default: When the dashboard loads, the end date will be the current time.
        :param period_override: (experimental) Use this field to specify the period for the graphs when the dashboard loads. Specifying ``Auto`` causes the period of all graphs on the dashboard to automatically adapt to the time range of the dashboard. Specifying ``Inherit`` ensures that the period set for each graph is always obeyed. Default: Auto
        :param start: (experimental) The start of the time range to use for each widget on the dashboard. You can specify start without specifying end to specify a relative time range that ends with the current time. In this case, the value of start must begin with -P, and you can use M, H, D, W and M as abbreviations for minutes, hours, days, weeks and months. For example, -PT8H shows the last 8 hours and -P3M shows the last three months. You can also use start along with an end field, to specify an absolute time range. When specifying an absolute time range, use the ISO 8601 format. For example, 2018-12-17T06:00:00.000Z. Default: When the dashboard loads, the start time will be the default time range.
        :param widgets: (experimental) Initial set of widgets on the dashboard. One array represents a row of widgets. Default: - No widgets

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.DashboardProps(
            dashboard_name=dashboard_name,
            end=end,
            period_override=period_override,
            start=start,
            widgets=widgets,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="addWidgets")
    def add_widgets(self, *widgets: monocdk.aws_cloudwatch.IWidget) -> None:
        '''(experimental) (experimental) Add a widget to the dashboard.

        Widgets given in multiple calls to add() will be laid out stacked on
        top of each other.

        Multiple widgets added in the same call to add() will be laid out next
        to each other.

        :param widgets: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "addWidgets", [*widgets]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bitmapCopy")
    def _bitmap_copy(self) -> BitmapDashboard:
        '''
        :stability: experimental
        '''
        return typing.cast(BitmapDashboard, jsii.get(self, "bitmapCopy"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DaysSinceUpdateThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_days_since_update": "maxDaysSinceUpdate",
    },
)
class DaysSinceUpdateThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_days_since_update: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_days_since_update: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_days_since_update": max_days_since_update,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_days_since_update(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_days_since_update")
        assert result is not None, "Required property 'max_days_since_update' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaysSinceUpdateThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DaysToExpiryThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_days_to_expiry": "minDaysToExpiry",
    },
)
class DaysToExpiryThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_days_to_expiry: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_days_to_expiry: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_days_to_expiry": min_days_to_expiry,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_days_to_expiry(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_days_to_expiry")
        assert result is not None, "Required property 'min_days_to_expiry' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaysToExpiryThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DurationThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_duration": "maxDuration",
    },
)
class DurationThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_duration: monocdk.Duration,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_duration: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_duration": max_duration,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_duration(self) -> monocdk.Duration:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_duration")
        assert result is not None, "Required property 'max_duration' is missing"
        return typing.cast(monocdk.Duration, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DurationThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DynamoAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DynamoAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addConsumedCapacityAlarm")
    def add_consumed_capacity_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        capacity_type: CapacityType,
        props: "ConsumedCapacityThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param capacity_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addConsumedCapacityAlarm", [metric, capacity_type, props, disambiguator]))

    @jsii.member(jsii_name="addThrottledEventsAlarm")
    def add_throttled_events_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        capacity_type: CapacityType,
        props: "ThrottledEventsThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param capacity_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addThrottledEventsAlarm", [metric, capacity_type, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class DynamoTableGlobalSecondaryIndexMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DynamoTableGlobalSecondaryIndexMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        global_secondary_index_name: builtins.str,
        table: monocdk.aws_dynamodb.ITable,
    ) -> None:
        '''
        :param metric_factory: -
        :param global_secondary_index_name: 
        :param table: 

        :stability: experimental
        '''
        props = DynamoTableGlobalSecondaryIndexMetricFactoryProps(
            global_secondary_index_name=global_secondary_index_name, table=table
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricConsumedReadCapacityUnits")
    def metric_consumed_read_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricConsumedReadCapacityUnits", []))

    @jsii.member(jsii_name="metricConsumedWriteCapacityUnits")
    def metric_consumed_write_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricConsumedWriteCapacityUnits", []))

    @jsii.member(jsii_name="metricIndexConsumedWriteUnitsMetric")
    def metric_index_consumed_write_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIndexConsumedWriteUnitsMetric", []))

    @jsii.member(jsii_name="metricProvisionedReadCapacityUnits")
    def metric_provisioned_read_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProvisionedReadCapacityUnits", []))

    @jsii.member(jsii_name="metricProvisionedWriteCapacityUnits")
    def metric_provisioned_write_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProvisionedWriteCapacityUnits", []))

    @jsii.member(jsii_name="metricThrottledIndexRequestCount")
    def metric_throttled_index_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottledIndexRequestCount", []))

    @jsii.member(jsii_name="metricThrottledReadRequestCount")
    def metric_throttled_read_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottledReadRequestCount", []))

    @jsii.member(jsii_name="metricThrottledWriteRequestCount")
    def metric_throttled_write_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottledWriteRequestCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DynamoTableGlobalSecondaryIndexMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "global_secondary_index_name": "globalSecondaryIndexName",
        "table": "table",
    },
)
class DynamoTableGlobalSecondaryIndexMetricFactoryProps:
    def __init__(
        self,
        *,
        global_secondary_index_name: builtins.str,
        table: monocdk.aws_dynamodb.ITable,
    ) -> None:
        '''
        :param global_secondary_index_name: 
        :param table: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "global_secondary_index_name": global_secondary_index_name,
            "table": table,
        }

    @builtins.property
    def global_secondary_index_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("global_secondary_index_name")
        assert result is not None, "Required property 'global_secondary_index_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def table(self) -> monocdk.aws_dynamodb.ITable:
        '''
        :stability: experimental
        '''
        result = self._values.get("table")
        assert result is not None, "Required property 'table' is missing"
        return typing.cast(monocdk.aws_dynamodb.ITable, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamoTableGlobalSecondaryIndexMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DynamoTableMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DynamoTableMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        table: monocdk.aws_dynamodb.ITable,
    ) -> None:
        '''
        :param metric_factory: -
        :param table: 

        :stability: experimental
        '''
        props = DynamoTableMetricFactoryProps(table=table)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricAverageSuccessfulRequestLatencyInMillis")
    def metric_average_successful_request_latency_in_millis(
        self,
        operation: monocdk.aws_dynamodb.Operation,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''
        :param operation: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricAverageSuccessfulRequestLatencyInMillis", [operation]))

    @jsii.member(jsii_name="metricConsumedReadCapacityUnits")
    def metric_consumed_read_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricConsumedReadCapacityUnits", []))

    @jsii.member(jsii_name="metricConsumedWriteCapacityUnits")
    def metric_consumed_write_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricConsumedWriteCapacityUnits", []))

    @jsii.member(jsii_name="metricProvisionedReadCapacityUnits")
    def metric_provisioned_read_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProvisionedReadCapacityUnits", []))

    @jsii.member(jsii_name="metricProvisionedWriteCapacityUnits")
    def metric_provisioned_write_capacity_units(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProvisionedWriteCapacityUnits", []))

    @jsii.member(jsii_name="metricReadCapacityUtilizationPercentage")
    def metric_read_capacity_utilization_percentage(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricReadCapacityUtilizationPercentage", []))

    @jsii.member(jsii_name="metricSearchAverageSuccessfulRequestLatencyInMillis")
    def metric_search_average_successful_request_latency_in_millis(
        self,
    ) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricSearchAverageSuccessfulRequestLatencyInMillis", []))

    @jsii.member(jsii_name="metricSystemErrorsCount")
    def metric_system_errors_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) This represents the number of requests that resulted in a 500 (server error) error code.

        It summarizes across all operations.
        It’s usually equal to zero.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSystemErrorsCount", []))

    @jsii.member(jsii_name="metricThrottledReadRequestCount")
    def metric_throttled_read_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottledReadRequestCount", []))

    @jsii.member(jsii_name="metricThrottledWriteRequestCount")
    def metric_throttled_write_request_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottledWriteRequestCount", []))

    @jsii.member(jsii_name="metricWriteCapacityUtilizationPercentage")
    def metric_write_capacity_utilization_percentage(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricWriteCapacityUtilizationPercentage", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="table")
    def _table(self) -> monocdk.aws_dynamodb.ITable:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_dynamodb.ITable, jsii.get(self, "table"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DynamoTableMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"table": "table"},
)
class DynamoTableMetricFactoryProps:
    def __init__(self, *, table: monocdk.aws_dynamodb.ITable) -> None:
        '''
        :param table: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "table": table,
        }

    @builtins.property
    def table(self) -> monocdk.aws_dynamodb.ITable:
        '''
        :stability: experimental
        '''
        result = self._values.get("table")
        assert result is not None, "Required property 'table' is missing"
        return typing.cast(monocdk.aws_dynamodb.ITable, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamoTableMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EC2MetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.EC2MetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        auto_scaling_group: typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param auto_scaling_group: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [metric_factory, auto_scaling_group])

    @jsii.member(jsii_name="metricAverageCpuUtilisationPercent")
    def metric_average_cpu_utilisation_percent(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) The percentage of allocated EC2 compute units that are currently in use on the instance.

        This metric identifies the processing power required to run an application on a selected instance.
        Depending on the instance type, tools in your operating system can show a lower percentage than
        CloudWatch when the instance is not allocated a full processor core.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageCpuUtilisationPercent", []))

    @jsii.member(jsii_name="metricAverageDiskReadBytes")
    def metric_average_disk_read_bytes(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) Bytes read from all instance store volumes available to the instance.

        This metric is used to determine the volume of the data the application reads from the hard disk of the instance.
        This can be used to determine the speed of the application.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageDiskReadBytes", []))

    @jsii.member(jsii_name="metricAverageDiskReadOps")
    def metric_average_disk_read_ops(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) Completed read operations from all instance store volumes available to the instance in a specified period of time.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageDiskReadOps", []))

    @jsii.member(jsii_name="metricAverageDiskWriteBytes")
    def metric_average_disk_write_bytes(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) Bytes written to all instance store volumes available to the instance.

        This metric is used to determine the volume of the data the application writes onto the hard disk of the instance.
        This can be used to determine the speed of the application.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageDiskWriteBytes", []))

    @jsii.member(jsii_name="metricAverageDiskWriteOps")
    def metric_average_disk_write_ops(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) Completed write operations to all instance store volumes available to the instance in a specified period of time.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageDiskWriteOps", []))

    @jsii.member(jsii_name="metricAverageNetworkInRateBytes")
    def metric_average_network_in_rate_bytes(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) The number of bytes received on all network interfaces by the instance.

        This metric identifies the volume of incoming network traffic to a single instance.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageNetworkInRateBytes", []))

    @jsii.member(jsii_name="metricAverageNetworkOutRateBytes")
    def metric_average_network_out_rate_bytes(self) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) The number of bytes sent out on all network interfaces by the instance.

        This metric identifies the volume of outgoing network traffic from a single instance.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "metricAverageNetworkOutRateBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="autoScalingGroup")
    def _auto_scaling_group(
        self,
    ) -> typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup], jsii.get(self, "autoScalingGroup"))


class ElastiCacheAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ElastiCacheAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addMaxEvictedItemsCountAlarm")
    def add_max_evicted_items_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MaxItemsCountThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxEvictedItemsCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxItemsCountAlarm")
    def add_max_items_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MaxItemsCountThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxItemsCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxUsedSwapMemoryAlarm")
    def add_max_used_swap_memory_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MaxUsedSwapMemoryThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxUsedSwapMemoryAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMinFreeableMemoryAlarm")
    def add_min_freeable_memory_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MinFreeableMemoryThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinFreeableMemoryAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class ElastiCacheClusterMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ElastiCacheClusterMetricFactory",
):
    '''
    :see: https://docs.aws.amazon.com/AmazonElastiCache/latest/mem-ug/CacheMetrics.html
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        cluster_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param cluster_id: (experimental) Cluster to monitor. Default: monitor all clusters

        :stability: experimental
        '''
        props = ElastiCacheClusterMetricFactoryProps(cluster_id=cluster_id)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricAverageCachedItemsSizeInBytes")
    def metric_average_cached_items_size_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageCachedItemsSizeInBytes", []))

    @jsii.member(jsii_name="metricAverageConnections")
    def metric_average_connections(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageConnections", []))

    @jsii.member(jsii_name="metricAverageFreeableMemoryInBytes")
    def metric_average_freeable_memory_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageFreeableMemoryInBytes", []))

    @jsii.member(jsii_name="metricAverageSwapUsageInBytes")
    def metric_average_swap_usage_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageSwapUsageInBytes", []))

    @jsii.member(jsii_name="metricAverageUnusedMemoryInBytes")
    def metric_average_unused_memory_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageUnusedMemoryInBytes", []))

    @jsii.member(jsii_name="metricEvictions")
    def metric_evictions(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricEvictions", []))

    @jsii.member(jsii_name="metricMaxCpuUtilizationInPercent")
    def metric_max_cpu_utilization_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMaxCpuUtilizationInPercent", []))

    @jsii.member(jsii_name="metricMaxItemCount")
    def metric_max_item_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMaxItemCount", []))

    @jsii.member(jsii_name="metricNetworkBytesIn")
    def metric_network_bytes_in(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNetworkBytesIn", []))

    @jsii.member(jsii_name="metricNetworkBytesOut")
    def metric_network_bytes_out(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNetworkBytesOut", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ElastiCacheClusterMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"cluster_id": "clusterId"},
)
class ElastiCacheClusterMetricFactoryProps:
    def __init__(self, *, cluster_id: typing.Optional[builtins.str] = None) -> None:
        '''
        :param cluster_id: (experimental) Cluster to monitor. Default: monitor all clusters

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''(experimental) Cluster to monitor.

        :default: monitor all clusters

        :stability: experimental
        '''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastiCacheClusterMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.ElastiCacheClusterType")
class ElastiCacheClusterType(enum.Enum):
    '''
    :stability: experimental
    '''

    MEMCACHED = "MEMCACHED"
    '''
    :stability: experimental
    '''
    REDIS = "REDIS"
    '''
    :stability: experimental
    '''


@jsii.enum(jsii_type="cdk-monitoring-constructs.ElasticsearchClusterStatus")
class ElasticsearchClusterStatus(enum.Enum):
    '''
    :stability: experimental
    '''

    RED = "RED"
    '''
    :stability: experimental
    '''
    YELLOW = "YELLOW"
    '''
    :stability: experimental
    '''


class ErrorAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ErrorAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addErrorCountAlarm")
    def add_error_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        error_type: "ErrorType",
        props: "ErrorCountThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param error_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addErrorCountAlarm", [metric, error_type, props, disambiguator]))

    @jsii.member(jsii_name="addErrorRateAlarm")
    def add_error_rate_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        error_type: "ErrorType",
        props: "ErrorRateThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param error_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addErrorRateAlarm", [metric, error_type, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ErrorCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_error_count": "maxErrorCount",
    },
)
class ErrorCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_error_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_error_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_error_count": max_error_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_error_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_error_count")
        assert result is not None, "Required property 'max_error_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ErrorCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ErrorRateThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_error_rate": "maxErrorRate",
    },
)
class ErrorRateThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_error_rate: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_error_rate: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_error_rate": max_error_rate,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_error_rate(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_error_rate")
        assert result is not None, "Required property 'max_error_rate' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ErrorRateThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.ErrorType")
class ErrorType(enum.Enum):
    '''
    :stability: experimental
    '''

    FAULT = "FAULT"
    '''
    :stability: experimental
    '''
    ERROR = "ERROR"
    '''
    :stability: experimental
    '''
    SYSTEM_ERROR = "SYSTEM_ERROR"
    '''
    :stability: experimental
    '''
    USER_ERROR = "USER_ERROR"
    '''
    :stability: experimental
    '''
    FAILURE = "FAILURE"
    '''
    :stability: experimental
    '''
    ABORTED = "ABORTED"
    '''
    :stability: experimental
    '''
    THROTTLED = "THROTTLED"
    '''
    :stability: experimental
    '''
    TIMED_OUT = "TIMED_OUT"
    '''
    :stability: experimental
    '''
    READ_ERROR = "READ_ERROR"
    '''
    :stability: experimental
    '''
    WRITE_ERROR = "WRITE_ERROR"
    '''
    :stability: experimental
    '''
    EXPIRED = "EXPIRED"
    '''
    :stability: experimental
    '''


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.FullRestartCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_full_restart_count": "maxFullRestartCount",
    },
)
class FullRestartCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_full_restart_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_full_restart_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_full_restart_count": max_full_restart_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_full_restart_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_full_restart_count")
        assert result is not None, "Required property 'max_full_restart_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FullRestartCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueJobMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.GlueJobMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, metric_factory: "MetricFactory", job_name: builtins.str) -> None:
        '''
        :param metric_factory: -
        :param job_name: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [metric_factory, job_name])

    @jsii.member(jsii_name="metricActiveExecutorsAverage")
    def metric_active_executors_average(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActiveExecutorsAverage", []))

    @jsii.member(jsii_name="metricAverageExecutorCpuUsagePercentage")
    def metric_average_executor_cpu_usage_percentage(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageExecutorCpuUsagePercentage", []))

    @jsii.member(jsii_name="metricAverageExecutorMemoryUsagePercentage")
    def metric_average_executor_memory_usage_percentage(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageExecutorMemoryUsagePercentage", []))

    @jsii.member(jsii_name="metricCompletedStagesSum")
    def metric_completed_stages_sum(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricCompletedStagesSum", []))

    @jsii.member(jsii_name="metricMaximumNeededExecutors")
    def metric_maximum_needed_executors(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMaximumNeededExecutors", []))

    @jsii.member(jsii_name="metricTotalReadBytesFromS3")
    def metric_total_read_bytes_from_s3(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalReadBytesFromS3", []))

    @jsii.member(jsii_name="metricTotalWrittenBytesToS3")
    def metric_total_written_bytes_to_s3(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalWrittenBytesToS3", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.enum(jsii_type="cdk-monitoring-constructs.GraphWidgetType")
class GraphWidgetType(enum.Enum):
    '''
    :stability: experimental
    '''

    LINE = "LINE"
    '''
    :stability: experimental
    '''
    STACKED_AREA = "STACKED_AREA"
    '''
    :stability: experimental
    '''
    PIE = "PIE"
    '''
    :stability: experimental
    '''
    BAR = "BAR"
    '''
    :stability: experimental
    '''


@jsii.enum(jsii_type="cdk-monitoring-constructs.HeaderLevel")
class HeaderLevel(enum.Enum):
    '''
    :stability: experimental
    '''

    LARGE = "LARGE"
    '''
    :stability: experimental
    '''
    MEDIUM = "MEDIUM"
    '''
    :stability: experimental
    '''
    SMALL = "SMALL"
    '''
    :stability: experimental
    '''


class HeaderWidget(
    monocdk.aws_cloudwatch.TextWidget,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.HeaderWidget",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        text: builtins.str,
        level: typing.Optional[HeaderLevel] = None,
    ) -> None:
        '''
        :param text: -
        :param level: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [text, level])


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.HealthyTaskCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_healthy_tasks": "minHealthyTasks",
    },
)
class HealthyTaskCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_healthy_tasks: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_healthy_tasks: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_healthy_tasks": min_healthy_tasks,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_healthy_tasks(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_healthy_tasks")
        assert result is not None, "Required property 'min_healthy_tasks' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HealthyTaskCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.HealthyTaskPercentThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_healthy_task_percent": "minHealthyTaskPercent",
    },
)
class HealthyTaskPercentThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_healthy_task_percent: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_healthy_task_percent: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_healthy_task_percent": min_healthy_task_percent,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_healthy_task_percent(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_healthy_task_percent")
        assert result is not None, "Required property 'min_healthy_task_percent' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HealthyTaskPercentThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.HighMessagesPublishedThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_messages_published_count": "maxMessagesPublishedCount",
    },
)
class HighMessagesPublishedThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_messages_published_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_messages_published_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_messages_published_count": max_messages_published_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_messages_published_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_messages_published_count")
        assert result is not None, "Required property 'max_messages_published_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HighMessagesPublishedThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.HighTpsThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_tps": "maxTps",
    },
)
class HighTpsThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional["IAlarmActionStrategy"] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_tps: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_tps: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_tps": max_tps,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional["IAlarmActionStrategy"]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional["IAlarmActionStrategy"], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_tps(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_tps")
        assert result is not None, "Required property 'max_tps' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "HighTpsThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.interface(jsii_type="cdk-monitoring-constructs.IAlarmActionStrategy")
class IAlarmActionStrategy(typing_extensions.Protocol):
    '''(experimental) An object that appends actions to alarms.

    :stability: experimental
    '''

    @jsii.member(jsii_name="addAlarmActions")
    def add_alarm_actions(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.AlarmBase,
        action: "IAlarmActionStrategy",
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        ...


class _IAlarmActionStrategyProxy:
    '''(experimental) An object that appends actions to alarms.

    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IAlarmActionStrategy"

    @jsii.member(jsii_name="addAlarmActions")
    def add_alarm_actions(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.AlarmBase,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmActionStrategyProps(
            alarm=alarm,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(None, jsii.invoke(self, "addAlarmActions", [props]))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IAlarmActionStrategy).__jsii_proxy_class__ = lambda : _IAlarmActionStrategyProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IAlarmAnnotationStrategy")
class IAlarmAnnotationStrategy(typing_extensions.Protocol):
    '''(experimental) Helper class for creating annotations for alarms.

    :stability: experimental
    '''

    @jsii.member(jsii_name="createAnnotation")
    def create_annotation(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''(experimental) Creates annotation based on the metric and alarm properties.

        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        ...


class _IAlarmAnnotationStrategyProxy:
    '''(experimental) Helper class for creating annotations for alarms.

    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IAlarmAnnotationStrategy"

    @jsii.member(jsii_name="createAnnotation")
    def create_annotation(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''(experimental) Creates annotation based on the metric and alarm properties.

        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmAnnotationStrategyProps(
            alarm=alarm,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            metric=metric,
            threshold=threshold,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.HorizontalAnnotation, jsii.invoke(self, "createAnnotation", [props]))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IAlarmAnnotationStrategy).__jsii_proxy_class__ = lambda : _IAlarmAnnotationStrategyProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IAlarmConsumer")
class IAlarmConsumer(typing_extensions.Protocol):
    '''
    :stability: experimental
    '''

    @jsii.member(jsii_name="consume")
    def consume(self, alarms: typing.Sequence[AlarmWithAnnotation]) -> None:
        '''
        :param alarms: -

        :stability: experimental
        '''
        ...


class _IAlarmConsumerProxy:
    '''
    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IAlarmConsumer"

    @jsii.member(jsii_name="consume")
    def consume(self, alarms: typing.Sequence[AlarmWithAnnotation]) -> None:
        '''
        :param alarms: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "consume", [alarms]))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IAlarmConsumer).__jsii_proxy_class__ = lambda : _IAlarmConsumerProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IAlarmDedupeStringProcessor")
class IAlarmDedupeStringProcessor(typing_extensions.Protocol):
    '''(experimental) Strategy used to finalize dedupe string.

    :stability: experimental
    '''

    @jsii.member(jsii_name="processDedupeString")
    def process_dedupe_string(self, dedupe_string: builtins.str) -> builtins.str:
        '''(experimental) Process the dedupe string which was auto-generated.

        :param dedupe_string: -

        :return: final dedupe string

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="processDedupeStringOverride")
    def process_dedupe_string_override(
        self,
        dedupe_string: builtins.str,
    ) -> builtins.str:
        '''(experimental) Process the dedupe string which was specified by the user as an override.

        :param dedupe_string: -

        :return: final dedupe string

        :stability: experimental
        '''
        ...


class _IAlarmDedupeStringProcessorProxy:
    '''(experimental) Strategy used to finalize dedupe string.

    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IAlarmDedupeStringProcessor"

    @jsii.member(jsii_name="processDedupeString")
    def process_dedupe_string(self, dedupe_string: builtins.str) -> builtins.str:
        '''(experimental) Process the dedupe string which was auto-generated.

        :param dedupe_string: -

        :return: final dedupe string

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "processDedupeString", [dedupe_string]))

    @jsii.member(jsii_name="processDedupeStringOverride")
    def process_dedupe_string_override(
        self,
        dedupe_string: builtins.str,
    ) -> builtins.str:
        '''(experimental) Process the dedupe string which was specified by the user as an override.

        :param dedupe_string: -

        :return: final dedupe string

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "processDedupeStringOverride", [dedupe_string]))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IAlarmDedupeStringProcessor).__jsii_proxy_class__ = lambda : _IAlarmDedupeStringProcessorProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IDashboardFactory")
class IDashboardFactory(typing_extensions.Protocol):
    '''
    :stability: experimental
    '''

    @jsii.member(jsii_name="addSegment")
    def add_segment(self, props: "IDashboardFactoryProps") -> None:
        '''
        :param props: -

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="createdAlarmDashboard")
    def created_alarm_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="createdDashboard")
    def created_dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="createdSummaryDashboard")
    def created_summary_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        ...


class _IDashboardFactoryProxy:
    '''
    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IDashboardFactory"

    @jsii.member(jsii_name="addSegment")
    def add_segment(self, props: "IDashboardFactoryProps") -> None:
        '''
        :param props: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "addSegment", [props]))

    @jsii.member(jsii_name="createdAlarmDashboard")
    def created_alarm_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdAlarmDashboard", []))

    @jsii.member(jsii_name="createdDashboard")
    def created_dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdDashboard", []))

    @jsii.member(jsii_name="createdSummaryDashboard")
    def created_summary_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdSummaryDashboard", []))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IDashboardFactory).__jsii_proxy_class__ = lambda : _IDashboardFactoryProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IDashboardFactoryProps")
class IDashboardFactoryProps(typing_extensions.Protocol):
    '''
    :stability: experimental
    '''

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segment")
    def segment(self) -> "IDashboardSegment":
        '''(experimental) Segment to be placed on the dashboard.

        :stability: experimental
        '''
        ...

    @segment.setter
    def segment(self, value: "IDashboardSegment") -> None:
        ...

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="overrideProps")
    def override_props(self) -> typing.Optional["MonitoringDashboardsOverrideProps"]:
        '''(experimental) Dashboard placement override props.

        :default: all default

        :stability: experimental
        '''
        ...

    @override_props.setter
    def override_props(
        self,
        value: typing.Optional["MonitoringDashboardsOverrideProps"],
    ) -> None:
        ...


class _IDashboardFactoryPropsProxy:
    '''
    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IDashboardFactoryProps"

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="segment")
    def segment(self) -> "IDashboardSegment":
        '''(experimental) Segment to be placed on the dashboard.

        :stability: experimental
        '''
        return typing.cast("IDashboardSegment", jsii.get(self, "segment"))

    @segment.setter
    def segment(self, value: "IDashboardSegment") -> None:
        jsii.set(self, "segment", value)

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="overrideProps")
    def override_props(self) -> typing.Optional["MonitoringDashboardsOverrideProps"]:
        '''(experimental) Dashboard placement override props.

        :default: all default

        :stability: experimental
        '''
        return typing.cast(typing.Optional["MonitoringDashboardsOverrideProps"], jsii.get(self, "overrideProps"))

    @override_props.setter
    def override_props(
        self,
        value: typing.Optional["MonitoringDashboardsOverrideProps"],
    ) -> None:
        jsii.set(self, "overrideProps", value)

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IDashboardFactoryProps).__jsii_proxy_class__ = lambda : _IDashboardFactoryPropsProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IDashboardSegment")
class IDashboardSegment(typing_extensions.Protocol):
    '''
    :stability: experimental
    '''

    @jsii.member(jsii_name="alarmWidgets")
    def alarm_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for all alarms.

        These should go to the runbook or service dashboard.

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for the summary.

        These should go to the team OPS dashboard.

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns all widgets.

        These should go to the detailed service dashboard.

        :stability: experimental
        '''
        ...


class _IDashboardSegmentProxy:
    '''
    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IDashboardSegment"

    @jsii.member(jsii_name="alarmWidgets")
    def alarm_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for all alarms.

        These should go to the runbook or service dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "alarmWidgets", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for the summary.

        These should go to the team OPS dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns all widgets.

        These should go to the detailed service dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IDashboardSegment).__jsii_proxy_class__ = lambda : _IDashboardSegmentProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.ILoadBalancerMetricFactory")
class ILoadBalancerMetricFactory(typing_extensions.Protocol):
    '''(experimental) Common interface for load-balancer based service metric factories.

    :stability: experimental
    '''

    @jsii.member(jsii_name="metricActiveConnectionCount")
    def metric_active_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="metricHealthyTaskCount")
    def metric_healthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="metricHealthyTaskInPercent")
    def metric_healthy_task_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="metricNewConnectionCount")
    def metric_new_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="metricProcessedBytesMin")
    def metric_processed_bytes_min(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="metricUnhealthyTaskCount")
    def metric_unhealthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        ...


class _ILoadBalancerMetricFactoryProxy:
    '''(experimental) Common interface for load-balancer based service metric factories.

    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.ILoadBalancerMetricFactory"

    @jsii.member(jsii_name="metricActiveConnectionCount")
    def metric_active_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActiveConnectionCount", []))

    @jsii.member(jsii_name="metricHealthyTaskCount")
    def metric_healthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHealthyTaskCount", []))

    @jsii.member(jsii_name="metricHealthyTaskInPercent")
    def metric_healthy_task_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHealthyTaskInPercent", []))

    @jsii.member(jsii_name="metricNewConnectionCount")
    def metric_new_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNewConnectionCount", []))

    @jsii.member(jsii_name="metricProcessedBytesMin")
    def metric_processed_bytes_min(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProcessedBytesMin", []))

    @jsii.member(jsii_name="metricUnhealthyTaskCount")
    def metric_unhealthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricUnhealthyTaskCount", []))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, ILoadBalancerMetricFactory).__jsii_proxy_class__ = lambda : _ILoadBalancerMetricFactoryProxy


@jsii.interface(jsii_type="cdk-monitoring-constructs.IWidgetFactory")
class IWidgetFactory(typing_extensions.Protocol):
    '''(experimental) Strategy for creating widgets.

    :stability: experimental
    '''

    @jsii.member(jsii_name="createAlarmDetailWidget")
    def create_alarm_detail_widget(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        alarm_description: builtins.str,
        alarm_label: builtins.str,
        alarm_name: builtins.str,
        alarm_name_suffix: builtins.str,
        alarm_rule_when_alarming: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_insufficient_data: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_ok: monocdk.aws_cloudwatch.IAlarmRule,
        annotation: monocdk.aws_cloudwatch.HorizontalAnnotation,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.IWidget:
        '''(experimental) Create widget representing an alarm detail.

        :param alarm: 
        :param alarm_description: 
        :param alarm_label: 
        :param alarm_name: 
        :param alarm_name_suffix: 
        :param alarm_rule_when_alarming: 
        :param alarm_rule_when_insufficient_data: 
        :param alarm_rule_when_ok: 
        :param annotation: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        ...


class _IWidgetFactoryProxy:
    '''(experimental) Strategy for creating widgets.

    :stability: experimental
    '''

    __jsii_type__: typing.ClassVar[str] = "cdk-monitoring-constructs.IWidgetFactory"

    @jsii.member(jsii_name="createAlarmDetailWidget")
    def create_alarm_detail_widget(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        alarm_description: builtins.str,
        alarm_label: builtins.str,
        alarm_name: builtins.str,
        alarm_name_suffix: builtins.str,
        alarm_rule_when_alarming: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_insufficient_data: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_ok: monocdk.aws_cloudwatch.IAlarmRule,
        annotation: monocdk.aws_cloudwatch.HorizontalAnnotation,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.IWidget:
        '''(experimental) Create widget representing an alarm detail.

        :param alarm: 
        :param alarm_description: 
        :param alarm_label: 
        :param alarm_name: 
        :param alarm_name_suffix: 
        :param alarm_rule_when_alarming: 
        :param alarm_rule_when_insufficient_data: 
        :param alarm_rule_when_ok: 
        :param annotation: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        alarm_ = AlarmWithAnnotation(
            alarm=alarm,
            alarm_description=alarm_description,
            alarm_label=alarm_label,
            alarm_name=alarm_name,
            alarm_name_suffix=alarm_name_suffix,
            alarm_rule_when_alarming=alarm_rule_when_alarming,
            alarm_rule_when_insufficient_data=alarm_rule_when_insufficient_data,
            alarm_rule_when_ok=alarm_rule_when_ok,
            annotation=annotation,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.IWidget, jsii.invoke(self, "createAlarmDetailWidget", [alarm_]))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
typing.cast(typing.Any, IWidgetFactory).__jsii_proxy_class__ = lambda : _IWidgetFactoryProxy


class KeyValueTableWidget(
    monocdk.aws_cloudwatch.TextWidget,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KeyValueTableWidget",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        data: typing.Sequence[typing.Mapping[typing.Any, typing.Any]],
    ) -> None:
        '''
        :param data: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [data])


class KinesisAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addIteratorMaxAgeAlarm")
    def add_iterator_max_age_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MaxIteratorAgeThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addIteratorMaxAgeAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addPutRecordsFailedAlarm")
    def add_put_records_failed_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "RecordsFailedThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addPutRecordsFailedAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addPutRecordsThrottledAlarm")
    def add_put_records_throttled_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "RecordsThrottledThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addPutRecordsThrottledAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class KinesisDataAnalyticsAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisDataAnalyticsAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addDowntimeAlarm")
    def add_downtime_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "MaxDowntimeThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addDowntimeAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addFullRestartAlarm")
    def add_full_restart_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: FullRestartCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addFullRestartAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class KinesisDataAnalyticsMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisDataAnalyticsMetricFactory",
):
    '''
    :see: https://docs.aws.amazon.com/kinesisanalytics/latest/java/metrics-dimensions.html
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        application: builtins.str,
    ) -> None:
        '''
        :param metric_factory: -
        :param application: 

        :stability: experimental
        '''
        props = KinesisDataAnalyticsMetricFactoryProps(application=application)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricCpuUtilizationPercent")
    def metric_cpu_utilization_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricCpuUtilizationPercent", []))

    @jsii.member(jsii_name="metricDowntimeMs")
    def metric_downtime_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDowntimeMs", []))

    @jsii.member(jsii_name="metricFullRestartsCount")
    def metric_full_restarts_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFullRestartsCount", []))

    @jsii.member(jsii_name="metricHeapMemoryUtilizationPercent")
    def metric_heap_memory_utilization_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHeapMemoryUtilizationPercent", []))

    @jsii.member(jsii_name="metricKPUsCount")
    def metric_kp_us_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricKPUsCount", []))

    @jsii.member(jsii_name="metricLastCheckpointDurationMs")
    def metric_last_checkpoint_duration_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLastCheckpointDurationMs", []))

    @jsii.member(jsii_name="metricLastCheckpointSizeBytes")
    def metric_last_checkpoint_size_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLastCheckpointSizeBytes", []))

    @jsii.member(jsii_name="metricNumberOfFailedCheckpointsCount")
    def metric_number_of_failed_checkpoints_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNumberOfFailedCheckpointsCount", []))

    @jsii.member(jsii_name="metricOldGenerationGCCount")
    def metric_old_generation_gc_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricOldGenerationGCCount", []))

    @jsii.member(jsii_name="metricOldGenerationGCTimeMs")
    def metric_old_generation_gc_time_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricOldGenerationGCTimeMs", []))

    @jsii.member(jsii_name="metricUptimeMs")
    def metric_uptime_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricUptimeMs", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.KinesisDataAnalyticsMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"application": "application"},
)
class KinesisDataAnalyticsMetricFactoryProps:
    def __init__(self, *, application: builtins.str) -> None:
        '''
        :param application: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "application": application,
        }

    @builtins.property
    def application(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("application")
        assert result is not None, "Required property 'application' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisDataAnalyticsMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisDataStreamMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisDataStreamMetricFactory",
):
    '''
    :see: https://docs.aws.amazon.com/streams/latest/dev/monitoring-with-cloudwatch.html
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        stream_name: builtins.str,
    ) -> None:
        '''
        :param metric_factory: -
        :param stream_name: 

        :stability: experimental
        '''
        props = KinesisDataStreamMetricFactoryProps(stream_name=stream_name)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricGetRecordsIteratorAgeMaxMs")
    def metric_get_records_iterator_age_max_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGetRecordsIteratorAgeMaxMs", []))

    @jsii.member(jsii_name="metricGetRecordsLatencyAverageMs")
    def metric_get_records_latency_average_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGetRecordsLatencyAverageMs", []))

    @jsii.member(jsii_name="metricGetRecordsSuccessCount")
    def metric_get_records_success_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGetRecordsSuccessCount", []))

    @jsii.member(jsii_name="metricGetRecordsSumBytes")
    def metric_get_records_sum_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGetRecordsSumBytes", []))

    @jsii.member(jsii_name="metricGetRecordsSumCount")
    def metric_get_records_sum_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricGetRecordsSumCount", []))

    @jsii.member(jsii_name="metricIncomingDataSumBytes")
    def metric_incoming_data_sum_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIncomingDataSumBytes", []))

    @jsii.member(jsii_name="metricIncomingDataSumCount")
    def metric_incoming_data_sum_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIncomingDataSumCount", []))

    @jsii.member(jsii_name="metricPutRecordLatencyAverageMs")
    def metric_put_record_latency_average_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordLatencyAverageMs", []))

    @jsii.member(jsii_name="metricPutRecordsFailedRecordsCount")
    def metric_put_records_failed_records_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsFailedRecordsCount", []))

    @jsii.member(jsii_name="metricPutRecordsLatencyAverageMs")
    def metric_put_records_latency_average_ms(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsLatencyAverageMs", []))

    @jsii.member(jsii_name="metricPutRecordsSuccessCount")
    def metric_put_records_success_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsSuccessCount", []))

    @jsii.member(jsii_name="metricPutRecordsSuccessfulRecordsCount")
    def metric_put_records_successful_records_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsSuccessfulRecordsCount", []))

    @jsii.member(jsii_name="metricPutRecordsSumBytes")
    def metric_put_records_sum_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsSumBytes", []))

    @jsii.member(jsii_name="metricPutRecordsThrottledRecordsCount")
    def metric_put_records_throttled_records_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsThrottledRecordsCount", []))

    @jsii.member(jsii_name="metricPutRecordsTotalRecordsCount")
    def metric_put_records_total_records_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordsTotalRecordsCount", []))

    @jsii.member(jsii_name="metricPutRecordSuccessCount")
    def metric_put_record_success_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordSuccessCount", []))

    @jsii.member(jsii_name="metricPutRecordSumBytes")
    def metric_put_record_sum_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordSumBytes", []))

    @jsii.member(jsii_name="metricReadProvisionedThroughputExceededPercent")
    def metric_read_provisioned_throughput_exceeded_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricReadProvisionedThroughputExceededPercent", []))

    @jsii.member(jsii_name="metricWriteProvisionedThroughputExceededPercent")
    def metric_write_provisioned_throughput_exceeded_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricWriteProvisionedThroughputExceededPercent", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.KinesisDataStreamMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"stream_name": "streamName"},
)
class KinesisDataStreamMetricFactoryProps:
    def __init__(self, *, stream_name: builtins.str) -> None:
        '''
        :param stream_name: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "stream_name": stream_name,
        }

    @builtins.property
    def stream_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("stream_name")
        assert result is not None, "Required property 'stream_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisDataStreamMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisFirehoseMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisFirehoseMetricFactory",
):
    '''
    :see: https://docs.aws.amazon.com/firehose/latest/dev/monitoring-with-cloudwatch-metrics.html
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        delivery_stream_name: builtins.str,
    ) -> None:
        '''
        :param metric_factory: -
        :param delivery_stream_name: 

        :stability: experimental
        '''
        props = KinesisFirehoseMetricFactoryProps(
            delivery_stream_name=delivery_stream_name
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricFailedConversionCount")
    def metric_failed_conversion_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFailedConversionCount", []))

    @jsii.member(jsii_name="metricIncomingBytes")
    def metric_incoming_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIncomingBytes", []))

    @jsii.member(jsii_name="metricIncomingRecordCount")
    def metric_incoming_record_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIncomingRecordCount", []))

    @jsii.member(jsii_name="metricPutRecordBatchLatencyP90InMillis")
    def metric_put_record_batch_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordBatchLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricPutRecordLatencyP90InMillis")
    def metric_put_record_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricPutRecordLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricSuccessfulConversionCount")
    def metric_successful_conversion_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSuccessfulConversionCount", []))

    @jsii.member(jsii_name="metricThrottledRecordCount")
    def metric_throttled_record_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottledRecordCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.KinesisFirehoseMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"delivery_stream_name": "deliveryStreamName"},
)
class KinesisFirehoseMetricFactoryProps:
    def __init__(self, *, delivery_stream_name: builtins.str) -> None:
        '''
        :param delivery_stream_name: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "delivery_stream_name": delivery_stream_name,
        }

    @builtins.property
    def delivery_stream_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("delivery_stream_name")
        assert result is not None, "Required property 'delivery_stream_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaFunctionEnhancedMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.LambdaFunctionEnhancedMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        lambda_function: monocdk.aws_lambda.IFunction,
    ) -> None:
        '''
        :param metric_factory: -
        :param lambda_function: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [metric_factory, lambda_function])

    @jsii.member(jsii_name="enhancedMetricAvgCpuTotalTime")
    def enhanced_metric_avg_cpu_total_time(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricAvgCpuTotalTime", []))

    @jsii.member(jsii_name="enhancedMetricAvgMemoryUtilization")
    def enhanced_metric_avg_memory_utilization(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricAvgMemoryUtilization", []))

    @jsii.member(jsii_name="enhancedMetricFunctionCost")
    def enhanced_metric_function_cost(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricFunctionCost", []))

    @jsii.member(jsii_name="enhancedMetricMaxCpuTotalTime")
    def enhanced_metric_max_cpu_total_time(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricMaxCpuTotalTime", []))

    @jsii.member(jsii_name="enhancedMetricMaxMemoryUtilization")
    def enhanced_metric_max_memory_utilization(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricMaxMemoryUtilization", []))

    @jsii.member(jsii_name="enhancedMetricP90CpuTotalTime")
    def enhanced_metric_p90_cpu_total_time(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricP90CpuTotalTime", []))

    @jsii.member(jsii_name="enhancedMetricP90MemoryUtilization")
    def enhanced_metric_p90_memory_utilization(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "enhancedMetricP90MemoryUtilization", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lambdaFunction")
    def _lambda_function(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_lambda.IFunction, jsii.get(self, "lambdaFunction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))


class LambdaFunctionMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.LambdaFunctionMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: "MetricFactory",
        *,
        lambda_function: monocdk.aws_lambda.IFunction,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        lambda_insights_enabled: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param lambda_function: 
        :param fill_tps_with_zeroes: Default: true
        :param lambda_insights_enabled: (experimental) Generate dashboard charts for Lambda Insights metrics. To enable Lambda Insights on your Lambda function, see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html Default: false
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = LambdaFunctionMetricFactoryProps(
            lambda_function=lambda_function,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            lambda_insights_enabled=lambda_insights_enabled,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricConcurrentExecutions")
    def metric_concurrent_executions(self) -> monocdk.aws_cloudwatch.Metric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricConcurrentExecutions", []))

    @jsii.member(jsii_name="metricFaultCount")
    def metric_fault_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFaultCount", []))

    @jsii.member(jsii_name="metricFaultRate")
    def metric_fault_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFaultRate", []))

    @jsii.member(jsii_name="metricInvocationCount")
    def metric_invocation_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricInvocationCount", []))

    @jsii.member(jsii_name="metricLatencyP50InMillis")
    def metric_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricLatencyP90InMillis")
    def metric_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricLatencyP99InMillis")
    def metric_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricMaxIteratorAgeInMillis")
    def metric_max_iterator_age_in_millis(self) -> monocdk.aws_cloudwatch.Metric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricMaxIteratorAgeInMillis", []))

    @jsii.member(jsii_name="metricProvisionedConcurrencySpilloverInvocations")
    def metric_provisioned_concurrency_spillover_invocations(
        self,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricProvisionedConcurrencySpilloverInvocations", []))

    @jsii.member(jsii_name="metricProvisionedConcurrencySpilloverRate")
    def metric_provisioned_concurrency_spillover_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProvisionedConcurrencySpilloverRate", []))

    @jsii.member(jsii_name="metricThrottlesCount")
    def metric_throttles_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottlesCount", []))

    @jsii.member(jsii_name="metricThrottlesRate")
    def metric_throttles_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricThrottlesRate", []))

    @jsii.member(jsii_name="metricTps")
    def metric_tps(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTps", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fillTpsWithZeroes")
    def _fill_tps_with_zeroes(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "fillTpsWithZeroes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lambdaFunction")
    def _lambda_function(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_lambda.IFunction, jsii.get(self, "lambdaFunction"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> "MetricFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactory", jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> "RateComputationMethod":
        '''
        :stability: experimental
        '''
        return typing.cast("RateComputationMethod", jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LambdaFunctionMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "lambda_function": "lambdaFunction",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "lambda_insights_enabled": "lambdaInsightsEnabled",
        "rate_computation_method": "rateComputationMethod",
    },
)
class LambdaFunctionMetricFactoryProps:
    def __init__(
        self,
        *,
        lambda_function: monocdk.aws_lambda.IFunction,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        lambda_insights_enabled: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional["RateComputationMethod"] = None,
    ) -> None:
        '''
        :param lambda_function: 
        :param fill_tps_with_zeroes: Default: true
        :param lambda_insights_enabled: (experimental) Generate dashboard charts for Lambda Insights metrics. To enable Lambda Insights on your Lambda function, see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html Default: false
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "lambda_function": lambda_function,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if lambda_insights_enabled is not None:
            self._values["lambda_insights_enabled"] = lambda_insights_enabled
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def lambda_function(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        result = self._values.get("lambda_function")
        assert result is not None, "Required property 'lambda_function' is missing"
        return typing.cast(monocdk.aws_lambda.IFunction, result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def lambda_insights_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Generate dashboard charts for Lambda Insights metrics.

        To enable Lambda Insights on your Lambda function, see
        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html

        :default: false

        :stability: experimental
        '''
        result = self._values.get("lambda_insights_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional["RateComputationMethod"]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional["RateComputationMethod"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LatencyAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.LatencyAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addDurationAlarm")
    def add_duration_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        latency_type: "LatencyType",
        props: DurationThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param latency_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addDurationAlarm", [metric, latency_type, props, disambiguator]))

    @jsii.member(jsii_name="addJvmGarbageCollectionDurationAlarm")
    def add_jvm_garbage_collection_duration_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        latency_type: "LatencyType",
        props: DurationThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param latency_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addJvmGarbageCollectionDurationAlarm", [metric, latency_type, props, disambiguator]))

    @jsii.member(jsii_name="addLatencyAlarm")
    def add_latency_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        latency_type: "LatencyType",
        props: "LatencyThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param latency_type: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addLatencyAlarm", [metric, latency_type, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LatencyThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_latency": "maxLatency",
    },
)
class LatencyThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_latency: monocdk.Duration,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_latency: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_latency": max_latency,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_latency(self) -> monocdk.Duration:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_latency")
        assert result is not None, "Required property 'max_latency' is missing"
        return typing.cast(monocdk.Duration, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LatencyThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.LatencyType")
class LatencyType(enum.Enum):
    '''
    :stability: experimental
    '''

    P50 = "P50"
    '''
    :stability: experimental
    '''
    P70 = "P70"
    '''
    :stability: experimental
    '''
    P90 = "P90"
    '''
    :stability: experimental
    '''
    P99 = "P99"
    '''
    :stability: experimental
    '''
    P999 = "P999"
    '''
    :stability: experimental
    '''
    P9999 = "P9999"
    '''
    :stability: experimental
    '''
    P100 = "P100"
    '''
    :stability: experimental
    '''
    TM50 = "TM50"
    '''
    :stability: experimental
    '''
    TM70 = "TM70"
    '''
    :stability: experimental
    '''
    TM90 = "TM90"
    '''
    :stability: experimental
    '''
    TM99 = "TM99"
    '''
    :stability: experimental
    '''
    TM999 = "TM999"
    '''
    :stability: experimental
    '''
    TM9999 = "TM9999"
    '''
    :stability: experimental
    '''
    AVERAGE = "AVERAGE"
    '''
    :stability: experimental
    '''


@jsii.enum(jsii_type="cdk-monitoring-constructs.LogLevel")
class LogLevel(enum.Enum):
    '''(experimental) Level of a given log.

    :stability: experimental
    '''

    ERROR = "ERROR"
    '''
    :stability: experimental
    '''
    CRITICAL = "CRITICAL"
    '''
    :stability: experimental
    '''


class LogLevelAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.LogLevelAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addLogCountAlarm")
    def add_log_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        log_level: LogLevel,
        props: "LogLevelCountThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param log_level: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addLogCountAlarm", [metric, log_level, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LogLevelCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_log_count": "maxLogCount",
    },
)
class LogLevelCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_log_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_log_count: (experimental) Threshold for the number of logs to alarm on.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_log_count": max_log_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_log_count(self) -> jsii.Number:
        '''(experimental) Threshold for the number of logs to alarm on.

        :stability: experimental
        '''
        result = self._values.get("max_log_count")
        assert result is not None, "Required property 'max_log_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogLevelCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LowMessagesPublishedThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_messages_published_count": "minMessagesPublishedCount",
    },
)
class LowMessagesPublishedThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_messages_published_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_messages_published_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_messages_published_count": min_messages_published_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_messages_published_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_messages_published_count")
        assert result is not None, "Required property 'min_messages_published_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LowMessagesPublishedThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LowTpsThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_tps": "minTps",
    },
)
class LowTpsThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_tps: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_tps: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_tps": min_tps,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_tps(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_tps")
        assert result is not None, "Required property 'min_tps' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LowTpsThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxAgeThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_age_in_millis": "maxAgeInMillis",
    },
)
class MaxAgeThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_age_in_millis: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_age_in_millis: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_age_in_millis": max_age_in_millis,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_age_in_millis(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_age_in_millis")
        assert result is not None, "Required property 'max_age_in_millis' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxAgeThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxDowntimeThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_downtime_in_millis": "maxDowntimeInMillis",
    },
)
class MaxDowntimeThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_downtime_in_millis: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_downtime_in_millis: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_downtime_in_millis": max_downtime_in_millis,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_downtime_in_millis(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_downtime_in_millis")
        assert result is not None, "Required property 'max_downtime_in_millis' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxDowntimeThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxIncomingMessagesCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_incoming_messages_count": "maxIncomingMessagesCount",
    },
)
class MaxIncomingMessagesCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_incoming_messages_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_incoming_messages_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_incoming_messages_count": max_incoming_messages_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_incoming_messages_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_incoming_messages_count")
        assert result is not None, "Required property 'max_incoming_messages_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxIncomingMessagesCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxItemsCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_items_count": "maxItemsCount",
    },
)
class MaxItemsCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_items_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_items_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_items_count": max_items_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_items_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_items_count")
        assert result is not None, "Required property 'max_items_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxItemsCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxIteratorAgeThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_age_in_millis": "maxAgeInMillis",
    },
)
class MaxIteratorAgeThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_age_in_millis: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_age_in_millis: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_age_in_millis": max_age_in_millis,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_age_in_millis(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_age_in_millis")
        assert result is not None, "Required property 'max_age_in_millis' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxIteratorAgeThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxMessageAgeThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_age_in_seconds": "maxAgeInSeconds",
    },
)
class MaxMessageAgeThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_age_in_seconds: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_age_in_seconds: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_age_in_seconds": max_age_in_seconds,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_age_in_seconds(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_age_in_seconds")
        assert result is not None, "Required property 'max_age_in_seconds' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxMessageAgeThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxMessageCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_message_count": "maxMessageCount",
    },
)
class MaxMessageCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_message_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_message_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_message_count": max_message_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_message_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_message_count")
        assert result is not None, "Required property 'max_message_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxMessageCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxTimeToDrainThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_time_to_drain": "maxTimeToDrain",
    },
)
class MaxTimeToDrainThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_time_to_drain: monocdk.Duration,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_time_to_drain: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_time_to_drain": max_time_to_drain,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_time_to_drain(self) -> monocdk.Duration:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_time_to_drain")
        assert result is not None, "Required property 'max_time_to_drain' is missing"
        return typing.cast(monocdk.Duration, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxTimeToDrainThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MaxUsedSwapMemoryThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_used_swap_memory_in_bytes": "maxUsedSwapMemoryInBytes",
    },
)
class MaxUsedSwapMemoryThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_used_swap_memory_in_bytes: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_used_swap_memory_in_bytes: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_used_swap_memory_in_bytes": max_used_swap_memory_in_bytes,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_used_swap_memory_in_bytes(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_used_swap_memory_in_bytes")
        assert result is not None, "Required property 'max_used_swap_memory_in_bytes' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MaxUsedSwapMemoryThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.MetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        global_defaults: typing.Optional["MetricFactoryDefaults"] = None,
    ) -> None:
        '''
        :param global_defaults: (experimental) Allows you to specify the global defaults, which can be overridden in the individual metrics or alarms.

        :stability: experimental
        '''
        props = MetricFactoryProps(global_defaults=global_defaults)

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="adaptMetric")
    def adapt_metric(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Adapts properties of a foreign metric (metric created outside of this metric factory) to comply with the global defaults.

        Might modify namespace and metric period.

        :param metric: metric to be adapted.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "adaptMetric", [metric]))

    @jsii.member(jsii_name="adaptMetricPreservingPeriod")
    def adapt_metric_preserving_period(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Adapts properties of a foreign metric (metric created outside of this metric factory) to comply with the global defaults.

        Might modify namespace. Preserves metric period.

        :param metric: metric to be adapted.

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "adaptMetricPreservingPeriod", [metric]))

    @jsii.member(jsii_name="addAdditionalDimensions")
    def add_additional_dimensions(
        self,
        target: typing.Mapping[builtins.str, typing.Any],
        additional_dimensions: typing.Mapping[builtins.str, typing.Any],
    ) -> None:
        '''(experimental) Merges the given additional dimensions to the given target dimension hash.

        All existing dimensions with the same key are replaced.

        :param target: target dimension hash to update.
        :param additional_dimensions: additional dimensions.

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "addAdditionalDimensions", [target, additional_dimensions]))

    @jsii.member(jsii_name="createMetric")
    def create_metric(
        self,
        metric_name: builtins.str,
        statistic: "MetricStatistic",
        label: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        color: typing.Optional[builtins.str] = None,
        namespace: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Factory method that creates a metric.

        The metric properties will already be updated to comply with the global defaults.

        :param metric_name: metric name.
        :param statistic: aggregation statistic to use.
        :param label: metric label; if undefined, metric name is used by CloudWatch
        :param dimensions: additional dimensions to be added.
        :param color: metric color; if undefined, uses a CloudWatch provided color (preferred)
        :param namespace: specify a custom namespace; if undefined, uses the global default
        :param period: specify a custom period; if undefined, uses the global default

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "createMetric", [metric_name, statistic, label, dimensions, color, namespace, period]))

    @jsii.member(jsii_name="createMetricAnomalyDetection")
    def create_metric_anomaly_detection(
        self,
        metric: monocdk.aws_cloudwatch.IMetric,
        stdev: jsii.Number,
        label: builtins.str,
        color: typing.Optional[builtins.str] = None,
        expression_id: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Factory method that creates anomaly detection on a metric.

        Anomaly occurs whenever a metric value falls outside of a precomputed range of predicted values.
        The detection does not need any setup. The model will start learning automatically and should be ready in a few minutes.
        Usually, the anomaly detection is paired with an alarm.

        :param metric: metric to detect anomaly detection of.
        :param stdev: standard deviation, basically the tolerance / band thickness.
        :param label: metric label (required, as there is no reasonable default).
        :param color: metric color; if undefined, uses a CloudWatch provided color (preferred)
        :param expression_id: expression ID of the metric; uses ``m1`` if undefined
        :param period: specify a custom period; if undefined, uses the global default

        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Anomaly_Detection.html
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "createMetricAnomalyDetection", [metric, stdev, label, color, expression_id, period]))

    @jsii.member(jsii_name="createMetricMath")
    def create_metric_math(
        self,
        expression: builtins.str,
        using_metrics: typing.Mapping[builtins.str, monocdk.aws_cloudwatch.IMetric],
        label: builtins.str,
        color: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Factory method that creates a metric math expression.

        The metric properties will already be updated to comply with the global defaults.

        :param expression: CloudWatch metric math expression (https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/using-metric-math.html).
        :param using_metrics: map of metrics, where keys are expression IDs (used in the expression) and values are metrics.
        :param label: metric label (required, as there is no reasonable default).
        :param color: metric color; if undefined, uses a CloudWatch provided color (preferred)
        :param period: specify a custom period; if undefined, uses the global default

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "createMetricMath", [expression, using_metrics, label, color, period]))

    @jsii.member(jsii_name="createMetricSearch")
    def create_metric_search(
        self,
        query: builtins.str,
        dimensions: typing.Mapping[builtins.str, typing.Any],
        statistic: "MetricStatistic",
        namespace: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> monocdk.aws_cloudwatch.IMetric:
        '''(experimental) Factory method that creates a metric search query.

        The metric properties will already be updated to comply with the global defaults.

        :param query: metric search query (the same as the search query prompt in CloudWatch AWS Console), it might also be empty.
        :param dimensions: dimensions, further narrowing the search results; values might be undefined if you want to represent "any value"
        :param statistic: aggregation statistic to use.
        :param namespace: specify a custom namespace; if undefined, uses the global default
        :param label: specify custom label for search metrics; default is " " as it cannot be empty string
        :param period: specify a custom period; if undefined, uses the global default

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "createMetricSearch", [query, dimensions, statistic, namespace, label, period]))

    @jsii.member(jsii_name="divideMetric")
    def divide_metric(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        divisor: jsii.Number,
        label: builtins.str,
        expression_id: typing.Optional[builtins.str] = None,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Creates a metric math expression that divides the given metric by given coefficient.

        Does nothing if the divisor is one. Preserves the metric period.

        :param metric: metric to multiply.
        :param divisor: divisor (must be > 1).
        :param label: expression label.
        :param expression_id: expression ID of the metric; uses ``m1`` if undefined

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "divideMetric", [metric, divisor, label, expression_id]))

    @jsii.member(jsii_name="getNamespaceWithFallback")
    def get_namespace_with_fallback(
        self,
        value: typing.Optional[builtins.str] = None,
    ) -> builtins.str:
        '''(experimental) Returns the given namespace (if defined) or the global namespace as a fallback.

        If there is no namespace to fallback to (neither the custom or the default one), it will fail.

        :param value: custom namespace.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "getNamespaceWithFallback", [value]))

    @jsii.member(jsii_name="multiplyMetric")
    def multiply_metric(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        multiplier: jsii.Number,
        label: builtins.str,
        expression_id: typing.Optional[builtins.str] = None,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Creates a metric math expression that multiplies the given metric by given coefficient.

        Does nothing if the multiplier is one. Preserves the metric period.

        :param metric: metric to multiply.
        :param multiplier: multiplier (must be > 1).
        :param label: expression label.
        :param expression_id: expression ID of the metric; uses ``m1`` if undefined

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "multiplyMetric", [metric, multiplier, label, expression_id]))

    @jsii.member(jsii_name="sanitizeMetricExpressionIdSuffix")
    def sanitize_metric_expression_id_suffix(
        self,
        expression_id: builtins.str,
    ) -> builtins.str:
        '''(experimental) Helper method that helps to sanitize the given expression ID and removes all invalid characters.

        Valid expression ID regexp is the following: ^[a-z][a-zA-Z0-9_]*$
        As this is just to validate a suffix and not the whole ID, we do not have to verify the first lower case letter.

        :param expression_id: expression ID to sanitize.

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "sanitizeMetricExpressionIdSuffix", [expression_id]))

    @jsii.member(jsii_name="toRate")
    def to_rate(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        method: "RateComputationMethod",
        add_stats_to_label: typing.Optional[builtins.bool] = None,
        expression_id: typing.Optional[builtins.str] = None,
        fill_with_zeroes: typing.Optional[builtins.bool] = None,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''(experimental) Creates a metric math expression that computes a rate from a regular metric.

        For example, it allows you to compute rate per second (TPS), per minute, or just an average of your transactions.

        :param metric: metric to calculate the rate from.
        :param method: rate computation method.
        :param add_stats_to_label: add detailed statistics (min, max, average) to the label.
        :param expression_id: expression ID of the metric; uses ``m1`` if undefined
        :param fill_with_zeroes: if TRUE, the final metric will be zero-filled (0 on no data); false if undefined

        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "toRate", [metric, method, add_stats_to_label, expression_id, fill_with_zeroes]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="globalDefaults")
    def _global_defaults(self) -> "MetricFactoryDefaults":
        '''
        :stability: experimental
        '''
        return typing.cast("MetricFactoryDefaults", jsii.get(self, "globalDefaults"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MetricFactoryDefaults",
    jsii_struct_bases=[],
    name_mapping={"namespace": "namespace", "period": "period"},
)
class MetricFactoryDefaults:
    def __init__(
        self,
        *,
        namespace: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> None:
        '''(experimental) These are the globals used for each metric, unless there is some kind of override.

        :param namespace: (experimental) Each metric exists in a namespace. AWS Services have their own namespace, but here you can specify your custom one.
        :param period: (experimental) Metric period. Default value is used if not defined. Default: DefaultMetricPeriod

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if namespace is not None:
            self._values["namespace"] = namespace
        if period is not None:
            self._values["period"] = period

    @builtins.property
    def namespace(self) -> typing.Optional[builtins.str]:
        '''(experimental) Each metric exists in a namespace.

        AWS Services have their own namespace, but here you can specify your custom one.

        :stability: experimental
        '''
        result = self._values.get("namespace")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Metric period.

        Default value is used if not defined.

        :default: DefaultMetricPeriod

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MetricFactoryDefaults(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"global_defaults": "globalDefaults"},
)
class MetricFactoryProps:
    def __init__(
        self,
        *,
        global_defaults: typing.Optional[MetricFactoryDefaults] = None,
    ) -> None:
        '''
        :param global_defaults: (experimental) Allows you to specify the global defaults, which can be overridden in the individual metrics or alarms.

        :stability: experimental
        '''
        if isinstance(global_defaults, dict):
            global_defaults = MetricFactoryDefaults(**global_defaults)
        self._values: typing.Dict[str, typing.Any] = {}
        if global_defaults is not None:
            self._values["global_defaults"] = global_defaults

    @builtins.property
    def global_defaults(self) -> typing.Optional[MetricFactoryDefaults]:
        '''(experimental) Allows you to specify the global defaults, which can be overridden in the individual metrics or alarms.

        :stability: experimental
        '''
        result = self._values.get("global_defaults")
        return typing.cast(typing.Optional[MetricFactoryDefaults], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.MetricStatistic")
class MetricStatistic(enum.Enum):
    '''(experimental) Metric aggregation statistic to be used with the IMetric objects.

    :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Statistics-definitions.html
    :stability: experimental
    '''

    P50 = "P50"
    '''(experimental) 50th percentile of all datapoints.

    :stability: experimental
    '''
    P70 = "P70"
    '''(experimental) 70th percentile of all datapoints.

    :stability: experimental
    '''
    P90 = "P90"
    '''(experimental) 90th percentile of all datapoints.

    :stability: experimental
    '''
    P99 = "P99"
    '''(experimental) 99th percentile of all datapoints.

    :stability: experimental
    '''
    P999 = "P999"
    '''(experimental) 99.9th percentile of all datapoints.

    :stability: experimental
    '''
    P9999 = "P9999"
    '''(experimental) 99.99th percentile of all datapoints.

    :stability: experimental
    '''
    P100 = "P100"
    '''(experimental) 100th percentile of all datapoints.

    :stability: experimental
    '''
    TM50 = "TM50"
    '''(experimental) trimmed mean;

    calculates the average after removing the 50% of data points with the highest values

    :stability: experimental
    '''
    TM70 = "TM70"
    '''(experimental) trimmed mean;

    calculates the average after removing the 30% of data points with the highest values

    :stability: experimental
    '''
    TM90 = "TM90"
    '''(experimental) trimmed mean;

    calculates the average after removing the 10% of data points with the highest values

    :stability: experimental
    '''
    TM99 = "TM99"
    '''(experimental) trimmed mean;

    calculates the average after removing the 1% of data points with the highest values

    :stability: experimental
    '''
    TM999 = "TM999"
    '''(experimental) trimmed mean;

    calculates the average after removing the 0.1% of data points with the highest values

    :stability: experimental
    '''
    TM9999 = "TM9999"
    '''(experimental) trimmed mean;

    calculates the average after removing the 0.01% of data points with the highest values

    :stability: experimental
    '''
    TM99_BOTH = "TM99_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 1% lowest data points and the 1% highest data points

    :stability: experimental
    '''
    TM95_BOTH = "TM95_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 5% lowest data points and the 5% highest data points

    :stability: experimental
    '''
    TM90_BOTH = "TM90_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 10% lowest data points and the 10% highest data points

    :stability: experimental
    '''
    TM85_BOTH = "TM85_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 15% lowest data points and the 15% highest data points

    :stability: experimental
    '''
    TM80_BOTH = "TM80_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 20% lowest data points and the 20% highest data points

    :stability: experimental
    '''
    TM75_BOTH = "TM75_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 25% lowest data points and the 25% highest data points

    :stability: experimental
    '''
    TM70_BOTH = "TM70_BOTH"
    '''(experimental) trimmed mean;

    calculates the average after removing the 30% lowest data points and the 30% highest data points

    :stability: experimental
    '''
    WM50 = "WM50"
    '''(experimental) winsorized mean;

    calculates the average while treating the 50% of the highest values to be equal to the value at the 50th percentile

    :stability: experimental
    '''
    WM70 = "WM70"
    '''(experimental) winsorized mean;

    calculates the average while treating the 30% of the highest values to be equal to the value at the 70th percentile

    :stability: experimental
    '''
    WM90 = "WM90"
    '''(experimental) winsorized mean;

    calculates the average while treating the 10% of the highest values to be equal to the value at the 90th percentile

    :stability: experimental
    '''
    WM99 = "WM99"
    '''(experimental) winsorized mean;

    calculates the average while treating the 1% of the highest values to be equal to the value at the 99th percentile

    :stability: experimental
    '''
    WM999 = "WM999"
    '''(experimental) winsorized mean;

    calculates the average while treating the 0.1% of the highest values to be equal to the value at the 99.9th percentile

    :stability: experimental
    '''
    WM9999 = "WM9999"
    '''(experimental) winsorized mean;

    calculates the average while treating the 0.01% of the highest values to be equal to the value at the 99.99th percentile

    :stability: experimental
    '''
    WM99_BOTH = "WM99_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 1% of data points to be the value of the 99% boundary, and treating the lowest 1% of data points to be the value of the 1% boundary

    :stability: experimental
    '''
    WM95_BOTH = "WM95_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 5% of data points to be the value of the 95% boundary, and treating the lowest 5% of data points to be the value of the 5% boundary

    :stability: experimental
    '''
    WM90_BOTH = "WM90_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 10% of data points to be the value of the 90% boundary, and treating the lowest 10% of data points to be the value of the 10% boundary

    :stability: experimental
    '''
    WM85_BOTH = "WM85_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 15% of data points to be the value of the 85% boundary, and treating the lowest 15% of data points to be the value of the 15% boundary

    :stability: experimental
    '''
    WM80_BOTH = "WM80_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 20% of data points to be the value of the 80% boundary, and treating the lowest 20% of data points to be the value of the 20% boundary

    :stability: experimental
    '''
    WM75_BOTH = "WM75_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 25% of data points to be the value of the 75% boundary, and treating the lowest 25% of data points to be the value of the 25% boundary

    :stability: experimental
    '''
    WM70_BOTH = "WM70_BOTH"
    '''(experimental) winsorized mean;

    calculates the average while treating the highest 30% of data points to be the value of the 70% boundary, and treating the lowest 30% of data points to be the value of the 30% boundary

    :stability: experimental
    '''
    MIN = "MIN"
    '''(experimental) minimum of all datapoints.

    :stability: experimental
    '''
    MAX = "MAX"
    '''(experimental) maximum of all datapoints.

    :stability: experimental
    '''
    SUM = "SUM"
    '''(experimental) sum of all datapoints.

    :stability: experimental
    '''
    AVERAGE = "AVERAGE"
    '''(experimental) average of all datapoints.

    :stability: experimental
    '''
    N = "N"
    '''(experimental) number of datapoints.

    :stability: experimental
    '''


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MinFreeableMemoryThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_freeable_memory_in_bytes": "minFreeableMemoryInBytes",
    },
)
class MinFreeableMemoryThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_freeable_memory_in_bytes: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_freeable_memory_in_bytes: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_freeable_memory_in_bytes": min_freeable_memory_in_bytes,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_freeable_memory_in_bytes(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_freeable_memory_in_bytes")
        assert result is not None, "Required property 'min_freeable_memory_in_bytes' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MinFreeableMemoryThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MinIncomingMessagesCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_incoming_messages_count": "minIncomingMessagesCount",
    },
)
class MinIncomingMessagesCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_incoming_messages_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_incoming_messages_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_incoming_messages_count": min_incoming_messages_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_incoming_messages_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_incoming_messages_count")
        assert result is not None, "Required property 'min_incoming_messages_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MinIncomingMessagesCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MinMessageCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_message_count": "minMessageCount",
    },
)
class MinMessageCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_message_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_message_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_message_count": min_message_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_message_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_message_count")
        assert result is not None, "Required property 'min_message_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MinMessageCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MinProcessedBytesThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_processed_bytes": "minProcessedBytes",
    },
)
class MinProcessedBytesThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_processed_bytes: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_processed_bytes: (experimental) Threshold for the least number of bytes processed.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_processed_bytes": min_processed_bytes,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_processed_bytes(self) -> jsii.Number:
        '''(experimental) Threshold for the least number of bytes processed.

        :stability: experimental
        '''
        result = self._values.get("min_processed_bytes")
        assert result is not None, "Required property 'min_processed_bytes' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MinProcessedBytesThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MinRunningTaskCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_running_tasks": "minRunningTasks",
    },
)
class MinRunningTaskCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_running_tasks: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_running_tasks: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_running_tasks": min_running_tasks,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_running_tasks(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_running_tasks")
        assert result is not None, "Required property 'min_running_tasks' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MinRunningTaskCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(IDashboardSegment)
class Monitoring(
    metaclass=jsii.JSIIAbstractClass,
    jsii_type="cdk-monitoring-constructs.Monitoring",
):
    '''(experimental) An independent unit of monitoring.

    This is the base for all monitoring classes with alarm support.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: "MonitoringScope",
        *,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = BaseMonitoringProps(
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="addAlarm")
    def add_alarm(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        alarm_description: builtins.str,
        alarm_label: builtins.str,
        alarm_name: builtins.str,
        alarm_name_suffix: builtins.str,
        alarm_rule_when_alarming: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_insufficient_data: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_ok: monocdk.aws_cloudwatch.IAlarmRule,
        annotation: monocdk.aws_cloudwatch.HorizontalAnnotation,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Adds an alarm.

        :param alarm: 
        :param alarm_description: 
        :param alarm_label: 
        :param alarm_name: 
        :param alarm_name_suffix: 
        :param alarm_rule_when_alarming: 
        :param alarm_rule_when_insufficient_data: 
        :param alarm_rule_when_ok: 
        :param annotation: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        alarm_ = AlarmWithAnnotation(
            alarm=alarm,
            alarm_description=alarm_description,
            alarm_label=alarm_label,
            alarm_name=alarm_name,
            alarm_name_suffix=alarm_name_suffix,
            alarm_rule_when_alarming=alarm_rule_when_alarming,
            alarm_rule_when_insufficient_data=alarm_rule_when_insufficient_data,
            alarm_rule_when_ok=alarm_rule_when_ok,
            annotation=annotation,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(None, jsii.invoke(self, "addAlarm", [alarm_]))

    @jsii.member(jsii_name="alarmWidgets")
    def alarm_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for all alarms.

        These can go to runbook or to service dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "alarmWidgets", []))

    @jsii.member(jsii_name="createAlarmFactory")
    def create_alarm_factory(self, alarm_name_prefix: builtins.str) -> AlarmFactory:
        '''(experimental) Creates a new alarm factory.

        Alarms created will be named with the given prefix, unless a local name override is present.

        :param alarm_name_prefix: alarm name prefix.

        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.invoke(self, "createAlarmFactory", [alarm_name_prefix]))

    @jsii.member(jsii_name="createdAlarms")
    def created_alarms(self) -> typing.List[AlarmWithAnnotation]:
        '''(experimental) Returns all the alarms created.

        :stability: experimental
        '''
        return typing.cast(typing.List[AlarmWithAnnotation], jsii.invoke(self, "createdAlarms", []))

    @jsii.member(jsii_name="createMetricFactory")
    def create_metric_factory(self) -> MetricFactory:
        '''(experimental) Creates a new metric factory.

        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.invoke(self, "createMetricFactory", []))

    @jsii.member(jsii_name="createWidgetFactory")
    def create_widget_factory(self) -> IWidgetFactory:
        '''(experimental) Creates a new widget factory.

        :stability: experimental
        '''
        return typing.cast(IWidgetFactory, jsii.invoke(self, "createWidgetFactory", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :default: no widgets.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets") # type: ignore[misc]
    @abc.abstractmethod
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        ...

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarms")
    def _alarms(self) -> typing.List[AlarmWithAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[AlarmWithAnnotation], jsii.get(self, "alarms"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scope")
    def _scope(self) -> "MonitoringScope":
        '''
        :stability: experimental
        '''
        return typing.cast("MonitoringScope", jsii.get(self, "scope"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="localAlarmNamePrefixOverride")
    def _local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "localAlarmNamePrefixOverride"))


class _MonitoringProxy(Monitoring):
    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
typing.cast(typing.Any, Monitoring).__jsii_proxy_class__ = lambda : _MonitoringProxy


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MonitoringDashboardsOverrideProps",
    jsii_struct_bases=[],
    name_mapping={
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
    },
)
class MonitoringDashboardsOverrideProps:
    def __init__(
        self,
        *,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitoringDashboardsOverrideProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MonitoringDashboardsProps",
    jsii_struct_bases=[],
    name_mapping={
        "create_alarm_dashboard": "createAlarmDashboard",
        "create_dashboard": "createDashboard",
        "create_summary_dashboard": "createSummaryDashboard",
        "dashboard_name_prefix": "dashboardNamePrefix",
        "rendering_preference": "renderingPreference",
        "detail_dashboard_period_override": "detailDashboardPeriodOverride",
        "detail_dashboard_range": "detailDashboardRange",
        "summary_dashboard_period_override": "summaryDashboardPeriodOverride",
        "summary_dashboard_range": "summaryDashboardRange",
    },
)
class MonitoringDashboardsProps:
    def __init__(
        self,
        *,
        create_alarm_dashboard: builtins.bool,
        create_dashboard: builtins.bool,
        create_summary_dashboard: builtins.bool,
        dashboard_name_prefix: builtins.str,
        rendering_preference: DashboardRenderingPreference,
        detail_dashboard_period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        detail_dashboard_range: typing.Optional[monocdk.Duration] = None,
        summary_dashboard_period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        summary_dashboard_range: typing.Optional[monocdk.Duration] = None,
    ) -> None:
        '''
        :param create_alarm_dashboard: (experimental) Flag indicating whether the alarm dashboard should be created. This is independent on other create dashboard flags.
        :param create_dashboard: (experimental) Flag indicating whether the default dashboard should be created. This is independent on other create dashboard flags.
        :param create_summary_dashboard: (experimental) Flag indicating whether the summary dashboard should be created. This is independent on other create dashboard flags.
        :param dashboard_name_prefix: (experimental) Prefix added to each dashboard name. This allows to have all dashboards sorted close to each other and also separate multiple monitoring facades.
        :param rendering_preference: (experimental) Dashboard rendering preference.
        :param detail_dashboard_period_override: (experimental) Period override for the detail dashboard (and other auxiliary dashboards). Default: automatic (period dependent)
        :param detail_dashboard_range: (experimental) Range of the detail dashboard (and other auxiliary dashboards). Default: 8 hours
        :param summary_dashboard_period_override: (experimental) Period override for the summary dashboard. Default: automatic (period dependent)
        :param summary_dashboard_range: (experimental) Range of the summary dashboard. Default: 14 days

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "create_alarm_dashboard": create_alarm_dashboard,
            "create_dashboard": create_dashboard,
            "create_summary_dashboard": create_summary_dashboard,
            "dashboard_name_prefix": dashboard_name_prefix,
            "rendering_preference": rendering_preference,
        }
        if detail_dashboard_period_override is not None:
            self._values["detail_dashboard_period_override"] = detail_dashboard_period_override
        if detail_dashboard_range is not None:
            self._values["detail_dashboard_range"] = detail_dashboard_range
        if summary_dashboard_period_override is not None:
            self._values["summary_dashboard_period_override"] = summary_dashboard_period_override
        if summary_dashboard_range is not None:
            self._values["summary_dashboard_range"] = summary_dashboard_range

    @builtins.property
    def create_alarm_dashboard(self) -> builtins.bool:
        '''(experimental) Flag indicating whether the alarm dashboard should be created.

        This is independent on other create dashboard flags.

        :stability: experimental
        '''
        result = self._values.get("create_alarm_dashboard")
        assert result is not None, "Required property 'create_alarm_dashboard' is missing"
        return typing.cast(builtins.bool, result)

    @builtins.property
    def create_dashboard(self) -> builtins.bool:
        '''(experimental) Flag indicating whether the default dashboard should be created.

        This is independent on other create dashboard flags.

        :stability: experimental
        '''
        result = self._values.get("create_dashboard")
        assert result is not None, "Required property 'create_dashboard' is missing"
        return typing.cast(builtins.bool, result)

    @builtins.property
    def create_summary_dashboard(self) -> builtins.bool:
        '''(experimental) Flag indicating whether the summary dashboard should be created.

        This is independent on other create dashboard flags.

        :stability: experimental
        '''
        result = self._values.get("create_summary_dashboard")
        assert result is not None, "Required property 'create_summary_dashboard' is missing"
        return typing.cast(builtins.bool, result)

    @builtins.property
    def dashboard_name_prefix(self) -> builtins.str:
        '''(experimental) Prefix added to each dashboard name.

        This allows to have all dashboards sorted close to each other and also separate multiple monitoring facades.

        :stability: experimental
        '''
        result = self._values.get("dashboard_name_prefix")
        assert result is not None, "Required property 'dashboard_name_prefix' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rendering_preference(self) -> DashboardRenderingPreference:
        '''(experimental) Dashboard rendering preference.

        :stability: experimental
        '''
        result = self._values.get("rendering_preference")
        assert result is not None, "Required property 'rendering_preference' is missing"
        return typing.cast(DashboardRenderingPreference, result)

    @builtins.property
    def detail_dashboard_period_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.PeriodOverride]:
        '''(experimental) Period override for the detail dashboard (and other auxiliary dashboards).

        :default: automatic (period dependent)

        :stability: experimental
        '''
        result = self._values.get("detail_dashboard_period_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.PeriodOverride], result)

    @builtins.property
    def detail_dashboard_range(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Range of the detail dashboard (and other auxiliary dashboards).

        :default: 8 hours

        :see: DefaultDetailDashboardRange
        :stability: experimental
        '''
        result = self._values.get("detail_dashboard_range")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def summary_dashboard_period_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.PeriodOverride]:
        '''(experimental) Period override for the summary dashboard.

        :default: automatic (period dependent)

        :stability: experimental
        '''
        result = self._values.get("summary_dashboard_period_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.PeriodOverride], result)

    @builtins.property
    def summary_dashboard_range(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Range of the summary dashboard.

        :default: 14 days

        :stability: experimental
        '''
        result = self._values.get("summary_dashboard_range")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitoringDashboardsProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MonitoringFacadeProps",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_factory_defaults": "alarmFactoryDefaults",
        "metric_factory_defaults": "metricFactoryDefaults",
        "dashboard_factory": "dashboardFactory",
    },
)
class MonitoringFacadeProps:
    def __init__(
        self,
        *,
        alarm_factory_defaults: AlarmFactoryDefaults,
        metric_factory_defaults: MetricFactoryDefaults,
        dashboard_factory: typing.Optional[IDashboardFactory] = None,
    ) -> None:
        '''
        :param alarm_factory_defaults: 
        :param metric_factory_defaults: 
        :param dashboard_factory: 

        :stability: experimental
        '''
        if isinstance(alarm_factory_defaults, dict):
            alarm_factory_defaults = AlarmFactoryDefaults(**alarm_factory_defaults)
        if isinstance(metric_factory_defaults, dict):
            metric_factory_defaults = MetricFactoryDefaults(**metric_factory_defaults)
        self._values: typing.Dict[str, typing.Any] = {
            "alarm_factory_defaults": alarm_factory_defaults,
            "metric_factory_defaults": metric_factory_defaults,
        }
        if dashboard_factory is not None:
            self._values["dashboard_factory"] = dashboard_factory

    @builtins.property
    def alarm_factory_defaults(self) -> AlarmFactoryDefaults:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_factory_defaults")
        assert result is not None, "Required property 'alarm_factory_defaults' is missing"
        return typing.cast(AlarmFactoryDefaults, result)

    @builtins.property
    def metric_factory_defaults(self) -> MetricFactoryDefaults:
        '''
        :stability: experimental
        '''
        result = self._values.get("metric_factory_defaults")
        assert result is not None, "Required property 'metric_factory_defaults' is missing"
        return typing.cast(MetricFactoryDefaults, result)

    @builtins.property
    def dashboard_factory(self) -> typing.Optional[IDashboardFactory]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dashboard_factory")
        return typing.cast(typing.Optional[IDashboardFactory], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitoringFacadeProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitoringHeaderWidget(
    HeaderWidget,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.MonitoringHeaderWidget",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        title: builtins.str,
        family: typing.Optional[builtins.str] = None,
        go_to_link_url: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param title: 
        :param family: 
        :param go_to_link_url: 

        :stability: experimental
        '''
        props = MonitoringHeaderWidgetProps(
            title=title, family=family, go_to_link_url=go_to_link_url
        )

        jsii.create(self.__class__, self, [props])


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.MonitoringHeaderWidgetProps",
    jsii_struct_bases=[],
    name_mapping={
        "title": "title",
        "family": "family",
        "go_to_link_url": "goToLinkUrl",
    },
)
class MonitoringHeaderWidgetProps:
    def __init__(
        self,
        *,
        title: builtins.str,
        family: typing.Optional[builtins.str] = None,
        go_to_link_url: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param title: 
        :param family: 
        :param go_to_link_url: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "title": title,
        }
        if family is not None:
            self._values["family"] = family
        if go_to_link_url is not None:
            self._values["go_to_link_url"] = go_to_link_url

    @builtins.property
    def title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("title")
        assert result is not None, "Required property 'title' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def family(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("family")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def go_to_link_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("go_to_link_url")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MonitoringHeaderWidgetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitoringNamingStrategy(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.MonitoringNamingStrategy",
):
    '''(experimental) Utility class to unify approach to naming monitoring sections.

    :see: https://docs.aws.amazon.com/cdk/latest/guide/tokens.html#tokens_lazy
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        fallback_construct_name: typing.Optional[builtins.str] = None,
        named_construct: typing.Optional[monocdk.IConstruct] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param fallback_construct_name: (experimental) Fallback name before we fallback to extracting name from the construct itself. This might be some construct reference, such is cluster ID, stream name, and so on. Default: use namedConstruct to extract the name
        :param named_construct: (experimental) Construct that this naming strategy is naming. It is used as a last resort for naming.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :stability: experimental
        '''
        input = NameResolutionInput(
            fallback_construct_name=fallback_construct_name,
            named_construct=named_construct,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
        )

        jsii.create(self.__class__, self, [input])

    @jsii.member(jsii_name="isAlarmFriendly") # type: ignore[misc]
    @builtins.classmethod
    def is_alarm_friendly(
        cls,
        str: builtins.str,
    ) -> typing.Union[builtins.bool, builtins.str]:
        '''
        :param str: -

        :stability: experimental
        '''
        return typing.cast(typing.Union[builtins.bool, builtins.str], jsii.sinvoke(cls, "isAlarmFriendly", [str]))

    @jsii.member(jsii_name="resolveAlarmFriendlyName")
    def resolve_alarm_friendly_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "resolveAlarmFriendlyName", []))

    @jsii.member(jsii_name="resolveHumanReadableName")
    def resolve_human_readable_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "resolveHumanReadableName", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="input")
    def _input(self) -> "NameResolutionInput":
        '''
        :stability: experimental
        '''
        return typing.cast("NameResolutionInput", jsii.get(self, "input"))


class MonitoringScope(
    monocdk.Construct,
    metaclass=jsii.JSIIAbstractClass,
    jsii_type="cdk-monitoring-constructs.MonitoringScope",
):
    '''(experimental) A scope (construct) where all monitoring constructs are living in.

    :stability: experimental
    '''

    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
        '''
        :param scope: -
        :param id: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [scope, id])

    @jsii.member(jsii_name="createAlarmFactory") # type: ignore[misc]
    @abc.abstractmethod
    def create_alarm_factory(self, alarm_name_prefix: builtins.str) -> AlarmFactory:
        '''(experimental) Creates a new alarm factory.

        Alarms created will be named with the given prefix, unless a local name override is present.

        :param alarm_name_prefix: alarm name prefix.

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="createAwsConsoleUrlFactory") # type: ignore[misc]
    @abc.abstractmethod
    def create_aws_console_url_factory(self) -> AwsConsoleUrlFactory:
        '''(experimental) Creates a new factory that creates AWS Console URLs.

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="createMetricFactory") # type: ignore[misc]
    @abc.abstractmethod
    def create_metric_factory(self) -> MetricFactory:
        '''(experimental) Creates a new metric factory.

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="createWidgetFactory") # type: ignore[misc]
    @abc.abstractmethod
    def create_widget_factory(self) -> IWidgetFactory:
        '''(experimental) Creates a new widget factory.

        :stability: experimental
        '''
        ...


class _MonitoringScopeProxy(MonitoringScope):
    @jsii.member(jsii_name="createAlarmFactory")
    def create_alarm_factory(self, alarm_name_prefix: builtins.str) -> AlarmFactory:
        '''(experimental) Creates a new alarm factory.

        Alarms created will be named with the given prefix, unless a local name override is present.

        :param alarm_name_prefix: alarm name prefix.

        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.invoke(self, "createAlarmFactory", [alarm_name_prefix]))

    @jsii.member(jsii_name="createAwsConsoleUrlFactory")
    def create_aws_console_url_factory(self) -> AwsConsoleUrlFactory:
        '''(experimental) Creates a new factory that creates AWS Console URLs.

        :stability: experimental
        '''
        return typing.cast(AwsConsoleUrlFactory, jsii.invoke(self, "createAwsConsoleUrlFactory", []))

    @jsii.member(jsii_name="createMetricFactory")
    def create_metric_factory(self) -> MetricFactory:
        '''(experimental) Creates a new metric factory.

        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.invoke(self, "createMetricFactory", []))

    @jsii.member(jsii_name="createWidgetFactory")
    def create_widget_factory(self) -> IWidgetFactory:
        '''(experimental) Creates a new widget factory.

        :stability: experimental
        '''
        return typing.cast(IWidgetFactory, jsii.invoke(self, "createWidgetFactory", []))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
typing.cast(typing.Any, MonitoringScope).__jsii_proxy_class__ = lambda : _MonitoringScopeProxy


@jsii.implements(IAlarmActionStrategy)
class MultipleAlarmActionStrategy(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.MultipleAlarmActionStrategy",
):
    '''(experimental) Alarm action strategy that combines multiple actions in the same order as they were given.

    :stability: experimental
    '''

    def __init__(self, actions: typing.Sequence[IAlarmActionStrategy]) -> None:
        '''
        :param actions: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [actions])

    @jsii.member(jsii_name="addAlarmActions")
    def add_alarm_actions(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.AlarmBase,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmActionStrategyProps(
            alarm=alarm,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(None, jsii.invoke(self, "addAlarmActions", [props]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="actions")
    def _actions(self) -> typing.List[IAlarmActionStrategy]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[IAlarmActionStrategy], jsii.get(self, "actions"))


@jsii.implements(ILoadBalancerMetricFactory)
class NetworkLoadBalancerMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.NetworkLoadBalancerMetricFactory",
):
    '''(experimental) Metric factory to create metrics for network load-balanced service.

    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
    ) -> None:
        '''
        :param metric_factory: -
        :param network_load_balancer: 
        :param network_target_group: 

        :stability: experimental
        '''
        props = NetworkLoadBalancerMetricFactoryProps(
            network_load_balancer=network_load_balancer,
            network_target_group=network_target_group,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricActiveConnectionCount")
    def metric_active_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActiveConnectionCount", []))

    @jsii.member(jsii_name="metricHealthyTaskCount")
    def metric_healthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHealthyTaskCount", []))

    @jsii.member(jsii_name="metricHealthyTaskInPercent")
    def metric_healthy_task_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHealthyTaskInPercent", []))

    @jsii.member(jsii_name="metricNewConnectionCount")
    def metric_new_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNewConnectionCount", []))

    @jsii.member(jsii_name="metricProcessedBytesMin")
    def metric_processed_bytes_min(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProcessedBytesMin", []))

    @jsii.member(jsii_name="metricUnhealthyTaskCount")
    def metric_unhealthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricUnhealthyTaskCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkLoadBalancer")
    def _network_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer, jsii.get(self, "networkLoadBalancer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkTargetGroup")
    def _network_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup, jsii.get(self, "networkTargetGroup"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.NetworkLoadBalancerMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "network_load_balancer": "networkLoadBalancer",
        "network_target_group": "networkTargetGroup",
    },
)
class NetworkLoadBalancerMetricFactoryProps:
    def __init__(
        self,
        *,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
    ) -> None:
        '''(experimental) Props to create NetworkLoadBalancerMetricFactory.

        :param network_load_balancer: 
        :param network_target_group: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "network_load_balancer": network_load_balancer,
            "network_target_group": network_target_group,
        }

    @builtins.property
    def network_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_load_balancer")
        assert result is not None, "Required property 'network_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer, result)

    @builtins.property
    def network_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_target_group")
        assert result is not None, "Required property 'network_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkLoadBalancerMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkLoadBalancerMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.NetworkLoadBalancerMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, "UnhealthyTaskCountThreshold"]] = None,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param network_load_balancer: 
        :param network_target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = NetworkLoadBalancerMonitoringProps(
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            network_load_balancer=network_load_balancer,
            network_target_group=network_target_group,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createTaskHealthWidget")
    def _create_task_health_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTaskHealthWidget", [width, height]))

    @jsii.member(jsii_name="createTcpFlowsWidget")
    def _create_tcp_flows_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTcpFlowsWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="activeTcpFlowCountMetric")
    def _active_tcp_flow_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "activeTcpFlowCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyTaskCountMetric")
    def _healthy_task_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "healthyTaskCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyTaskPercentMetric")
    def _healthy_task_percent_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "healthyTaskPercentMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="humanReadableName")
    def _human_readable_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "humanReadableName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> NetworkLoadBalancerMetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(NetworkLoadBalancerMetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newTcpFlowCountMetric")
    def _new_tcp_flow_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "newTcpFlowCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="processedBytesAnnotations")
    def _processed_bytes_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "processedBytesAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="processedBytesMetric")
    def _processed_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "processedBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAlarmFactory")
    def _task_health_alarm_factory(self) -> "TaskHealthAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("TaskHealthAlarmFactory", jsii.get(self, "taskHealthAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAnnotations")
    def _task_health_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "taskHealthAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throughputAlarmFactory")
    def _throughput_alarm_factory(self) -> "ThroughputAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("ThroughputAlarmFactory", jsii.get(self, "throughputAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyTaskCountMetric")
    def _unhealthy_task_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "unhealthyTaskCountMetric"))


@jsii.implements(IAlarmActionStrategy)
class NoopAlarmActionStrategy(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.NoopAlarmActionStrategy",
):
    '''(experimental) Alarm action strategy that does not add any actions.

    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="addAlarmActions")
    def add_alarm_actions(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.AlarmBase,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        _props = AlarmActionStrategyProps(
            alarm=alarm,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(None, jsii.invoke(self, "addAlarmActions", [_props]))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.NotificationsFailedThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_notifications_failed_count": "maxNotificationsFailedCount",
    },
)
class NotificationsFailedThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_notifications_failed_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_notifications_failed_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_notifications_failed_count": max_notifications_failed_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_notifications_failed_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_notifications_failed_count")
        assert result is not None, "Required property 'max_notifications_failed_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NotificationsFailedThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpenSearchBackportedMetrics(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.OpenSearchBackportedMetrics",
):
    '''(experimental) Backported set of metric functions added in @aws-cdk/aws-elasticsearch@1.65.0.

    :see: https://github.com/aws/aws-cdk/releases/tag/v1.73.0
    :stability: experimental
    '''

    def __init__(
        self,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
    ) -> None:
        '''
        :param domain: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [domain])

    @jsii.member(jsii_name="metric")
    def metric(
        self,
        metric_name: builtins.str,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Return the given named metric for this Domain.

        :param metric_name: -
        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metric", [metric_name, props]))

    @jsii.member(jsii_name="metricAutomatedSnapshotFailure")
    def metric_automated_snapshot_failure(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for automated snapshot failures.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricAutomatedSnapshotFailure", [props]))

    @jsii.member(jsii_name="metricClusterIndexWriteBlocked")
    def metric_cluster_index_write_blocked(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for the cluster blocking index writes.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 1 minute

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricClusterIndexWriteBlocked", [props]))

    @jsii.member(jsii_name="metricClusterStatusRed")
    def metric_cluster_status_red(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for the time the cluster status is red.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricClusterStatusRed", [props]))

    @jsii.member(jsii_name="metricClusterStatusYellow")
    def metric_cluster_status_yellow(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for the time the cluster status is yellow.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricClusterStatusYellow", [props]))

    @jsii.member(jsii_name="metricCPUUtilization")
    def metric_cpu_utilization(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for CPU utilization.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricCPUUtilization", [props]))

    @jsii.member(jsii_name="metricFreeStorageSpace")
    def metric_free_storage_space(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for the storage space of nodes in the cluster.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: minimum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricFreeStorageSpace", [props]))

    @jsii.member(jsii_name="metricIndexingLatency")
    def metric_indexing_latency(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for indexing latency.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: p99 over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricIndexingLatency", [props]))

    @jsii.member(jsii_name="metricJVMMemoryPressure")
    def metric_jvm_memory_pressure(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for JVM memory pressure.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricJVMMemoryPressure", [props]))

    @jsii.member(jsii_name="metricKMSKeyError")
    def metric_kms_key_error(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for KMS key errors.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricKMSKeyError", [props]))

    @jsii.member(jsii_name="metricKMSKeyInaccessible")
    def metric_kms_key_inaccessible(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for KMS key being inaccessible.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricKMSKeyInaccessible", [props]))

    @jsii.member(jsii_name="metricMasterCPUUtilization")
    def metric_master_cpu_utilization(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for master CPU utilization.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricMasterCPUUtilization", [props]))

    @jsii.member(jsii_name="metricMasterJVMMemoryPressure")
    def metric_master_jvm_memory_pressure(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for master JVM memory pressure.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricMasterJVMMemoryPressure", [props]))

    @jsii.member(jsii_name="metricNodes")
    def metric_nodes(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for the number of nodes.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: minimum over 1 hour

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricNodes", [props]))

    @jsii.member(jsii_name="metricSearchableDocuments")
    def metric_searchable_documents(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for number of searchable documents.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: maximum over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricSearchableDocuments", [props]))

    @jsii.member(jsii_name="metricSearchLatency")
    def metric_search_latency(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        color: typing.Optional[builtins.str] = None,
        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        region: typing.Optional[builtins.str] = None,
        statistic: typing.Optional[builtins.str] = None,
        unit: typing.Optional[monocdk.aws_cloudwatch.Unit] = None,
    ) -> monocdk.aws_cloudwatch.Metric:
        '''(experimental) Metric for search latency.

        :param account: (experimental) Account which this metric comes from. Default: - Deployment account.
        :param color: (experimental) The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
        :param dimensions_map: (experimental) Dimensions of the metric. Default: - No dimensions.
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - No label
        :param period: (experimental) The period over which the specified statistic is applied. Default: Duration.minutes(5)
        :param region: (experimental) Region which this metric comes from. Default: - Deployment region.
        :param statistic: (experimental) What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
        :param unit: (experimental) Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream

        :default: p99 over 5 minutes

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.MetricOptions(
            account=account,
            color=color,
            dimensions=dimensions,
            dimensions_map=dimensions_map,
            label=label,
            period=period,
            region=region,
            statistic=statistic,
            unit=unit,
        )

        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricSearchLatency", [props]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))


class OpenSearchClusterAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addAutomatedSnapshotFailureAlarm")
    def add_automated_snapshot_failure_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "OpenSearchClusterAutomatedSnapshotFailureThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addAutomatedSnapshotFailureAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addClusterIndexWritesBlockedAlarm")
    def add_cluster_index_writes_blocked_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "OpenSearchClusterIndexWritesBlockedThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addClusterIndexWritesBlockedAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addClusterNodeCountAlarm")
    def add_cluster_node_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "OpenSearchClusterNodesThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addClusterNodeCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addClusterStatusAlarm")
    def add_cluster_status_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "OpenSearchClusterStatusCustomization",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addClusterStatusAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addKmsKeyErrorAlarm")
    def add_kms_key_error_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "OpenSearchKmsKeyErrorThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addKmsKeyErrorAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addKmsKeyInaccessibleAlarm")
    def add_kms_key_inaccessible_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "OpenSearchKmsKeyInaccessibleThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addKmsKeyInaccessibleAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterAutomatedSnapshotFailureThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_failures": "maxFailures",
    },
)
class OpenSearchClusterAutomatedSnapshotFailureThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_failures: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_failures: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_failures": max_failures,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_failures(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_failures")
        assert result is not None, "Required property 'max_failures' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchClusterAutomatedSnapshotFailureThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterIndexWritesBlockedThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_blocked_writes": "maxBlockedWrites",
    },
)
class OpenSearchClusterIndexWritesBlockedThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_blocked_writes: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_blocked_writes: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_blocked_writes": max_blocked_writes,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_blocked_writes(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_blocked_writes")
        assert result is not None, "Required property 'max_blocked_writes' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchClusterIndexWritesBlockedThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpenSearchClusterMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param domain: 
        :param fill_tps_with_zeroes: Default: true

        :stability: experimental
        '''
        props = OpenSearchClusterMetricFactoryProps(
            domain=domain, fill_tps_with_zeroes=fill_tps_with_zeroes
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricAutomatedSnapshotFailure")
    def metric_automated_snapshot_failure(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAutomatedSnapshotFailure", []))

    @jsii.member(jsii_name="metricClusterIndexWriteBlocked")
    def metric_cluster_index_write_blocked(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricClusterIndexWriteBlocked", []))

    @jsii.member(jsii_name="metricClusterStatusRed")
    def metric_cluster_status_red(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricClusterStatusRed", []))

    @jsii.member(jsii_name="metricClusterStatusYellow")
    def metric_cluster_status_yellow(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricClusterStatusYellow", []))

    @jsii.member(jsii_name="metricCpuUsage")
    def metric_cpu_usage(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricCpuUsage", []))

    @jsii.member(jsii_name="metricDiskSpaceUsageInPercent")
    def metric_disk_space_usage_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDiskSpaceUsageInPercent", []))

    @jsii.member(jsii_name="metricIndexingLatencyP50InMillis")
    def metric_indexing_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIndexingLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricIndexingLatencyP90InMillis")
    def metric_indexing_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIndexingLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricIndexingLatencyP99InMillis")
    def metric_indexing_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIndexingLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricJvmMemoryPressure")
    def metric_jvm_memory_pressure(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricJvmMemoryPressure", []))

    @jsii.member(jsii_name="metricKmsKeyError")
    def metric_kms_key_error(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricKmsKeyError", []))

    @jsii.member(jsii_name="metricKmsKeyInaccessible")
    def metric_kms_key_inaccessible(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricKmsKeyInaccessible", []))

    @jsii.member(jsii_name="metricMasterCpuUsage")
    def metric_master_cpu_usage(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMasterCpuUsage", []))

    @jsii.member(jsii_name="metricMasterJvmMemoryPressure")
    def metric_master_jvm_memory_pressure(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMasterJvmMemoryPressure", []))

    @jsii.member(jsii_name="metricNodes")
    def metric_nodes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNodes", []))

    @jsii.member(jsii_name="metricSearchLatencyP50InMillis")
    def metric_search_latency_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSearchLatencyP50InMillis", []))

    @jsii.member(jsii_name="metricSearchLatencyP90InMillis")
    def metric_search_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSearchLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricSearchLatencyP99InMillis")
    def metric_search_latency_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSearchLatencyP99InMillis", []))

    @jsii.member(jsii_name="metricTps")
    def metric_tps(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTps", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="domainMetrics")
    def _domain_metrics(self) -> OpenSearchBackportedMetrics:
        '''
        :stability: experimental
        '''
        return typing.cast(OpenSearchBackportedMetrics, jsii.get(self, "domainMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fillTpsWithZeroes")
    def _fill_tps_with_zeroes(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "fillTpsWithZeroes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"domain": "domain", "fill_tps_with_zeroes": "fillTpsWithZeroes"},
)
class OpenSearchClusterMetricFactoryProps:
    def __init__(
        self,
        *,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param domain: 
        :param fill_tps_with_zeroes: Default: true

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "domain": domain,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes

    @builtins.property
    def domain(
        self,
    ) -> typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain]:
        '''
        :stability: experimental
        '''
        result = self._values.get("domain")
        assert result is not None, "Required property 'domain' is missing"
        return typing.cast(typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain], result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchClusterMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpenSearchClusterMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_cluster_automated_snapshot_failure_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterAutomatedSnapshotFailureThreshold]] = None,
        add_cluster_index_writes_blocked_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterIndexWritesBlockedThreshold]] = None,
        add_cluster_node_count_alarm: typing.Optional[typing.Mapping[builtins.str, "OpenSearchClusterNodesThreshold"]] = None,
        add_cluster_status_alarm: typing.Optional[typing.Mapping[builtins.str, "OpenSearchClusterStatusCustomization"]] = None,
        add_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_indexing_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_kms_key_error_alarm: typing.Optional[typing.Mapping[builtins.str, "OpenSearchKmsKeyErrorThreshold"]] = None,
        add_kms_key_inaccessible_alarm: typing.Optional[typing.Mapping[builtins.str, "OpenSearchKmsKeyInaccessibleThreshold"]] = None,
        add_master_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_master_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_search_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_cluster_automated_snapshot_failure_alarm: 
        :param add_cluster_index_writes_blocked_alarm: 
        :param add_cluster_node_count_alarm: 
        :param add_cluster_status_alarm: 
        :param add_cpu_space_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param add_indexing_latency_p50_alarm: 
        :param add_indexing_latency_p90_alarm: 
        :param add_indexing_latency_p99_alarm: 
        :param add_jvm_memory_pressure_alarm: 
        :param add_kms_key_error_alarm: 
        :param add_kms_key_inaccessible_alarm: 
        :param add_master_cpu_space_usage_alarm: 
        :param add_master_jvm_memory_pressure_alarm: 
        :param add_search_latency_p50_alarm: 
        :param add_search_latency_p90_alarm: 
        :param add_search_latency_p99_alarm: 
        :param domain: 
        :param fill_tps_with_zeroes: Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = OpenSearchClusterMonitoringProps(
            add_cluster_automated_snapshot_failure_alarm=add_cluster_automated_snapshot_failure_alarm,
            add_cluster_index_writes_blocked_alarm=add_cluster_index_writes_blocked_alarm,
            add_cluster_node_count_alarm=add_cluster_node_count_alarm,
            add_cluster_status_alarm=add_cluster_status_alarm,
            add_cpu_space_usage_alarm=add_cpu_space_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            add_indexing_latency_p50_alarm=add_indexing_latency_p50_alarm,
            add_indexing_latency_p90_alarm=add_indexing_latency_p90_alarm,
            add_indexing_latency_p99_alarm=add_indexing_latency_p99_alarm,
            add_jvm_memory_pressure_alarm=add_jvm_memory_pressure_alarm,
            add_kms_key_error_alarm=add_kms_key_error_alarm,
            add_kms_key_inaccessible_alarm=add_kms_key_inaccessible_alarm,
            add_master_cpu_space_usage_alarm=add_master_cpu_space_usage_alarm,
            add_master_jvm_memory_pressure_alarm=add_master_jvm_memory_pressure_alarm,
            add_search_latency_p50_alarm=add_search_latency_p50_alarm,
            add_search_latency_p90_alarm=add_search_latency_p90_alarm,
            add_search_latency_p99_alarm=add_search_latency_p99_alarm,
            domain=domain,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="automatedSnapshotFailureMetric")
    def _automated_snapshot_failure_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "automatedSnapshotFailureMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterAlarmFactory")
    def _cluster_alarm_factory(self) -> OpenSearchClusterAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(OpenSearchClusterAlarmFactory, jsii.get(self, "clusterAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterAnnotations")
    def _cluster_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "clusterAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterStatusRedMetric")
    def _cluster_status_red_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "clusterStatusRedMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterStatusYellowMetric")
    def _cluster_status_yellow_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "clusterStatusYellowMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageMetric")
    def _cpu_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSpaceUsageMetric")
    def _disk_space_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "diskSpaceUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexingLatencyAlarmFactory")
    def _indexing_latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "indexingLatencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexingLatencyAnnotations")
    def _indexing_latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "indexingLatencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexWriteBlockedMetric")
    def _index_write_blocked_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "indexWriteBlockedMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="jvmMemoryPressureMetric")
    def _jvm_memory_pressure_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "jvmMemoryPressureMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsKeyErrorMetric")
    def _kms_key_error_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "kmsKeyErrorMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kmsKeyInaccessibleMetric")
    def _kms_key_inaccessible_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "kmsKeyInaccessibleMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterCpuUsageMetric")
    def _master_cpu_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "masterCpuUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterJvmMemoryPressureMetric")
    def _master_jvm_memory_pressure_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "masterJvmMemoryPressureMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="masterUsageAnnotations")
    def _master_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "masterUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodeAnnotations")
    def _node_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "nodeAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="nodesMetric")
    def _nodes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "nodesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50IndexingLatencyMetric")
    def _p50_indexing_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50IndexingLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50SearchLatencyMetric")
    def _p50_search_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50SearchLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90IndexingLatencyMetric")
    def _p90_indexing_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90IndexingLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90SearchLatencyMetric")
    def _p90_search_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90SearchLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99IndexingLatencyMetric")
    def _p99_indexing_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99IndexingLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99SearchLatencyMetric")
    def _p99_search_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99SearchLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="searchLatencyAlarmFactory")
    def _search_latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "searchLatencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="searchLatencyAnnotations")
    def _search_latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "searchLatencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsMetric")
    def _tps_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "tpsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> "UsageAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("UsageAlarmFactory", jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAnnotations")
    def _usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "usageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def _url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "url"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterNodesThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_nodes": "minNodes",
    },
)
class OpenSearchClusterNodesThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_nodes: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_nodes: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_nodes": min_nodes,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_nodes(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_nodes")
        assert result is not None, "Required property 'min_nodes' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchClusterNodesThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.OpenSearchClusterStatus")
class OpenSearchClusterStatus(enum.Enum):
    '''
    :stability: experimental
    '''

    RED = "RED"
    '''
    :stability: experimental
    '''
    YELLOW = "YELLOW"
    '''
    :stability: experimental
    '''


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterStatusCustomization",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "status": "status",
    },
)
class OpenSearchClusterStatusCustomization(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        status: typing.Union[OpenSearchClusterStatus, ElasticsearchClusterStatus],
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param status: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "status": status,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def status(
        self,
    ) -> typing.Union[OpenSearchClusterStatus, ElasticsearchClusterStatus]:
        '''
        :stability: experimental
        '''
        result = self._values.get("status")
        assert result is not None, "Required property 'status' is missing"
        return typing.cast(typing.Union[OpenSearchClusterStatus, ElasticsearchClusterStatus], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchClusterStatusCustomization(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchKmsKeyErrorThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_errors": "maxErrors",
    },
)
class OpenSearchKmsKeyErrorThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_errors: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_errors: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_errors": max_errors,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_errors(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_errors")
        assert result is not None, "Required property 'max_errors' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchKmsKeyErrorThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchKmsKeyInaccessibleThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_access_attempts": "maxAccessAttempts",
    },
)
class OpenSearchKmsKeyInaccessibleThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_access_attempts: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_access_attempts: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_access_attempts": max_access_attempts,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_access_attempts(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_access_attempts")
        assert result is not None, "Required property 'max_access_attempts' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchKmsKeyInaccessibleThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class QueueAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.QueueAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addMaxQueueIncomingMessagesCountAlarm")
    def add_max_queue_incoming_messages_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MaxIncomingMessagesCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxQueueIncomingMessagesCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxQueueMessageAgeAlarm")
    def add_max_queue_message_age_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MaxMessageAgeThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxQueueMessageAgeAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxQueueMessageCountAlarm")
    def add_max_queue_message_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MaxMessageCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxQueueMessageCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxQueueTimeToDrainMessagesAlarm")
    def add_max_queue_time_to_drain_messages_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MaxTimeToDrainThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxQueueTimeToDrainMessagesAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMinQueueIncomingMessagesCountAlarm")
    def add_min_queue_incoming_messages_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MinIncomingMessagesCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinQueueIncomingMessagesCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMinQueueMessageCountAlarm")
    def add_min_queue_message_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MinMessageCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinQueueMessageCountAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.enum(jsii_type="cdk-monitoring-constructs.RateComputationMethod")
class RateComputationMethod(enum.Enum):
    '''(experimental) Enumeration of different rate computation methods.

    :stability: experimental
    '''

    AVERAGE = "AVERAGE"
    '''(experimental) Number of occurrences relative to requests.

    Less sensitive than per-second when TPS > 1.

    :stability: experimental
    '''
    PER_SECOND = "PER_SECOND"
    '''(experimental) Number of occurrences per second.

    More sensitive than average when TPS > 1.

    :stability: experimental
    '''
    PER_MINUTE = "PER_MINUTE"
    '''(experimental) Number of occurrences per minute.

    :stability: experimental
    '''
    PER_HOUR = "PER_HOUR"
    '''(experimental) Number of occurrences per hour.

    :stability: experimental
    '''
    PER_DAY = "PER_DAY"
    '''(experimental) Number of occurrences per day.

    :stability: experimental
    '''


class RdsClusterMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.RdsClusterMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        cluster_identifier: builtins.str,
    ) -> None:
        '''
        :param metric_factory: -
        :param cluster_identifier: 

        :stability: experimental
        '''
        props = RdsClusterMetricFactoryProps(cluster_identifier=cluster_identifier)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricAverageCpuUsageInPercent")
    def metric_average_cpu_usage_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageCpuUsageInPercent", []))

    @jsii.member(jsii_name="metricCommitLatencyP90InMillis")
    def metric_commit_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricCommitLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricDeleteLatencyP90InMillis")
    def metric_delete_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDeleteLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricDiskSpaceUsageInPercent")
    def metric_disk_space_usage_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDiskSpaceUsageInPercent", []))

    @jsii.member(jsii_name="metricFreeStorageInBytes")
    def metric_free_storage_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFreeStorageInBytes", []))

    @jsii.member(jsii_name="metricInsertLatencyP90InMillis")
    def metric_insert_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricInsertLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricSelectLatencyP90InMillis")
    def metric_select_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricSelectLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricTotalConnectionCount")
    def metric_total_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalConnectionCount", []))

    @jsii.member(jsii_name="metricUpdateLatencyP90InMillis")
    def metric_update_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricUpdateLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricUsedStorageInBytes")
    def metric_used_storage_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricUsedStorageInBytes", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RdsClusterMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"cluster_identifier": "clusterIdentifier"},
)
class RdsClusterMetricFactoryProps:
    def __init__(self, *, cluster_identifier: builtins.str) -> None:
        '''
        :param cluster_identifier: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_identifier": cluster_identifier,
        }

    @builtins.property
    def cluster_identifier(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("cluster_identifier")
        assert result is not None, "Required property 'cluster_identifier' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RdsClusterMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.RdsClusterMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        cluster_identifier: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_cpu_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param cluster_identifier: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = RdsClusterMonitoringProps(
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            cluster_identifier=cluster_identifier,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createConnectionsWidget")
    def _create_connections_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createConnectionsWidget", [width, height]))

    @jsii.member(jsii_name="createCpuAndDiskUsageWidget")
    def _create_cpu_and_disk_usage_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuAndDiskUsageWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="commitLatencyMetric")
    def _commit_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "commitLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionsMetric")
    def _connections_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "connectionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageMetric")
    def _cpu_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deleteLatencyMetric")
    def _delete_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "deleteLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSpaceUsageMetric")
    def _disk_space_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "diskSpaceUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="insertLatencyMetric")
    def _insert_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "insertLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="selectLatencyMetric")
    def _select_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "selectLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="updateLatencyMetric")
    def _update_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "updateLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> "UsageAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("UsageAlarmFactory", jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAnnotations")
    def _usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "usageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def _url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "url"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RecordsFailedThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_records_failed_threshold": "maxRecordsFailedThreshold",
    },
)
class RecordsFailedThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_records_failed_threshold: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_records_failed_threshold: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_records_failed_threshold": max_records_failed_threshold,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_records_failed_threshold(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_records_failed_threshold")
        assert result is not None, "Required property 'max_records_failed_threshold' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RecordsFailedThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RecordsThrottledThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_records_throttled_threshold": "maxRecordsThrottledThreshold",
    },
)
class RecordsThrottledThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_records_throttled_threshold: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_records_throttled_threshold: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_records_throttled_threshold": max_records_throttled_threshold,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_records_throttled_threshold(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_records_throttled_threshold")
        assert result is not None, "Required property 'max_records_throttled_threshold' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RecordsThrottledThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftClusterMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.RedshiftClusterMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        cluster_identifier: builtins.str,
    ) -> None:
        '''
        :param metric_factory: -
        :param cluster_identifier: 

        :stability: experimental
        '''
        props = RedshiftClusterMetricFactoryProps(
            cluster_identifier=cluster_identifier
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricAverageCpuUsageInPercent")
    def metric_average_cpu_usage_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageCpuUsageInPercent", []))

    @jsii.member(jsii_name="metricAverageDiskSpaceUsageInPercent")
    def metric_average_disk_space_usage_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageDiskSpaceUsageInPercent", []))

    @jsii.member(jsii_name="metricLongQueryDurationP90InMillis")
    def metric_long_query_duration_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricLongQueryDurationP90InMillis", []))

    @jsii.member(jsii_name="metricMaintenanceModeEnabled")
    def metric_maintenance_mode_enabled(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMaintenanceModeEnabled", []))

    @jsii.member(jsii_name="metricMediumQueryDurationP90InMillis")
    def metric_medium_query_duration_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricMediumQueryDurationP90InMillis", []))

    @jsii.member(jsii_name="metricReadLatencyP90InMillis")
    def metric_read_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricReadLatencyP90InMillis", []))

    @jsii.member(jsii_name="metricShortQueryDurationP90InMillis")
    def metric_short_query_duration_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricShortQueryDurationP90InMillis", []))

    @jsii.member(jsii_name="metricTotalConnectionCount")
    def metric_total_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTotalConnectionCount", []))

    @jsii.member(jsii_name="metricWriteLatencyP90InMillis")
    def metric_write_latency_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricWriteLatencyP90InMillis", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RedshiftClusterMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"cluster_identifier": "clusterIdentifier"},
)
class RedshiftClusterMetricFactoryProps:
    def __init__(self, *, cluster_identifier: builtins.str) -> None:
        '''
        :param cluster_identifier: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_identifier": cluster_identifier,
        }

    @builtins.property
    def cluster_identifier(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("cluster_identifier")
        assert result is not None, "Required property 'cluster_identifier' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftClusterMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftClusterMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.RedshiftClusterMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, "UsageThreshold"]] = None,
        cluster_identifier: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_cpu_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param cluster_identifier: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = RedshiftClusterMonitoringProps(
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            cluster_identifier=cluster_identifier,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createConnectionsWidget")
    def _create_connections_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createConnectionsWidget", [width, height]))

    @jsii.member(jsii_name="createCpuAndDiskUsageWidget")
    def _create_cpu_and_disk_usage_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuAndDiskUsageWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createMaintenanceWidget")
    def _create_maintenance_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMaintenanceWidget", [width, height]))

    @jsii.member(jsii_name="createQueryDurationWidget")
    def _create_query_duration_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createQueryDurationWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionsMetric")
    def _connections_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "connectionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageMetric")
    def _cpu_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskSpaceUsageMetric")
    def _disk_space_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "diskSpaceUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="longQueryDurationMetric")
    def _long_query_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "longQueryDurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maintenanceModeMetric")
    def _maintenance_mode_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "maintenanceModeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="mediumQueryDurationMetric")
    def _medium_query_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "mediumQueryDurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readLatencyMetric")
    def _read_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "readLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="shortQueryDurationMetric")
    def _short_query_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "shortQueryDurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> "UsageAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("UsageAlarmFactory", jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAnnotations")
    def _usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "usageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="writeLatencyMetric")
    def _write_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "writeLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def _url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "url"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RunningTaskCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_running_tasks": "maxRunningTasks",
    },
)
class RunningTaskCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_running_tasks: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_running_tasks: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_running_tasks": max_running_tasks,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_running_tasks(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_running_tasks")
        assert result is not None, "Required property 'max_running_tasks' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RunningTaskCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RunningTaskRateThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_running_task_rate": "maxRunningTaskRate",
    },
)
class RunningTaskRateThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_running_task_rate: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_running_task_rate: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_running_task_rate": max_running_task_rate,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_running_task_rate(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_running_task_rate")
        assert result is not None, "Required property 'max_running_task_rate' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RunningTaskRateThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.S3BucketMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        bucket: monocdk.aws_s3.IBucket,
        storage_type: typing.Optional["StorageType"] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param bucket: 
        :param storage_type: 

        :stability: experimental
        '''
        props = S3BucketMetricFactoryProps(bucket=bucket, storage_type=storage_type)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricBucketSizeBytes")
    def metric_bucket_size_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricBucketSizeBytes", []))

    @jsii.member(jsii_name="metricNumberOfObjects")
    def metric_number_of_objects(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNumberOfObjects", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="props")
    def _props(self) -> "S3BucketMetricFactoryProps":
        '''
        :stability: experimental
        '''
        return typing.cast("S3BucketMetricFactoryProps", jsii.get(self, "props"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.S3BucketMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket", "storage_type": "storageType"},
)
class S3BucketMetricFactoryProps:
    def __init__(
        self,
        *,
        bucket: monocdk.aws_s3.IBucket,
        storage_type: typing.Optional["StorageType"] = None,
    ) -> None:
        '''
        :param bucket: 
        :param storage_type: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "bucket": bucket,
        }
        if storage_type is not None:
            self._values["storage_type"] = storage_type

    @builtins.property
    def bucket(self) -> monocdk.aws_s3.IBucket:
        '''
        :stability: experimental
        '''
        result = self._values.get("bucket")
        assert result is not None, "Required property 'bucket' is missing"
        return typing.cast(monocdk.aws_s3.IBucket, result)

    @builtins.property
    def storage_type(self) -> typing.Optional["StorageType"]:
        '''
        :stability: experimental
        '''
        result = self._values.get("storage_type")
        return typing.cast(typing.Optional["StorageType"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.S3BucketMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        bucket: monocdk.aws_s3.IBucket,
        storage_type: typing.Optional["StorageType"] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param bucket: 
        :param storage_type: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = S3BucketMonitoringProps(
            bucket=bucket,
            storage_type=storage_type,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bucketSizeBytesMetric")
    def _bucket_size_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "bucketSizeBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numberOfObjectsMetric")
    def _number_of_objects_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "numberOfObjectsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="url")
    def _url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "url"))


class SecretsManagerMetricsPublisher(
    monocdk.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SecretsManagerMetricsPublisher",
):
    '''
    :stability: experimental
    '''

    @jsii.member(jsii_name="getInstance") # type: ignore[misc]
    @builtins.classmethod
    def get_instance(cls, scope: MonitoringScope) -> "SecretsManagerMetricsPublisher":
        '''
        :param scope: -

        :stability: experimental
        '''
        return typing.cast("SecretsManagerMetricsPublisher", jsii.sinvoke(cls, "getInstance", [scope]))

    @jsii.member(jsii_name="addSecret")
    def add_secret(self, secret: monocdk.aws_secretsmanager.ISecret) -> None:
        '''
        :param secret: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "addSecret", [secret]))


class SecretsManagerSecretMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SecretsManagerSecretMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        secret: monocdk.aws_secretsmanager.ISecret,
    ) -> None:
        '''
        :param metric_factory: -
        :param secret: 

        :stability: experimental
        '''
        props = SecretsManagerSecretMetricFactoryProps(secret=secret)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricDaysSinceLastChange")
    def metric_days_since_last_change(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDaysSinceLastChange", []))

    @jsii.member(jsii_name="metricDaysSinceLastRotation")
    def metric_days_since_last_rotation(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricDaysSinceLastRotation", []))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="MetricNameDaysSinceLastChange")
    def METRIC_NAME_DAYS_SINCE_LAST_CHANGE(cls) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.sget(cls, "MetricNameDaysSinceLastChange"))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="MetricNameDaysSinceLastRotation")
    def METRIC_NAME_DAYS_SINCE_LAST_ROTATION(cls) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.sget(cls, "MetricNameDaysSinceLastRotation"))

    @jsii.python.classproperty # type: ignore[misc]
    @jsii.member(jsii_name="Namespace")
    def NAMESPACE(cls) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.sget(cls, "Namespace"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="secret")
    def _secret(self) -> monocdk.aws_secretsmanager.ISecret:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_secretsmanager.ISecret, jsii.get(self, "secret"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SecretsManagerSecretMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"secret": "secret"},
)
class SecretsManagerSecretMetricFactoryProps:
    def __init__(self, *, secret: monocdk.aws_secretsmanager.ISecret) -> None:
        '''
        :param secret: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "secret": secret,
        }

    @builtins.property
    def secret(self) -> monocdk.aws_secretsmanager.ISecret:
        '''
        :stability: experimental
        '''
        result = self._values.get("secret")
        assert result is not None, "Required property 'secret' is missing"
        return typing.cast(monocdk.aws_secretsmanager.ISecret, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsManagerSecretMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecretsManagerSecretMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SecretsManagerSecretMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_days_since_last_change_alarm: typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]] = None,
        add_days_since_last_rotation_alarm: typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]] = None,
        show_last_rotation_widget: typing.Optional[builtins.bool] = None,
        secret: monocdk.aws_secretsmanager.ISecret,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_days_since_last_change_alarm: 
        :param add_days_since_last_rotation_alarm: 
        :param show_last_rotation_widget: Default: true, if ``addDaysSinceLastRotationAlarm`` is set, otherwise ``false``.
        :param secret: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SecretsManagerSecretMonitoringProps(
            add_days_since_last_change_alarm=add_days_since_last_change_alarm,
            add_days_since_last_rotation_alarm=add_days_since_last_rotation_alarm,
            show_last_rotation_widget=show_last_rotation_widget,
            secret=secret,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


@jsii.implements(IDashboardSegment)
class SingleWidgetDashboardSegment(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SingleWidgetDashboardSegment",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        widget: monocdk.aws_cloudwatch.IWidget,
        add_to_summary: typing.Optional[builtins.bool] = None,
        add_to_alarm: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param widget: -
        :param add_to_summary: -
        :param add_to_alarm: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [widget, add_to_summary, add_to_alarm])

    @jsii.member(jsii_name="alarmWidgets")
    def alarm_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for all alarms.

        These should go to the runbook or service dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "alarmWidgets", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets for the summary.

        These should go to the team OPS dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns all widgets.

        These should go to the detailed service dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addToAlarm")
    def _add_to_alarm(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "addToAlarm"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addToSummary")
    def _add_to_summary(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "addToSummary"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="widget")
    def _widget(self) -> monocdk.aws_cloudwatch.IWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IWidget, jsii.get(self, "widget"))


@jsii.implements(IAlarmActionStrategy)
class SnsAlarmActionStrategy(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SnsAlarmActionStrategy",
):
    '''(experimental) Alarm action strategy that sends a notification to the specified SNS topic.

    :stability: experimental
    '''

    def __init__(
        self,
        *,
        on_alarm_topic: monocdk.aws_sns.ITopic,
        on_insufficient_data_topic: typing.Optional[monocdk.aws_sns.ITopic] = None,
        on_ok_topic: typing.Optional[monocdk.aws_sns.ITopic] = None,
    ) -> None:
        '''
        :param on_alarm_topic: (experimental) Target topic used when the alarm is triggered.
        :param on_insufficient_data_topic: (experimental) Optional target topic for when the alarm goes into the INSUFFICIENT_DATA state. Default: no notification sent
        :param on_ok_topic: (experimental) Optional target topic for when the alarm goes into the OK state. Default: no notification sent

        :stability: experimental
        '''
        props = SnsAlarmActionStrategyProps(
            on_alarm_topic=on_alarm_topic,
            on_insufficient_data_topic=on_insufficient_data_topic,
            on_ok_topic=on_ok_topic,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="addAlarmActions")
    def add_alarm_actions(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.AlarmBase,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmActionStrategyProps(
            alarm=alarm,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(None, jsii.invoke(self, "addAlarmActions", [props]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onAlarmTopic")
    def _on_alarm_topic(self) -> monocdk.aws_sns.ITopic:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_sns.ITopic, jsii.get(self, "onAlarmTopic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onInsufficientDataTopic")
    def _on_insufficient_data_topic(self) -> typing.Optional[monocdk.aws_sns.ITopic]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_sns.ITopic], jsii.get(self, "onInsufficientDataTopic"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="onOkTopic")
    def _on_ok_topic(self) -> typing.Optional[monocdk.aws_sns.ITopic]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_sns.ITopic], jsii.get(self, "onOkTopic"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SnsAlarmActionStrategyProps",
    jsii_struct_bases=[],
    name_mapping={
        "on_alarm_topic": "onAlarmTopic",
        "on_insufficient_data_topic": "onInsufficientDataTopic",
        "on_ok_topic": "onOkTopic",
    },
)
class SnsAlarmActionStrategyProps:
    def __init__(
        self,
        *,
        on_alarm_topic: monocdk.aws_sns.ITopic,
        on_insufficient_data_topic: typing.Optional[monocdk.aws_sns.ITopic] = None,
        on_ok_topic: typing.Optional[monocdk.aws_sns.ITopic] = None,
    ) -> None:
        '''
        :param on_alarm_topic: (experimental) Target topic used when the alarm is triggered.
        :param on_insufficient_data_topic: (experimental) Optional target topic for when the alarm goes into the INSUFFICIENT_DATA state. Default: no notification sent
        :param on_ok_topic: (experimental) Optional target topic for when the alarm goes into the OK state. Default: no notification sent

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "on_alarm_topic": on_alarm_topic,
        }
        if on_insufficient_data_topic is not None:
            self._values["on_insufficient_data_topic"] = on_insufficient_data_topic
        if on_ok_topic is not None:
            self._values["on_ok_topic"] = on_ok_topic

    @builtins.property
    def on_alarm_topic(self) -> monocdk.aws_sns.ITopic:
        '''(experimental) Target topic used when the alarm is triggered.

        :stability: experimental
        '''
        result = self._values.get("on_alarm_topic")
        assert result is not None, "Required property 'on_alarm_topic' is missing"
        return typing.cast(monocdk.aws_sns.ITopic, result)

    @builtins.property
    def on_insufficient_data_topic(self) -> typing.Optional[monocdk.aws_sns.ITopic]:
        '''(experimental) Optional target topic for when the alarm goes into the INSUFFICIENT_DATA state.

        :default: no notification sent

        :stability: experimental
        '''
        result = self._values.get("on_insufficient_data_topic")
        return typing.cast(typing.Optional[monocdk.aws_sns.ITopic], result)

    @builtins.property
    def on_ok_topic(self) -> typing.Optional[monocdk.aws_sns.ITopic]:
        '''(experimental) Optional target topic for when the alarm goes into the OK state.

        :default: no notification sent

        :stability: experimental
        '''
        result = self._values.get("on_ok_topic")
        return typing.cast(typing.Optional[monocdk.aws_sns.ITopic], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsAlarmActionStrategyProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsTopicMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SnsTopicMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        topic: monocdk.aws_sns.ITopic,
    ) -> None:
        '''
        :param metric_factory: -
        :param topic: 

        :stability: experimental
        '''
        props = SnsTopicMetricFactoryProps(topic=topic)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricAverageMessageSizeInBytes")
    def metric_average_message_size_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageMessageSizeInBytes", []))

    @jsii.member(jsii_name="metricIncomingMessageCount")
    def metric_incoming_message_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIncomingMessageCount", []))

    @jsii.member(jsii_name="metricNumberOfNotificationsFailed")
    def metric_number_of_notifications_failed(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNumberOfNotificationsFailed", []))

    @jsii.member(jsii_name="metricOutgoingMessageCount")
    def metric_outgoing_message_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricOutgoingMessageCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topic")
    def _topic(self) -> monocdk.aws_sns.ITopic:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_sns.ITopic, jsii.get(self, "topic"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SnsTopicMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"topic": "topic"},
)
class SnsTopicMetricFactoryProps:
    def __init__(self, *, topic: monocdk.aws_sns.ITopic) -> None:
        '''
        :param topic: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "topic": topic,
        }

    @builtins.property
    def topic(self) -> monocdk.aws_sns.ITopic:
        '''
        :stability: experimental
        '''
        result = self._values.get("topic")
        assert result is not None, "Required property 'topic' is missing"
        return typing.cast(monocdk.aws_sns.ITopic, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsTopicMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsTopicMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SnsTopicMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_max_number_of_messages_published_alarm: typing.Optional[typing.Mapping[builtins.str, HighMessagesPublishedThreshold]] = None,
        add_message_notifications_failed_alarm: typing.Optional[typing.Mapping[builtins.str, NotificationsFailedThreshold]] = None,
        add_min_number_of_messages_published_alarm: typing.Optional[typing.Mapping[builtins.str, LowMessagesPublishedThreshold]] = None,
        topic: monocdk.aws_sns.ITopic,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_max_number_of_messages_published_alarm: 
        :param add_message_notifications_failed_alarm: 
        :param add_min_number_of_messages_published_alarm: 
        :param topic: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SnsTopicMonitoringProps(
            add_max_number_of_messages_published_alarm=add_max_number_of_messages_published_alarm,
            add_message_notifications_failed_alarm=add_message_notifications_failed_alarm,
            add_min_number_of_messages_published_alarm=add_min_number_of_messages_published_alarm,
            topic=topic,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createMessageCountWidget")
    def _create_message_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMessageCountWidget", [width, height]))

    @jsii.member(jsii_name="createMessageFailedWidget")
    def _create_message_failed_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMessageFailedWidget", [width, height]))

    @jsii.member(jsii_name="createMessageSizeWidget")
    def _create_message_size_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMessageSizeWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedDeliveryAnnotations")
    def _failed_delivery_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "failedDeliveryAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingMessagesAnnotations")
    def _incoming_messages_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "incomingMessagesAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingMessagesMetric")
    def _incoming_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "incomingMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messagesFailedMetric")
    def _messages_failed_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "messagesFailedMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageSizeMetric")
    def _message_size_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "messageSizeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="outgoingMessagesMetric")
    def _outgoing_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "outgoingMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicAlarmFactory")
    def _topic_alarm_factory(self) -> "TopicAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("TopicAlarmFactory", jsii.get(self, "topicAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="topicUrl")
    def _topic_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "topicUrl"))


class SqsQueueMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SqsQueueMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        queue: monocdk.aws_sqs.IQueue,
    ) -> None:
        '''
        :param metric_factory: -
        :param queue: 

        :stability: experimental
        '''
        props = SqsQueueMetricFactoryProps(queue=queue)

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricApproximateAgeOfOldestMessageInSeconds")
    def metric_approximate_age_of_oldest_message_in_seconds(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricApproximateAgeOfOldestMessageInSeconds", []))

    @jsii.member(jsii_name="metricApproximateVisibleMessageCount")
    def metric_approximate_visible_message_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricApproximateVisibleMessageCount", []))

    @jsii.member(jsii_name="metricAverageMessageSizeInBytes")
    def metric_average_message_size_in_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricAverageMessageSizeInBytes", []))

    @jsii.member(jsii_name="metricConsumptionRate")
    def metric_consumption_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricConsumptionRate", []))

    @jsii.member(jsii_name="metricDeletedMessageCount")
    def metric_deleted_message_count(self) -> monocdk.aws_cloudwatch.Metric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricDeletedMessageCount", []))

    @jsii.member(jsii_name="metricIncomingMessageCount")
    def metric_incoming_message_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricIncomingMessageCount", []))

    @jsii.member(jsii_name="metricProductionRate")
    def metric_production_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProductionRate", []))

    @jsii.member(jsii_name="metricTimeToDrain")
    def metric_time_to_drain(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricTimeToDrain", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queue")
    def _queue(self) -> monocdk.aws_sqs.IQueue:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_sqs.IQueue, jsii.get(self, "queue"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SqsQueueMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={"queue": "queue"},
)
class SqsQueueMetricFactoryProps:
    def __init__(self, *, queue: monocdk.aws_sqs.IQueue) -> None:
        '''
        :param queue: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "queue": queue,
        }

    @builtins.property
    def queue(self) -> monocdk.aws_sqs.IQueue:
        '''
        :stability: experimental
        '''
        result = self._values.get("queue")
        assert result is not None, "Required property 'queue' is missing"
        return typing.cast(monocdk.aws_sqs.IQueue, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqsQueueMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqsQueueMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SqsQueueMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        props: "SqsQueueMonitoringProps",
        invoked_from_super: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param props: -
        :param invoked_from_super: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [scope, props, invoked_from_super])

    @jsii.member(jsii_name="createMessageAgeWidget")
    def _create_message_age_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMessageAgeWidget", [width, height]))

    @jsii.member(jsii_name="createMessageCountWidget")
    def _create_message_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMessageCountWidget", [width, height]))

    @jsii.member(jsii_name="createMessageSizeWidget")
    def _create_message_size_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMessageSizeWidget", [width, height]))

    @jsii.member(jsii_name="createProducerAndConsumerRateWidget")
    def _create_producer_and_consumer_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createProducerAndConsumerRateWidget", [width, height]))

    @jsii.member(jsii_name="createTimeToDrainWidget")
    def _create_time_to_drain_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTimeToDrainWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="resolveQueueName")
    def _resolve_queue_name(
        self,
        queue: monocdk.aws_sqs.IQueue,
    ) -> typing.Optional[builtins.str]:
        '''
        :param queue: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "resolveQueueName", [queue]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ageAnnotations")
    def _age_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "ageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="consumptionRateMetric")
    def _consumption_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "consumptionRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="countAnnotations")
    def _count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "countAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deletedMessagesMetric")
    def _deleted_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "deletedMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingMessagesMetric")
    def _incoming_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "incomingMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="messageSizeMetric")
    def _message_size_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "messageSizeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="oldestMessageAgeMetric")
    def _oldest_message_age_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "oldestMessageAgeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="productionRateMetric")
    def _production_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "productionRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueAlarmFactory")
    def _queue_alarm_factory(self) -> QueueAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(QueueAlarmFactory, jsii.get(self, "queueAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeToDrainAnnotations")
    def _time_to_drain_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "timeToDrainAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timeToDrainMetric")
    def _time_to_drain_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "timeToDrainMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="visibleMessagesMetric")
    def _visible_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "visibleMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="queueUrl")
    def _queue_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "queueUrl"))


class SqsQueueMonitoringWithDlq(
    SqsQueueMonitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.SqsQueueMonitoringWithDlq",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        dead_letter_queue: monocdk.aws_sqs.IQueue,
        add_dead_letter_queue_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        add_dead_letter_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_dead_letter_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_dead_letter_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        queue: monocdk.aws_sqs.IQueue,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        add_queue_max_time_to_drain_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]] = None,
        add_queue_min_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]] = None,
        add_queue_min_size_alarm: typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param dead_letter_queue: 
        :param add_dead_letter_queue_to_summary_dashboard: (experimental) Indicates whether the DLQ monitoring should be added to summary dashboard. Default: true
        :param add_dead_letter_queue_max_incoming_messages_alarm: 
        :param add_dead_letter_queue_max_message_age_alarm: 
        :param add_dead_letter_queue_max_size_alarm: 
        :param queue: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_queue_max_incoming_messages_alarm: 
        :param add_queue_max_message_age_alarm: 
        :param add_queue_max_size_alarm: 
        :param add_queue_max_time_to_drain_messages_alarm: 
        :param add_queue_min_incoming_messages_alarm: 
        :param add_queue_min_size_alarm: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SqsQueueMonitoringWithDlqProps(
            dead_letter_queue=dead_letter_queue,
            add_dead_letter_queue_to_summary_dashboard=add_dead_letter_queue_to_summary_dashboard,
            add_dead_letter_queue_max_incoming_messages_alarm=add_dead_letter_queue_max_incoming_messages_alarm,
            add_dead_letter_queue_max_message_age_alarm=add_dead_letter_queue_max_message_age_alarm,
            add_dead_letter_queue_max_size_alarm=add_dead_letter_queue_max_size_alarm,
            queue=queue,
            use_created_alarms=use_created_alarms,
            add_queue_max_incoming_messages_alarm=add_queue_max_incoming_messages_alarm,
            add_queue_max_message_age_alarm=add_queue_max_message_age_alarm,
            add_queue_max_size_alarm=add_queue_max_size_alarm,
            add_queue_max_time_to_drain_messages_alarm=add_queue_max_time_to_drain_messages_alarm,
            add_queue_min_incoming_messages_alarm=add_queue_min_incoming_messages_alarm,
            add_queue_min_size_alarm=add_queue_min_size_alarm,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createDeadLetterMessageAgeWidget")
    def _create_dead_letter_message_age_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDeadLetterMessageAgeWidget", [width, height]))

    @jsii.member(jsii_name="createDeadLetterMessageCountWidget")
    def _create_dead_letter_message_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDeadLetterMessageCountWidget", [width, height]))

    @jsii.member(jsii_name="createDeadLetterTitleWidget")
    def _create_dead_letter_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createDeadLetterTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="addDeadLetterQueueToSummaryDashboard")
    def _add_dead_letter_queue_to_summary_dashboard(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "addDeadLetterQueueToSummaryDashboard"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterAgeAnnotations")
    def _dead_letter_age_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "deadLetterAgeAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterCountAnnotations")
    def _dead_letter_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "deadLetterCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterQueueAlarmFactory")
    def _dead_letter_queue_alarm_factory(self) -> QueueAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(QueueAlarmFactory, jsii.get(self, "deadLetterQueueAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterQueueIncomingMessagesMetric")
    def _dead_letter_queue_incoming_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "deadLetterQueueIncomingMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterQueueOldestMessageAgeMetric")
    def _dead_letter_queue_oldest_message_age_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "deadLetterQueueOldestMessageAgeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterQueueVisibleMessagesMetric")
    def _dead_letter_queue_visible_messages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "deadLetterQueueVisibleMessagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterTitle")
    def _dead_letter_title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "deadLetterTitle"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="deadLetterUrl")
    def _dead_letter_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "deadLetterUrl"))


class StepFunctionActivityMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionActivityMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        activity: monocdk.aws_stepfunctions.IActivity,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param activity: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = StepFunctionActivityMetricFactoryProps(
            activity=activity, rate_computation_method=rate_computation_method
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricActivitiesFailed")
    def metric_activities_failed(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesFailed", []))

    @jsii.member(jsii_name="metricActivitiesFailedRate")
    def metric_activities_failed_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesFailedRate", []))

    @jsii.member(jsii_name="metricActivitiesHeartbeatTimedOut")
    def metric_activities_heartbeat_timed_out(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesHeartbeatTimedOut", []))

    @jsii.member(jsii_name="metricActivitiesScheduled")
    def metric_activities_scheduled(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesScheduled", []))

    @jsii.member(jsii_name="metricActivitiesStarted")
    def metric_activities_started(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesStarted", []))

    @jsii.member(jsii_name="metricActivitiesSucceeded")
    def metric_activities_succeeded(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesSucceeded", []))

    @jsii.member(jsii_name="metricActivitiesTimedOut")
    def metric_activities_timed_out(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivitiesTimedOut", []))

    @jsii.member(jsii_name="metricActivityRunTimeP50InMillis")
    def metric_activity_run_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityRunTimeP50InMillis", []))

    @jsii.member(jsii_name="metricActivityRunTimeP90InMillis")
    def metric_activity_run_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityRunTimeP90InMillis", []))

    @jsii.member(jsii_name="metricActivityRunTimeP99InMillis")
    def metric_activity_run_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityRunTimeP99InMillis", []))

    @jsii.member(jsii_name="metricActivityScheduleTimeP50InMillis")
    def metric_activity_schedule_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityScheduleTimeP50InMillis", []))

    @jsii.member(jsii_name="metricActivityScheduleTimeP90InMillis")
    def metric_activity_schedule_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityScheduleTimeP90InMillis", []))

    @jsii.member(jsii_name="metricActivityScheduleTimeP99InMillis")
    def metric_activity_schedule_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityScheduleTimeP99InMillis", []))

    @jsii.member(jsii_name="metricActivityTimeP50InMillis")
    def metric_activity_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityTimeP50InMillis", []))

    @jsii.member(jsii_name="metricActivityTimeP90InMillis")
    def metric_activity_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityTimeP90InMillis", []))

    @jsii.member(jsii_name="metricActivityTimeP99InMillis")
    def metric_activity_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActivityTimeP99InMillis", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> RateComputationMethod:
        '''
        :stability: experimental
        '''
        return typing.cast(RateComputationMethod, jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionActivityMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "activity": "activity",
        "rate_computation_method": "rateComputationMethod",
    },
)
class StepFunctionActivityMetricFactoryProps:
    def __init__(
        self,
        *,
        activity: monocdk.aws_stepfunctions.IActivity,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param activity: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "activity": activity,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def activity(self) -> monocdk.aws_stepfunctions.IActivity:
        '''
        :stability: experimental
        '''
        result = self._values.get("activity")
        assert result is not None, "Required property 'activity' is missing"
        return typing.cast(monocdk.aws_stepfunctions.IActivity, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionActivityMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StepFunctionActivityMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionActivityMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_activities_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_activities_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_activities_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        activity: monocdk.aws_stepfunctions.IActivity,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_activities_count_alarm: 
        :param add_failed_activities_rate_alarm: 
        :param add_timed_out_activities_count_alarm: 
        :param activity: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionActivityMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_activities_count_alarm=add_failed_activities_count_alarm,
            add_failed_activities_rate_alarm=add_failed_activities_rate_alarm,
            add_timed_out_activities_count_alarm=add_timed_out_activities_count_alarm,
            activity=activity,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAlarmFactory")
    def _duration_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "durationAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAnnotations")
    def _duration_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "durationAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedActivitiesMetric")
    def _failed_activities_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedActivitiesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedActivitiesRateMetric")
    def _failed_activities_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedActivitiesRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="heartbeatTimedOutActivitiesMetrics")
    def _heartbeat_timed_out_activities_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "heartbeatTimedOutActivitiesMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50DurationMetric")
    def _p50_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90DurationMetric")
    def _p90_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99DurationMetric")
    def _p99_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scheduledActivitiesMetric")
    def _scheduled_activities_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "scheduledActivitiesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startedActivitiesMetric")
    def _started_activities_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "startedActivitiesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="succeededActivitiesMetric")
    def _succeeded_activities_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "succeededActivitiesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timedOutActivitiesMetrics")
    def _timed_out_activities_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "timedOutActivitiesMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


class StepFunctionLambdaIntegrationMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionLambdaIntegrationMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        lambda_function: monocdk.aws_lambda.IFunction,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param lambda_function: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = StepFunctionLambdaIntegrationMetricFactoryProps(
            lambda_function=lambda_function,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricFunctionRunTimeP50InMillis")
    def metric_function_run_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionRunTimeP50InMillis", []))

    @jsii.member(jsii_name="metricFunctionRunTimeP90InMillis")
    def metric_function_run_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionRunTimeP90InMillis", []))

    @jsii.member(jsii_name="metricFunctionRunTimeP99InMillis")
    def metric_function_run_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionRunTimeP99InMillis", []))

    @jsii.member(jsii_name="metricFunctionScheduleTimeP50InMillis")
    def metric_function_schedule_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionScheduleTimeP50InMillis", []))

    @jsii.member(jsii_name="metricFunctionScheduleTimeP90InMillis")
    def metric_function_schedule_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionScheduleTimeP90InMillis", []))

    @jsii.member(jsii_name="metricFunctionScheduleTimeP99InMillis")
    def metric_function_schedule_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionScheduleTimeP99InMillis", []))

    @jsii.member(jsii_name="metricFunctionsFailed")
    def metric_functions_failed(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionsFailed", []))

    @jsii.member(jsii_name="metricFunctionsFailedRate")
    def metric_functions_failed_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionsFailedRate", []))

    @jsii.member(jsii_name="metricFunctionsScheduled")
    def metric_functions_scheduled(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionsScheduled", []))

    @jsii.member(jsii_name="metricFunctionsStarted")
    def metric_functions_started(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionsStarted", []))

    @jsii.member(jsii_name="metricFunctionsSucceeded")
    def metric_functions_succeeded(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionsSucceeded", []))

    @jsii.member(jsii_name="metricFunctionsTimedOut")
    def metric_functions_timed_out(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionsTimedOut", []))

    @jsii.member(jsii_name="metricFunctionTimeP50InMillis")
    def metric_function_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionTimeP50InMillis", []))

    @jsii.member(jsii_name="metricFunctionTimeP90InMillis")
    def metric_function_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionTimeP90InMillis", []))

    @jsii.member(jsii_name="metricFunctionTimeP99InMillis")
    def metric_function_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricFunctionTimeP99InMillis", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> RateComputationMethod:
        '''
        :stability: experimental
        '''
        return typing.cast(RateComputationMethod, jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionLambdaIntegrationMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "lambda_function": "lambdaFunction",
        "rate_computation_method": "rateComputationMethod",
    },
)
class StepFunctionLambdaIntegrationMetricFactoryProps:
    def __init__(
        self,
        *,
        lambda_function: monocdk.aws_lambda.IFunction,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param lambda_function: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "lambda_function": lambda_function,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def lambda_function(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        result = self._values.get("lambda_function")
        assert result is not None, "Required property 'lambda_function' is missing"
        return typing.cast(monocdk.aws_lambda.IFunction, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionLambdaIntegrationMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StepFunctionLambdaIntegrationMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionLambdaIntegrationMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_functions_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_functions_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_functions_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        lambda_function: monocdk.aws_lambda.IFunction,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_functions_count_alarm: 
        :param add_failed_functions_rate_alarm: 
        :param add_timed_out_functions_count_alarm: 
        :param lambda_function: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionLambdaIntegrationMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_functions_count_alarm=add_failed_functions_count_alarm,
            add_failed_functions_rate_alarm=add_failed_functions_rate_alarm,
            add_timed_out_functions_count_alarm=add_timed_out_functions_count_alarm,
            lambda_function=lambda_function,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAlarmFactory")
    def _duration_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "durationAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAnnotations")
    def _duration_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "durationAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedFunctionRateMetric")
    def _failed_function_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedFunctionRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedFunctionsMetric")
    def _failed_functions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedFunctionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50DurationMetric")
    def _p50_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90DurationMetric")
    def _p90_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99DurationMetric")
    def _p99_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scheduledFunctionsMetric")
    def _scheduled_functions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "scheduledFunctionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startedFunctionsMetric")
    def _started_functions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "startedFunctionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="succeededFunctionsMetric")
    def _succeeded_functions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "succeededFunctionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timedOutFunctionsMetrics")
    def _timed_out_functions_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "timedOutFunctionsMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionUrl")
    def _function_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionUrl"))


class StepFunctionMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        state_machine: monocdk.aws_stepfunctions.IStateMachine,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param state_machine: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = StepFunctionMetricFactoryProps(
            state_machine=state_machine,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricExecutionsAborted")
    def metric_executions_aborted(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionsAborted", []))

    @jsii.member(jsii_name="metricExecutionsFailed")
    def metric_executions_failed(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionsFailed", []))

    @jsii.member(jsii_name="metricExecutionsFailedRate")
    def metric_executions_failed_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionsFailedRate", []))

    @jsii.member(jsii_name="metricExecutionsStarted")
    def metric_executions_started(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionsStarted", []))

    @jsii.member(jsii_name="metricExecutionsSucceeded")
    def metric_executions_succeeded(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionsSucceeded", []))

    @jsii.member(jsii_name="metricExecutionsTimedOut")
    def metric_executions_timed_out(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionsTimedOut", []))

    @jsii.member(jsii_name="metricExecutionThrottled")
    def metric_execution_throttled(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionThrottled", []))

    @jsii.member(jsii_name="metricExecutionTimeP50InMillis")
    def metric_execution_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionTimeP50InMillis", []))

    @jsii.member(jsii_name="metricExecutionTimeP90InMillis")
    def metric_execution_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionTimeP90InMillis", []))

    @jsii.member(jsii_name="metricExecutionTimeP99InMillis")
    def metric_execution_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricExecutionTimeP99InMillis", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> RateComputationMethod:
        '''
        :stability: experimental
        '''
        return typing.cast(RateComputationMethod, jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "state_machine": "stateMachine",
        "rate_computation_method": "rateComputationMethod",
    },
)
class StepFunctionMetricFactoryProps:
    def __init__(
        self,
        *,
        state_machine: monocdk.aws_stepfunctions.IStateMachine,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param state_machine: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "state_machine": state_machine,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def state_machine(self) -> monocdk.aws_stepfunctions.IStateMachine:
        '''
        :stability: experimental
        '''
        result = self._values.get("state_machine")
        assert result is not None, "Required property 'state_machine' is missing"
        return typing.cast(monocdk.aws_stepfunctions.IStateMachine, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StepFunctionMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_aborted_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_execution_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_min_started_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, MinRunningTaskCountThreshold]] = None,
        add_throttled_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_timed_out_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        state_machine: monocdk.aws_stepfunctions.IStateMachine,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_aborted_execution_count_alarm: 
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_execution_count_alarm: 
        :param add_failed_execution_rate_alarm: 
        :param add_min_started_execution_count_alarm: (experimental) Add minimum started execution count alarm for the stepfunctions.
        :param add_throttled_execution_count_alarm: 
        :param add_timed_out_execution_count_alarm: 
        :param state_machine: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionMonitoringProps(
            add_aborted_execution_count_alarm=add_aborted_execution_count_alarm,
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_execution_count_alarm=add_failed_execution_count_alarm,
            add_failed_execution_rate_alarm=add_failed_execution_rate_alarm,
            add_min_started_execution_count_alarm=add_min_started_execution_count_alarm,
            add_throttled_execution_count_alarm=add_throttled_execution_count_alarm,
            add_timed_out_execution_count_alarm=add_timed_out_execution_count_alarm,
            state_machine=state_machine,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="abortedExecutionsMetric")
    def _aborted_executions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "abortedExecutionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAlarmFactory")
    def _duration_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "durationAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAnnotations")
    def _duration_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "durationAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedExecutionRateMetric")
    def _failed_execution_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedExecutionRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedExecutionsMetric")
    def _failed_executions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedExecutionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50DurationMetric")
    def _p50_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90DurationMetric")
    def _p90_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99DurationMetric")
    def _p99_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startedExecutionsMetric")
    def _started_executions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "startedExecutionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="succeededExecutionsMetric")
    def _succeeded_executions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "succeededExecutionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAlarmFactory")
    def _task_health_alarm_factory(self) -> "TaskHealthAlarmFactory":
        '''
        :stability: experimental
        '''
        return typing.cast("TaskHealthAlarmFactory", jsii.get(self, "taskHealthAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throttledExecutionsMetric")
    def _throttled_executions_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "throttledExecutionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timedOutExecutionsMetrics")
    def _timed_out_executions_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "timedOutExecutionsMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="stateMachineUrl")
    def _state_machine_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "stateMachineUrl"))


class StepFunctionServiceIntegrationMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionServiceIntegrationMetricFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        service_integration_resource_arn: builtins.str,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param metric_factory: -
        :param service_integration_resource_arn: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        props = StepFunctionServiceIntegrationMetricFactoryProps(
            service_integration_resource_arn=service_integration_resource_arn,
            rate_computation_method=rate_computation_method,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricServiceIntegrationRunTimeP50InMillis")
    def metric_service_integration_run_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationRunTimeP50InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationRunTimeP90InMillis")
    def metric_service_integration_run_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationRunTimeP90InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationRunTimeP99InMillis")
    def metric_service_integration_run_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationRunTimeP99InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationScheduleTimeP50InMillis")
    def metric_service_integration_schedule_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationScheduleTimeP50InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationScheduleTimeP90InMillis")
    def metric_service_integration_schedule_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationScheduleTimeP90InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationScheduleTimeP99InMillis")
    def metric_service_integration_schedule_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationScheduleTimeP99InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationsFailed")
    def metric_service_integrations_failed(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationsFailed", []))

    @jsii.member(jsii_name="metricServiceIntegrationsFailedRate")
    def metric_service_integrations_failed_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationsFailedRate", []))

    @jsii.member(jsii_name="metricServiceIntegrationsScheduled")
    def metric_service_integrations_scheduled(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationsScheduled", []))

    @jsii.member(jsii_name="metricServiceIntegrationsStarted")
    def metric_service_integrations_started(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationsStarted", []))

    @jsii.member(jsii_name="metricServiceIntegrationsSucceeded")
    def metric_service_integrations_succeeded(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationsSucceeded", []))

    @jsii.member(jsii_name="metricServiceIntegrationsTimedOut")
    def metric_service_integrations_timed_out(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationsTimedOut", []))

    @jsii.member(jsii_name="metricServiceIntegrationTimeP50InMillis")
    def metric_service_integration_time_p50_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationTimeP50InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationTimeP90InMillis")
    def metric_service_integration_time_p90_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationTimeP90InMillis", []))

    @jsii.member(jsii_name="metricServiceIntegrationTimeP99InMillis")
    def metric_service_integration_time_p99_in_millis(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricServiceIntegrationTimeP99InMillis", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dimensions")
    def _dimensions(self) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "dimensions"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="rateComputationMethod")
    def _rate_computation_method(self) -> RateComputationMethod:
        '''
        :stability: experimental
        '''
        return typing.cast(RateComputationMethod, jsii.get(self, "rateComputationMethod"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionServiceIntegrationMetricFactoryProps",
    jsii_struct_bases=[],
    name_mapping={
        "service_integration_resource_arn": "serviceIntegrationResourceArn",
        "rate_computation_method": "rateComputationMethod",
    },
)
class StepFunctionServiceIntegrationMetricFactoryProps:
    def __init__(
        self,
        *,
        service_integration_resource_arn: builtins.str,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
    ) -> None:
        '''
        :param service_integration_resource_arn: 
        :param rate_computation_method: Default: average

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "service_integration_resource_arn": service_integration_resource_arn,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method

    @builtins.property
    def service_integration_resource_arn(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("service_integration_resource_arn")
        assert result is not None, "Required property 'service_integration_resource_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionServiceIntegrationMetricFactoryProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StepFunctionServiceIntegrationMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.StepFunctionServiceIntegrationMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_service_integrations_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_service_integrations_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_service_integrations_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        service_integration_resource_arn: builtins.str,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_service_integrations_count_alarm: 
        :param add_failed_service_integrations_rate_alarm: 
        :param add_timed_out_service_integrations_count_alarm: 
        :param service_integration_resource_arn: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionServiceIntegrationMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_service_integrations_count_alarm=add_failed_service_integrations_count_alarm,
            add_failed_service_integrations_rate_alarm=add_failed_service_integrations_rate_alarm,
            add_timed_out_service_integrations_count_alarm=add_timed_out_service_integrations_count_alarm,
            service_integration_resource_arn=service_integration_resource_arn,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAlarmFactory")
    def _duration_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "durationAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAnnotations")
    def _duration_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "durationAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedServiceIntegrationRateMetric")
    def _failed_service_integration_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedServiceIntegrationRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedServiceIntegrationsMetric")
    def _failed_service_integrations_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedServiceIntegrationsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50DurationMetric")
    def _p50_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90DurationMetric")
    def _p90_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99DurationMetric")
    def _p99_duration_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99DurationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="scheduledServiceIntegrationsMetric")
    def _scheduled_service_integrations_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "scheduledServiceIntegrationsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="startedServiceIntegrationsMetric")
    def _started_service_integrations_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "startedServiceIntegrationsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="succeededServiceIntegrationsMetric")
    def _succeeded_service_integrations_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "succeededServiceIntegrationsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="timedOutServiceIntegrationsMetrics")
    def _timed_out_service_integrations_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "timedOutServiceIntegrationsMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


@jsii.enum(jsii_type="cdk-monitoring-constructs.StorageType")
class StorageType(enum.Enum):
    '''
    :stability: experimental
    '''

    DEEP_ARCHIVE_OBJECT_OVERHEAD = "DEEP_ARCHIVE_OBJECT_OVERHEAD"
    '''
    :stability: experimental
    '''
    DEEP_ARCHIVE_S3_OBJECT_OVERHEAD = "DEEP_ARCHIVE_S3_OBJECT_OVERHEAD"
    '''
    :stability: experimental
    '''
    DEEP_ARCHIVE_STAGING_STORAGE = "DEEP_ARCHIVE_STAGING_STORAGE"
    '''
    :stability: experimental
    '''
    DEEP_ARCHIVE_STORAGE = "DEEP_ARCHIVE_STORAGE"
    '''
    :stability: experimental
    '''
    GLACIER_OBJECT_OVERHEAD = "GLACIER_OBJECT_OVERHEAD"
    '''
    :stability: experimental
    '''
    GLACIER_S3_OBJECT_OVERHEAD = "GLACIER_S3_OBJECT_OVERHEAD"
    '''
    :stability: experimental
    '''
    GLACIER_STAGING_STORAGE = "GLACIER_STAGING_STORAGE"
    '''
    :stability: experimental
    '''
    GLACIER_STORAGE = "GLACIER_STORAGE"
    '''
    :stability: experimental
    '''
    INTELLIGENT_TIERING_FA_STORAGE = "INTELLIGENT_TIERING_FA_STORAGE"
    '''
    :stability: experimental
    '''
    INTELLIGENT_TIERING_IA_STORAGE = "INTELLIGENT_TIERING_IA_STORAGE"
    '''
    :stability: experimental
    '''
    ONE_ZONE_IA_SIZE_OVERHEAD = "ONE_ZONE_IA_SIZE_OVERHEAD"
    '''
    :stability: experimental
    '''
    ONE_ZONE_IA_STORAGE = "ONE_ZONE_IA_STORAGE"
    '''
    :stability: experimental
    '''
    REDUCED_REDUNDANCY_STORAGE = "REDUCED_REDUNDANCY_STORAGE"
    '''
    :stability: experimental
    '''
    STANDARD_IA_SIZE_OVERHEAD = "STANDARD_IA_SIZE_OVERHEAD"
    '''
    :stability: experimental
    '''
    STANDARD_IA_STORAGE = "STANDARD_IA_STORAGE"
    '''
    :stability: experimental
    '''
    STANDARD_STORAGE = "STANDARD_STORAGE"
    '''
    :stability: experimental
    '''


class TaskHealthAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.TaskHealthAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addAvailabilityAlarm")
    def add_availability_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "AvailabilityThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addAvailabilityAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addHealthyTaskCountAlarm")
    def add_healthy_task_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: HealthyTaskCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addHealthyTaskCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addHealthyTaskPercentAlarm")
    def add_healthy_task_percent_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: HealthyTaskPercentThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addHealthyTaskPercentAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMinRunningTaskCountAlarm")
    def add_min_running_task_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MinRunningTaskCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinRunningTaskCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addRunningTaskCountAlarm")
    def add_running_task_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: RunningTaskCountThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addRunningTaskCountAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addRunningTaskRateAlarm")
    def add_running_task_rate_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: RunningTaskRateThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addRunningTaskRateAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addUnhealthyTaskCountAlarm")
    def add_unhealthy_task_count_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UnhealthyTaskCountThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addUnhealthyTaskCountAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ThrottledEventsThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_throttled_events_threshold": "maxThrottledEventsThreshold",
    },
)
class ThrottledEventsThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_throttled_events_threshold: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_throttled_events_threshold: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_throttled_events_threshold": max_throttled_events_threshold,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_throttled_events_threshold(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_throttled_events_threshold")
        assert result is not None, "Required property 'max_throttled_events_threshold' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ThrottledEventsThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ThroughputAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ThroughputAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addMinProcessedBytesAlarm")
    def add_min_processed_bytes_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: MinProcessedBytesThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinProcessedBytesAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class TopicAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.TopicAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addMaxMessagesPublishedAlarm")
    def add_max_messages_published_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: HighMessagesPublishedThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxMessagesPublishedAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMessageNotificationsFailedAlarm")
    def add_message_notifications_failed_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: NotificationsFailedThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMessageNotificationsFailedAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMinMessagesPublishedAlarm")
    def add_min_messages_published_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: LowMessagesPublishedThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinMessagesPublishedAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


class TpsAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.TpsAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addMaxTpsAlarm")
    def add_max_tps_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: HighTpsThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxTpsAlarm", [metric, props, disambiguator]))

    @jsii.member(jsii_name="addMinTpsAlarm")
    def add_min_tps_alarm(
        self,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: LowTpsThreshold,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMinTpsAlarm", [metric, props, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.UnhealthyTaskCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_unhealthy_tasks": "maxUnhealthyTasks",
    },
)
class UnhealthyTaskCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_unhealthy_tasks: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_unhealthy_tasks: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_unhealthy_tasks": max_unhealthy_tasks,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_unhealthy_tasks(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_unhealthy_tasks")
        assert result is not None, "Required property 'max_unhealthy_tasks' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UnhealthyTaskCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class UsageAlarmFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.UsageAlarmFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self, alarm_factory: AlarmFactory) -> None:
        '''
        :param alarm_factory: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [alarm_factory])

    @jsii.member(jsii_name="addMaxCpuUsagePercentAlarm")
    def add_max_cpu_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxCpuUsagePercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxDiskUsagePercentAlarm")
    def add_max_disk_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxDiskUsagePercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxFileDescriptorPercentAlarm")
    def add_max_file_descriptor_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxFileDescriptorPercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxHeapMemoryAfterGCUsagePercentAlarm")
    def add_max_heap_memory_after_gc_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxHeapMemoryAfterGCUsagePercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxMasterCpuUsagePercentAlarm")
    def add_max_master_cpu_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxMasterCpuUsagePercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxMasterMemoryUsagePercentAlarm")
    def add_max_master_memory_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxMasterMemoryUsagePercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxMemoryUsagePercentAlarm")
    def add_max_memory_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxMemoryUsagePercentAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMaxThreadCountUsageAlarm")
    def add_max_thread_count_usage_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageCountThreshold",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMaxThreadCountUsageAlarm", [percent_metric, props, disambiguator]))

    @jsii.member(jsii_name="addMemoryUsagePercentAlarm")
    def add_memory_usage_percent_alarm(
        self,
        percent_metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        props: "UsageThreshold",
        usage_type: "UsageType",
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> AlarmWithAnnotation:
        '''
        :param percent_metric: -
        :param props: -
        :param usage_type: -
        :param disambiguator: -

        :stability: experimental
        '''
        return typing.cast(AlarmWithAnnotation, jsii.invoke(self, "addMemoryUsagePercentAlarm", [percent_metric, props, usage_type, disambiguator]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.UsageCountThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_usage_count": "maxUsageCount",
    },
)
class UsageCountThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_usage_count: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_usage_count: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_usage_count": max_usage_count,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_usage_count(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_usage_count")
        assert result is not None, "Required property 'max_usage_count' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UsageCountThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.UsageThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_usage_percent": "maxUsagePercent",
    },
)
class UsageThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_usage_percent: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_usage_percent: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_usage_percent": max_usage_percent,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_usage_percent(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_usage_percent")
        assert result is not None, "Required property 'max_usage_percent' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UsageThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-monitoring-constructs.UsageType")
class UsageType(enum.Enum):
    '''
    :stability: experimental
    '''

    P50 = "P50"
    '''
    :stability: experimental
    '''
    P70 = "P70"
    '''
    :stability: experimental
    '''
    P90 = "P90"
    '''
    :stability: experimental
    '''
    P99 = "P99"
    '''
    :stability: experimental
    '''
    P999 = "P999"
    '''
    :stability: experimental
    '''
    P9999 = "P9999"
    '''
    :stability: experimental
    '''
    P100 = "P100"
    '''
    :stability: experimental
    '''
    AVERAGE = "AVERAGE"
    '''
    :stability: experimental
    '''
    MAX = "MAX"
    '''
    :stability: experimental
    '''


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.UserProvidedNames",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
    },
)
class UserProvidedNames:
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "UserProvidedNames(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(monocdk.aws_cloudwatch.IMetric)
class XaxrMathExpression(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.XaxrMathExpression",
):
    '''(experimental) Custom wrapper class for MathExpression that supports account and region specification.

    :see: https://github.com/aws/aws-cdk/issues/9039
    :stability: experimental
    '''

    def __init__(
        self,
        *,
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
        expression: builtins.str,
        using_metrics: typing.Mapping[builtins.str, monocdk.aws_cloudwatch.IMetric],
        color: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> None:
        '''
        :param account: (experimental) (experimental) Account which this metric comes from. Default: - Deployment account.
        :param region: (experimental) (experimental) Region which this metric comes from. Default: - Deployment region.
        :param expression: (experimental) The expression defining the metric.
        :param using_metrics: (experimental) The metrics used in the expression, in a map. The key is the identifier that represents the given metric in the expression, and the value is the actual Metric object.
        :param color: (experimental) Color for this metric when added to a Graph in a Dashboard. Default: - Automatic color
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - Expression value is used as label
        :param period: (experimental) The period over which the expression's statistics are applied. This period overrides all periods in the metrics used in this math expression. Default: Duration.minutes(5)

        :stability: experimental
        '''
        props = XaxrMathExpressionProps(
            account=account,
            region=region,
            expression=expression,
            using_metrics=using_metrics,
            color=color,
            label=label,
            period=period,
        )

        jsii.create(self.__class__, self, [props])

    @jsii.member(jsii_name="toAlarmConfig")
    def to_alarm_config(self) -> monocdk.aws_cloudwatch.MetricAlarmConfig:
        '''(experimental) (deprecated) Turn this metric object into an alarm configuration.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.MetricAlarmConfig, jsii.invoke(self, "toAlarmConfig", []))

    @jsii.member(jsii_name="toGraphConfig")
    def to_graph_config(self) -> monocdk.aws_cloudwatch.MetricGraphConfig:
        '''(experimental) (deprecated) Turn this metric object into a graph configuration.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.MetricGraphConfig, jsii.invoke(self, "toGraphConfig", []))

    @jsii.member(jsii_name="toMetricConfig")
    def to_metric_config(self) -> monocdk.aws_cloudwatch.MetricConfig:
        '''(experimental) (experimental) Inspect the details of the metric object.

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.MetricConfig, jsii.invoke(self, "toMetricConfig", []))

    @jsii.member(jsii_name="with")
    def with_(
        self,
        *,
        color: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
    ) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :param color: (experimental) Color for this metric when added to a Graph in a Dashboard. Default: - Automatic color
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - Expression value is used as label
        :param period: (experimental) The period over which the expression's statistics are applied. This period overrides all periods in the metrics used in this math expression. Default: Duration.minutes(5)

        :stability: experimental
        '''
        options = monocdk.aws_cloudwatch.MathExpressionOptions(
            color=color, label=label, period=period
        )

        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.invoke(self, "with", [options]))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.XaxrMathExpressionProps",
    jsii_struct_bases=[monocdk.aws_cloudwatch.MathExpressionProps],
    name_mapping={
        "color": "color",
        "label": "label",
        "period": "period",
        "expression": "expression",
        "using_metrics": "usingMetrics",
        "account": "account",
        "region": "region",
    },
)
class XaxrMathExpressionProps(monocdk.aws_cloudwatch.MathExpressionProps):
    def __init__(
        self,
        *,
        color: typing.Optional[builtins.str] = None,
        label: typing.Optional[builtins.str] = None,
        period: typing.Optional[monocdk.Duration] = None,
        expression: builtins.str,
        using_metrics: typing.Mapping[builtins.str, monocdk.aws_cloudwatch.IMetric],
        account: typing.Optional[builtins.str] = None,
        region: typing.Optional[builtins.str] = None,
    ) -> None:
        '''(experimental) Custom wrapper class for MathExpressionProps that supports account and region customization.

        :param color: (experimental) Color for this metric when added to a Graph in a Dashboard. Default: - Automatic color
        :param label: (experimental) Label for this metric when added to a Graph in a Dashboard. Default: - Expression value is used as label
        :param period: (experimental) The period over which the expression's statistics are applied. This period overrides all periods in the metrics used in this math expression. Default: Duration.minutes(5)
        :param expression: (experimental) The expression defining the metric.
        :param using_metrics: (experimental) The metrics used in the expression, in a map. The key is the identifier that represents the given metric in the expression, and the value is the actual Metric object.
        :param account: (experimental) (experimental) Account which this metric comes from. Default: - Deployment account.
        :param region: (experimental) (experimental) Region which this metric comes from. Default: - Deployment region.

        :see: https://github.com/aws/aws-cdk/issues/9039
        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "expression": expression,
            "using_metrics": using_metrics,
        }
        if color is not None:
            self._values["color"] = color
        if label is not None:
            self._values["label"] = label
        if period is not None:
            self._values["period"] = period
        if account is not None:
            self._values["account"] = account
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def color(self) -> typing.Optional[builtins.str]:
        '''(experimental) Color for this metric when added to a Graph in a Dashboard.

        :default: - Automatic color

        :stability: experimental
        '''
        result = self._values.get("color")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def label(self) -> typing.Optional[builtins.str]:
        '''(experimental) Label for this metric when added to a Graph in a Dashboard.

        :default: - Expression value is used as label

        :stability: experimental
        '''
        result = self._values.get("label")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) The period over which the expression's statistics are applied.

        This period overrides all periods in the metrics used in this
        math expression.

        :default: Duration.minutes(5)

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def expression(self) -> builtins.str:
        '''(experimental) The expression defining the metric.

        :stability: experimental
        '''
        result = self._values.get("expression")
        assert result is not None, "Required property 'expression' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def using_metrics(
        self,
    ) -> typing.Mapping[builtins.str, monocdk.aws_cloudwatch.IMetric]:
        '''(experimental) The metrics used in the expression, in a map.

        The key is the identifier that represents the given metric in the
        expression, and the value is the actual Metric object.

        :stability: experimental
        '''
        result = self._values.get("using_metrics")
        assert result is not None, "Required property 'using_metrics' is missing"
        return typing.cast(typing.Mapping[builtins.str, monocdk.aws_cloudwatch.IMetric], result)

    @builtins.property
    def account(self) -> typing.Optional[builtins.str]:
        '''(experimental) (experimental) Account which this metric comes from.

        :default: - Deployment account.

        :stability: experimental
        '''
        result = self._values.get("account")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def region(self) -> typing.Optional[builtins.str]:
        '''(experimental) (experimental) Region which this metric comes from.

        :default: - Deployment region.

        :stability: experimental
        '''
        result = self._values.get("region")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "XaxrMathExpressionProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmActionStrategyProps",
    jsii_struct_bases=[AlarmMetadata],
    name_mapping={
        "action": "action",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "dedupe_string": "dedupeString",
        "disambiguator": "disambiguator",
        "alarm": "alarm",
    },
)
class AlarmActionStrategyProps(AlarmMetadata):
    def __init__(
        self,
        *,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
        alarm: monocdk.aws_cloudwatch.AlarmBase,
    ) -> None:
        '''(experimental) Properties necessary to append actions to an alarm.

        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 
        :param alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "alarm": alarm,
        }
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if dedupe_string is not None:
            self._values["dedupe_string"] = dedupe_string
        if disambiguator is not None:
            self._values["disambiguator"] = disambiguator

    @builtins.property
    def action(self) -> IAlarmActionStrategy:
        '''
        :stability: experimental
        '''
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return typing.cast(IAlarmActionStrategy, result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dedupe_string(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dedupe_string")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disambiguator(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm(self) -> monocdk.aws_cloudwatch.AlarmBase:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm")
        assert result is not None, "Required property 'alarm' is missing"
        return typing.cast(monocdk.aws_cloudwatch.AlarmBase, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmActionStrategyProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AlarmAnnotationStrategyProps",
    jsii_struct_bases=[AlarmMetadata],
    name_mapping={
        "action": "action",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "dedupe_string": "dedupeString",
        "disambiguator": "disambiguator",
        "alarm": "alarm",
        "comparison_operator": "comparisonOperator",
        "datapoints_to_alarm": "datapointsToAlarm",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "metric": "metric",
        "threshold": "threshold",
    },
)
class AlarmAnnotationStrategyProps(AlarmMetadata):
    def __init__(
        self,
        *,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
    ) -> None:
        '''
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 
        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "action": action,
            "alarm": alarm,
            "comparison_operator": comparison_operator,
            "datapoints_to_alarm": datapoints_to_alarm,
            "evaluation_periods": evaluation_periods,
            "fill_alarm_range": fill_alarm_range,
            "metric": metric,
            "threshold": threshold,
        }
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if dedupe_string is not None:
            self._values["dedupe_string"] = dedupe_string
        if disambiguator is not None:
            self._values["disambiguator"] = disambiguator

    @builtins.property
    def action(self) -> IAlarmActionStrategy:
        '''
        :stability: experimental
        '''
        result = self._values.get("action")
        assert result is not None, "Required property 'action' is missing"
        return typing.cast(IAlarmActionStrategy, result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def dedupe_string(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("dedupe_string")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def disambiguator(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("disambiguator")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm(self) -> monocdk.aws_cloudwatch.Alarm:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm")
        assert result is not None, "Required property 'alarm' is missing"
        return typing.cast(monocdk.aws_cloudwatch.Alarm, result)

    @builtins.property
    def comparison_operator(self) -> monocdk.aws_cloudwatch.ComparisonOperator:
        '''
        :stability: experimental
        '''
        result = self._values.get("comparison_operator")
        assert result is not None, "Required property 'comparison_operator' is missing"
        return typing.cast(monocdk.aws_cloudwatch.ComparisonOperator, result)

    @builtins.property
    def datapoints_to_alarm(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        assert result is not None, "Required property 'datapoints_to_alarm' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def evaluation_periods(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        assert result is not None, "Required property 'evaluation_periods' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def fill_alarm_range(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        assert result is not None, "Required property 'fill_alarm_range' is missing"
        return typing.cast(builtins.bool, result)

    @builtins.property
    def metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        result = self._values.get("metric")
        assert result is not None, "Required property 'metric' is missing"
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], result)

    @builtins.property
    def threshold(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("threshold")
        assert result is not None, "Required property 'threshold' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlarmAnnotationStrategyProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AnomalyDetectionThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "alarm_when_above_the_band": "alarmWhenAboveTheBand",
        "alarm_when_below_the_band": "alarmWhenBelowTheBand",
        "standard_deviation_for_alarm": "standardDeviationForAlarm",
        "additional_description": "additionalDescription",
    },
)
class AnomalyDetectionThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        alarm_when_above_the_band: builtins.bool,
        alarm_when_below_the_band: builtins.bool,
        standard_deviation_for_alarm: jsii.Number,
        additional_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param alarm_when_above_the_band: 
        :param alarm_when_below_the_band: 
        :param standard_deviation_for_alarm: 
        :param additional_description: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "alarm_when_above_the_band": alarm_when_above_the_band,
            "alarm_when_below_the_band": alarm_when_below_the_band,
            "standard_deviation_for_alarm": standard_deviation_for_alarm,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override
        if additional_description is not None:
            self._values["additional_description"] = additional_description

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def alarm_when_above_the_band(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_when_above_the_band")
        assert result is not None, "Required property 'alarm_when_above_the_band' is missing"
        return typing.cast(builtins.bool, result)

    @builtins.property
    def alarm_when_below_the_band(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        result = self._values.get("alarm_when_below_the_band")
        assert result is not None, "Required property 'alarm_when_below_the_band' is missing"
        return typing.cast(builtins.bool, result)

    @builtins.property
    def standard_deviation_for_alarm(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("standard_deviation_for_alarm")
        assert result is not None, "Required property 'standard_deviation_for_alarm' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def additional_description(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("additional_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AnomalyDetectionThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ApiGatewayMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add4_xx_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4_xx_error_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5_xx_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5_xx_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        api: monocdk.aws_apigateway.RestApiBase,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add4_xx_error_count_alarm: 
        :param add4_xx_error_rate_alarm: 
        :param add5_xx_fault_count_alarm: 
        :param add5_xx_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param api: (experimental) API to monitor (cannot use IRestApi, since it does not provide API name).
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: prod
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = ApiGatewayMonitoringProps(
            add4_xx_error_count_alarm=add4_xx_error_count_alarm,
            add4_xx_error_rate_alarm=add4_xx_error_rate_alarm,
            add5_xx_fault_count_alarm=add5_xx_fault_count_alarm,
            add5_xx_fault_rate_alarm=add5_xx_fault_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            api=api,
            api_method=api_method,
            api_resource=api_resource,
            api_stage=api_stage,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createErrorCountWidget")
    def _create_error_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorCountWidget", [width, height]))

    @jsii.member(jsii_name="createErrorRateWidget")
    def _create_error_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorRateWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTpsWidget")
    def _create_tps_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpsWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4XXCountMetric")
    def _error4_xx_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4XXCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4XXRateMetric")
    def _error4_xx_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4XXRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fault5XXCountMetric")
    def _fault5_xx_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "fault5XXCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fault5XXRateMetric")
    def _fault5_xx_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "fault5XXRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAlarmFactory")
    def _latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "latencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAnnotations")
    def _latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "latencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50LatencyMetric")
    def _p50_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90LatencyMetric")
    def _p90_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99LatencyMetric")
    def _p99_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAlarmFactory")
    def _tps_alarm_factory(self) -> TpsAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TpsAlarmFactory, jsii.get(self, "tpsAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAnnotations")
    def _tps_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "tpsAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsMetric")
    def _tps_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "tpsMetric"))


class ApiGatewayV2HttpApiMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ApiGatewayV2HttpApiMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add4xx_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4xx_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5xx_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5xx_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_integration_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_integration_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_integration_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        api: monocdk.aws_apigatewayv2.IHttpApi,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add4xx_count_alarm: 
        :param add4xx_rate_alarm: 
        :param add5xx_count_alarm: 
        :param add5xx_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_integration_latency_p50_alarm: 
        :param add_integration_latency_p90_alarm: 
        :param add_integration_latency_p99_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param api: 
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: $default
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = ApiGatewayV2HttpApiMonitoringProps(
            add4xx_count_alarm=add4xx_count_alarm,
            add4xx_rate_alarm=add4xx_rate_alarm,
            add5xx_count_alarm=add5xx_count_alarm,
            add5xx_rate_alarm=add5xx_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_integration_latency_p50_alarm=add_integration_latency_p50_alarm,
            add_integration_latency_p90_alarm=add_integration_latency_p90_alarm,
            add_integration_latency_p99_alarm=add_integration_latency_p99_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            api=api,
            api_method=api_method,
            api_resource=api_resource,
            api_stage=api_stage,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createErrorCountWidget")
    def _create_error_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorCountWidget", [width, height]))

    @jsii.member(jsii_name="createErrorRateWidget")
    def _create_error_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorRateWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTpsWidget")
    def _create_tps_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpsWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4xxCountMetric")
    def _error4xx_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4xxCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4xxRateMetric")
    def _error4xx_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4xxRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error5xxCountMetric")
    def _error5xx_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error5xxCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error5xxRateMetric")
    def _error5xx_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error5xxRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAlarmFactory")
    def _latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "latencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAnnotations")
    def _latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "latencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50IntegrationLatencyMetric")
    def _p50_integration_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50IntegrationLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50LatencyMetric")
    def _p50_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90IntegrationLatencyMetric")
    def _p90_integration_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90IntegrationLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90LatencyMetric")
    def _p90_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99IntegrationLatencyMetric")
    def _p99_integration_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99IntegrationLatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99LatencyMetric")
    def _p99_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAlarmFactory")
    def _tps_alarm_factory(self) -> TpsAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TpsAlarmFactory, jsii.get(self, "tpsAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAnnotations")
    def _tps_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "tpsAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsMetric")
    def _tps_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "tpsMetric"))


class AppSyncMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AppSyncMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add4_xx_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4_xx_error_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5_xx_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5_xx_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        api: monocdk.aws_appsync.GraphqlApi,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add4_xx_error_count_alarm: 
        :param add4_xx_error_rate_alarm: 
        :param add5_xx_fault_count_alarm: 
        :param add5_xx_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param api: (experimental) the GraphQL API to monitor.
        :param fill_tps_with_zeroes: (experimental) whether the TPS should be filled with zeroes. Default: true
        :param rate_computation_method: (experimental) method to compute TPS. Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = AppSyncMonitoringProps(
            add4_xx_error_count_alarm=add4_xx_error_count_alarm,
            add4_xx_error_rate_alarm=add4_xx_error_rate_alarm,
            add5_xx_fault_count_alarm=add5_xx_fault_count_alarm,
            add5_xx_fault_rate_alarm=add5_xx_fault_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            use_created_alarms=use_created_alarms,
            api=api,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createErrorCountWidget")
    def _create_error_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorCountWidget", [width, height]))

    @jsii.member(jsii_name="createErrorRateWidget")
    def _create_error_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorRateWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createTpsWidget")
    def _create_tps_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpsWidget", [width, height]))

    @jsii.member(jsii_name="createtTitleWidget")
    def _createt_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createtTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4xxCountMetric")
    def _error4xx_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4xxCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4xxRateMetric")
    def _error4xx_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4xxRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fault5xxCountMetric")
    def _fault5xx_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "fault5xxCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fault5xxRateMetric")
    def _fault5xx_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "fault5xxRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAlarmFactory")
    def _latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "latencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAnnotations")
    def _latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "latencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> AppSyncMetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AppSyncMetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="namingStrategy")
    def _naming_strategy(self) -> MonitoringNamingStrategy:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringNamingStrategy, jsii.get(self, "namingStrategy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50LatencyMetric")
    def _p50_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90LatencyMetric")
    def _p90_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99LatencyMetric")
    def _p99_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAlarmFactory")
    def _tps_alarm_factory(self) -> TpsAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TpsAlarmFactory, jsii.get(self, "tpsAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAnnotations")
    def _tps_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "tpsAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsMetric")
    def _tps_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "tpsMetric"))


@jsii.implements(ILoadBalancerMetricFactory)
class ApplicationLoadBalancerMetricFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ApplicationLoadBalancerMetricFactory",
):
    '''(experimental) Metric factory to create metrics for application load-balanced service.

    :stability: experimental
    '''

    def __init__(
        self,
        metric_factory: MetricFactory,
        *,
        application_load_balancer: monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
        application_target_group: monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup,
    ) -> None:
        '''
        :param metric_factory: -
        :param application_load_balancer: 
        :param application_target_group: 

        :stability: experimental
        '''
        props = ApplicationLoadBalancerMetricFactoryProps(
            application_load_balancer=application_load_balancer,
            application_target_group=application_target_group,
        )

        jsii.create(self.__class__, self, [metric_factory, props])

    @jsii.member(jsii_name="metricActiveConnectionCount")
    def metric_active_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricActiveConnectionCount", []))

    @jsii.member(jsii_name="metricHealthyTaskCount")
    def metric_healthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHealthyTaskCount", []))

    @jsii.member(jsii_name="metricHealthyTaskInPercent")
    def metric_healthy_task_in_percent(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricHealthyTaskInPercent", []))

    @jsii.member(jsii_name="metricNewConnectionCount")
    def metric_new_connection_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricNewConnectionCount", []))

    @jsii.member(jsii_name="metricProcessedBytesMin")
    def metric_processed_bytes_min(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricProcessedBytesMin", []))

    @jsii.member(jsii_name="metricUnhealthyTaskCount")
    def metric_unhealthy_task_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.invoke(self, "metricUnhealthyTaskCount", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applicationLoadBalancer")
    def _application_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, jsii.get(self, "applicationLoadBalancer"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="applicationTargetGroup")
    def _application_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, jsii.get(self, "applicationTargetGroup"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))


class AutoScalingGroupMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.AutoScalingGroupMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        auto_scaling_group: monocdk.aws_autoscaling.IAutoScalingGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param auto_scaling_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = AutoScalingGroupMonitoringProps(
            auto_scaling_group=auto_scaling_group,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createGroupSizeWidget")
    def _create_group_size_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createGroupSizeWidget", [width, height]))

    @jsii.member(jsii_name="createGroupStatusWidget")
    def _create_group_status_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createGroupStatusWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupDesiredSizeMetric")
    def _group_desired_size_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "groupDesiredSizeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupMaxSizeMetric")
    def _group_max_size_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "groupMaxSizeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="groupMinSizeMetric")
    def _group_min_size_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "groupMinSizeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instancesInServiceMetric")
    def _instances_in_service_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "instancesInServiceMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instancesPendingMetric")
    def _instances_pending_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "instancesPendingMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instancesStandbyMetric")
    def _instances_standby_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "instancesStandbyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instancesTerminatingMetric")
    def _instances_terminating_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "instancesTerminatingMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="instancesTotalMetric")
    def _instances_total_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "instancesTotalMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AvailabilityThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "min_availability_percent": "minAvailabilityPercent",
    },
)
class AvailabilityThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        min_availability_percent: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param min_availability_percent: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "min_availability_percent": min_availability_percent,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def min_availability_percent(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("min_availability_percent")
        assert result is not None, "Required property 'min_availability_percent' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AvailabilityThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.BaseMonitoringProps",
    jsii_struct_bases=[UserProvidedNames, MonitoringDashboardsOverrideProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
    },
)
class BaseMonitoringProps(UserProvidedNames, MonitoringDashboardsOverrideProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
    ) -> None:
        '''(experimental) Base class for properties passed to each monitoring construct.

        It contains (mostly optional) properties to specify naming, placement, and so on.

        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BaseMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BillingMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.BillingMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = BaseMonitoringProps(
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createChargesByServiceWidget")
    def _create_charges_by_service_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createChargesByServiceWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTotalChargesWidget")
    def _create_total_charges_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.SingleValueWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.SingleValueWidget, jsii.invoke(self, "createTotalChargesWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="costByServiceMetric")
    def _cost_by_service_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "costByServiceMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="totalCostMetric")
    def _total_cost_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "totalCostMetric"))


class CertificateManagerMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CertificateManagerMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_days_to_expiry_alarm: typing.Optional[typing.Mapping[builtins.str, DaysToExpiryThreshold]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        certificate: monocdk.aws_certificatemanager.ICertificate,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_days_to_expiry_alarm: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param certificate: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CertificateManagerMonitoringProps(
            add_days_to_expiry_alarm=add_days_to_expiry_alarm,
            use_created_alarms=use_created_alarms,
            certificate=certificate,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createDaysToExpiryWidget")
    def _create_days_to_expiry_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDaysToExpiryWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="daysToExpiryAnnotations")
    def _days_to_expiry_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "daysToExpiryAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="daysToExpiryMetric")
    def _days_to_expiry_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "daysToExpiryMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CertificateManagerMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, CertificateManagerMetricFactoryProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "certificate": "certificate",
        "add_days_to_expiry_alarm": "addDaysToExpiryAlarm",
    },
)
class CertificateManagerMonitoringProps(
    BaseMonitoringProps,
    CertificateManagerMetricFactoryProps,
):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        certificate: monocdk.aws_certificatemanager.ICertificate,
        add_days_to_expiry_alarm: typing.Optional[typing.Mapping[builtins.str, DaysToExpiryThreshold]] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param certificate: 
        :param add_days_to_expiry_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "certificate": certificate,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_days_to_expiry_alarm is not None:
            self._values["add_days_to_expiry_alarm"] = add_days_to_expiry_alarm

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def certificate(self) -> monocdk.aws_certificatemanager.ICertificate:
        '''
        :stability: experimental
        '''
        result = self._values.get("certificate")
        assert result is not None, "Required property 'certificate' is missing"
        return typing.cast(monocdk.aws_certificatemanager.ICertificate, result)

    @builtins.property
    def add_days_to_expiry_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DaysToExpiryThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_days_to_expiry_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DaysToExpiryThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CertificateManagerMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudFrontDistributionMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CloudFrontDistributionMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        distribution: monocdk.aws_cloudfront.IDistribution,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param distribution: 
        :param fill_tps_with_zeroes: Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CloudFrontDistributionMonitoringProps(
            distribution=distribution,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createCacheWidget")
    def _create_cache_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCacheWidget", [width, height]))

    @jsii.member(jsii_name="createErrorRateWidget")
    def _create_error_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorRateWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTpsWidget")
    def _create_tps_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpsWidget", [width, height]))

    @jsii.member(jsii_name="createTrafficWidget")
    def _create_traffic_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTrafficWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cacheHitRate")
    def _cache_hit_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cacheHitRate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="downloadedBytesMetric")
    def _downloaded_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "downloadedBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error4xxRate")
    def _error4xx_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error4xxRate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="error5xxRate")
    def _error5xx_rate(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "error5xxRate"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsMetric")
    def _tps_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "tpsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="uploadedBytesMetric")
    def _uploaded_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "uploadedBytesMetric"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CloudFrontDistributionMonitoringProps",
    jsii_struct_bases=[CloudFrontDistributionMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "distribution": "distribution",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
    },
)
class CloudFrontDistributionMonitoringProps(
    CloudFrontDistributionMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        distribution: monocdk.aws_cloudfront.IDistribution,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
    ) -> None:
        '''
        :param distribution: 
        :param fill_tps_with_zeroes: Default: true
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "distribution": distribution,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def distribution(self) -> monocdk.aws_cloudfront.IDistribution:
        '''
        :stability: experimental
        '''
        result = self._values.get("distribution")
        assert result is not None, "Required property 'distribution' is missing"
        return typing.cast(monocdk.aws_cloudfront.IDistribution, result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudFrontDistributionMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodeBuildProjectMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CodeBuildProjectMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_build_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_build_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        project: monocdk.aws_codebuild.IProject,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_build_count_alarm: 
        :param add_failed_build_rate_alarm: 
        :param project: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CodeBuildProjectMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_build_count_alarm=add_failed_build_count_alarm,
            add_failed_build_rate_alarm=add_failed_build_rate_alarm,
            project=project,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createBuildCountsWidget")
    def _create_build_counts_widget(self) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createBuildCountsWidget", []))

    @jsii.member(jsii_name="createDurationWidget")
    def _create_duration_widget(self) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDurationWidget", []))

    @jsii.member(jsii_name="createFailedBuildRateWidget")
    def _create_failed_build_rate_widget(self) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createFailedBuildRateWidget", []))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="resolveProjectName")
    def _resolve_project_name(
        self,
        project: monocdk.aws_codebuild.IProject,
    ) -> typing.Optional[builtins.str]:
        '''
        :param project: -

        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "resolveProjectName", [project]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="buildCountMetric")
    def _build_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "buildCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAlarmFactory")
    def _duration_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "durationAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationAnnotations")
    def _duration_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "durationAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationP50InSecondsMetric")
    def _duration_p50_in_seconds_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "durationP50InSecondsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationP90InSecondsMetric")
    def _duration_p90_in_seconds_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "durationP90InSecondsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="durationP99InSecondsMetric")
    def _duration_p99_in_seconds_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "durationP99InSecondsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedBuildCountMetric")
    def _failed_build_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedBuildCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedBuildRateMetric")
    def _failed_build_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedBuildRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="succeededBuildCountMetric")
    def _succeeded_build_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "succeededBuildCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="projectUrl")
    def _project_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "projectUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CodeBuildProjectMonitoringProps",
    jsii_struct_bases=[CodeBuildProjectMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "project": "project",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_duration_p50_alarm": "addDurationP50Alarm",
        "add_duration_p90_alarm": "addDurationP90Alarm",
        "add_duration_p99_alarm": "addDurationP99Alarm",
        "add_failed_build_count_alarm": "addFailedBuildCountAlarm",
        "add_failed_build_rate_alarm": "addFailedBuildRateAlarm",
    },
)
class CodeBuildProjectMonitoringProps(
    CodeBuildProjectMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        project: monocdk.aws_codebuild.IProject,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_build_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_build_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for CodeBuild projects.

        :param project: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_build_count_alarm: 
        :param add_failed_build_rate_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "project": project,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_duration_p50_alarm is not None:
            self._values["add_duration_p50_alarm"] = add_duration_p50_alarm
        if add_duration_p90_alarm is not None:
            self._values["add_duration_p90_alarm"] = add_duration_p90_alarm
        if add_duration_p99_alarm is not None:
            self._values["add_duration_p99_alarm"] = add_duration_p99_alarm
        if add_failed_build_count_alarm is not None:
            self._values["add_failed_build_count_alarm"] = add_failed_build_count_alarm
        if add_failed_build_rate_alarm is not None:
            self._values["add_failed_build_rate_alarm"] = add_failed_build_rate_alarm

    @builtins.property
    def project(self) -> monocdk.aws_codebuild.IProject:
        '''
        :stability: experimental
        '''
        result = self._values.get("project")
        assert result is not None, "Required property 'project' is missing"
        return typing.cast(monocdk.aws_codebuild.IProject, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_duration_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_failed_build_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_build_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_failed_build_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_build_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodeBuildProjectMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ConsumedCapacityThreshold",
    jsii_struct_bases=[CustomAlarmThreshold],
    name_mapping={
        "action_override": "actionOverride",
        "actions_enabled": "actionsEnabled",
        "alarm_description_override": "alarmDescriptionOverride",
        "alarm_name_override": "alarmNameOverride",
        "comparison_operator_override": "comparisonOperatorOverride",
        "custom_params": "customParams",
        "custom_tags": "customTags",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dedupe_string_override": "dedupeStringOverride",
        "documentation_link": "documentationLink",
        "evaluate_low_sample_count_percentile": "evaluateLowSampleCountPercentile",
        "evaluation_periods": "evaluationPeriods",
        "fill_alarm_range": "fillAlarmRange",
        "period": "period",
        "runbook_link": "runbookLink",
        "treat_missing_data_override": "treatMissingDataOverride",
        "max_consumed_capacity_units": "maxConsumedCapacityUnits",
    },
)
class ConsumedCapacityThreshold(CustomAlarmThreshold):
    def __init__(
        self,
        *,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        comparison_operator_override: typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        evaluate_low_sample_count_percentile: typing.Optional[builtins.bool] = None,
        evaluation_periods: typing.Optional[jsii.Number] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        period: typing.Optional[monocdk.Duration] = None,
        runbook_link: typing.Optional[builtins.str] = None,
        treat_missing_data_override: typing.Optional[monocdk.aws_cloudwatch.TreatMissingData] = None,
        max_consumed_capacity_units: jsii.Number,
    ) -> None:
        '''
        :param action_override: (experimental) Allows to override the default alarm action. Default: undefined (default action will be used, if any)
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param comparison_operator_override: (experimental) Comparison operator used to compare actual value against the threshold. Default: alarm-specific default
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param datapoints_to_alarm: (experimental) Number of breaches required to transition into an ALARM state. Default: the same as monitoring facade default
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Dedupe strings are global and not unique per CTI. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param evaluate_low_sample_count_percentile: (experimental) Used only for alarms based on percentiles. If you specify false, the alarm state does not change during periods with too few data points to be statistically significant. If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available. Default: true
        :param evaluation_periods: (experimental) Number of periods to consider when checking the number of breaching datapoints. Default: the same as monitoring facade default
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param period: (experimental) Period override for the metric to alarm on. Default: the default specified in MetricFactory
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param treat_missing_data_override: (experimental) Behaviour in case the metric data is missing. Default: alarm-specific default
        :param max_consumed_capacity_units: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "max_consumed_capacity_units": max_consumed_capacity_units,
        }
        if action_override is not None:
            self._values["action_override"] = action_override
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_description_override is not None:
            self._values["alarm_description_override"] = alarm_description_override
        if alarm_name_override is not None:
            self._values["alarm_name_override"] = alarm_name_override
        if comparison_operator_override is not None:
            self._values["comparison_operator_override"] = comparison_operator_override
        if custom_params is not None:
            self._values["custom_params"] = custom_params
        if custom_tags is not None:
            self._values["custom_tags"] = custom_tags
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dedupe_string_override is not None:
            self._values["dedupe_string_override"] = dedupe_string_override
        if documentation_link is not None:
            self._values["documentation_link"] = documentation_link
        if evaluate_low_sample_count_percentile is not None:
            self._values["evaluate_low_sample_count_percentile"] = evaluate_low_sample_count_percentile
        if evaluation_periods is not None:
            self._values["evaluation_periods"] = evaluation_periods
        if fill_alarm_range is not None:
            self._values["fill_alarm_range"] = fill_alarm_range
        if period is not None:
            self._values["period"] = period
        if runbook_link is not None:
            self._values["runbook_link"] = runbook_link
        if treat_missing_data_override is not None:
            self._values["treat_missing_data_override"] = treat_missing_data_override

    @builtins.property
    def action_override(self) -> typing.Optional[IAlarmActionStrategy]:
        '''(experimental) Allows to override the default alarm action.

        :default: undefined (default action will be used, if any)

        :stability: experimental
        '''
        result = self._values.get("action_override")
        return typing.cast(typing.Optional[IAlarmActionStrategy], result)

    @builtins.property
    def actions_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Enables the configured CloudWatch alarm ticketing actions.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("actions_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_description_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) A text included in the generated ticket description body, which fully replaces the generated text.

        :default: default auto-generated content only

        :stability: experimental
        '''
        result = self._values.get("alarm_description_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_name_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm name is set to this exact value.

        Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.

        :stability: experimental
        '''
        result = self._values.get("alarm_name_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def comparison_operator_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator]:
        '''(experimental) Comparison operator used to compare actual value against the threshold.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("comparison_operator_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.ComparisonOperator], result)

    @builtins.property
    def custom_params(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
        '''(experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no parameters

        :stability: experimental
        '''
        result = self._values.get("custom_params")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.Any]], result)

    @builtins.property
    def custom_tags(self) -> typing.Optional[typing.List[builtins.str]]:
        '''(experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method.

        :default: no tags

        :stability: experimental
        '''
        result = self._values.get("custom_tags")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of breaches required to transition into an ALARM state.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("datapoints_to_alarm")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def dedupe_string_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the alarm dedupe string is set to this exact value.

        Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        Dedupe strings are global and not unique per CTI.

        :default: undefined (no override)

        :stability: experimental
        '''
        result = self._values.get("dedupe_string_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def documentation_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("documentation_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def evaluate_low_sample_count_percentile(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Used only for alarms based on percentiles.

        If you specify false, the alarm state does not change during periods with too few data points to be statistically significant.
        If you specify true, the alarm is always evaluated and possibly changes state no matter how many data points are available.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("evaluate_low_sample_count_percentile")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def evaluation_periods(self) -> typing.Optional[jsii.Number]:
        '''(experimental) Number of periods to consider when checking the number of breaching datapoints.

        :default: the same as monitoring facade default

        :stability: experimental
        '''
        result = self._values.get("evaluation_periods")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fill_alarm_range(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the alarming range of values should be highlighted in the widget.

        :default: false

        :stability: experimental
        '''
        result = self._values.get("fill_alarm_range")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def period(self) -> typing.Optional[monocdk.Duration]:
        '''(experimental) Period override for the metric to alarm on.

        :default: the default specified in MetricFactory

        :stability: experimental
        '''
        result = self._values.get("period")
        return typing.cast(typing.Optional[monocdk.Duration], result)

    @builtins.property
    def runbook_link(self) -> typing.Optional[builtins.str]:
        '''(experimental) An optional link included in the generated ticket description body.

        :default: no additional link will be added

        :stability: experimental
        '''
        result = self._values.get("runbook_link")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def treat_missing_data_override(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.TreatMissingData]:
        '''(experimental) Behaviour in case the metric data is missing.

        :default: alarm-specific default

        :stability: experimental
        '''
        result = self._values.get("treat_missing_data_override")
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.TreatMissingData], result)

    @builtins.property
    def max_consumed_capacity_units(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        result = self._values.get("max_consumed_capacity_units")
        assert result is not None, "Required property 'max_consumed_capacity_units' is missing"
        return typing.cast(jsii.Number, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConsumedCapacityThreshold(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomEc2ServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, BaseEc2ServiceAlarms],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "ec2_service": "ec2Service",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
        "load_balancer": "loadBalancer",
        "target_group": "targetGroup",
    },
)
class CustomEc2ServiceMonitoringProps(BaseMonitoringProps, BaseEc2ServiceAlarms):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        load_balancer: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]] = None,
        target_group: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param load_balancer: 
        :param target_group: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "ec2_service": ec2_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm
        if load_balancer is not None:
            self._values["load_balancer"] = load_balancer
        if target_group is not None:
            self._values["target_group"] = target_group

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def ec2_service(self) -> monocdk.aws_ecs.Ec2Service:
        '''
        :stability: experimental
        '''
        result = self._values.get("ec2_service")
        assert result is not None, "Required property 'ec2_service' is missing"
        return typing.cast(monocdk.aws_ecs.Ec2Service, result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    @builtins.property
    def load_balancer(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("load_balancer")
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]], result)

    @builtins.property
    def target_group(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("target_group")
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomEc2ServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomFargateServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, BaseFargateServiceAlarms],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "fargate_service": "fargateService",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
        "load_balancer": "loadBalancer",
        "target_group": "targetGroup",
    },
)
class CustomFargateServiceMonitoringProps(
    BaseMonitoringProps,
    BaseFargateServiceAlarms,
):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        fargate_service: monocdk.aws_ecs.FargateService,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        load_balancer: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]] = None,
        target_group: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param load_balancer: 
        :param target_group: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fargate_service": fargate_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm
        if load_balancer is not None:
            self._values["load_balancer"] = load_balancer
        if target_group is not None:
            self._values["target_group"] = target_group

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fargate_service(self) -> monocdk.aws_ecs.FargateService:
        '''
        :stability: experimental
        '''
        result = self._values.get("fargate_service")
        assert result is not None, "Required property 'fargate_service' is missing"
        return typing.cast(monocdk.aws_ecs.FargateService, result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    @builtins.property
    def load_balancer(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("load_balancer")
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]], result)

    @builtins.property
    def target_group(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("target_group")
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomFargateServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CustomMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.CustomMonitoring",
):
    '''(experimental) Custom monitoring is a construct allowing you to monitor your own custom metrics.

    The entire construct consists of metric groups.
    Each metric group represents a single graph widget with multiple metrics.
    Each metric inside the metric group represents a single metric inside a graph.
    The widgets will be sized automatically to waste as little space as possible.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        metric_groups: typing.Sequence[CustomMetricGroup],
        description: typing.Optional[builtins.str] = None,
        description_widget_height: typing.Optional[jsii.Number] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param metric_groups: 
        :param description: 
        :param description_widget_height: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CustomMonitoringProps(
            metric_groups=metric_groups,
            description=description,
            description_widget_height=description_widget_height,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="anomalyDetectingAlarmFactory")
    def _anomaly_detecting_alarm_factory(self) -> AnomalyDetectingAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AnomalyDetectingAlarmFactory, jsii.get(self, "anomalyDetectingAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="customAlarmFactory")
    def _custom_alarm_factory(self) -> CustomAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(CustomAlarmFactory, jsii.get(self, "customAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricGroups")
    def _metric_groups(self) -> typing.List[CustomMetricGroupWithAnnotations]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[CustomMetricGroupWithAnnotations], jsii.get(self, "metricGroups"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="description")
    def _description(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="descriptionWidgetHeight")
    def _description_widget_height(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[jsii.Number], jsii.get(self, "descriptionWidgetHeight"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.CustomMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "metric_groups": "metricGroups",
        "description": "description",
        "description_widget_height": "descriptionWidgetHeight",
    },
)
class CustomMonitoringProps(BaseMonitoringProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        metric_groups: typing.Sequence[CustomMetricGroup],
        description: typing.Optional[builtins.str] = None,
        description_widget_height: typing.Optional[jsii.Number] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param metric_groups: 
        :param description: 
        :param description_widget_height: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "metric_groups": metric_groups,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if description is not None:
            self._values["description"] = description
        if description_widget_height is not None:
            self._values["description_widget_height"] = description_widget_height

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def metric_groups(self) -> typing.List[CustomMetricGroup]:
        '''
        :stability: experimental
        '''
        result = self._values.get("metric_groups")
        assert result is not None, "Required property 'metric_groups' is missing"
        return typing.cast(typing.List[CustomMetricGroup], result)

    @builtins.property
    def description(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        result = self._values.get("description")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def description_widget_height(self) -> typing.Optional[jsii.Number]:
        '''
        :stability: experimental
        '''
        result = self._values.get("description_widget_height")
        return typing.cast(typing.Optional[jsii.Number], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(IDashboardFactory)
class DefaultDashboardFactory(
    monocdk.Construct,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DefaultDashboardFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: monocdk.Construct,
        id: builtins.str,
        *,
        create_alarm_dashboard: builtins.bool,
        create_dashboard: builtins.bool,
        create_summary_dashboard: builtins.bool,
        dashboard_name_prefix: builtins.str,
        rendering_preference: DashboardRenderingPreference,
        detail_dashboard_period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        detail_dashboard_range: typing.Optional[monocdk.Duration] = None,
        summary_dashboard_period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        summary_dashboard_range: typing.Optional[monocdk.Duration] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param create_alarm_dashboard: (experimental) Flag indicating whether the alarm dashboard should be created. This is independent on other create dashboard flags.
        :param create_dashboard: (experimental) Flag indicating whether the default dashboard should be created. This is independent on other create dashboard flags.
        :param create_summary_dashboard: (experimental) Flag indicating whether the summary dashboard should be created. This is independent on other create dashboard flags.
        :param dashboard_name_prefix: (experimental) Prefix added to each dashboard name. This allows to have all dashboards sorted close to each other and also separate multiple monitoring facades.
        :param rendering_preference: (experimental) Dashboard rendering preference.
        :param detail_dashboard_period_override: (experimental) Period override for the detail dashboard (and other auxiliary dashboards). Default: automatic (period dependent)
        :param detail_dashboard_range: (experimental) Range of the detail dashboard (and other auxiliary dashboards). Default: 8 hours
        :param summary_dashboard_period_override: (experimental) Period override for the summary dashboard. Default: automatic (period dependent)
        :param summary_dashboard_range: (experimental) Range of the summary dashboard. Default: 14 days

        :stability: experimental
        '''
        props = MonitoringDashboardsProps(
            create_alarm_dashboard=create_alarm_dashboard,
            create_dashboard=create_dashboard,
            create_summary_dashboard=create_summary_dashboard,
            dashboard_name_prefix=dashboard_name_prefix,
            rendering_preference=rendering_preference,
            detail_dashboard_period_override=detail_dashboard_period_override,
            detail_dashboard_range=detail_dashboard_range,
            summary_dashboard_period_override=summary_dashboard_period_override,
            summary_dashboard_range=summary_dashboard_range,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="addSegment")
    def add_segment(self, props: IDashboardFactoryProps) -> None:
        '''
        :param props: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "addSegment", [props]))

    @jsii.member(jsii_name="createdAlarmDashboard")
    def created_alarm_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdAlarmDashboard", []))

    @jsii.member(jsii_name="createDashboard")
    def _create_dashboard(
        self,
        rendering_preference: DashboardRenderingPreference,
        id: builtins.str,
        *,
        dashboard_name: typing.Optional[builtins.str] = None,
        end: typing.Optional[builtins.str] = None,
        period_override: typing.Optional[monocdk.aws_cloudwatch.PeriodOverride] = None,
        start: typing.Optional[builtins.str] = None,
        widgets: typing.Optional[typing.Sequence[typing.Sequence[monocdk.aws_cloudwatch.IWidget]]] = None,
    ) -> monocdk.aws_cloudwatch.Dashboard:
        '''
        :param rendering_preference: -
        :param id: -
        :param dashboard_name: (experimental) Name of the dashboard. If set, must only contain alphanumerics, dash (-) and underscore (_) Default: - automatically generated name
        :param end: (experimental) The end of the time range to use for each widget on the dashboard when the dashboard loads. If you specify a value for end, you must also specify a value for start. Specify an absolute time in the ISO 8601 format. For example, 2018-12-17T06:00:00.000Z. Default: When the dashboard loads, the end date will be the current time.
        :param period_override: (experimental) Use this field to specify the period for the graphs when the dashboard loads. Specifying ``Auto`` causes the period of all graphs on the dashboard to automatically adapt to the time range of the dashboard. Specifying ``Inherit`` ensures that the period set for each graph is always obeyed. Default: Auto
        :param start: (experimental) The start of the time range to use for each widget on the dashboard. You can specify start without specifying end to specify a relative time range that ends with the current time. In this case, the value of start must begin with -P, and you can use M, H, D, W and M as abbreviations for minutes, hours, days, weeks and months. For example, -PT8H shows the last 8 hours and -P3M shows the last three months. You can also use start along with an end field, to specify an absolute time range. When specifying an absolute time range, use the ISO 8601 format. For example, 2018-12-17T06:00:00.000Z. Default: When the dashboard loads, the start time will be the default time range.
        :param widgets: (experimental) Initial set of widgets on the dashboard. One array represents a row of widgets. Default: - No widgets

        :stability: experimental
        '''
        props = monocdk.aws_cloudwatch.DashboardProps(
            dashboard_name=dashboard_name,
            end=end,
            period_override=period_override,
            start=start,
            widgets=widgets,
        )

        return typing.cast(monocdk.aws_cloudwatch.Dashboard, jsii.invoke(self, "createDashboard", [rendering_preference, id, props]))

    @jsii.member(jsii_name="createdDashboard")
    def created_dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdDashboard", []))

    @jsii.member(jsii_name="createdSummaryDashboard")
    def created_summary_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdSummaryDashboard", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="anyDashboardCreated")
    def _any_dashboard_created(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "anyDashboardCreated"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmDashboard")
    def alarm_dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.get(self, "alarmDashboard"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dashboard")
    def dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.get(self, "dashboard"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="summaryDashboard")
    def summary_dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.get(self, "summaryDashboard"))


@jsii.implements(IWidgetFactory)
class DefaultWidgetFactory(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DefaultWidgetFactory",
):
    '''
    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="createAlarmDetailWidget")
    def create_alarm_detail_widget(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        alarm_description: builtins.str,
        alarm_label: builtins.str,
        alarm_name: builtins.str,
        alarm_name_suffix: builtins.str,
        alarm_rule_when_alarming: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_insufficient_data: monocdk.aws_cloudwatch.IAlarmRule,
        alarm_rule_when_ok: monocdk.aws_cloudwatch.IAlarmRule,
        annotation: monocdk.aws_cloudwatch.HorizontalAnnotation,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.IWidget:
        '''(experimental) Create widget representing an alarm detail.

        :param alarm: 
        :param alarm_description: 
        :param alarm_label: 
        :param alarm_name: 
        :param alarm_name_suffix: 
        :param alarm_rule_when_alarming: 
        :param alarm_rule_when_insufficient_data: 
        :param alarm_rule_when_ok: 
        :param annotation: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        alarm_ = AlarmWithAnnotation(
            alarm=alarm,
            alarm_description=alarm_description,
            alarm_label=alarm_label,
            alarm_name=alarm_name,
            alarm_name_suffix=alarm_name_suffix,
            alarm_rule_when_alarming=alarm_rule_when_alarming,
            alarm_rule_when_insufficient_data=alarm_rule_when_insufficient_data,
            alarm_rule_when_ok=alarm_rule_when_ok,
            annotation=annotation,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.IWidget, jsii.invoke(self, "createAlarmDetailWidget", [alarm_]))


class DynamoTableGlobalSecondaryIndexMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DynamoTableGlobalSecondaryIndexMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        global_secondary_index_name: builtins.str,
        table: monocdk.aws_dynamodb.ITable,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param global_secondary_index_name: 
        :param table: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = DynamoTableGlobalSecondaryIndexMonitoringProps(
            global_secondary_index_name=global_secondary_index_name,
            table=table,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createReadCapacityWidget")
    def _create_read_capacity_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createReadCapacityWidget", [width, height]))

    @jsii.member(jsii_name="createThrottlesWidget")
    def _create_throttles_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createThrottlesWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createWriteCapacityWidget")
    def _create_write_capacity_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createWriteCapacityWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="consumedReadUnitsMetric")
    def _consumed_read_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "consumedReadUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="consumedWriteUnitsMetric")
    def _consumed_write_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "consumedWriteUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexConsumedWriteUnitsMetric")
    def _index_consumed_write_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "indexConsumedWriteUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="indexThrottleCountMetric")
    def _index_throttle_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "indexThrottleCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="provisionedReadUnitsMetric")
    def _provisioned_read_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "provisionedReadUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="provisionedWriteUnitsMetric")
    def _provisioned_write_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "provisionedWriteUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readThrottleCountMetric")
    def _read_throttle_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "readThrottleCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="writeThrottleCountMetric")
    def _write_throttle_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "writeThrottleCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tableUrl")
    def _table_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tableUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DynamoTableGlobalSecondaryIndexMonitoringProps",
    jsii_struct_bases=[
        DynamoTableGlobalSecondaryIndexMetricFactoryProps, BaseMonitoringProps
    ],
    name_mapping={
        "global_secondary_index_name": "globalSecondaryIndexName",
        "table": "table",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
    },
)
class DynamoTableGlobalSecondaryIndexMonitoringProps(
    DynamoTableGlobalSecondaryIndexMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        global_secondary_index_name: builtins.str,
        table: monocdk.aws_dynamodb.ITable,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
    ) -> None:
        '''
        :param global_secondary_index_name: 
        :param table: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "global_secondary_index_name": global_secondary_index_name,
            "table": table,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def global_secondary_index_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("global_secondary_index_name")
        assert result is not None, "Required property 'global_secondary_index_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def table(self) -> monocdk.aws_dynamodb.ITable:
        '''
        :stability: experimental
        '''
        result = self._values.get("table")
        assert result is not None, "Required property 'table' is missing"
        return typing.cast(monocdk.aws_dynamodb.ITable, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamoTableGlobalSecondaryIndexMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DynamoTableMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DynamoTableMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_average_successful_batch_get_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_batch_write_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_delete_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_get_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_get_records_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_put_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_query_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_scan_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_update_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_consumed_read_capacity_alarm: typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]] = None,
        add_consumed_write_capacity_alarm: typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]] = None,
        add_read_throttled_events_count_alarm: typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]] = None,
        add_system_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_write_throttled_events_count_alarm: typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]] = None,
        table: monocdk.aws_dynamodb.ITable,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_average_successful_batch_get_item_latency_alarm: 
        :param add_average_successful_batch_write_item_latency_alarm: 
        :param add_average_successful_delete_item_latency_alarm: 
        :param add_average_successful_get_item_latency_alarm: 
        :param add_average_successful_get_records_latency_alarm: 
        :param add_average_successful_put_item_latency_alarm: 
        :param add_average_successful_query_latency_alarm: 
        :param add_average_successful_scan_latency_alarm: 
        :param add_average_successful_update_item_latency_alarm: 
        :param add_consumed_read_capacity_alarm: 
        :param add_consumed_write_capacity_alarm: 
        :param add_read_throttled_events_count_alarm: 
        :param add_system_error_count_alarm: 
        :param add_write_throttled_events_count_alarm: 
        :param table: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = DynamoTableMonitoringProps(
            add_average_successful_batch_get_item_latency_alarm=add_average_successful_batch_get_item_latency_alarm,
            add_average_successful_batch_write_item_latency_alarm=add_average_successful_batch_write_item_latency_alarm,
            add_average_successful_delete_item_latency_alarm=add_average_successful_delete_item_latency_alarm,
            add_average_successful_get_item_latency_alarm=add_average_successful_get_item_latency_alarm,
            add_average_successful_get_records_latency_alarm=add_average_successful_get_records_latency_alarm,
            add_average_successful_put_item_latency_alarm=add_average_successful_put_item_latency_alarm,
            add_average_successful_query_latency_alarm=add_average_successful_query_latency_alarm,
            add_average_successful_scan_latency_alarm=add_average_successful_scan_latency_alarm,
            add_average_successful_update_item_latency_alarm=add_average_successful_update_item_latency_alarm,
            add_consumed_read_capacity_alarm=add_consumed_read_capacity_alarm,
            add_consumed_write_capacity_alarm=add_consumed_write_capacity_alarm,
            add_read_throttled_events_count_alarm=add_read_throttled_events_count_alarm,
            add_system_error_count_alarm=add_system_error_count_alarm,
            add_write_throttled_events_count_alarm=add_write_throttled_events_count_alarm,
            table=table,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createErrorsWidget")
    def _create_errors_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorsWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createReadCapacityWidget")
    def _create_read_capacity_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createReadCapacityWidget", [width, height]))

    @jsii.member(jsii_name="createThrottlesWidget")
    def _create_throttles_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createThrottlesWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createWriteCapacityWidget")
    def _create_write_capacity_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createWriteCapacityWidget", [width, height]))

    @jsii.member(jsii_name="forEachOperationLatencyAlarmDefinition")
    def _for_each_operation_latency_alarm_definition(
        self,
        operation: monocdk.aws_dynamodb.Operation,
        alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
    ) -> None:
        '''
        :param operation: -
        :param alarm: -

        :stability: experimental
        '''
        return typing.cast(None, jsii.invoke(self, "forEachOperationLatencyAlarmDefinition", [operation, alarm]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="averagePerOperationLatencyMetrics")
    def _average_per_operation_latency_metrics(
        self,
    ) -> typing.Mapping[builtins.str, typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Mapping[builtins.str, typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "averagePerOperationLatencyMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="consumedReadUnitsMetric")
    def _consumed_read_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "consumedReadUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="consumedWriteUnitsMetric")
    def _consumed_write_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "consumedWriteUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dynamoCapacityAlarmFactory")
    def _dynamo_capacity_alarm_factory(self) -> DynamoAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(DynamoAlarmFactory, jsii.get(self, "dynamoCapacityAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dynamoReadCapacityAnnotations")
    def _dynamo_read_capacity_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "dynamoReadCapacityAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dynamoWriteCapacityAnnotations")
    def _dynamo_write_capacity_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "dynamoWriteCapacityAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAlarmFactory")
    def _latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "latencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAnnotations")
    def _latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "latencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAverageSearchMetrics")
    def _latency_average_search_metrics(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "latencyAverageSearchMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="provisionedReadUnitsMetric")
    def _provisioned_read_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "provisionedReadUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="provisionedWriteUnitsMetric")
    def _provisioned_write_units_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "provisionedWriteUnitsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readCapacityUsageMetric")
    def _read_capacity_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "readCapacityUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readThrottleCountMetric")
    def _read_throttle_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "readThrottleCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="systemErrorMetric")
    def _system_error_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "systemErrorMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throttledEventsAnnotations")
    def _throttled_events_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "throttledEventsAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="writeCapacityUsageMetric")
    def _write_capacity_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "writeCapacityUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="writeThrottleCountMetric")
    def _write_throttle_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "writeThrottleCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tableUrl")
    def _table_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "tableUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.DynamoTableMonitoringProps",
    jsii_struct_bases=[DynamoTableMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "table": "table",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_average_successful_batch_get_item_latency_alarm": "addAverageSuccessfulBatchGetItemLatencyAlarm",
        "add_average_successful_batch_write_item_latency_alarm": "addAverageSuccessfulBatchWriteItemLatencyAlarm",
        "add_average_successful_delete_item_latency_alarm": "addAverageSuccessfulDeleteItemLatencyAlarm",
        "add_average_successful_get_item_latency_alarm": "addAverageSuccessfulGetItemLatencyAlarm",
        "add_average_successful_get_records_latency_alarm": "addAverageSuccessfulGetRecordsLatencyAlarm",
        "add_average_successful_put_item_latency_alarm": "addAverageSuccessfulPutItemLatencyAlarm",
        "add_average_successful_query_latency_alarm": "addAverageSuccessfulQueryLatencyAlarm",
        "add_average_successful_scan_latency_alarm": "addAverageSuccessfulScanLatencyAlarm",
        "add_average_successful_update_item_latency_alarm": "addAverageSuccessfulUpdateItemLatencyAlarm",
        "add_consumed_read_capacity_alarm": "addConsumedReadCapacityAlarm",
        "add_consumed_write_capacity_alarm": "addConsumedWriteCapacityAlarm",
        "add_read_throttled_events_count_alarm": "addReadThrottledEventsCountAlarm",
        "add_system_error_count_alarm": "addSystemErrorCountAlarm",
        "add_write_throttled_events_count_alarm": "addWriteThrottledEventsCountAlarm",
    },
)
class DynamoTableMonitoringProps(DynamoTableMetricFactoryProps, BaseMonitoringProps):
    def __init__(
        self,
        *,
        table: monocdk.aws_dynamodb.ITable,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_average_successful_batch_get_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_batch_write_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_delete_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_get_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_get_records_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_put_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_query_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_scan_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_update_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_consumed_read_capacity_alarm: typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]] = None,
        add_consumed_write_capacity_alarm: typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]] = None,
        add_read_throttled_events_count_alarm: typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]] = None,
        add_system_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_write_throttled_events_count_alarm: typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]] = None,
    ) -> None:
        '''
        :param table: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_average_successful_batch_get_item_latency_alarm: 
        :param add_average_successful_batch_write_item_latency_alarm: 
        :param add_average_successful_delete_item_latency_alarm: 
        :param add_average_successful_get_item_latency_alarm: 
        :param add_average_successful_get_records_latency_alarm: 
        :param add_average_successful_put_item_latency_alarm: 
        :param add_average_successful_query_latency_alarm: 
        :param add_average_successful_scan_latency_alarm: 
        :param add_average_successful_update_item_latency_alarm: 
        :param add_consumed_read_capacity_alarm: 
        :param add_consumed_write_capacity_alarm: 
        :param add_read_throttled_events_count_alarm: 
        :param add_system_error_count_alarm: 
        :param add_write_throttled_events_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "table": table,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_average_successful_batch_get_item_latency_alarm is not None:
            self._values["add_average_successful_batch_get_item_latency_alarm"] = add_average_successful_batch_get_item_latency_alarm
        if add_average_successful_batch_write_item_latency_alarm is not None:
            self._values["add_average_successful_batch_write_item_latency_alarm"] = add_average_successful_batch_write_item_latency_alarm
        if add_average_successful_delete_item_latency_alarm is not None:
            self._values["add_average_successful_delete_item_latency_alarm"] = add_average_successful_delete_item_latency_alarm
        if add_average_successful_get_item_latency_alarm is not None:
            self._values["add_average_successful_get_item_latency_alarm"] = add_average_successful_get_item_latency_alarm
        if add_average_successful_get_records_latency_alarm is not None:
            self._values["add_average_successful_get_records_latency_alarm"] = add_average_successful_get_records_latency_alarm
        if add_average_successful_put_item_latency_alarm is not None:
            self._values["add_average_successful_put_item_latency_alarm"] = add_average_successful_put_item_latency_alarm
        if add_average_successful_query_latency_alarm is not None:
            self._values["add_average_successful_query_latency_alarm"] = add_average_successful_query_latency_alarm
        if add_average_successful_scan_latency_alarm is not None:
            self._values["add_average_successful_scan_latency_alarm"] = add_average_successful_scan_latency_alarm
        if add_average_successful_update_item_latency_alarm is not None:
            self._values["add_average_successful_update_item_latency_alarm"] = add_average_successful_update_item_latency_alarm
        if add_consumed_read_capacity_alarm is not None:
            self._values["add_consumed_read_capacity_alarm"] = add_consumed_read_capacity_alarm
        if add_consumed_write_capacity_alarm is not None:
            self._values["add_consumed_write_capacity_alarm"] = add_consumed_write_capacity_alarm
        if add_read_throttled_events_count_alarm is not None:
            self._values["add_read_throttled_events_count_alarm"] = add_read_throttled_events_count_alarm
        if add_system_error_count_alarm is not None:
            self._values["add_system_error_count_alarm"] = add_system_error_count_alarm
        if add_write_throttled_events_count_alarm is not None:
            self._values["add_write_throttled_events_count_alarm"] = add_write_throttled_events_count_alarm

    @builtins.property
    def table(self) -> monocdk.aws_dynamodb.ITable:
        '''
        :stability: experimental
        '''
        result = self._values.get("table")
        assert result is not None, "Required property 'table' is missing"
        return typing.cast(monocdk.aws_dynamodb.ITable, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_average_successful_batch_get_item_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_batch_get_item_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_batch_write_item_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_batch_write_item_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_delete_item_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_delete_item_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_get_item_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_get_item_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_get_records_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_get_records_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_put_item_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_put_item_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_query_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_query_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_scan_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_scan_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_average_successful_update_item_latency_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_average_successful_update_item_latency_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_consumed_read_capacity_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_consumed_read_capacity_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]], result)

    @builtins.property
    def add_consumed_write_capacity_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_consumed_write_capacity_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]], result)

    @builtins.property
    def add_read_throttled_events_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_read_throttled_events_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]], result)

    @builtins.property
    def add_system_error_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_system_error_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_write_throttled_events_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_write_throttled_events_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamoTableMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EC2Monitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.EC2Monitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        auto_scaling_group: typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param auto_scaling_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = EC2MonitoringProps(
            auto_scaling_group=auto_scaling_group,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createCpuWidget")
    def _create_cpu_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuWidget", [width, height]))

    @jsii.member(jsii_name="createDiskOpsWidget")
    def _create_disk_ops_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDiskOpsWidget", [width, height]))

    @jsii.member(jsii_name="createDiskWidget")
    def _create_disk_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDiskWidget", [width, height]))

    @jsii.member(jsii_name="createNetworkWidget")
    def _create_network_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createNetworkWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilisationMetric")
    def _cpu_utilisation_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "cpuUtilisationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskReadBytesMetric")
    def _disk_read_bytes_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "diskReadBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskReadOpsMetric")
    def _disk_read_ops_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "diskReadOpsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskWriteBytesMetric")
    def _disk_write_bytes_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "diskWriteBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="diskWriteOpsMetric")
    def _disk_write_ops_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "diskWriteOpsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="family")
    def _family(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "family"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkInMetric")
    def _network_in_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "networkInMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="networkOutMetric")
    def _network_out_metric(self) -> monocdk.aws_cloudwatch.IMetric:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.IMetric, jsii.get(self, "networkOutMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.EC2MonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "auto_scaling_group": "autoScalingGroup",
    },
)
class EC2MonitoringProps(BaseMonitoringProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        auto_scaling_group: typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param auto_scaling_group: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if auto_scaling_group is not None:
            self._values["auto_scaling_group"] = auto_scaling_group

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def auto_scaling_group(
        self,
    ) -> typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup]:
        '''
        :stability: experimental
        '''
        result = self._values.get("auto_scaling_group")
        return typing.cast(typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EC2MonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.Ec2ApplicationLoadBalancerMonitoringProps",
    jsii_struct_bases=[
        ApplicationLoadBalancerMetricFactoryProps,
        BaseMonitoringProps,
        BaseEc2ServiceAlarms,
    ],
    name_mapping={
        "application_load_balancer": "applicationLoadBalancer",
        "application_target_group": "applicationTargetGroup",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "ec2_service": "ec2Service",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class Ec2ApplicationLoadBalancerMonitoringProps(
    ApplicationLoadBalancerMetricFactoryProps,
    BaseMonitoringProps,
    BaseEc2ServiceAlarms,
):
    def __init__(
        self,
        *,
        application_load_balancer: monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
        application_target_group: monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for EC2 service with application load balancer and plain service.

        :param application_load_balancer: 
        :param application_target_group: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "application_load_balancer": application_load_balancer,
            "application_target_group": application_target_group,
            "ec2_service": ec2_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def application_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("application_load_balancer")
        assert result is not None, "Required property 'application_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, result)

    @builtins.property
    def application_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("application_target_group")
        assert result is not None, "Required property 'application_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def ec2_service(self) -> monocdk.aws_ecs.Ec2Service:
        '''
        :stability: experimental
        '''
        result = self._values.get("ec2_service")
        assert result is not None, "Required property 'ec2_service' is missing"
        return typing.cast(monocdk.aws_ecs.Ec2Service, result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ApplicationLoadBalancerMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.Ec2NetworkLoadBalancerMonitoringProps",
    jsii_struct_bases=[
        NetworkLoadBalancerMetricFactoryProps,
        BaseMonitoringProps,
        BaseEc2ServiceAlarms,
    ],
    name_mapping={
        "network_load_balancer": "networkLoadBalancer",
        "network_target_group": "networkTargetGroup",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "ec2_service": "ec2Service",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class Ec2NetworkLoadBalancerMonitoringProps(
    NetworkLoadBalancerMetricFactoryProps,
    BaseMonitoringProps,
    BaseEc2ServiceAlarms,
):
    def __init__(
        self,
        *,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for EC2 service with network load balancer and plain service.

        :param network_load_balancer: 
        :param network_target_group: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "network_load_balancer": network_load_balancer,
            "network_target_group": network_target_group,
            "ec2_service": ec2_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def network_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_load_balancer")
        assert result is not None, "Required property 'network_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer, result)

    @builtins.property
    def network_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_target_group")
        assert result is not None, "Required property 'network_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def ec2_service(self) -> monocdk.aws_ecs.Ec2Service:
        '''
        :stability: experimental
        '''
        result = self._values.get("ec2_service")
        assert result is not None, "Required property 'ec2_service' is missing"
        return typing.cast(monocdk.aws_ecs.Ec2Service, result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2NetworkLoadBalancerMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2ServiceMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.Ec2ServiceMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        load_balancer: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]] = None,
        target_group: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param load_balancer: 
        :param target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CustomEc2ServiceMonitoringProps(
            ec2_service=ec2_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            load_balancer=load_balancer,
            target_group=target_group,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createCpuWidget")
    def _create_cpu_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuWidget", [width, height]))

    @jsii.member(jsii_name="createMemoryWidget")
    def _create_memory_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMemoryWidget", [width, height]))

    @jsii.member(jsii_name="createTaskHealthWidget")
    def _create_task_health_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTaskHealthWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTpcFlowsWidget")
    def _create_tpc_flows_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpcFlowsWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="baseServiceMetricFactory")
    def _base_service_metric_factory(self) -> BaseServiceMetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(BaseServiceMetricFactory, jsii.get(self, "baseServiceMetricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageAnnotations")
    def _cpu_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "cpuUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilisationMetric")
    def _cpu_utilisation_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUtilisationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryUsageAnnotations")
    def _memory_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "memoryUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryUtilisationMetric")
    def _memory_utilisation_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "memoryUtilisationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="processedBytesAnnotations")
    def _processed_bytes_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "processedBytesAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="runningTaskCountMetric")
    def _running_task_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "runningTaskCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAlarmFactory")
    def _task_health_alarm_factory(self) -> TaskHealthAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TaskHealthAlarmFactory, jsii.get(self, "taskHealthAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAnnotations")
    def _task_health_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "taskHealthAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throughputAlarmFactory")
    def _throughput_alarm_factory(self) -> ThroughputAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ThroughputAlarmFactory, jsii.get(self, "throughputAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> UsageAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(UsageAlarmFactory, jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="activeTcpFlowCountMetric")
    def _active_tcp_flow_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "activeTcpFlowCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyTaskCountMetric")
    def _healthy_task_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "healthyTaskCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyTaskPercentMetric")
    def _healthy_task_percent_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "healthyTaskPercentMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancerMetricFactory")
    def _load_balancer_metric_factory(
        self,
    ) -> typing.Optional[ILoadBalancerMetricFactory]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[ILoadBalancerMetricFactory], jsii.get(self, "loadBalancerMetricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newTcpFlowCountMetric")
    def _new_tcp_flow_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "newTcpFlowCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="processedBytesMetric")
    def _processed_bytes_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "processedBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyTaskCountMetric")
    def _unhealthy_task_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "unhealthyTaskCountMetric"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.Ec2ServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, BaseEc2ServiceAlarms],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "ec2_service": "ec2Service",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class Ec2ServiceMonitoringProps(BaseMonitoringProps, BaseEc2ServiceAlarms):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        ec2_service: typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedEc2Service, monocdk.aws_ecs_patterns.ApplicationLoadBalancedEc2Service],
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for load-balanced EC2 service.

        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "ec2_service": ec2_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def ec2_service(
        self,
    ) -> typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedEc2Service, monocdk.aws_ecs_patterns.ApplicationLoadBalancedEc2Service]:
        '''
        :stability: experimental
        '''
        result = self._values.get("ec2_service")
        assert result is not None, "Required property 'ec2_service' is missing"
        return typing.cast(typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedEc2Service, monocdk.aws_ecs_patterns.ApplicationLoadBalancedEc2Service], result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElastiCacheClusterMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ElastiCacheClusterMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        cluster_type: ElastiCacheClusterType,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_max_evicted_items_count_alarm: typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]] = None,
        add_max_items_count_alarm: typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]] = None,
        add_max_used_swap_memory_alarm: typing.Optional[typing.Mapping[builtins.str, MaxUsedSwapMemoryThreshold]] = None,
        add_min_freeable_memory_alarm: typing.Optional[typing.Mapping[builtins.str, MinFreeableMemoryThreshold]] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param cluster_type: (experimental) Cluster type (needed, since each type has their own specific metrics).
        :param add_cpu_usage_alarm: (experimental) Add CPU usage alarm.
        :param add_max_evicted_items_count_alarm: (experimental) Add alarm on number of evicted items.
        :param add_max_items_count_alarm: (experimental) Add alarm on total number of items.
        :param add_max_used_swap_memory_alarm: (experimental) Add alarm on amount of used swap memory.
        :param add_min_freeable_memory_alarm: (experimental) Add alarm on amount of freeable memory.
        :param cluster_id: (experimental) Cluster to monitor. Default: monitor all clusters
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = ElastiCacheClusterMonitoringProps(
            cluster_type=cluster_type,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_max_evicted_items_count_alarm=add_max_evicted_items_count_alarm,
            add_max_items_count_alarm=add_max_items_count_alarm,
            add_max_used_swap_memory_alarm=add_max_used_swap_memory_alarm,
            add_min_freeable_memory_alarm=add_min_freeable_memory_alarm,
            cluster_id=cluster_id,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createConnectionsWidget")
    def _create_connections_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createConnectionsWidget", [width, height]))

    @jsii.member(jsii_name="createCpuUsageWidget")
    def _create_cpu_usage_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuUsageWidget", [width, height]))

    @jsii.member(jsii_name="createItemCountWidget")
    def _create_item_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createItemCountWidget", [width, height]))

    @jsii.member(jsii_name="createMemoryUsageWidget")
    def _create_memory_usage_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMemoryUsageWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="connectionsMetric")
    def _connections_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "connectionsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageAnnotations")
    def _cpu_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "cpuUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageMetric")
    def _cpu_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="elastiCacheAlarmFactory")
    def _elasti_cache_alarm_factory(self) -> ElastiCacheAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ElastiCacheAlarmFactory, jsii.get(self, "elastiCacheAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="evictedItemsCountAnnotations")
    def _evicted_items_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "evictedItemsCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="freeableMemoryMetric")
    def _freeable_memory_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "freeableMemoryMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="itemsCountAnnotations")
    def _items_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "itemsCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="itemsCountMetrics")
    def _items_count_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "itemsCountMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="itemsEvictedMetrics")
    def _items_evicted_metrics(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "itemsEvictedMetrics"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="itemsMemoryMetric")
    def _items_memory_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "itemsMemoryMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryUsageAnnotations")
    def _memory_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "memoryUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="swapMemoryMetric")
    def _swap_memory_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "swapMemoryMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unusedMemoryMetric")
    def _unused_memory_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "unusedMemoryMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> UsageAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(UsageAlarmFactory, jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="clusterUrl")
    def _cluster_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "clusterUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ElastiCacheClusterMonitoringProps",
    jsii_struct_bases=[ElastiCacheClusterMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "cluster_id": "clusterId",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "cluster_type": "clusterType",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_max_evicted_items_count_alarm": "addMaxEvictedItemsCountAlarm",
        "add_max_items_count_alarm": "addMaxItemsCountAlarm",
        "add_max_used_swap_memory_alarm": "addMaxUsedSwapMemoryAlarm",
        "add_min_freeable_memory_alarm": "addMinFreeableMemoryAlarm",
    },
)
class ElastiCacheClusterMonitoringProps(
    ElastiCacheClusterMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        cluster_id: typing.Optional[builtins.str] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        cluster_type: ElastiCacheClusterType,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_max_evicted_items_count_alarm: typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]] = None,
        add_max_items_count_alarm: typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]] = None,
        add_max_used_swap_memory_alarm: typing.Optional[typing.Mapping[builtins.str, MaxUsedSwapMemoryThreshold]] = None,
        add_min_freeable_memory_alarm: typing.Optional[typing.Mapping[builtins.str, MinFreeableMemoryThreshold]] = None,
    ) -> None:
        '''
        :param cluster_id: (experimental) Cluster to monitor. Default: monitor all clusters
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param cluster_type: (experimental) Cluster type (needed, since each type has their own specific metrics).
        :param add_cpu_usage_alarm: (experimental) Add CPU usage alarm.
        :param add_max_evicted_items_count_alarm: (experimental) Add alarm on number of evicted items.
        :param add_max_items_count_alarm: (experimental) Add alarm on total number of items.
        :param add_max_used_swap_memory_alarm: (experimental) Add alarm on amount of used swap memory.
        :param add_min_freeable_memory_alarm: (experimental) Add alarm on amount of freeable memory.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_type": cluster_type,
        }
        if cluster_id is not None:
            self._values["cluster_id"] = cluster_id
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_max_evicted_items_count_alarm is not None:
            self._values["add_max_evicted_items_count_alarm"] = add_max_evicted_items_count_alarm
        if add_max_items_count_alarm is not None:
            self._values["add_max_items_count_alarm"] = add_max_items_count_alarm
        if add_max_used_swap_memory_alarm is not None:
            self._values["add_max_used_swap_memory_alarm"] = add_max_used_swap_memory_alarm
        if add_min_freeable_memory_alarm is not None:
            self._values["add_min_freeable_memory_alarm"] = add_min_freeable_memory_alarm

    @builtins.property
    def cluster_id(self) -> typing.Optional[builtins.str]:
        '''(experimental) Cluster to monitor.

        :default: monitor all clusters

        :stability: experimental
        '''
        result = self._values.get("cluster_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def cluster_type(self) -> ElastiCacheClusterType:
        '''(experimental) Cluster type (needed, since each type has their own specific metrics).

        :stability: experimental
        '''
        result = self._values.get("cluster_type")
        assert result is not None, "Required property 'cluster_type' is missing"
        return typing.cast(ElastiCacheClusterType, result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''(experimental) Add CPU usage alarm.

        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_max_evicted_items_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]]:
        '''(experimental) Add alarm on number of evicted items.

        :stability: experimental
        '''
        result = self._values.get("add_max_evicted_items_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]], result)

    @builtins.property
    def add_max_items_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]]:
        '''(experimental) Add alarm on total number of items.

        :stability: experimental
        '''
        result = self._values.get("add_max_items_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]], result)

    @builtins.property
    def add_max_used_swap_memory_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxUsedSwapMemoryThreshold]]:
        '''(experimental) Add alarm on amount of used swap memory.

        :stability: experimental
        '''
        result = self._values.get("add_max_used_swap_memory_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxUsedSwapMemoryThreshold]], result)

    @builtins.property
    def add_min_freeable_memory_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinFreeableMemoryThreshold]]:
        '''(experimental) Add alarm on amount of freeable memory.

        :stability: experimental
        '''
        result = self._values.get("add_min_freeable_memory_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinFreeableMemoryThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastiCacheClusterMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(IAlarmDedupeStringProcessor)
class ExtendDedupeString(
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.ExtendDedupeString",
):
    '''(experimental) Dedupe string processor that adds prefix and/or suffix to the dedupe string.

    :stability: experimental
    '''

    def __init__(
        self,
        prefix: typing.Optional[builtins.str] = None,
        suffix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param prefix: -
        :param suffix: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [prefix, suffix])

    @jsii.member(jsii_name="processDedupeString")
    def process_dedupe_string(self, dedupe_string: builtins.str) -> builtins.str:
        '''(experimental) Process the dedupe string which was auto-generated.

        :param dedupe_string: -

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "processDedupeString", [dedupe_string]))

    @jsii.member(jsii_name="processDedupeStringOverride")
    def process_dedupe_string_override(
        self,
        dedupe_string: builtins.str,
    ) -> builtins.str:
        '''(experimental) Process the dedupe string which was specified by the user as an override.

        :param dedupe_string: -

        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.invoke(self, "processDedupeStringOverride", [dedupe_string]))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.FargateApplicationLoadBalancerMonitoringProps",
    jsii_struct_bases=[
        ApplicationLoadBalancerMetricFactoryProps,
        BaseMonitoringProps,
        BaseFargateServiceAlarms,
    ],
    name_mapping={
        "application_load_balancer": "applicationLoadBalancer",
        "application_target_group": "applicationTargetGroup",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "fargate_service": "fargateService",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class FargateApplicationLoadBalancerMonitoringProps(
    ApplicationLoadBalancerMetricFactoryProps,
    BaseMonitoringProps,
    BaseFargateServiceAlarms,
):
    def __init__(
        self,
        *,
        application_load_balancer: monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
        application_target_group: monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        fargate_service: monocdk.aws_ecs.FargateService,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for Fargate service with application load balancer and plain service.

        :param application_load_balancer: 
        :param application_target_group: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "application_load_balancer": application_load_balancer,
            "application_target_group": application_target_group,
            "fargate_service": fargate_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def application_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("application_load_balancer")
        assert result is not None, "Required property 'application_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, result)

    @builtins.property
    def application_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("application_target_group")
        assert result is not None, "Required property 'application_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fargate_service(self) -> monocdk.aws_ecs.FargateService:
        '''
        :stability: experimental
        '''
        result = self._values.get("fargate_service")
        assert result is not None, "Required property 'fargate_service' is missing"
        return typing.cast(monocdk.aws_ecs.FargateService, result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FargateApplicationLoadBalancerMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.FargateNetworkLoadBalancerMonitoringProps",
    jsii_struct_bases=[
        NetworkLoadBalancerMetricFactoryProps,
        BaseMonitoringProps,
        BaseFargateServiceAlarms,
    ],
    name_mapping={
        "network_load_balancer": "networkLoadBalancer",
        "network_target_group": "networkTargetGroup",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "fargate_service": "fargateService",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class FargateNetworkLoadBalancerMonitoringProps(
    NetworkLoadBalancerMetricFactoryProps,
    BaseMonitoringProps,
    BaseFargateServiceAlarms,
):
    def __init__(
        self,
        *,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        fargate_service: monocdk.aws_ecs.FargateService,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for Fargate service with network load balancer and plain service.

        :param network_load_balancer: 
        :param network_target_group: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "network_load_balancer": network_load_balancer,
            "network_target_group": network_target_group,
            "fargate_service": fargate_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def network_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_load_balancer")
        assert result is not None, "Required property 'network_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer, result)

    @builtins.property
    def network_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_target_group")
        assert result is not None, "Required property 'network_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fargate_service(self) -> monocdk.aws_ecs.FargateService:
        '''
        :stability: experimental
        '''
        result = self._values.get("fargate_service")
        assert result is not None, "Required property 'fargate_service' is missing"
        return typing.cast(monocdk.aws_ecs.FargateService, result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FargateNetworkLoadBalancerMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FargateServiceMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.FargateServiceMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        fargate_service: monocdk.aws_ecs.FargateService,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        load_balancer: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer]] = None,
        target_group: typing.Optional[typing.Union[monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup, monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param load_balancer: 
        :param target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CustomFargateServiceMonitoringProps(
            fargate_service=fargate_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            load_balancer=load_balancer,
            target_group=target_group,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createCpuWidget")
    def _create_cpu_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuWidget", [width, height]))

    @jsii.member(jsii_name="createMemoryWidget")
    def _create_memory_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMemoryWidget", [width, height]))

    @jsii.member(jsii_name="createTaskHealthWidget")
    def _create_task_health_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTaskHealthWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTpcFlowsWidget")
    def _create_tpc_flows_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpcFlowsWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="baseServiceMetricFactory")
    def _base_service_metric_factory(self) -> BaseServiceMetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(BaseServiceMetricFactory, jsii.get(self, "baseServiceMetricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageAnnotations")
    def _cpu_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "cpuUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilisationMetric")
    def _cpu_utilisation_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUtilisationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryUsageAnnotations")
    def _memory_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "memoryUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryUtilisationMetric")
    def _memory_utilisation_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "memoryUtilisationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> MetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="processedBytesAnnotations")
    def _processed_bytes_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "processedBytesAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="runningTaskCountMetric")
    def _running_task_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "runningTaskCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAlarmFactory")
    def _task_health_alarm_factory(self) -> TaskHealthAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TaskHealthAlarmFactory, jsii.get(self, "taskHealthAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAnnotations")
    def _task_health_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "taskHealthAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throughputAlarmFactory")
    def _throughput_alarm_factory(self) -> ThroughputAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ThroughputAlarmFactory, jsii.get(self, "throughputAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> UsageAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(UsageAlarmFactory, jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="activeTcpFlowCountMetric")
    def _active_tcp_flow_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "activeTcpFlowCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyTaskCountMetric")
    def _healthy_task_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "healthyTaskCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="healthyTaskPercentMetric")
    def _healthy_task_percent_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "healthyTaskPercentMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="loadBalancerMetricFactory")
    def _load_balancer_metric_factory(
        self,
    ) -> typing.Optional[ILoadBalancerMetricFactory]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[ILoadBalancerMetricFactory], jsii.get(self, "loadBalancerMetricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="newTcpFlowCountMetric")
    def _new_tcp_flow_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "newTcpFlowCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="processedBytesMetric")
    def _processed_bytes_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "processedBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="unhealthyTaskCountMetric")
    def _unhealthy_task_count_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "unhealthyTaskCountMetric"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.FargateServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, BaseFargateServiceAlarms],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "fargate_service": "fargateService",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class FargateServiceMonitoringProps(BaseMonitoringProps, BaseFargateServiceAlarms):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        fargate_service: typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedFargateService, monocdk.aws_ecs_patterns.ApplicationLoadBalancedFargateService],
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''(experimental) Monitoring props for load-balanced Fargate service.

        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fargate_service": fargate_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fargate_service(
        self,
    ) -> typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedFargateService, monocdk.aws_ecs_patterns.ApplicationLoadBalancedFargateService]:
        '''
        :stability: experimental
        '''
        result = self._values.get("fargate_service")
        assert result is not None, "Required property 'fargate_service' is missing"
        return typing.cast(typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedFargateService, monocdk.aws_ecs_patterns.ApplicationLoadBalancedFargateService], result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FargateServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(IAlarmAnnotationStrategy)
class FillingAlarmAnnotationStrategy(
    metaclass=jsii.JSIIAbstractClass,
    jsii_type="cdk-monitoring-constructs.FillingAlarmAnnotationStrategy",
):
    '''(experimental) Annotation strategy that fills the annotation provided, using the input and user requirements.

    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="createAnnotation")
    def create_annotation(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''(experimental) Creates annotation based on the metric and alarm properties.

        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmAnnotationStrategyProps(
            alarm=alarm,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            metric=metric,
            threshold=threshold,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.HorizontalAnnotation, jsii.invoke(self, "createAnnotation", [props]))

    @jsii.member(jsii_name="createAnnotationToFill") # type: ignore[misc]
    @abc.abstractmethod
    def _create_annotation_to_fill(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''
        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        ...

    @jsii.member(jsii_name="getAlarmingRangeShade")
    def _get_alarming_range_shade(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Shading]:
        '''
        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmAnnotationStrategyProps(
            alarm=alarm,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            metric=metric,
            threshold=threshold,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Shading], jsii.invoke(self, "getAlarmingRangeShade", [props]))


class _FillingAlarmAnnotationStrategyProxy(FillingAlarmAnnotationStrategy):
    @jsii.member(jsii_name="createAnnotationToFill")
    def _create_annotation_to_fill(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''
        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmAnnotationStrategyProps(
            alarm=alarm,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            metric=metric,
            threshold=threshold,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.HorizontalAnnotation, jsii.invoke(self, "createAnnotationToFill", [props]))

# Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
typing.cast(typing.Any, FillingAlarmAnnotationStrategy).__jsii_proxy_class__ = lambda : _FillingAlarmAnnotationStrategyProxy


class GlueJobMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.GlueJobMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        job_name: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param job_name: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = GlueJobMonitoringProps(
            job_name=job_name,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createCpuUtilizationWidget")
    def _create_cpu_utilization_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createCpuUtilizationWidget", [width, height]))

    @jsii.member(jsii_name="createDataMovementWidget")
    def _create_data_movement_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDataMovementWidget", [width, height]))

    @jsii.member(jsii_name="createJobExecutionWidget")
    def _create_job_execution_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createJobExecutionWidget", [width, height]))

    @jsii.member(jsii_name="createMemoryUtilizationWidget")
    def _create_memory_utilization_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createMemoryUtilizationWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createUtilizationWidget")
    def _create_utilization_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createUtilizationWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="activeExecutorsMetric")
    def _active_executors_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "activeExecutorsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bytesReadFromS3Metric")
    def _bytes_read_from_s3_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "bytesReadFromS3Metric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="bytesWrittenToS3Metric")
    def _bytes_written_to_s3_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "bytesWrittenToS3Metric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="completedStagesMetric")
    def _completed_stages_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "completedStagesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUsageMetric")
    def _cpu_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="heapMemoryUsageMetric")
    def _heap_memory_usage_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "heapMemoryUsageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="neededExecutorsMetric")
    def _needed_executors_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "neededExecutorsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.GlueJobMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "job_name": "jobName",
    },
)
class GlueJobMonitoringProps(BaseMonitoringProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        job_name: builtins.str,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param job_name: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "job_name": job_name,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def job_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("job_name")
        assert result is not None, "Required property 'job_name' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueJobMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisDataAnalyticsMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisDataAnalyticsMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_downtime_alarm: typing.Optional[typing.Mapping[builtins.str, MaxDowntimeThreshold]] = None,
        add_full_restart_count_alarm: typing.Optional[typing.Mapping[builtins.str, FullRestartCountThreshold]] = None,
        application: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_downtime_alarm: 
        :param add_full_restart_count_alarm: 
        :param application: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = KinesisDataAnalyticsMonitoringProps(
            add_downtime_alarm=add_downtime_alarm,
            add_full_restart_count_alarm=add_full_restart_count_alarm,
            application=application,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createDownTimeWidget")
    def _create_down_time_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createDownTimeWidget", [width, height]))

    @jsii.member(jsii_name="createFullRestartsWidget")
    def _create_full_restarts_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createFullRestartsWidget", [width, height]))

    @jsii.member(jsii_name="createGarbageCollectionWidget")
    def _create_garbage_collection_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createGarbageCollectionWidget", [width, height]))

    @jsii.member(jsii_name="createKPUWidget")
    def _create_kpu_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createKPUWidget", [width, height]))

    @jsii.member(jsii_name="createLastCheckpointDurationWidget")
    def _create_last_checkpoint_duration_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLastCheckpointDurationWidget", [width, height]))

    @jsii.member(jsii_name="createLastCheckpointSizeWidget")
    def _create_last_checkpoint_size_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLastCheckpointSizeWidget", [width, height]))

    @jsii.member(jsii_name="createNumberOfFailedCheckpointsWidget")
    def _create_number_of_failed_checkpoints_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createNumberOfFailedCheckpointsWidget", [width, height]))

    @jsii.member(jsii_name="createResourceUtilizationWidget")
    def _create_resource_utilization_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createResourceUtilizationWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuUtilizationPercentMetric")
    def _cpu_utilization_percent_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "cpuUtilizationPercentMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="downtimeAnnotations")
    def _downtime_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "downtimeAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="downtimeMsMetric")
    def _downtime_ms_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "downtimeMsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fullRestartAnnotations")
    def _full_restart_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "fullRestartAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="fullRestartsCountMetric")
    def _full_restarts_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "fullRestartsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="heapMemoryUtilizationPercentMetric")
    def _heap_memory_utilization_percent_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "heapMemoryUtilizationPercentMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kdaAlarmFactory")
    def _kda_alarm_factory(self) -> KinesisDataAnalyticsAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(KinesisDataAnalyticsAlarmFactory, jsii.get(self, "kdaAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kpusCountMetric")
    def _kpus_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "kpusCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lastCheckpointDurationMsMetric")
    def _last_checkpoint_duration_ms_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "lastCheckpointDurationMsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lastCheckpointSizeBytesMetric")
    def _last_checkpoint_size_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "lastCheckpointSizeBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="numberOfFailedCheckpointsCountMetric")
    def _number_of_failed_checkpoints_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "numberOfFailedCheckpointsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="oldGenerationGCCountMetric")
    def _old_generation_gc_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "oldGenerationGCCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="oldGenerationGCTimeMsMetric")
    def _old_generation_gc_time_ms_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "oldGenerationGCTimeMsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kinesisDataAnalyticsUrl")
    def _kinesis_data_analytics_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "kinesisDataAnalyticsUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.KinesisDataAnalyticsMonitoringProps",
    jsii_struct_bases=[KinesisDataAnalyticsMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "application": "application",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_downtime_alarm": "addDowntimeAlarm",
        "add_full_restart_count_alarm": "addFullRestartCountAlarm",
    },
)
class KinesisDataAnalyticsMonitoringProps(
    KinesisDataAnalyticsMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        application: builtins.str,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_downtime_alarm: typing.Optional[typing.Mapping[builtins.str, MaxDowntimeThreshold]] = None,
        add_full_restart_count_alarm: typing.Optional[typing.Mapping[builtins.str, FullRestartCountThreshold]] = None,
    ) -> None:
        '''
        :param application: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_downtime_alarm: 
        :param add_full_restart_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "application": application,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_downtime_alarm is not None:
            self._values["add_downtime_alarm"] = add_downtime_alarm
        if add_full_restart_count_alarm is not None:
            self._values["add_full_restart_count_alarm"] = add_full_restart_count_alarm

    @builtins.property
    def application(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("application")
        assert result is not None, "Required property 'application' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_downtime_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxDowntimeThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_downtime_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxDowntimeThreshold]], result)

    @builtins.property
    def add_full_restart_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, FullRestartCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_full_restart_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, FullRestartCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisDataAnalyticsMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisDataStreamMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisDataStreamMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_iterator_max_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIteratorAgeThreshold]] = None,
        add_put_records_failed_alarm: typing.Optional[typing.Mapping[builtins.str, RecordsFailedThreshold]] = None,
        add_put_records_throttled_alarm: typing.Optional[typing.Mapping[builtins.str, RecordsThrottledThreshold]] = None,
        stream_name: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_iterator_max_age_alarm: 
        :param add_put_records_failed_alarm: 
        :param add_put_records_throttled_alarm: 
        :param stream_name: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = KinesisDataStreamMonitoringProps(
            add_iterator_max_age_alarm=add_iterator_max_age_alarm,
            add_put_records_failed_alarm=add_put_records_failed_alarm,
            add_put_records_throttled_alarm=add_put_records_throttled_alarm,
            stream_name=stream_name,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createIncomingDataWidget")
    def _create_incoming_data_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createIncomingDataWidget", [width, height]))

    @jsii.member(jsii_name="createIteratorAgeWidget")
    def _create_iterator_age_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createIteratorAgeWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createOperationWidget")
    def _create_operation_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createOperationWidget", [width, height]))

    @jsii.member(jsii_name="createRecordNumberWidget")
    def _create_record_number_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createRecordNumberWidget", [width, height]))

    @jsii.member(jsii_name="createRecordSizeWidget")
    def _create_record_size_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createRecordSizeWidget", [width, height]))

    @jsii.member(jsii_name="createSecondAdditionalRow")
    def _create_second_additional_row(self) -> monocdk.aws_cloudwatch.Row:
        '''
        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.Row, jsii.invoke(self, "createSecondAdditionalRow", []))

    @jsii.member(jsii_name="createThrottleWidget")
    def _create_throttle_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createThrottleWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ageAnnotations")
    def _age_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "ageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingDataSumBytesMetric")
    def _incoming_data_sum_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "incomingDataSumBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingDataSumCountMetric")
    def _incoming_data_sum_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "incomingDataSumCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="kinesisAlarmFactory")
    def _kinesis_alarm_factory(self) -> KinesisAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(KinesisAlarmFactory, jsii.get(self, "kinesisAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricGetRecordsIteratorAge")
    def _metric_get_records_iterator_age(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "metricGetRecordsIteratorAge"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricGetRecordsLatencyAverage")
    def _metric_get_records_latency_average(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "metricGetRecordsLatencyAverage"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricGetRecordsSuccessCount")
    def _metric_get_records_success_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "metricGetRecordsSuccessCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricGetRecordsSumCount")
    def _metric_get_records_sum_count(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "metricGetRecordsSumCount"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricGetRecordSumBytes")
    def _metric_get_record_sum_bytes(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "metricGetRecordSumBytes"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordLatencyAverageMetric")
    def _put_record_latency_average_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordLatencyAverageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsFailedRecordsCountMetric")
    def _put_records_failed_records_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsFailedRecordsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsLatencyAverageMetric")
    def _put_records_latency_average_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsLatencyAverageMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsSuccessCountMetric")
    def _put_records_success_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsSuccessCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsSuccessfulRecordsCountMetric")
    def _put_records_successful_records_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsSuccessfulRecordsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsSumBytesMetric")
    def _put_records_sum_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsSumBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsThrottledRecordsCountMetric")
    def _put_records_throttled_records_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsThrottledRecordsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordsTotalRecordsCountMetric")
    def _put_records_total_records_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordsTotalRecordsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordSuccessCountMetric")
    def _put_record_success_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordSuccessCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordSumBytesMetric")
    def _put_record_sum_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordSumBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="readProvisionedThroughputExceededMetric")
    def _read_provisioned_throughput_exceeded_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "readProvisionedThroughputExceededMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="recordCountAnnotations")
    def _record_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "recordCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="writeProvisionedThroughputExceededMetric")
    def _write_provisioned_throughput_exceeded_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "writeProvisionedThroughputExceededMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamUrl")
    def _stream_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "streamUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.KinesisDataStreamMonitoringProps",
    jsii_struct_bases=[KinesisDataStreamMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "stream_name": "streamName",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_iterator_max_age_alarm": "addIteratorMaxAgeAlarm",
        "add_put_records_failed_alarm": "addPutRecordsFailedAlarm",
        "add_put_records_throttled_alarm": "addPutRecordsThrottledAlarm",
    },
)
class KinesisDataStreamMonitoringProps(
    KinesisDataStreamMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        stream_name: builtins.str,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_iterator_max_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIteratorAgeThreshold]] = None,
        add_put_records_failed_alarm: typing.Optional[typing.Mapping[builtins.str, RecordsFailedThreshold]] = None,
        add_put_records_throttled_alarm: typing.Optional[typing.Mapping[builtins.str, RecordsThrottledThreshold]] = None,
    ) -> None:
        '''
        :param stream_name: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_iterator_max_age_alarm: 
        :param add_put_records_failed_alarm: 
        :param add_put_records_throttled_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "stream_name": stream_name,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_iterator_max_age_alarm is not None:
            self._values["add_iterator_max_age_alarm"] = add_iterator_max_age_alarm
        if add_put_records_failed_alarm is not None:
            self._values["add_put_records_failed_alarm"] = add_put_records_failed_alarm
        if add_put_records_throttled_alarm is not None:
            self._values["add_put_records_throttled_alarm"] = add_put_records_throttled_alarm

    @builtins.property
    def stream_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("stream_name")
        assert result is not None, "Required property 'stream_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_iterator_max_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxIteratorAgeThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_iterator_max_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxIteratorAgeThreshold]], result)

    @builtins.property
    def add_put_records_failed_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RecordsFailedThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_put_records_failed_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RecordsFailedThreshold]], result)

    @builtins.property
    def add_put_records_throttled_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RecordsThrottledThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_put_records_throttled_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RecordsThrottledThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisDataStreamMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisFirehoseMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.KinesisFirehoseMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        delivery_stream_name: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param delivery_stream_name: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = KinesisFirehoseMonitoringProps(
            delivery_stream_name=delivery_stream_name,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createConversionWidget")
    def _create_conversion_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createConversionWidget", [width, height]))

    @jsii.member(jsii_name="createIncomingRecordWidget")
    def _create_incoming_record_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createIncomingRecordWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="failedConversionMetric")
    def _failed_conversion_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "failedConversionMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingBytesMetric")
    def _incoming_bytes_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "incomingBytesMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="incomingRecordsMetric")
    def _incoming_records_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "incomingRecordsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordBatchLatency")
    def _put_record_batch_latency(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordBatchLatency"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="putRecordLatency")
    def _put_record_latency(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "putRecordLatency"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="successfulConversionMetric")
    def _successful_conversion_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "successfulConversionMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throttledRecordsMetric")
    def _throttled_records_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "throttledRecordsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="streamUrl")
    def _stream_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "streamUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.KinesisFirehoseMonitoringProps",
    jsii_struct_bases=[KinesisFirehoseMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "delivery_stream_name": "deliveryStreamName",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
    },
)
class KinesisFirehoseMonitoringProps(
    KinesisFirehoseMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        delivery_stream_name: builtins.str,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
    ) -> None:
        '''
        :param delivery_stream_name: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "delivery_stream_name": delivery_stream_name,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def delivery_stream_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("delivery_stream_name")
        assert result is not None, "Required property 'delivery_stream_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaFunctionMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.LambdaFunctionMonitoring",
):
    '''
    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        add_concurrent_executions_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        add_enhanced_monitoring_avg_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_avg_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_enhanced_monitoring_max_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_max_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_enhanced_monitoring_p90_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_p90_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        add_max_iterator_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxAgeThreshold]] = None,
        add_provisioned_concurrency_spillover_invocations_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        add_provisioned_concurrency_spillover_invocations_rate_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskRateThreshold]] = None,
        add_throttles_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_throttles_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        lambda_function: monocdk.aws_lambda.IFunction,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        lambda_insights_enabled: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param add_concurrent_executions_count_alarm: 
        :param add_enhanced_monitoring_avg_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_avg_memory_utilization_alarm: 
        :param add_enhanced_monitoring_max_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_max_memory_utilization_alarm: 
        :param add_enhanced_monitoring_p90_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_p90_memory_utilization_alarm: 
        :param add_fault_count_alarm: 
        :param add_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param add_max_iterator_age_alarm: 
        :param add_provisioned_concurrency_spillover_invocations_count_alarm: 
        :param add_provisioned_concurrency_spillover_invocations_rate_alarm: 
        :param add_throttles_count_alarm: 
        :param add_throttles_rate_alarm: 
        :param lambda_function: 
        :param fill_tps_with_zeroes: Default: true
        :param lambda_insights_enabled: (experimental) Generate dashboard charts for Lambda Insights metrics. To enable Lambda Insights on your Lambda function, see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html Default: false
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = LambdaFunctionMonitoringProps(
            add_concurrent_executions_count_alarm=add_concurrent_executions_count_alarm,
            add_enhanced_monitoring_avg_cpu_total_time_alarm=add_enhanced_monitoring_avg_cpu_total_time_alarm,
            add_enhanced_monitoring_avg_memory_utilization_alarm=add_enhanced_monitoring_avg_memory_utilization_alarm,
            add_enhanced_monitoring_max_cpu_total_time_alarm=add_enhanced_monitoring_max_cpu_total_time_alarm,
            add_enhanced_monitoring_max_memory_utilization_alarm=add_enhanced_monitoring_max_memory_utilization_alarm,
            add_enhanced_monitoring_p90_cpu_total_time_alarm=add_enhanced_monitoring_p90_cpu_total_time_alarm,
            add_enhanced_monitoring_p90_memory_utilization_alarm=add_enhanced_monitoring_p90_memory_utilization_alarm,
            add_fault_count_alarm=add_fault_count_alarm,
            add_fault_rate_alarm=add_fault_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            add_max_iterator_age_alarm=add_max_iterator_age_alarm,
            add_provisioned_concurrency_spillover_invocations_count_alarm=add_provisioned_concurrency_spillover_invocations_count_alarm,
            add_provisioned_concurrency_spillover_invocations_rate_alarm=add_provisioned_concurrency_spillover_invocations_rate_alarm,
            add_throttles_count_alarm=add_throttles_count_alarm,
            add_throttles_rate_alarm=add_throttles_rate_alarm,
            lambda_function=lambda_function,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            lambda_insights_enabled=lambda_insights_enabled,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="createErrorCountWidget")
    def _create_error_count_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorCountWidget", [width, height]))

    @jsii.member(jsii_name="createErrorRateWidget")
    def _create_error_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createErrorRateWidget", [width, height]))

    @jsii.member(jsii_name="createInvocationWidget")
    def _create_invocation_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createInvocationWidget", [width, height]))

    @jsii.member(jsii_name="createLambdaInsightsCpuWidget")
    def _create_lambda_insights_cpu_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLambdaInsightsCpuWidget", [width, height]))

    @jsii.member(jsii_name="createLambdaInsightsFunctionCostWidget")
    def _create_lambda_insights_function_cost_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLambdaInsightsFunctionCostWidget", [width, height]))

    @jsii.member(jsii_name="createLambdaInsightsMemoryWidget")
    def _create_lambda_insights_memory_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLambdaInsightsMemoryWidget", [width, height]))

    @jsii.member(jsii_name="createLatencyWidget")
    def _create_latency_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createLatencyWidget", [width, height]))

    @jsii.member(jsii_name="createRateWidget")
    def _create_rate_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createRateWidget", [width, height]))

    @jsii.member(jsii_name="createTitleWidget")
    def _create_title_widget(self) -> MonitoringHeaderWidget:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringHeaderWidget, jsii.invoke(self, "createTitleWidget", []))

    @jsii.member(jsii_name="createTpsWidget")
    def _create_tps_widget(
        self,
        width: jsii.Number,
        height: jsii.Number,
    ) -> monocdk.aws_cloudwatch.GraphWidget:
        '''
        :param width: -
        :param height: -

        :stability: experimental
        '''
        return typing.cast(monocdk.aws_cloudwatch.GraphWidget, jsii.invoke(self, "createTpsWidget", [width, height]))

    @jsii.member(jsii_name="summaryWidgets")
    def summary_widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the summary dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "summaryWidgets", []))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="ageAlarmFactory")
    def _age_alarm_factory(self) -> AgeAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AgeAlarmFactory, jsii.get(self, "ageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactory")
    def _alarm_factory(self) -> AlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.get(self, "alarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="concurrentExecutionsCountMetric")
    def _concurrent_executions_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "concurrentExecutionsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="cpuTotalTimeAnnotations")
    def _cpu_total_time_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "cpuTotalTimeAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorAlarmFactory")
    def _error_alarm_factory(self) -> ErrorAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(ErrorAlarmFactory, jsii.get(self, "errorAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorCountAnnotations")
    def _error_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="errorRateAnnotations")
    def _error_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "errorRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="faultCountMetric")
    def _fault_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "faultCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="faultRateMetric")
    def _fault_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "faultRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="invocationCountAnnotations")
    def _invocation_count_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "invocationCountAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="invocationCountMetric")
    def _invocation_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "invocationCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="invocationRateAnnotations")
    def _invocation_rate_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "invocationRateAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="lambdaInsightsEnabled")
    def _lambda_insights_enabled(self) -> builtins.bool:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.bool, jsii.get(self, "lambdaInsightsEnabled"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAlarmFactory")
    def _latency_alarm_factory(self) -> LatencyAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LatencyAlarmFactory, jsii.get(self, "latencyAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="latencyAnnotations")
    def _latency_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "latencyAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="maxIteratorAgeMetric")
    def _max_iterator_age_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "maxIteratorAgeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="memoryUsageAnnotations")
    def _memory_usage_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "memoryUsageAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactory")
    def _metric_factory(self) -> LambdaFunctionMetricFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(LambdaFunctionMetricFactory, jsii.get(self, "metricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="namingStrategy")
    def _naming_strategy(self) -> MonitoringNamingStrategy:
        '''
        :stability: experimental
        '''
        return typing.cast(MonitoringNamingStrategy, jsii.get(self, "namingStrategy"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p50LatencyMetric")
    def _p50_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p50LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p90LatencyMetric")
    def _p90_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p90LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="p99LatencyMetric")
    def _p99_latency_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "p99LatencyMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="provisionedConcurrencySpilloverInvocationsCountMetric")
    def _provisioned_concurrency_spillover_invocations_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "provisionedConcurrencySpilloverInvocationsCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="provisionedConcurrencySpilloverInvocationsRateMetric")
    def _provisioned_concurrency_spillover_invocations_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "provisionedConcurrencySpilloverInvocationsRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="taskHealthAlarmFactory")
    def _task_health_alarm_factory(self) -> TaskHealthAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TaskHealthAlarmFactory, jsii.get(self, "taskHealthAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throttlesCountMetric")
    def _throttles_count_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "throttlesCountMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="throttlesRateMetric")
    def _throttles_rate_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "throttlesRateMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "title"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAlarmFactory")
    def _tps_alarm_factory(self) -> TpsAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(TpsAlarmFactory, jsii.get(self, "tpsAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsAnnotations")
    def _tps_annotations(
        self,
    ) -> typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.HorizontalAnnotation], jsii.get(self, "tpsAnnotations"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="tpsMetric")
    def _tps_metric(
        self,
    ) -> typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression], jsii.get(self, "tpsMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="usageAlarmFactory")
    def _usage_alarm_factory(self) -> UsageAlarmFactory:
        '''
        :stability: experimental
        '''
        return typing.cast(UsageAlarmFactory, jsii.get(self, "usageAlarmFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMetricFactory")
    def _enhanced_metric_factory(
        self,
    ) -> typing.Optional[LambdaFunctionEnhancedMetricFactory]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[LambdaFunctionEnhancedMetricFactory], jsii.get(self, "enhancedMetricFactory"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMetricFunctionCostMetric")
    def _enhanced_metric_function_cost_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMetricFunctionCostMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMonitoringAvgCpuTotalTimeMetric")
    def _enhanced_monitoring_avg_cpu_total_time_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMonitoringAvgCpuTotalTimeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMonitoringAvgMemoryUtilizationMetric")
    def _enhanced_monitoring_avg_memory_utilization_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMonitoringAvgMemoryUtilizationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMonitoringMaxCpuTotalTimeMetric")
    def _enhanced_monitoring_max_cpu_total_time_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMonitoringMaxCpuTotalTimeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMonitoringMaxMemoryUtilizationMetric")
    def _enhanced_monitoring_max_memory_utilization_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMonitoringMaxMemoryUtilizationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMonitoringP90CpuTotalTimeMetric")
    def _enhanced_monitoring_p90_cpu_total_time_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMonitoringP90CpuTotalTimeMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="enhancedMonitoringP90MemoryUtilizationMetric")
    def _enhanced_monitoring_p90_memory_utilization_metric(
        self,
    ) -> typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression]], jsii.get(self, "enhancedMonitoringP90MemoryUtilizationMetric"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="functionUrl")
    def _function_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "functionUrl"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LambdaFunctionMonitoringProps",
    jsii_struct_bases=[LambdaFunctionMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "lambda_function": "lambdaFunction",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "lambda_insights_enabled": "lambdaInsightsEnabled",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_concurrent_executions_count_alarm": "addConcurrentExecutionsCountAlarm",
        "add_enhanced_monitoring_avg_cpu_total_time_alarm": "addEnhancedMonitoringAvgCpuTotalTimeAlarm",
        "add_enhanced_monitoring_avg_memory_utilization_alarm": "addEnhancedMonitoringAvgMemoryUtilizationAlarm",
        "add_enhanced_monitoring_max_cpu_total_time_alarm": "addEnhancedMonitoringMaxCpuTotalTimeAlarm",
        "add_enhanced_monitoring_max_memory_utilization_alarm": "addEnhancedMonitoringMaxMemoryUtilizationAlarm",
        "add_enhanced_monitoring_p90_cpu_total_time_alarm": "addEnhancedMonitoringP90CpuTotalTimeAlarm",
        "add_enhanced_monitoring_p90_memory_utilization_alarm": "addEnhancedMonitoringP90MemoryUtilizationAlarm",
        "add_fault_count_alarm": "addFaultCountAlarm",
        "add_fault_rate_alarm": "addFaultRateAlarm",
        "add_high_tps_alarm": "addHighTpsAlarm",
        "add_latency_p50_alarm": "addLatencyP50Alarm",
        "add_latency_p90_alarm": "addLatencyP90Alarm",
        "add_latency_p99_alarm": "addLatencyP99Alarm",
        "add_low_tps_alarm": "addLowTpsAlarm",
        "add_max_iterator_age_alarm": "addMaxIteratorAgeAlarm",
        "add_provisioned_concurrency_spillover_invocations_count_alarm": "addProvisionedConcurrencySpilloverInvocationsCountAlarm",
        "add_provisioned_concurrency_spillover_invocations_rate_alarm": "addProvisionedConcurrencySpilloverInvocationsRateAlarm",
        "add_throttles_count_alarm": "addThrottlesCountAlarm",
        "add_throttles_rate_alarm": "addThrottlesRateAlarm",
    },
)
class LambdaFunctionMonitoringProps(
    LambdaFunctionMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        lambda_function: monocdk.aws_lambda.IFunction,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        lambda_insights_enabled: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_concurrent_executions_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        add_enhanced_monitoring_avg_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_avg_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_enhanced_monitoring_max_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_max_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_enhanced_monitoring_p90_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_p90_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        add_max_iterator_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxAgeThreshold]] = None,
        add_provisioned_concurrency_spillover_invocations_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        add_provisioned_concurrency_spillover_invocations_rate_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskRateThreshold]] = None,
        add_throttles_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_throttles_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
    ) -> None:
        '''
        :param lambda_function: 
        :param fill_tps_with_zeroes: Default: true
        :param lambda_insights_enabled: (experimental) Generate dashboard charts for Lambda Insights metrics. To enable Lambda Insights on your Lambda function, see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html Default: false
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_concurrent_executions_count_alarm: 
        :param add_enhanced_monitoring_avg_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_avg_memory_utilization_alarm: 
        :param add_enhanced_monitoring_max_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_max_memory_utilization_alarm: 
        :param add_enhanced_monitoring_p90_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_p90_memory_utilization_alarm: 
        :param add_fault_count_alarm: 
        :param add_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param add_max_iterator_age_alarm: 
        :param add_provisioned_concurrency_spillover_invocations_count_alarm: 
        :param add_provisioned_concurrency_spillover_invocations_rate_alarm: 
        :param add_throttles_count_alarm: 
        :param add_throttles_rate_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "lambda_function": lambda_function,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if lambda_insights_enabled is not None:
            self._values["lambda_insights_enabled"] = lambda_insights_enabled
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_concurrent_executions_count_alarm is not None:
            self._values["add_concurrent_executions_count_alarm"] = add_concurrent_executions_count_alarm
        if add_enhanced_monitoring_avg_cpu_total_time_alarm is not None:
            self._values["add_enhanced_monitoring_avg_cpu_total_time_alarm"] = add_enhanced_monitoring_avg_cpu_total_time_alarm
        if add_enhanced_monitoring_avg_memory_utilization_alarm is not None:
            self._values["add_enhanced_monitoring_avg_memory_utilization_alarm"] = add_enhanced_monitoring_avg_memory_utilization_alarm
        if add_enhanced_monitoring_max_cpu_total_time_alarm is not None:
            self._values["add_enhanced_monitoring_max_cpu_total_time_alarm"] = add_enhanced_monitoring_max_cpu_total_time_alarm
        if add_enhanced_monitoring_max_memory_utilization_alarm is not None:
            self._values["add_enhanced_monitoring_max_memory_utilization_alarm"] = add_enhanced_monitoring_max_memory_utilization_alarm
        if add_enhanced_monitoring_p90_cpu_total_time_alarm is not None:
            self._values["add_enhanced_monitoring_p90_cpu_total_time_alarm"] = add_enhanced_monitoring_p90_cpu_total_time_alarm
        if add_enhanced_monitoring_p90_memory_utilization_alarm is not None:
            self._values["add_enhanced_monitoring_p90_memory_utilization_alarm"] = add_enhanced_monitoring_p90_memory_utilization_alarm
        if add_fault_count_alarm is not None:
            self._values["add_fault_count_alarm"] = add_fault_count_alarm
        if add_fault_rate_alarm is not None:
            self._values["add_fault_rate_alarm"] = add_fault_rate_alarm
        if add_high_tps_alarm is not None:
            self._values["add_high_tps_alarm"] = add_high_tps_alarm
        if add_latency_p50_alarm is not None:
            self._values["add_latency_p50_alarm"] = add_latency_p50_alarm
        if add_latency_p90_alarm is not None:
            self._values["add_latency_p90_alarm"] = add_latency_p90_alarm
        if add_latency_p99_alarm is not None:
            self._values["add_latency_p99_alarm"] = add_latency_p99_alarm
        if add_low_tps_alarm is not None:
            self._values["add_low_tps_alarm"] = add_low_tps_alarm
        if add_max_iterator_age_alarm is not None:
            self._values["add_max_iterator_age_alarm"] = add_max_iterator_age_alarm
        if add_provisioned_concurrency_spillover_invocations_count_alarm is not None:
            self._values["add_provisioned_concurrency_spillover_invocations_count_alarm"] = add_provisioned_concurrency_spillover_invocations_count_alarm
        if add_provisioned_concurrency_spillover_invocations_rate_alarm is not None:
            self._values["add_provisioned_concurrency_spillover_invocations_rate_alarm"] = add_provisioned_concurrency_spillover_invocations_rate_alarm
        if add_throttles_count_alarm is not None:
            self._values["add_throttles_count_alarm"] = add_throttles_count_alarm
        if add_throttles_rate_alarm is not None:
            self._values["add_throttles_rate_alarm"] = add_throttles_rate_alarm

    @builtins.property
    def lambda_function(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        result = self._values.get("lambda_function")
        assert result is not None, "Required property 'lambda_function' is missing"
        return typing.cast(monocdk.aws_lambda.IFunction, result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def lambda_insights_enabled(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Generate dashboard charts for Lambda Insights metrics.

        To enable Lambda Insights on your Lambda function, see
        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html

        :default: false

        :stability: experimental
        '''
        result = self._values.get("lambda_insights_enabled")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_concurrent_executions_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_concurrent_executions_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def add_enhanced_monitoring_avg_cpu_total_time_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_enhanced_monitoring_avg_cpu_total_time_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_enhanced_monitoring_avg_memory_utilization_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_enhanced_monitoring_avg_memory_utilization_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_enhanced_monitoring_max_cpu_total_time_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_enhanced_monitoring_max_cpu_total_time_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_enhanced_monitoring_max_memory_utilization_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_enhanced_monitoring_max_memory_utilization_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_enhanced_monitoring_p90_cpu_total_time_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_enhanced_monitoring_p90_cpu_total_time_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_enhanced_monitoring_p90_memory_utilization_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_enhanced_monitoring_p90_memory_utilization_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_fault_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_fault_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_fault_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_fault_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_high_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_high_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]], result)

    @builtins.property
    def add_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_low_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_low_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]], result)

    @builtins.property
    def add_max_iterator_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxAgeThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_max_iterator_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxAgeThreshold]], result)

    @builtins.property
    def add_provisioned_concurrency_spillover_invocations_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_provisioned_concurrency_spillover_invocations_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def add_provisioned_concurrency_spillover_invocations_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_provisioned_concurrency_spillover_invocations_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskRateThreshold]], result)

    @builtins.property
    def add_throttles_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_throttles_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_throttles_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_throttles_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LogMonitoring(
    Monitoring,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.LogMonitoring",
):
    '''(experimental) Monitors a CloudWatch log group for various patterns.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: MonitoringScope,
        *,
        log_group_name: builtins.str,
        pattern: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param scope: -
        :param log_group_name: (experimental) name of the log group to analyze for the given pattern.
        :param pattern: (experimental) pattern to show, e.g. ERROR.
        :param limit: (experimental) number of log messages to search for. Default: 10
        :param title: (experimental) widget title. Default: auto-generated title based on the pattern and limit
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = LogMonitoringProps(
            log_group_name=log_group_name,
            pattern=pattern,
            limit=limit,
            title=title,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        jsii.create(self.__class__, self, [scope, props])

    @jsii.member(jsii_name="resolveRecommendedHeight")
    def _resolve_recommended_height(self, num_rows: jsii.Number) -> jsii.Number:
        '''
        :param num_rows: -

        :stability: experimental
        '''
        return typing.cast(jsii.Number, jsii.invoke(self, "resolveRecommendedHeight", [num_rows]))

    @jsii.member(jsii_name="widgets")
    def widgets(self) -> typing.List[monocdk.aws_cloudwatch.IWidget]:
        '''(experimental) Returns widgets to be placed on the main dashboard.

        :stability: experimental
        '''
        return typing.cast(typing.List[monocdk.aws_cloudwatch.IWidget], jsii.invoke(self, "widgets", []))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="limit")
    def _limit(self) -> jsii.Number:
        '''
        :stability: experimental
        '''
        return typing.cast(jsii.Number, jsii.get(self, "limit"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupName")
    def _log_group_name(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "logGroupName"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="pattern")
    def _pattern(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        return typing.cast(builtins.str, jsii.get(self, "pattern"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="logGroupUrl")
    def _log_group_url(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "logGroupUrl"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="title")
    def _title(self) -> typing.Optional[builtins.str]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "title"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.LogMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "log_group_name": "logGroupName",
        "pattern": "pattern",
        "limit": "limit",
        "title": "title",
    },
)
class LogMonitoringProps(BaseMonitoringProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        log_group_name: builtins.str,
        pattern: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param log_group_name: (experimental) name of the log group to analyze for the given pattern.
        :param pattern: (experimental) pattern to show, e.g. ERROR.
        :param limit: (experimental) number of log messages to search for. Default: 10
        :param title: (experimental) widget title. Default: auto-generated title based on the pattern and limit

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "log_group_name": log_group_name,
            "pattern": pattern,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if limit is not None:
            self._values["limit"] = limit
        if title is not None:
            self._values["title"] = title

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def log_group_name(self) -> builtins.str:
        '''(experimental) name of the log group to analyze for the given pattern.

        :stability: experimental
        '''
        result = self._values.get("log_group_name")
        assert result is not None, "Required property 'log_group_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def pattern(self) -> builtins.str:
        '''(experimental) pattern to show, e.g. ERROR.

        :stability: experimental
        '''
        result = self._values.get("pattern")
        assert result is not None, "Required property 'pattern' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def limit(self) -> typing.Optional[jsii.Number]:
        '''(experimental) number of log messages to search for.

        :default: 10

        :stability: experimental
        '''
        result = self._values.get("limit")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def title(self) -> typing.Optional[builtins.str]:
        '''(experimental) widget title.

        :default: auto-generated title based on the pattern and limit

        :stability: experimental
        '''
        result = self._values.get("title")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LogMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MonitoringFacade(
    MonitoringScope,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.MonitoringFacade",
):
    '''(experimental) Main entry point to create your monitoring.

    :stability: experimental
    '''

    def __init__(
        self,
        scope: monocdk.Construct,
        id: builtins.str,
        *,
        alarm_factory_defaults: AlarmFactoryDefaults,
        metric_factory_defaults: MetricFactoryDefaults,
        dashboard_factory: typing.Optional[IDashboardFactory] = None,
    ) -> None:
        '''
        :param scope: -
        :param id: -
        :param alarm_factory_defaults: 
        :param metric_factory_defaults: 
        :param dashboard_factory: 

        :stability: experimental
        '''
        props = MonitoringFacadeProps(
            alarm_factory_defaults=alarm_factory_defaults,
            metric_factory_defaults=metric_factory_defaults,
            dashboard_factory=dashboard_factory,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="addLargeHeader")
    def add_large_header(
        self,
        text: builtins.str,
        add_to_summary: typing.Optional[builtins.bool] = None,
        add_to_alarm: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param text: -
        :param add_to_summary: -
        :param add_to_alarm: -

        :stability: experimental
        '''
        return typing.cast("MonitoringFacade", jsii.invoke(self, "addLargeHeader", [text, add_to_summary, add_to_alarm]))

    @jsii.member(jsii_name="addMediumHeader")
    def add_medium_header(
        self,
        text: builtins.str,
        add_to_summary: typing.Optional[builtins.bool] = None,
        add_to_alarm: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param text: -
        :param add_to_summary: -
        :param add_to_alarm: -

        :stability: experimental
        '''
        return typing.cast("MonitoringFacade", jsii.invoke(self, "addMediumHeader", [text, add_to_summary, add_to_alarm]))

    @jsii.member(jsii_name="addSegment")
    def add_segment(
        self,
        segment: IDashboardSegment,
        *,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param segment: -
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        override_props = MonitoringDashboardsOverrideProps(
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "addSegment", [segment, override_props]))

    @jsii.member(jsii_name="addSmallHeader")
    def add_small_header(
        self,
        text: builtins.str,
        add_to_summary: typing.Optional[builtins.bool] = None,
        add_to_alarm: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param text: -
        :param add_to_summary: -
        :param add_to_alarm: -

        :stability: experimental
        '''
        return typing.cast("MonitoringFacade", jsii.invoke(self, "addSmallHeader", [text, add_to_summary, add_to_alarm]))

    @jsii.member(jsii_name="addWidget")
    def add_widget(
        self,
        widget: monocdk.aws_cloudwatch.IWidget,
        add_to_summary: typing.Optional[builtins.bool] = None,
        add_to_alarm: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param widget: -
        :param add_to_summary: -
        :param add_to_alarm: -

        :stability: experimental
        '''
        return typing.cast("MonitoringFacade", jsii.invoke(self, "addWidget", [widget, add_to_summary, add_to_alarm]))

    @jsii.member(jsii_name="createAlarmFactory")
    def create_alarm_factory(self, alarm_name_prefix: builtins.str) -> AlarmFactory:
        '''(experimental) Creates a new alarm factory.

        Alarms created will be named with the given prefix, unless a local name override is present.

        :param alarm_name_prefix: -

        :stability: experimental
        '''
        return typing.cast(AlarmFactory, jsii.invoke(self, "createAlarmFactory", [alarm_name_prefix]))

    @jsii.member(jsii_name="createAwsConsoleUrlFactory")
    def create_aws_console_url_factory(self) -> AwsConsoleUrlFactory:
        '''(experimental) Creates a new factory that creates AWS Console URLs.

        :stability: experimental
        '''
        return typing.cast(AwsConsoleUrlFactory, jsii.invoke(self, "createAwsConsoleUrlFactory", []))

    @jsii.member(jsii_name="createCompositeAlarmUsingDisambiguator")
    def create_composite_alarm_using_disambiguator(
        self,
        alarm_disambiguator: builtins.str,
        *,
        disambiguator: builtins.str,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        alarm_name_suffix: typing.Optional[builtins.str] = None,
        composite_operator: typing.Optional[CompositeAlarmOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> typing.Optional[monocdk.aws_cloudwatch.CompositeAlarm]:
        '''(experimental) Finds a subset of created alarms that are marked by a specific disambiguator and creates a composite alarm.

        This composite alarm is created with an 'OR' condition, so it triggers with any child alarm.
        NOTE: This composite alarm is not added among other alarms, so it is not returned by getCreatedAlarms() calls.

        :param alarm_disambiguator: disambiguator to filter alarms by.
        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible. Default: no description
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique. Default: no suffix
        :param composite_operator: (experimental) Logical operator used to aggregate the status individual alarms. Default: OR
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        props = AddCompositeAlarmProps(
            disambiguator=disambiguator,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_description=alarm_description,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            alarm_name_suffix=alarm_name_suffix,
            composite_operator=composite_operator,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string_override=dedupe_string_override,
            documentation_link=documentation_link,
            fill_alarm_range=fill_alarm_range,
            runbook_link=runbook_link,
        )

        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.CompositeAlarm], jsii.invoke(self, "createCompositeAlarmUsingDisambiguator", [alarm_disambiguator, props]))

    @jsii.member(jsii_name="createCompositeAlarmUsingTag")
    def create_composite_alarm_using_tag(
        self,
        custom_tag: builtins.str,
        *,
        disambiguator: builtins.str,
        action_override: typing.Optional[IAlarmActionStrategy] = None,
        actions_enabled: typing.Optional[builtins.bool] = None,
        alarm_dedupe_string_suffix: typing.Optional[builtins.str] = None,
        alarm_description: typing.Optional[builtins.str] = None,
        alarm_description_override: typing.Optional[builtins.str] = None,
        alarm_name_override: typing.Optional[builtins.str] = None,
        alarm_name_suffix: typing.Optional[builtins.str] = None,
        composite_operator: typing.Optional[CompositeAlarmOperator] = None,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string_override: typing.Optional[builtins.str] = None,
        documentation_link: typing.Optional[builtins.str] = None,
        fill_alarm_range: typing.Optional[builtins.bool] = None,
        runbook_link: typing.Optional[builtins.str] = None,
    ) -> typing.Optional[monocdk.aws_cloudwatch.CompositeAlarm]:
        '''(experimental) Finds a subset of created alarms that are marked by a specific custom tag and creates a composite alarm.

        This composite alarm is created with an 'OR' condition, so it triggers with any child alarm.
        NOTE: This composite alarm is not added among other alarms, so it is not returned by getCreatedAlarms() calls.

        :param custom_tag: tag to filter alarms by.
        :param disambiguator: (experimental) Disambiguator is a string that differentiates this alarm from other similar ones.
        :param action_override: (experimental) Allows to override the default action strategy. Default: default action will be used
        :param actions_enabled: (experimental) Enables the configured CloudWatch alarm ticketing actions. Default: the same as monitoring facade default
        :param alarm_dedupe_string_suffix: (experimental) If this is defined, the default resource-specific alarm dedupe string will be set and this will be added as a suffix. This allows you to specify the same dedupe string for a family of alarms. Cannot be defined at the same time as alarmDedupeStringOverride. Default: undefined (no suffix)
        :param alarm_description: (experimental) Alarm description is included in the ticket and therefore should describe what happened, with as much context as possible. Default: no description
        :param alarm_description_override: (experimental) A text included in the generated ticket description body, which fully replaces the generated text. Default: default auto-generated content only
        :param alarm_name_override: (experimental) If this is defined, the alarm name is set to this exact value. Please be aware that you need to specify prefix for different stages (Beta, Prod...) and realms (EU, NA...) manually.
        :param alarm_name_suffix: (experimental) Suffix added to base alarm name. Alarm names need to be unique. Default: no suffix
        :param composite_operator: (experimental) Logical operator used to aggregate the status individual alarms. Default: OR
        :param custom_params: (experimental) This allows user to attach custom parameters to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no parameters
        :param custom_tags: (experimental) This allows user to attach custom values to this alarm, which can later be accessed from the "useCreatedAlarms" method. Default: no tags
        :param dedupe_string_override: (experimental) If this is defined, the alarm dedupe string is set to this exact value. Please be aware that you need to handle deduping for different stages (Beta, Prod...) and realms (EU, NA...) manually. Default: undefined (no override)
        :param documentation_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added
        :param fill_alarm_range: (experimental) Indicates whether the alarming range of values should be highlighted in the widget. Default: false
        :param runbook_link: (experimental) An optional link included in the generated ticket description body. Default: no additional link will be added

        :stability: experimental
        '''
        props = AddCompositeAlarmProps(
            disambiguator=disambiguator,
            action_override=action_override,
            actions_enabled=actions_enabled,
            alarm_dedupe_string_suffix=alarm_dedupe_string_suffix,
            alarm_description=alarm_description,
            alarm_description_override=alarm_description_override,
            alarm_name_override=alarm_name_override,
            alarm_name_suffix=alarm_name_suffix,
            composite_operator=composite_operator,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string_override=dedupe_string_override,
            documentation_link=documentation_link,
            fill_alarm_range=fill_alarm_range,
            runbook_link=runbook_link,
        )

        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.CompositeAlarm], jsii.invoke(self, "createCompositeAlarmUsingTag", [custom_tag, props]))

    @jsii.member(jsii_name="createdAlarmDashboard")
    def created_alarm_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdAlarmDashboard", []))

    @jsii.member(jsii_name="createdAlarms")
    def created_alarms(self) -> typing.List[AlarmWithAnnotation]:
        '''(experimental) Returns the created alarms across all the monitorings added up until now.

        :stability: experimental
        '''
        return typing.cast(typing.List[AlarmWithAnnotation], jsii.invoke(self, "createdAlarms", []))

    @jsii.member(jsii_name="createdAlarmsWithDisambiguator")
    def created_alarms_with_disambiguator(
        self,
        disambiguator: builtins.str,
    ) -> typing.List[AlarmWithAnnotation]:
        '''(experimental) Returns a subset of created alarms that are marked by a specific disambiguator.

        :param disambiguator: disambiguator to filter alarms by.

        :stability: experimental
        '''
        return typing.cast(typing.List[AlarmWithAnnotation], jsii.invoke(self, "createdAlarmsWithDisambiguator", [disambiguator]))

    @jsii.member(jsii_name="createdAlarmsWithTag")
    def created_alarms_with_tag(
        self,
        custom_tag: builtins.str,
    ) -> typing.List[AlarmWithAnnotation]:
        '''(experimental) Returns a subset of created alarms that are marked by a specific custom tag.

        :param custom_tag: tag to filter alarms by.

        :stability: experimental
        '''
        return typing.cast(typing.List[AlarmWithAnnotation], jsii.invoke(self, "createdAlarmsWithTag", [custom_tag]))

    @jsii.member(jsii_name="createdDashboard")
    def created_dashboard(self) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdDashboard", []))

    @jsii.member(jsii_name="createdMonitorings")
    def created_monitorings(self) -> typing.List[Monitoring]:
        '''(experimental) Returns the created monitorings added up until now.

        :stability: experimental
        '''
        return typing.cast(typing.List[Monitoring], jsii.invoke(self, "createdMonitorings", []))

    @jsii.member(jsii_name="createdSummaryDashboard")
    def created_summary_dashboard(
        self,
    ) -> typing.Optional[monocdk.aws_cloudwatch.Dashboard]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[monocdk.aws_cloudwatch.Dashboard], jsii.invoke(self, "createdSummaryDashboard", []))

    @jsii.member(jsii_name="createMetricFactory")
    def create_metric_factory(self) -> MetricFactory:
        '''(experimental) Creates a new metric factory.

        :stability: experimental
        '''
        return typing.cast(MetricFactory, jsii.invoke(self, "createMetricFactory", []))

    @jsii.member(jsii_name="createWidgetFactory")
    def create_widget_factory(self) -> IWidgetFactory:
        '''(experimental) Creates a new widget factory.

        :stability: experimental
        '''
        return typing.cast(IWidgetFactory, jsii.invoke(self, "createWidgetFactory", []))

    @jsii.member(jsii_name="monitorApiGateway")
    def monitor_api_gateway(
        self,
        *,
        add4_xx_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4_xx_error_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5_xx_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5_xx_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        api: monocdk.aws_apigateway.RestApiBase,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add4_xx_error_count_alarm: 
        :param add4_xx_error_rate_alarm: 
        :param add5_xx_fault_count_alarm: 
        :param add5_xx_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param api: (experimental) API to monitor (cannot use IRestApi, since it does not provide API name).
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: prod
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = ApiGatewayMonitoringProps(
            add4_xx_error_count_alarm=add4_xx_error_count_alarm,
            add4_xx_error_rate_alarm=add4_xx_error_rate_alarm,
            add5_xx_fault_count_alarm=add5_xx_fault_count_alarm,
            add5_xx_fault_rate_alarm=add5_xx_fault_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            api=api,
            api_method=api_method,
            api_resource=api_resource,
            api_stage=api_stage,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorApiGateway", [props]))

    @jsii.member(jsii_name="monitorApiGatewayV2HttpApi")
    def monitor_api_gateway_v2_http_api(
        self,
        *,
        add4xx_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4xx_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5xx_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5xx_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_integration_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_integration_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_integration_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        api: monocdk.aws_apigatewayv2.IHttpApi,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add4xx_count_alarm: 
        :param add4xx_rate_alarm: 
        :param add5xx_count_alarm: 
        :param add5xx_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_integration_latency_p50_alarm: 
        :param add_integration_latency_p90_alarm: 
        :param add_integration_latency_p99_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param api: 
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: $default
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = ApiGatewayV2HttpApiMonitoringProps(
            add4xx_count_alarm=add4xx_count_alarm,
            add4xx_rate_alarm=add4xx_rate_alarm,
            add5xx_count_alarm=add5xx_count_alarm,
            add5xx_rate_alarm=add5xx_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_integration_latency_p50_alarm=add_integration_latency_p50_alarm,
            add_integration_latency_p90_alarm=add_integration_latency_p90_alarm,
            add_integration_latency_p99_alarm=add_integration_latency_p99_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            api=api,
            api_method=api_method,
            api_resource=api_resource,
            api_stage=api_stage,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorApiGatewayV2HttpApi", [props]))

    @jsii.member(jsii_name="monitorAppSyncApi")
    def monitor_app_sync_api(
        self,
        *,
        add4_xx_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4_xx_error_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5_xx_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5_xx_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        api: monocdk.aws_appsync.GraphqlApi,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add4_xx_error_count_alarm: 
        :param add4_xx_error_rate_alarm: 
        :param add5_xx_fault_count_alarm: 
        :param add5_xx_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param api: (experimental) the GraphQL API to monitor.
        :param fill_tps_with_zeroes: (experimental) whether the TPS should be filled with zeroes. Default: true
        :param rate_computation_method: (experimental) method to compute TPS. Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = AppSyncMonitoringProps(
            add4_xx_error_count_alarm=add4_xx_error_count_alarm,
            add4_xx_error_rate_alarm=add4_xx_error_rate_alarm,
            add5_xx_fault_count_alarm=add5_xx_fault_count_alarm,
            add5_xx_fault_rate_alarm=add5_xx_fault_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            use_created_alarms=use_created_alarms,
            api=api,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            rate_computation_method=rate_computation_method,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorAppSyncApi", [props]))

    @jsii.member(jsii_name="monitorAutoScalingGroup")
    def monitor_auto_scaling_group(
        self,
        *,
        auto_scaling_group: monocdk.aws_autoscaling.IAutoScalingGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param auto_scaling_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = AutoScalingGroupMonitoringProps(
            auto_scaling_group=auto_scaling_group,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorAutoScalingGroup", [props]))

    @jsii.member(jsii_name="monitorBilling")
    def monitor_billing(
        self,
        *,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = BaseMonitoringProps(
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorBilling", [props]))

    @jsii.member(jsii_name="monitorCertificate")
    def monitor_certificate(
        self,
        *,
        add_days_to_expiry_alarm: typing.Optional[typing.Mapping[builtins.str, DaysToExpiryThreshold]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        certificate: monocdk.aws_certificatemanager.ICertificate,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_days_to_expiry_alarm: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param certificate: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CertificateManagerMonitoringProps(
            add_days_to_expiry_alarm=add_days_to_expiry_alarm,
            use_created_alarms=use_created_alarms,
            certificate=certificate,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorCertificate", [props]))

    @jsii.member(jsii_name="monitorCloudFrontDistribution")
    def monitor_cloud_front_distribution(
        self,
        *,
        distribution: monocdk.aws_cloudfront.IDistribution,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param distribution: 
        :param fill_tps_with_zeroes: Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CloudFrontDistributionMonitoringProps(
            distribution=distribution,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorCloudFrontDistribution", [props]))

    @jsii.member(jsii_name="monitorCodeBuildProject")
    def monitor_code_build_project(
        self,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_build_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_build_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        project: monocdk.aws_codebuild.IProject,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_build_count_alarm: 
        :param add_failed_build_rate_alarm: 
        :param project: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CodeBuildProjectMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_build_count_alarm=add_failed_build_count_alarm,
            add_failed_build_rate_alarm=add_failed_build_rate_alarm,
            project=project,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorCodeBuildProject", [props]))

    @jsii.member(jsii_name="monitorCustom")
    def monitor_custom(
        self,
        *,
        metric_groups: typing.Sequence[CustomMetricGroup],
        description: typing.Optional[builtins.str] = None,
        description_widget_height: typing.Optional[jsii.Number] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param metric_groups: 
        :param description: 
        :param description_widget_height: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = CustomMonitoringProps(
            metric_groups=metric_groups,
            description=description,
            description_widget_height=description_widget_height,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorCustom", [props]))

    @jsii.member(jsii_name="monitorDynamoTable")
    def monitor_dynamo_table(
        self,
        *,
        add_average_successful_batch_get_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_batch_write_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_delete_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_get_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_get_records_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_put_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_query_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_scan_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_average_successful_update_item_latency_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_consumed_read_capacity_alarm: typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]] = None,
        add_consumed_write_capacity_alarm: typing.Optional[typing.Mapping[builtins.str, ConsumedCapacityThreshold]] = None,
        add_read_throttled_events_count_alarm: typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]] = None,
        add_system_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_write_throttled_events_count_alarm: typing.Optional[typing.Mapping[builtins.str, ThrottledEventsThreshold]] = None,
        table: monocdk.aws_dynamodb.ITable,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_average_successful_batch_get_item_latency_alarm: 
        :param add_average_successful_batch_write_item_latency_alarm: 
        :param add_average_successful_delete_item_latency_alarm: 
        :param add_average_successful_get_item_latency_alarm: 
        :param add_average_successful_get_records_latency_alarm: 
        :param add_average_successful_put_item_latency_alarm: 
        :param add_average_successful_query_latency_alarm: 
        :param add_average_successful_scan_latency_alarm: 
        :param add_average_successful_update_item_latency_alarm: 
        :param add_consumed_read_capacity_alarm: 
        :param add_consumed_write_capacity_alarm: 
        :param add_read_throttled_events_count_alarm: 
        :param add_system_error_count_alarm: 
        :param add_write_throttled_events_count_alarm: 
        :param table: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = DynamoTableMonitoringProps(
            add_average_successful_batch_get_item_latency_alarm=add_average_successful_batch_get_item_latency_alarm,
            add_average_successful_batch_write_item_latency_alarm=add_average_successful_batch_write_item_latency_alarm,
            add_average_successful_delete_item_latency_alarm=add_average_successful_delete_item_latency_alarm,
            add_average_successful_get_item_latency_alarm=add_average_successful_get_item_latency_alarm,
            add_average_successful_get_records_latency_alarm=add_average_successful_get_records_latency_alarm,
            add_average_successful_put_item_latency_alarm=add_average_successful_put_item_latency_alarm,
            add_average_successful_query_latency_alarm=add_average_successful_query_latency_alarm,
            add_average_successful_scan_latency_alarm=add_average_successful_scan_latency_alarm,
            add_average_successful_update_item_latency_alarm=add_average_successful_update_item_latency_alarm,
            add_consumed_read_capacity_alarm=add_consumed_read_capacity_alarm,
            add_consumed_write_capacity_alarm=add_consumed_write_capacity_alarm,
            add_read_throttled_events_count_alarm=add_read_throttled_events_count_alarm,
            add_system_error_count_alarm=add_system_error_count_alarm,
            add_write_throttled_events_count_alarm=add_write_throttled_events_count_alarm,
            table=table,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorDynamoTable", [props]))

    @jsii.member(jsii_name="monitorDynamoTableGlobalSecondaryIndex")
    def monitor_dynamo_table_global_secondary_index(
        self,
        *,
        global_secondary_index_name: builtins.str,
        table: monocdk.aws_dynamodb.ITable,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param global_secondary_index_name: 
        :param table: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = DynamoTableGlobalSecondaryIndexMonitoringProps(
            global_secondary_index_name=global_secondary_index_name,
            table=table,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorDynamoTableGlobalSecondaryIndex", [props]))

    @jsii.member(jsii_name="monitorEc2ApplicationLoadBalancer")
    def monitor_ec2_application_load_balancer(
        self,
        *,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        application_load_balancer: monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
        application_target_group: monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param application_load_balancer: 
        :param application_target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = Ec2ApplicationLoadBalancerMonitoringProps(
            ec2_service=ec2_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            application_load_balancer=application_load_balancer,
            application_target_group=application_target_group,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorEc2ApplicationLoadBalancer", [props]))

    @jsii.member(jsii_name="monitorEC2Instances")
    def monitor_ec2_instances(
        self,
        *,
        auto_scaling_group: typing.Optional[monocdk.aws_autoscaling.IAutoScalingGroup] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param auto_scaling_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = EC2MonitoringProps(
            auto_scaling_group=auto_scaling_group,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorEC2Instances", [props]))

    @jsii.member(jsii_name="monitorEc2NetworkLoadBalancer")
    def monitor_ec2_network_load_balancer(
        self,
        *,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param network_load_balancer: 
        :param network_target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = Ec2NetworkLoadBalancerMonitoringProps(
            ec2_service=ec2_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            network_load_balancer=network_load_balancer,
            network_target_group=network_target_group,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorEc2NetworkLoadBalancer", [props]))

    @jsii.member(jsii_name="monitorEc2Service")
    def monitor_ec2_service(
        self,
        *,
        ec2_service: typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedEc2Service, monocdk.aws_ecs_patterns.ApplicationLoadBalancedEc2Service],
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param ec2_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = Ec2ServiceMonitoringProps(
            ec2_service=ec2_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorEc2Service", [props]))

    @jsii.member(jsii_name="monitorElastiCacheCluster")
    def monitor_elasti_cache_cluster(
        self,
        *,
        cluster_type: ElastiCacheClusterType,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_max_evicted_items_count_alarm: typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]] = None,
        add_max_items_count_alarm: typing.Optional[typing.Mapping[builtins.str, MaxItemsCountThreshold]] = None,
        add_max_used_swap_memory_alarm: typing.Optional[typing.Mapping[builtins.str, MaxUsedSwapMemoryThreshold]] = None,
        add_min_freeable_memory_alarm: typing.Optional[typing.Mapping[builtins.str, MinFreeableMemoryThreshold]] = None,
        cluster_id: typing.Optional[builtins.str] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param cluster_type: (experimental) Cluster type (needed, since each type has their own specific metrics).
        :param add_cpu_usage_alarm: (experimental) Add CPU usage alarm.
        :param add_max_evicted_items_count_alarm: (experimental) Add alarm on number of evicted items.
        :param add_max_items_count_alarm: (experimental) Add alarm on total number of items.
        :param add_max_used_swap_memory_alarm: (experimental) Add alarm on amount of used swap memory.
        :param add_min_freeable_memory_alarm: (experimental) Add alarm on amount of freeable memory.
        :param cluster_id: (experimental) Cluster to monitor. Default: monitor all clusters
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = ElastiCacheClusterMonitoringProps(
            cluster_type=cluster_type,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_max_evicted_items_count_alarm=add_max_evicted_items_count_alarm,
            add_max_items_count_alarm=add_max_items_count_alarm,
            add_max_used_swap_memory_alarm=add_max_used_swap_memory_alarm,
            add_min_freeable_memory_alarm=add_min_freeable_memory_alarm,
            cluster_id=cluster_id,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorElastiCacheCluster", [props]))

    @jsii.member(jsii_name="monitorElasticsearchCluster")
    def monitor_elasticsearch_cluster(
        self,
        *,
        add_cluster_automated_snapshot_failure_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterAutomatedSnapshotFailureThreshold]] = None,
        add_cluster_index_writes_blocked_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterIndexWritesBlockedThreshold]] = None,
        add_cluster_node_count_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterNodesThreshold]] = None,
        add_cluster_status_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterStatusCustomization]] = None,
        add_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_indexing_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_kms_key_error_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyErrorThreshold]] = None,
        add_kms_key_inaccessible_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyInaccessibleThreshold]] = None,
        add_master_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_master_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_search_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_cluster_automated_snapshot_failure_alarm: 
        :param add_cluster_index_writes_blocked_alarm: 
        :param add_cluster_node_count_alarm: 
        :param add_cluster_status_alarm: 
        :param add_cpu_space_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param add_indexing_latency_p50_alarm: 
        :param add_indexing_latency_p90_alarm: 
        :param add_indexing_latency_p99_alarm: 
        :param add_jvm_memory_pressure_alarm: 
        :param add_kms_key_error_alarm: 
        :param add_kms_key_inaccessible_alarm: 
        :param add_master_cpu_space_usage_alarm: 
        :param add_master_jvm_memory_pressure_alarm: 
        :param add_search_latency_p50_alarm: 
        :param add_search_latency_p90_alarm: 
        :param add_search_latency_p99_alarm: 
        :param domain: 
        :param fill_tps_with_zeroes: Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = OpenSearchClusterMonitoringProps(
            add_cluster_automated_snapshot_failure_alarm=add_cluster_automated_snapshot_failure_alarm,
            add_cluster_index_writes_blocked_alarm=add_cluster_index_writes_blocked_alarm,
            add_cluster_node_count_alarm=add_cluster_node_count_alarm,
            add_cluster_status_alarm=add_cluster_status_alarm,
            add_cpu_space_usage_alarm=add_cpu_space_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            add_indexing_latency_p50_alarm=add_indexing_latency_p50_alarm,
            add_indexing_latency_p90_alarm=add_indexing_latency_p90_alarm,
            add_indexing_latency_p99_alarm=add_indexing_latency_p99_alarm,
            add_jvm_memory_pressure_alarm=add_jvm_memory_pressure_alarm,
            add_kms_key_error_alarm=add_kms_key_error_alarm,
            add_kms_key_inaccessible_alarm=add_kms_key_inaccessible_alarm,
            add_master_cpu_space_usage_alarm=add_master_cpu_space_usage_alarm,
            add_master_jvm_memory_pressure_alarm=add_master_jvm_memory_pressure_alarm,
            add_search_latency_p50_alarm=add_search_latency_p50_alarm,
            add_search_latency_p90_alarm=add_search_latency_p90_alarm,
            add_search_latency_p99_alarm=add_search_latency_p99_alarm,
            domain=domain,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorElasticsearchCluster", [props]))

    @jsii.member(jsii_name="monitorFargateApplicationLoadBalancer")
    def monitor_fargate_application_load_balancer(
        self,
        *,
        fargate_service: monocdk.aws_ecs.FargateService,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        application_load_balancer: monocdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
        application_target_group: monocdk.aws_elasticloadbalancingv2.ApplicationTargetGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param application_load_balancer: 
        :param application_target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = FargateApplicationLoadBalancerMonitoringProps(
            fargate_service=fargate_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            application_load_balancer=application_load_balancer,
            application_target_group=application_target_group,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorFargateApplicationLoadBalancer", [props]))

    @jsii.member(jsii_name="monitorFargateNetworkLoadBalancer")
    def monitor_fargate_network_load_balancer(
        self,
        *,
        fargate_service: monocdk.aws_ecs.FargateService,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param network_load_balancer: 
        :param network_target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = FargateNetworkLoadBalancerMonitoringProps(
            fargate_service=fargate_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            network_load_balancer=network_load_balancer,
            network_target_group=network_target_group,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorFargateNetworkLoadBalancer", [props]))

    @jsii.member(jsii_name="monitorFargateService")
    def monitor_fargate_service(
        self,
        *,
        fargate_service: typing.Union[monocdk.aws_ecs_patterns.NetworkLoadBalancedFargateService, monocdk.aws_ecs_patterns.ApplicationLoadBalancedFargateService],
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param fargate_service: 
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = FargateServiceMonitoringProps(
            fargate_service=fargate_service,
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorFargateService", [props]))

    @jsii.member(jsii_name="monitorGlueJob")
    def monitor_glue_job(
        self,
        *,
        job_name: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param job_name: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = GlueJobMonitoringProps(
            job_name=job_name,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorGlueJob", [props]))

    @jsii.member(jsii_name="monitorKinesisDataAnalytics")
    def monitor_kinesis_data_analytics(
        self,
        *,
        add_downtime_alarm: typing.Optional[typing.Mapping[builtins.str, MaxDowntimeThreshold]] = None,
        add_full_restart_count_alarm: typing.Optional[typing.Mapping[builtins.str, FullRestartCountThreshold]] = None,
        application: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_downtime_alarm: 
        :param add_full_restart_count_alarm: 
        :param application: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = KinesisDataAnalyticsMonitoringProps(
            add_downtime_alarm=add_downtime_alarm,
            add_full_restart_count_alarm=add_full_restart_count_alarm,
            application=application,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorKinesisDataAnalytics", [props]))

    @jsii.member(jsii_name="monitorKinesisDataStream")
    def monitor_kinesis_data_stream(
        self,
        *,
        add_iterator_max_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIteratorAgeThreshold]] = None,
        add_put_records_failed_alarm: typing.Optional[typing.Mapping[builtins.str, RecordsFailedThreshold]] = None,
        add_put_records_throttled_alarm: typing.Optional[typing.Mapping[builtins.str, RecordsThrottledThreshold]] = None,
        stream_name: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_iterator_max_age_alarm: 
        :param add_put_records_failed_alarm: 
        :param add_put_records_throttled_alarm: 
        :param stream_name: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = KinesisDataStreamMonitoringProps(
            add_iterator_max_age_alarm=add_iterator_max_age_alarm,
            add_put_records_failed_alarm=add_put_records_failed_alarm,
            add_put_records_throttled_alarm=add_put_records_throttled_alarm,
            stream_name=stream_name,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorKinesisDataStream", [props]))

    @jsii.member(jsii_name="monitorKinesisFirehose")
    def monitor_kinesis_firehose(
        self,
        *,
        delivery_stream_name: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param delivery_stream_name: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = KinesisFirehoseMonitoringProps(
            delivery_stream_name=delivery_stream_name,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorKinesisFirehose", [props]))

    @jsii.member(jsii_name="monitorLambdaFunction")
    def monitor_lambda_function(
        self,
        *,
        add_concurrent_executions_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        add_enhanced_monitoring_avg_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_avg_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_enhanced_monitoring_max_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_max_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_enhanced_monitoring_p90_cpu_total_time_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_enhanced_monitoring_p90_memory_utilization_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
        add_max_iterator_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxAgeThreshold]] = None,
        add_provisioned_concurrency_spillover_invocations_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        add_provisioned_concurrency_spillover_invocations_rate_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskRateThreshold]] = None,
        add_throttles_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_throttles_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        lambda_function: monocdk.aws_lambda.IFunction,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        lambda_insights_enabled: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_concurrent_executions_count_alarm: 
        :param add_enhanced_monitoring_avg_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_avg_memory_utilization_alarm: 
        :param add_enhanced_monitoring_max_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_max_memory_utilization_alarm: 
        :param add_enhanced_monitoring_p90_cpu_total_time_alarm: 
        :param add_enhanced_monitoring_p90_memory_utilization_alarm: 
        :param add_fault_count_alarm: 
        :param add_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 
        :param add_max_iterator_age_alarm: 
        :param add_provisioned_concurrency_spillover_invocations_count_alarm: 
        :param add_provisioned_concurrency_spillover_invocations_rate_alarm: 
        :param add_throttles_count_alarm: 
        :param add_throttles_rate_alarm: 
        :param lambda_function: 
        :param fill_tps_with_zeroes: Default: true
        :param lambda_insights_enabled: (experimental) Generate dashboard charts for Lambda Insights metrics. To enable Lambda Insights on your Lambda function, see https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-clouddevelopmentkit.html Default: false
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = LambdaFunctionMonitoringProps(
            add_concurrent_executions_count_alarm=add_concurrent_executions_count_alarm,
            add_enhanced_monitoring_avg_cpu_total_time_alarm=add_enhanced_monitoring_avg_cpu_total_time_alarm,
            add_enhanced_monitoring_avg_memory_utilization_alarm=add_enhanced_monitoring_avg_memory_utilization_alarm,
            add_enhanced_monitoring_max_cpu_total_time_alarm=add_enhanced_monitoring_max_cpu_total_time_alarm,
            add_enhanced_monitoring_max_memory_utilization_alarm=add_enhanced_monitoring_max_memory_utilization_alarm,
            add_enhanced_monitoring_p90_cpu_total_time_alarm=add_enhanced_monitoring_p90_cpu_total_time_alarm,
            add_enhanced_monitoring_p90_memory_utilization_alarm=add_enhanced_monitoring_p90_memory_utilization_alarm,
            add_fault_count_alarm=add_fault_count_alarm,
            add_fault_rate_alarm=add_fault_rate_alarm,
            add_high_tps_alarm=add_high_tps_alarm,
            add_latency_p50_alarm=add_latency_p50_alarm,
            add_latency_p90_alarm=add_latency_p90_alarm,
            add_latency_p99_alarm=add_latency_p99_alarm,
            add_low_tps_alarm=add_low_tps_alarm,
            add_max_iterator_age_alarm=add_max_iterator_age_alarm,
            add_provisioned_concurrency_spillover_invocations_count_alarm=add_provisioned_concurrency_spillover_invocations_count_alarm,
            add_provisioned_concurrency_spillover_invocations_rate_alarm=add_provisioned_concurrency_spillover_invocations_rate_alarm,
            add_throttles_count_alarm=add_throttles_count_alarm,
            add_throttles_rate_alarm=add_throttles_rate_alarm,
            lambda_function=lambda_function,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            lambda_insights_enabled=lambda_insights_enabled,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorLambdaFunction", [props]))

    @jsii.member(jsii_name="monitorLog")
    def monitor_log(
        self,
        *,
        log_group_name: builtins.str,
        pattern: builtins.str,
        limit: typing.Optional[jsii.Number] = None,
        title: typing.Optional[builtins.str] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param log_group_name: (experimental) name of the log group to analyze for the given pattern.
        :param pattern: (experimental) pattern to show, e.g. ERROR.
        :param limit: (experimental) number of log messages to search for. Default: 10
        :param title: (experimental) widget title. Default: auto-generated title based on the pattern and limit
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = LogMonitoringProps(
            log_group_name=log_group_name,
            pattern=pattern,
            limit=limit,
            title=title,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorLog", [props]))

    @jsii.member(jsii_name="monitorNetworkLoadBalancer")
    def monitor_network_load_balancer(
        self,
        *,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 
        :param network_load_balancer: 
        :param network_target_group: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = NetworkLoadBalancerMonitoringProps(
            add_healthy_task_count_alarm=add_healthy_task_count_alarm,
            add_healthy_task_percent_alarm=add_healthy_task_percent_alarm,
            add_min_processed_bytes_alarm=add_min_processed_bytes_alarm,
            add_unhealthy_task_count_alarm=add_unhealthy_task_count_alarm,
            network_load_balancer=network_load_balancer,
            network_target_group=network_target_group,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorNetworkLoadBalancer", [props]))

    @jsii.member(jsii_name="monitorOpenSearchCluster")
    def monitor_open_search_cluster(
        self,
        *,
        add_cluster_automated_snapshot_failure_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterAutomatedSnapshotFailureThreshold]] = None,
        add_cluster_index_writes_blocked_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterIndexWritesBlockedThreshold]] = None,
        add_cluster_node_count_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterNodesThreshold]] = None,
        add_cluster_status_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterStatusCustomization]] = None,
        add_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_indexing_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_kms_key_error_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyErrorThreshold]] = None,
        add_kms_key_inaccessible_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyInaccessibleThreshold]] = None,
        add_master_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_master_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_search_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_cluster_automated_snapshot_failure_alarm: 
        :param add_cluster_index_writes_blocked_alarm: 
        :param add_cluster_node_count_alarm: 
        :param add_cluster_status_alarm: 
        :param add_cpu_space_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param add_indexing_latency_p50_alarm: 
        :param add_indexing_latency_p90_alarm: 
        :param add_indexing_latency_p99_alarm: 
        :param add_jvm_memory_pressure_alarm: 
        :param add_kms_key_error_alarm: 
        :param add_kms_key_inaccessible_alarm: 
        :param add_master_cpu_space_usage_alarm: 
        :param add_master_jvm_memory_pressure_alarm: 
        :param add_search_latency_p50_alarm: 
        :param add_search_latency_p90_alarm: 
        :param add_search_latency_p99_alarm: 
        :param domain: 
        :param fill_tps_with_zeroes: Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = OpenSearchClusterMonitoringProps(
            add_cluster_automated_snapshot_failure_alarm=add_cluster_automated_snapshot_failure_alarm,
            add_cluster_index_writes_blocked_alarm=add_cluster_index_writes_blocked_alarm,
            add_cluster_node_count_alarm=add_cluster_node_count_alarm,
            add_cluster_status_alarm=add_cluster_status_alarm,
            add_cpu_space_usage_alarm=add_cpu_space_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            add_indexing_latency_p50_alarm=add_indexing_latency_p50_alarm,
            add_indexing_latency_p90_alarm=add_indexing_latency_p90_alarm,
            add_indexing_latency_p99_alarm=add_indexing_latency_p99_alarm,
            add_jvm_memory_pressure_alarm=add_jvm_memory_pressure_alarm,
            add_kms_key_error_alarm=add_kms_key_error_alarm,
            add_kms_key_inaccessible_alarm=add_kms_key_inaccessible_alarm,
            add_master_cpu_space_usage_alarm=add_master_cpu_space_usage_alarm,
            add_master_jvm_memory_pressure_alarm=add_master_jvm_memory_pressure_alarm,
            add_search_latency_p50_alarm=add_search_latency_p50_alarm,
            add_search_latency_p90_alarm=add_search_latency_p90_alarm,
            add_search_latency_p99_alarm=add_search_latency_p99_alarm,
            domain=domain,
            fill_tps_with_zeroes=fill_tps_with_zeroes,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorOpenSearchCluster", [props]))

    @jsii.member(jsii_name="monitorQueueProcessingEc2Service")
    def monitor_queue_processing_ec2_service(
        self,
        *,
        ec2_service: monocdk.aws_ecs_patterns.QueueProcessingEc2Service,
        add_dead_letter_queue_alarms: typing.Optional[BaseDlqAlarms] = None,
        add_queue_alarms: typing.Optional[BaseSqsQueueAlarms] = None,
        add_service_alarms: typing.Optional[BaseFargateServiceAlarms] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param ec2_service: 
        :param add_dead_letter_queue_alarms: 
        :param add_queue_alarms: 
        :param add_service_alarms: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = QueueProcessingEc2ServiceMonitoringProps(
            ec2_service=ec2_service,
            add_dead_letter_queue_alarms=add_dead_letter_queue_alarms,
            add_queue_alarms=add_queue_alarms,
            add_service_alarms=add_service_alarms,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorQueueProcessingEc2Service", [props]))

    @jsii.member(jsii_name="monitorQueueProcessingFargateService")
    def monitor_queue_processing_fargate_service(
        self,
        *,
        fargate_service: monocdk.aws_ecs_patterns.QueueProcessingFargateService,
        add_dead_letter_queue_alarms: typing.Optional[BaseDlqAlarms] = None,
        add_queue_alarms: typing.Optional[BaseSqsQueueAlarms] = None,
        add_service_alarms: typing.Optional[BaseFargateServiceAlarms] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param fargate_service: 
        :param add_dead_letter_queue_alarms: 
        :param add_queue_alarms: 
        :param add_service_alarms: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = QueueProcessingFargateServiceMonitoringProps(
            fargate_service=fargate_service,
            add_dead_letter_queue_alarms=add_dead_letter_queue_alarms,
            add_queue_alarms=add_queue_alarms,
            add_service_alarms=add_service_alarms,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorQueueProcessingFargateService", [props]))

    @jsii.member(jsii_name="monitorRdsCluster")
    def monitor_rds_cluster(
        self,
        *,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        cluster_identifier: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_cpu_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param cluster_identifier: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = RdsClusterMonitoringProps(
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            cluster_identifier=cluster_identifier,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorRdsCluster", [props]))

    @jsii.member(jsii_name="monitorRedshiftCluster")
    def monitor_redshift_cluster(
        self,
        *,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        cluster_identifier: builtins.str,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_cpu_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param cluster_identifier: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = RedshiftClusterMonitoringProps(
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_disk_space_usage_alarm=add_disk_space_usage_alarm,
            cluster_identifier=cluster_identifier,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorRedshiftCluster", [props]))

    @jsii.member(jsii_name="monitorS3Bucket")
    def monitor_s3_bucket(
        self,
        *,
        bucket: monocdk.aws_s3.IBucket,
        storage_type: typing.Optional[StorageType] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param bucket: 
        :param storage_type: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = S3BucketMonitoringProps(
            bucket=bucket,
            storage_type=storage_type,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorS3Bucket", [props]))

    @jsii.member(jsii_name="monitorSecretsManagerSecret")
    def monitor_secrets_manager_secret(
        self,
        *,
        add_days_since_last_change_alarm: typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]] = None,
        add_days_since_last_rotation_alarm: typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]] = None,
        show_last_rotation_widget: typing.Optional[builtins.bool] = None,
        secret: monocdk.aws_secretsmanager.ISecret,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_days_since_last_change_alarm: 
        :param add_days_since_last_rotation_alarm: 
        :param show_last_rotation_widget: Default: true, if ``addDaysSinceLastRotationAlarm`` is set, otherwise ``false``.
        :param secret: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SecretsManagerSecretMonitoringProps(
            add_days_since_last_change_alarm=add_days_since_last_change_alarm,
            add_days_since_last_rotation_alarm=add_days_since_last_rotation_alarm,
            show_last_rotation_widget=show_last_rotation_widget,
            secret=secret,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorSecretsManagerSecret", [props]))

    @jsii.member(jsii_name="monitorSimpleEc2Service")
    def monitor_simple_ec2_service(
        self,
        *,
        ec2_service: monocdk.aws_ecs.Ec2Service,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param ec2_service: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SimpleEc2ServiceMonitoringProps(
            ec2_service=ec2_service,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorSimpleEc2Service", [props]))

    @jsii.member(jsii_name="monitorSimpleFargateService")
    def monitor_simple_fargate_service(
        self,
        *,
        fargate_service: monocdk.aws_ecs.FargateService,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param fargate_service: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SimpleFargateServiceMonitoringProps(
            fargate_service=fargate_service,
            use_created_alarms=use_created_alarms,
            add_cpu_usage_alarm=add_cpu_usage_alarm,
            add_memory_usage_alarm=add_memory_usage_alarm,
            add_running_task_count_alarm=add_running_task_count_alarm,
            max_auto_scaling_task_count=max_auto_scaling_task_count,
            min_auto_scaling_task_count=min_auto_scaling_task_count,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorSimpleFargateService", [props]))

    @jsii.member(jsii_name="monitorSnsTopic")
    def monitor_sns_topic(
        self,
        *,
        add_max_number_of_messages_published_alarm: typing.Optional[typing.Mapping[builtins.str, HighMessagesPublishedThreshold]] = None,
        add_message_notifications_failed_alarm: typing.Optional[typing.Mapping[builtins.str, NotificationsFailedThreshold]] = None,
        add_min_number_of_messages_published_alarm: typing.Optional[typing.Mapping[builtins.str, LowMessagesPublishedThreshold]] = None,
        topic: monocdk.aws_sns.ITopic,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_max_number_of_messages_published_alarm: 
        :param add_message_notifications_failed_alarm: 
        :param add_min_number_of_messages_published_alarm: 
        :param topic: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SnsTopicMonitoringProps(
            add_max_number_of_messages_published_alarm=add_max_number_of_messages_published_alarm,
            add_message_notifications_failed_alarm=add_message_notifications_failed_alarm,
            add_min_number_of_messages_published_alarm=add_min_number_of_messages_published_alarm,
            topic=topic,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorSnsTopic", [props]))

    @jsii.member(jsii_name="monitorSqsQueue")
    def monitor_sqs_queue(
        self,
        *,
        queue: monocdk.aws_sqs.IQueue,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        add_queue_max_time_to_drain_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]] = None,
        add_queue_min_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]] = None,
        add_queue_min_size_alarm: typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param queue: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_queue_max_incoming_messages_alarm: 
        :param add_queue_max_message_age_alarm: 
        :param add_queue_max_size_alarm: 
        :param add_queue_max_time_to_drain_messages_alarm: 
        :param add_queue_min_incoming_messages_alarm: 
        :param add_queue_min_size_alarm: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SqsQueueMonitoringProps(
            queue=queue,
            use_created_alarms=use_created_alarms,
            add_queue_max_incoming_messages_alarm=add_queue_max_incoming_messages_alarm,
            add_queue_max_message_age_alarm=add_queue_max_message_age_alarm,
            add_queue_max_size_alarm=add_queue_max_size_alarm,
            add_queue_max_time_to_drain_messages_alarm=add_queue_max_time_to_drain_messages_alarm,
            add_queue_min_incoming_messages_alarm=add_queue_min_incoming_messages_alarm,
            add_queue_min_size_alarm=add_queue_min_size_alarm,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorSqsQueue", [props]))

    @jsii.member(jsii_name="monitorSqsQueueWithDlq")
    def monitor_sqs_queue_with_dlq(
        self,
        *,
        dead_letter_queue: monocdk.aws_sqs.IQueue,
        add_dead_letter_queue_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        add_dead_letter_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_dead_letter_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_dead_letter_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        queue: monocdk.aws_sqs.IQueue,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        add_queue_max_time_to_drain_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]] = None,
        add_queue_min_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]] = None,
        add_queue_min_size_alarm: typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param dead_letter_queue: 
        :param add_dead_letter_queue_to_summary_dashboard: (experimental) Indicates whether the DLQ monitoring should be added to summary dashboard. Default: true
        :param add_dead_letter_queue_max_incoming_messages_alarm: 
        :param add_dead_letter_queue_max_message_age_alarm: 
        :param add_dead_letter_queue_max_size_alarm: 
        :param queue: 
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_queue_max_incoming_messages_alarm: 
        :param add_queue_max_message_age_alarm: 
        :param add_queue_max_size_alarm: 
        :param add_queue_max_time_to_drain_messages_alarm: 
        :param add_queue_min_incoming_messages_alarm: 
        :param add_queue_min_size_alarm: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = SqsQueueMonitoringWithDlqProps(
            dead_letter_queue=dead_letter_queue,
            add_dead_letter_queue_to_summary_dashboard=add_dead_letter_queue_to_summary_dashboard,
            add_dead_letter_queue_max_incoming_messages_alarm=add_dead_letter_queue_max_incoming_messages_alarm,
            add_dead_letter_queue_max_message_age_alarm=add_dead_letter_queue_max_message_age_alarm,
            add_dead_letter_queue_max_size_alarm=add_dead_letter_queue_max_size_alarm,
            queue=queue,
            use_created_alarms=use_created_alarms,
            add_queue_max_incoming_messages_alarm=add_queue_max_incoming_messages_alarm,
            add_queue_max_message_age_alarm=add_queue_max_message_age_alarm,
            add_queue_max_size_alarm=add_queue_max_size_alarm,
            add_queue_max_time_to_drain_messages_alarm=add_queue_max_time_to_drain_messages_alarm,
            add_queue_min_incoming_messages_alarm=add_queue_min_incoming_messages_alarm,
            add_queue_min_size_alarm=add_queue_min_size_alarm,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorSqsQueueWithDlq", [props]))

    @jsii.member(jsii_name="monitorStepFunction")
    def monitor_step_function(
        self,
        *,
        add_aborted_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_execution_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_min_started_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, MinRunningTaskCountThreshold]] = None,
        add_throttled_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_timed_out_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        state_machine: monocdk.aws_stepfunctions.IStateMachine,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_aborted_execution_count_alarm: 
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_execution_count_alarm: 
        :param add_failed_execution_rate_alarm: 
        :param add_min_started_execution_count_alarm: (experimental) Add minimum started execution count alarm for the stepfunctions.
        :param add_throttled_execution_count_alarm: 
        :param add_timed_out_execution_count_alarm: 
        :param state_machine: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionMonitoringProps(
            add_aborted_execution_count_alarm=add_aborted_execution_count_alarm,
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_execution_count_alarm=add_failed_execution_count_alarm,
            add_failed_execution_rate_alarm=add_failed_execution_rate_alarm,
            add_min_started_execution_count_alarm=add_min_started_execution_count_alarm,
            add_throttled_execution_count_alarm=add_throttled_execution_count_alarm,
            add_timed_out_execution_count_alarm=add_timed_out_execution_count_alarm,
            state_machine=state_machine,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorStepFunction", [props]))

    @jsii.member(jsii_name="monitorStepFunctionActivity")
    def monitor_step_function_activity(
        self,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_activities_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_activities_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_activities_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        activity: monocdk.aws_stepfunctions.IActivity,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_activities_count_alarm: 
        :param add_failed_activities_rate_alarm: 
        :param add_timed_out_activities_count_alarm: 
        :param activity: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionActivityMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_activities_count_alarm=add_failed_activities_count_alarm,
            add_failed_activities_rate_alarm=add_failed_activities_rate_alarm,
            add_timed_out_activities_count_alarm=add_timed_out_activities_count_alarm,
            activity=activity,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorStepFunctionActivity", [props]))

    @jsii.member(jsii_name="monitorStepFunctionLambdaIntegration")
    def monitor_step_function_lambda_integration(
        self,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_functions_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_functions_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_functions_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        lambda_function: monocdk.aws_lambda.IFunction,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_functions_count_alarm: 
        :param add_failed_functions_rate_alarm: 
        :param add_timed_out_functions_count_alarm: 
        :param lambda_function: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionLambdaIntegrationMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_functions_count_alarm=add_failed_functions_count_alarm,
            add_failed_functions_rate_alarm=add_failed_functions_rate_alarm,
            add_timed_out_functions_count_alarm=add_timed_out_functions_count_alarm,
            lambda_function=lambda_function,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorStepFunctionLambdaIntegration", [props]))

    @jsii.member(jsii_name="monitorStepFunctionServiceIntegration")
    def monitor_step_function_service_integration(
        self,
        *,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_service_integrations_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_service_integrations_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_service_integrations_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        service_integration_resource_arn: builtins.str,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> "MonitoringFacade":
        '''
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_service_integrations_count_alarm: 
        :param add_failed_service_integrations_rate_alarm: 
        :param add_timed_out_service_integrations_count_alarm: 
        :param service_integration_resource_arn: 
        :param rate_computation_method: Default: average
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        props = StepFunctionServiceIntegrationMonitoringProps(
            add_duration_p50_alarm=add_duration_p50_alarm,
            add_duration_p90_alarm=add_duration_p90_alarm,
            add_duration_p99_alarm=add_duration_p99_alarm,
            add_failed_service_integrations_count_alarm=add_failed_service_integrations_count_alarm,
            add_failed_service_integrations_rate_alarm=add_failed_service_integrations_rate_alarm,
            add_timed_out_service_integrations_count_alarm=add_timed_out_service_integrations_count_alarm,
            service_integration_resource_arn=service_integration_resource_arn,
            rate_computation_method=rate_computation_method,
            use_created_alarms=use_created_alarms,
            alarm_friendly_name=alarm_friendly_name,
            human_readable_name=human_readable_name,
            local_alarm_name_prefix_override=local_alarm_name_prefix_override,
            add_to_alarm_dashboard=add_to_alarm_dashboard,
            add_to_detail_dashboard=add_to_detail_dashboard,
            add_to_summary_dashboard=add_to_summary_dashboard,
        )

        return typing.cast("MonitoringFacade", jsii.invoke(self, "monitorStepFunctionServiceIntegration", [props]))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="alarmFactoryDefaults")
    def _alarm_factory_defaults(self) -> AlarmFactoryDefaults:
        '''
        :stability: experimental
        '''
        return typing.cast(AlarmFactoryDefaults, jsii.get(self, "alarmFactoryDefaults"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="createdSegments")
    def _created_segments(self) -> typing.List[IDashboardSegment]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.List[IDashboardSegment], jsii.get(self, "createdSegments"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="metricFactoryDefaults")
    def _metric_factory_defaults(self) -> MetricFactoryDefaults:
        '''
        :stability: experimental
        '''
        return typing.cast(MetricFactoryDefaults, jsii.get(self, "metricFactoryDefaults"))

    @builtins.property # type: ignore[misc]
    @jsii.member(jsii_name="dashboardFactory")
    def _dashboard_factory(self) -> typing.Optional[IDashboardFactory]:
        '''
        :stability: experimental
        '''
        return typing.cast(typing.Optional[IDashboardFactory], jsii.get(self, "dashboardFactory"))


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.NameResolutionInput",
    jsii_struct_bases=[UserProvidedNames],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "fallback_construct_name": "fallbackConstructName",
        "named_construct": "namedConstruct",
    },
)
class NameResolutionInput(UserProvidedNames):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        fallback_construct_name: typing.Optional[builtins.str] = None,
        named_construct: typing.Optional[monocdk.IConstruct] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param fallback_construct_name: (experimental) Fallback name before we fallback to extracting name from the construct itself. This might be some construct reference, such is cluster ID, stream name, and so on. Default: use namedConstruct to extract the name
        :param named_construct: (experimental) Construct that this naming strategy is naming. It is used as a last resort for naming.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {}
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if fallback_construct_name is not None:
            self._values["fallback_construct_name"] = fallback_construct_name
        if named_construct is not None:
            self._values["named_construct"] = named_construct

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fallback_construct_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Fallback name before we fallback to extracting name from the construct itself.

        This might be some construct reference, such is cluster ID, stream name, and so on.

        :default: use namedConstruct to extract the name

        :stability: experimental
        '''
        result = self._values.get("fallback_construct_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def named_construct(self) -> typing.Optional[monocdk.IConstruct]:
        '''(experimental) Construct that this naming strategy is naming.

        It is used as a last resort for naming.

        :stability: experimental
        '''
        result = self._values.get("named_construct")
        return typing.cast(typing.Optional[monocdk.IConstruct], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NameResolutionInput(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.NetworkLoadBalancerMonitoringProps",
    jsii_struct_bases=[NetworkLoadBalancerMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "network_load_balancer": "networkLoadBalancer",
        "network_target_group": "networkTargetGroup",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_healthy_task_count_alarm": "addHealthyTaskCountAlarm",
        "add_healthy_task_percent_alarm": "addHealthyTaskPercentAlarm",
        "add_min_processed_bytes_alarm": "addMinProcessedBytesAlarm",
        "add_unhealthy_task_count_alarm": "addUnhealthyTaskCountAlarm",
    },
)
class NetworkLoadBalancerMonitoringProps(
    NetworkLoadBalancerMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        network_load_balancer: monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer,
        network_target_group: monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_healthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]] = None,
        add_healthy_task_percent_alarm: typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]] = None,
        add_min_processed_bytes_alarm: typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]] = None,
        add_unhealthy_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]] = None,
    ) -> None:
        '''
        :param network_load_balancer: 
        :param network_target_group: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_healthy_task_count_alarm: 
        :param add_healthy_task_percent_alarm: 
        :param add_min_processed_bytes_alarm: 
        :param add_unhealthy_task_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "network_load_balancer": network_load_balancer,
            "network_target_group": network_target_group,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_healthy_task_count_alarm is not None:
            self._values["add_healthy_task_count_alarm"] = add_healthy_task_count_alarm
        if add_healthy_task_percent_alarm is not None:
            self._values["add_healthy_task_percent_alarm"] = add_healthy_task_percent_alarm
        if add_min_processed_bytes_alarm is not None:
            self._values["add_min_processed_bytes_alarm"] = add_min_processed_bytes_alarm
        if add_unhealthy_task_count_alarm is not None:
            self._values["add_unhealthy_task_count_alarm"] = add_unhealthy_task_count_alarm

    @builtins.property
    def network_load_balancer(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_load_balancer")
        assert result is not None, "Required property 'network_load_balancer' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkLoadBalancer, result)

    @builtins.property
    def network_target_group(
        self,
    ) -> monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("network_target_group")
        assert result is not None, "Required property 'network_target_group' is missing"
        return typing.cast(monocdk.aws_elasticloadbalancingv2.NetworkTargetGroup, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_healthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskCountThreshold]], result)

    @builtins.property
    def add_healthy_task_percent_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_healthy_task_percent_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HealthyTaskPercentThreshold]], result)

    @builtins.property
    def add_min_processed_bytes_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_processed_bytes_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinProcessedBytesThreshold]], result)

    @builtins.property
    def add_unhealthy_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_unhealthy_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UnhealthyTaskCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkLoadBalancerMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.OpenSearchClusterMonitoringProps",
    jsii_struct_bases=[OpenSearchClusterMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "domain": "domain",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cluster_automated_snapshot_failure_alarm": "addClusterAutomatedSnapshotFailureAlarm",
        "add_cluster_index_writes_blocked_alarm": "addClusterIndexWritesBlockedAlarm",
        "add_cluster_node_count_alarm": "addClusterNodeCountAlarm",
        "add_cluster_status_alarm": "addClusterStatusAlarm",
        "add_cpu_space_usage_alarm": "addCpuSpaceUsageAlarm",
        "add_disk_space_usage_alarm": "addDiskSpaceUsageAlarm",
        "add_indexing_latency_p50_alarm": "addIndexingLatencyP50Alarm",
        "add_indexing_latency_p90_alarm": "addIndexingLatencyP90Alarm",
        "add_indexing_latency_p99_alarm": "addIndexingLatencyP99Alarm",
        "add_jvm_memory_pressure_alarm": "addJvmMemoryPressureAlarm",
        "add_kms_key_error_alarm": "addKmsKeyErrorAlarm",
        "add_kms_key_inaccessible_alarm": "addKmsKeyInaccessibleAlarm",
        "add_master_cpu_space_usage_alarm": "addMasterCpuSpaceUsageAlarm",
        "add_master_jvm_memory_pressure_alarm": "addMasterJvmMemoryPressureAlarm",
        "add_search_latency_p50_alarm": "addSearchLatencyP50Alarm",
        "add_search_latency_p90_alarm": "addSearchLatencyP90Alarm",
        "add_search_latency_p99_alarm": "addSearchLatencyP99Alarm",
    },
)
class OpenSearchClusterMonitoringProps(
    OpenSearchClusterMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        domain: typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain],
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cluster_automated_snapshot_failure_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterAutomatedSnapshotFailureThreshold]] = None,
        add_cluster_index_writes_blocked_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterIndexWritesBlockedThreshold]] = None,
        add_cluster_node_count_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterNodesThreshold]] = None,
        add_cluster_status_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterStatusCustomization]] = None,
        add_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_indexing_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_indexing_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_kms_key_error_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyErrorThreshold]] = None,
        add_kms_key_inaccessible_alarm: typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyInaccessibleThreshold]] = None,
        add_master_cpu_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_master_jvm_memory_pressure_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_search_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_search_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
    ) -> None:
        '''
        :param domain: 
        :param fill_tps_with_zeroes: Default: true
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cluster_automated_snapshot_failure_alarm: 
        :param add_cluster_index_writes_blocked_alarm: 
        :param add_cluster_node_count_alarm: 
        :param add_cluster_status_alarm: 
        :param add_cpu_space_usage_alarm: 
        :param add_disk_space_usage_alarm: 
        :param add_indexing_latency_p50_alarm: 
        :param add_indexing_latency_p90_alarm: 
        :param add_indexing_latency_p99_alarm: 
        :param add_jvm_memory_pressure_alarm: 
        :param add_kms_key_error_alarm: 
        :param add_kms_key_inaccessible_alarm: 
        :param add_master_cpu_space_usage_alarm: 
        :param add_master_jvm_memory_pressure_alarm: 
        :param add_search_latency_p50_alarm: 
        :param add_search_latency_p90_alarm: 
        :param add_search_latency_p99_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "domain": domain,
        }
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cluster_automated_snapshot_failure_alarm is not None:
            self._values["add_cluster_automated_snapshot_failure_alarm"] = add_cluster_automated_snapshot_failure_alarm
        if add_cluster_index_writes_blocked_alarm is not None:
            self._values["add_cluster_index_writes_blocked_alarm"] = add_cluster_index_writes_blocked_alarm
        if add_cluster_node_count_alarm is not None:
            self._values["add_cluster_node_count_alarm"] = add_cluster_node_count_alarm
        if add_cluster_status_alarm is not None:
            self._values["add_cluster_status_alarm"] = add_cluster_status_alarm
        if add_cpu_space_usage_alarm is not None:
            self._values["add_cpu_space_usage_alarm"] = add_cpu_space_usage_alarm
        if add_disk_space_usage_alarm is not None:
            self._values["add_disk_space_usage_alarm"] = add_disk_space_usage_alarm
        if add_indexing_latency_p50_alarm is not None:
            self._values["add_indexing_latency_p50_alarm"] = add_indexing_latency_p50_alarm
        if add_indexing_latency_p90_alarm is not None:
            self._values["add_indexing_latency_p90_alarm"] = add_indexing_latency_p90_alarm
        if add_indexing_latency_p99_alarm is not None:
            self._values["add_indexing_latency_p99_alarm"] = add_indexing_latency_p99_alarm
        if add_jvm_memory_pressure_alarm is not None:
            self._values["add_jvm_memory_pressure_alarm"] = add_jvm_memory_pressure_alarm
        if add_kms_key_error_alarm is not None:
            self._values["add_kms_key_error_alarm"] = add_kms_key_error_alarm
        if add_kms_key_inaccessible_alarm is not None:
            self._values["add_kms_key_inaccessible_alarm"] = add_kms_key_inaccessible_alarm
        if add_master_cpu_space_usage_alarm is not None:
            self._values["add_master_cpu_space_usage_alarm"] = add_master_cpu_space_usage_alarm
        if add_master_jvm_memory_pressure_alarm is not None:
            self._values["add_master_jvm_memory_pressure_alarm"] = add_master_jvm_memory_pressure_alarm
        if add_search_latency_p50_alarm is not None:
            self._values["add_search_latency_p50_alarm"] = add_search_latency_p50_alarm
        if add_search_latency_p90_alarm is not None:
            self._values["add_search_latency_p90_alarm"] = add_search_latency_p90_alarm
        if add_search_latency_p99_alarm is not None:
            self._values["add_search_latency_p99_alarm"] = add_search_latency_p99_alarm

    @builtins.property
    def domain(
        self,
    ) -> typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain]:
        '''
        :stability: experimental
        '''
        result = self._values.get("domain")
        assert result is not None, "Required property 'domain' is missing"
        return typing.cast(typing.Union[monocdk.aws_elasticsearch.IDomain, monocdk.aws_elasticsearch.CfnDomain, monocdk.aws_opensearchservice.IDomain, monocdk.aws_opensearchservice.CfnDomain], result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cluster_automated_snapshot_failure_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterAutomatedSnapshotFailureThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cluster_automated_snapshot_failure_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterAutomatedSnapshotFailureThreshold]], result)

    @builtins.property
    def add_cluster_index_writes_blocked_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterIndexWritesBlockedThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cluster_index_writes_blocked_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterIndexWritesBlockedThreshold]], result)

    @builtins.property
    def add_cluster_node_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterNodesThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cluster_node_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterNodesThreshold]], result)

    @builtins.property
    def add_cluster_status_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterStatusCustomization]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cluster_status_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, OpenSearchClusterStatusCustomization]], result)

    @builtins.property
    def add_cpu_space_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_space_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_disk_space_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_disk_space_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_indexing_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_indexing_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_indexing_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_indexing_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_indexing_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_indexing_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_jvm_memory_pressure_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_jvm_memory_pressure_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_kms_key_error_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyErrorThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_kms_key_error_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyErrorThreshold]], result)

    @builtins.property
    def add_kms_key_inaccessible_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyInaccessibleThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_kms_key_inaccessible_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, OpenSearchKmsKeyInaccessibleThreshold]], result)

    @builtins.property
    def add_master_cpu_space_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_master_cpu_space_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_master_jvm_memory_pressure_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_master_jvm_memory_pressure_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_search_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_search_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_search_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_search_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_search_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_search_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpenSearchClusterMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.QueueProcessingEc2ServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "ec2_service": "ec2Service",
        "add_dead_letter_queue_alarms": "addDeadLetterQueueAlarms",
        "add_queue_alarms": "addQueueAlarms",
        "add_service_alarms": "addServiceAlarms",
    },
)
class QueueProcessingEc2ServiceMonitoringProps(BaseMonitoringProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        ec2_service: monocdk.aws_ecs_patterns.QueueProcessingEc2Service,
        add_dead_letter_queue_alarms: typing.Optional[BaseDlqAlarms] = None,
        add_queue_alarms: typing.Optional[BaseSqsQueueAlarms] = None,
        add_service_alarms: typing.Optional[BaseFargateServiceAlarms] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param ec2_service: 
        :param add_dead_letter_queue_alarms: 
        :param add_queue_alarms: 
        :param add_service_alarms: 

        :stability: experimental
        '''
        if isinstance(add_dead_letter_queue_alarms, dict):
            add_dead_letter_queue_alarms = BaseDlqAlarms(**add_dead_letter_queue_alarms)
        if isinstance(add_queue_alarms, dict):
            add_queue_alarms = BaseSqsQueueAlarms(**add_queue_alarms)
        if isinstance(add_service_alarms, dict):
            add_service_alarms = BaseFargateServiceAlarms(**add_service_alarms)
        self._values: typing.Dict[str, typing.Any] = {
            "ec2_service": ec2_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_dead_letter_queue_alarms is not None:
            self._values["add_dead_letter_queue_alarms"] = add_dead_letter_queue_alarms
        if add_queue_alarms is not None:
            self._values["add_queue_alarms"] = add_queue_alarms
        if add_service_alarms is not None:
            self._values["add_service_alarms"] = add_service_alarms

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def ec2_service(self) -> monocdk.aws_ecs_patterns.QueueProcessingEc2Service:
        '''
        :stability: experimental
        '''
        result = self._values.get("ec2_service")
        assert result is not None, "Required property 'ec2_service' is missing"
        return typing.cast(monocdk.aws_ecs_patterns.QueueProcessingEc2Service, result)

    @builtins.property
    def add_dead_letter_queue_alarms(self) -> typing.Optional[BaseDlqAlarms]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_alarms")
        return typing.cast(typing.Optional[BaseDlqAlarms], result)

    @builtins.property
    def add_queue_alarms(self) -> typing.Optional[BaseSqsQueueAlarms]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_alarms")
        return typing.cast(typing.Optional[BaseSqsQueueAlarms], result)

    @builtins.property
    def add_service_alarms(self) -> typing.Optional[BaseFargateServiceAlarms]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_service_alarms")
        return typing.cast(typing.Optional[BaseFargateServiceAlarms], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "QueueProcessingEc2ServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.QueueProcessingFargateServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "fargate_service": "fargateService",
        "add_dead_letter_queue_alarms": "addDeadLetterQueueAlarms",
        "add_queue_alarms": "addQueueAlarms",
        "add_service_alarms": "addServiceAlarms",
    },
)
class QueueProcessingFargateServiceMonitoringProps(BaseMonitoringProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        fargate_service: monocdk.aws_ecs_patterns.QueueProcessingFargateService,
        add_dead_letter_queue_alarms: typing.Optional[BaseDlqAlarms] = None,
        add_queue_alarms: typing.Optional[BaseSqsQueueAlarms] = None,
        add_service_alarms: typing.Optional[BaseFargateServiceAlarms] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param fargate_service: 
        :param add_dead_letter_queue_alarms: 
        :param add_queue_alarms: 
        :param add_service_alarms: 

        :stability: experimental
        '''
        if isinstance(add_dead_letter_queue_alarms, dict):
            add_dead_letter_queue_alarms = BaseDlqAlarms(**add_dead_letter_queue_alarms)
        if isinstance(add_queue_alarms, dict):
            add_queue_alarms = BaseSqsQueueAlarms(**add_queue_alarms)
        if isinstance(add_service_alarms, dict):
            add_service_alarms = BaseFargateServiceAlarms(**add_service_alarms)
        self._values: typing.Dict[str, typing.Any] = {
            "fargate_service": fargate_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_dead_letter_queue_alarms is not None:
            self._values["add_dead_letter_queue_alarms"] = add_dead_letter_queue_alarms
        if add_queue_alarms is not None:
            self._values["add_queue_alarms"] = add_queue_alarms
        if add_service_alarms is not None:
            self._values["add_service_alarms"] = add_service_alarms

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def fargate_service(self) -> monocdk.aws_ecs_patterns.QueueProcessingFargateService:
        '''
        :stability: experimental
        '''
        result = self._values.get("fargate_service")
        assert result is not None, "Required property 'fargate_service' is missing"
        return typing.cast(monocdk.aws_ecs_patterns.QueueProcessingFargateService, result)

    @builtins.property
    def add_dead_letter_queue_alarms(self) -> typing.Optional[BaseDlqAlarms]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_alarms")
        return typing.cast(typing.Optional[BaseDlqAlarms], result)

    @builtins.property
    def add_queue_alarms(self) -> typing.Optional[BaseSqsQueueAlarms]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_alarms")
        return typing.cast(typing.Optional[BaseSqsQueueAlarms], result)

    @builtins.property
    def add_service_alarms(self) -> typing.Optional[BaseFargateServiceAlarms]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_service_alarms")
        return typing.cast(typing.Optional[BaseFargateServiceAlarms], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "QueueProcessingFargateServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RdsClusterMonitoringProps",
    jsii_struct_bases=[RdsClusterMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "cluster_identifier": "clusterIdentifier",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_disk_space_usage_alarm": "addDiskSpaceUsageAlarm",
    },
)
class RdsClusterMonitoringProps(RdsClusterMetricFactoryProps, BaseMonitoringProps):
    def __init__(
        self,
        *,
        cluster_identifier: builtins.str,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
    ) -> None:
        '''
        :param cluster_identifier: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_disk_space_usage_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_identifier": cluster_identifier,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_disk_space_usage_alarm is not None:
            self._values["add_disk_space_usage_alarm"] = add_disk_space_usage_alarm

    @builtins.property
    def cluster_identifier(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("cluster_identifier")
        assert result is not None, "Required property 'cluster_identifier' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_disk_space_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_disk_space_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.RedshiftClusterMonitoringProps",
    jsii_struct_bases=[RedshiftClusterMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "cluster_identifier": "clusterIdentifier",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_disk_space_usage_alarm": "addDiskSpaceUsageAlarm",
    },
)
class RedshiftClusterMonitoringProps(
    RedshiftClusterMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        cluster_identifier: builtins.str,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_disk_space_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
    ) -> None:
        '''
        :param cluster_identifier: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_disk_space_usage_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "cluster_identifier": cluster_identifier,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_disk_space_usage_alarm is not None:
            self._values["add_disk_space_usage_alarm"] = add_disk_space_usage_alarm

    @builtins.property
    def cluster_identifier(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("cluster_identifier")
        assert result is not None, "Required property 'cluster_identifier' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_disk_space_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_disk_space_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftClusterMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.S3BucketMonitoringProps",
    jsii_struct_bases=[S3BucketMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "bucket": "bucket",
        "storage_type": "storageType",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
    },
)
class S3BucketMonitoringProps(S3BucketMetricFactoryProps, BaseMonitoringProps):
    def __init__(
        self,
        *,
        bucket: monocdk.aws_s3.IBucket,
        storage_type: typing.Optional[StorageType] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
    ) -> None:
        '''
        :param bucket: 
        :param storage_type: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "bucket": bucket,
        }
        if storage_type is not None:
            self._values["storage_type"] = storage_type
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def bucket(self) -> monocdk.aws_s3.IBucket:
        '''
        :stability: experimental
        '''
        result = self._values.get("bucket")
        assert result is not None, "Required property 'bucket' is missing"
        return typing.cast(monocdk.aws_s3.IBucket, result)

    @builtins.property
    def storage_type(self) -> typing.Optional[StorageType]:
        '''
        :stability: experimental
        '''
        result = self._values.get("storage_type")
        return typing.cast(typing.Optional[StorageType], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SecretsManagerSecretMonitoringProps",
    jsii_struct_bases=[SecretsManagerSecretMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "secret": "secret",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_days_since_last_change_alarm": "addDaysSinceLastChangeAlarm",
        "add_days_since_last_rotation_alarm": "addDaysSinceLastRotationAlarm",
        "show_last_rotation_widget": "showLastRotationWidget",
    },
)
class SecretsManagerSecretMonitoringProps(
    SecretsManagerSecretMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        secret: monocdk.aws_secretsmanager.ISecret,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_days_since_last_change_alarm: typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]] = None,
        add_days_since_last_rotation_alarm: typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]] = None,
        show_last_rotation_widget: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''(experimental) Monitoring props for Secrets Manager secrets.

        :param secret: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_days_since_last_change_alarm: 
        :param add_days_since_last_rotation_alarm: 
        :param show_last_rotation_widget: Default: true, if ``addDaysSinceLastRotationAlarm`` is set, otherwise ``false``.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "secret": secret,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_days_since_last_change_alarm is not None:
            self._values["add_days_since_last_change_alarm"] = add_days_since_last_change_alarm
        if add_days_since_last_rotation_alarm is not None:
            self._values["add_days_since_last_rotation_alarm"] = add_days_since_last_rotation_alarm
        if show_last_rotation_widget is not None:
            self._values["show_last_rotation_widget"] = show_last_rotation_widget

    @builtins.property
    def secret(self) -> monocdk.aws_secretsmanager.ISecret:
        '''
        :stability: experimental
        '''
        result = self._values.get("secret")
        assert result is not None, "Required property 'secret' is missing"
        return typing.cast(monocdk.aws_secretsmanager.ISecret, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_days_since_last_change_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_days_since_last_change_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]], result)

    @builtins.property
    def add_days_since_last_rotation_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_days_since_last_rotation_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DaysSinceUpdateThreshold]], result)

    @builtins.property
    def show_last_rotation_widget(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true, if ``addDaysSinceLastRotationAlarm`` is set, otherwise ``false``.

        :stability: experimental
        '''
        result = self._values.get("show_last_rotation_widget")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsManagerSecretMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SimpleEc2ServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, BaseEc2ServiceAlarms],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "ec2_service": "ec2Service",
    },
)
class SimpleEc2ServiceMonitoringProps(BaseMonitoringProps, BaseEc2ServiceAlarms):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        ec2_service: monocdk.aws_ecs.Ec2Service,
    ) -> None:
        '''(experimental) Monitoring props for Simple EC2 service.

        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param ec2_service: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "ec2_service": ec2_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def ec2_service(self) -> monocdk.aws_ecs.Ec2Service:
        '''
        :stability: experimental
        '''
        result = self._values.get("ec2_service")
        assert result is not None, "Required property 'ec2_service' is missing"
        return typing.cast(monocdk.aws_ecs.Ec2Service, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SimpleEc2ServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SimpleFargateServiceMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, BaseFargateServiceAlarms],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_cpu_usage_alarm": "addCpuUsageAlarm",
        "add_memory_usage_alarm": "addMemoryUsageAlarm",
        "add_running_task_count_alarm": "addRunningTaskCountAlarm",
        "max_auto_scaling_task_count": "maxAutoScalingTaskCount",
        "min_auto_scaling_task_count": "minAutoScalingTaskCount",
        "fargate_service": "fargateService",
    },
)
class SimpleFargateServiceMonitoringProps(
    BaseMonitoringProps,
    BaseFargateServiceAlarms,
):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_cpu_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_memory_usage_alarm: typing.Optional[typing.Mapping[builtins.str, UsageThreshold]] = None,
        add_running_task_count_alarm: typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]] = None,
        max_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        min_auto_scaling_task_count: typing.Optional[jsii.Number] = None,
        fargate_service: monocdk.aws_ecs.FargateService,
    ) -> None:
        '''(experimental) Monitoring props for Simple Fargate service.

        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_cpu_usage_alarm: 
        :param add_memory_usage_alarm: 
        :param add_running_task_count_alarm: (experimental) Container Insights needs to be enabled for the cluster for this alarm.
        :param max_auto_scaling_task_count: (experimental) maximum number of tasks, as specified in your auto scaling config.
        :param min_auto_scaling_task_count: (experimental) minimum number of tasks, as specified in your auto scaling config.
        :param fargate_service: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "fargate_service": fargate_service,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_cpu_usage_alarm is not None:
            self._values["add_cpu_usage_alarm"] = add_cpu_usage_alarm
        if add_memory_usage_alarm is not None:
            self._values["add_memory_usage_alarm"] = add_memory_usage_alarm
        if add_running_task_count_alarm is not None:
            self._values["add_running_task_count_alarm"] = add_running_task_count_alarm
        if max_auto_scaling_task_count is not None:
            self._values["max_auto_scaling_task_count"] = max_auto_scaling_task_count
        if min_auto_scaling_task_count is not None:
            self._values["min_auto_scaling_task_count"] = min_auto_scaling_task_count

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_cpu_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_cpu_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_memory_usage_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, UsageThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_memory_usage_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, UsageThreshold]], result)

    @builtins.property
    def add_running_task_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]]:
        '''(experimental) Container Insights needs to be enabled for the cluster for this alarm.

        :stability: experimental
        '''
        result = self._values.get("add_running_task_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, RunningTaskCountThreshold]], result)

    @builtins.property
    def max_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) maximum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("max_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def min_auto_scaling_task_count(self) -> typing.Optional[jsii.Number]:
        '''(experimental) minimum number of tasks, as specified in your auto scaling config.

        :stability: experimental
        '''
        result = self._values.get("min_auto_scaling_task_count")
        return typing.cast(typing.Optional[jsii.Number], result)

    @builtins.property
    def fargate_service(self) -> monocdk.aws_ecs.FargateService:
        '''
        :stability: experimental
        '''
        result = self._values.get("fargate_service")
        assert result is not None, "Required property 'fargate_service' is missing"
        return typing.cast(monocdk.aws_ecs.FargateService, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SimpleFargateServiceMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SnsTopicMonitoringProps",
    jsii_struct_bases=[SnsTopicMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "topic": "topic",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_max_number_of_messages_published_alarm": "addMaxNumberOfMessagesPublishedAlarm",
        "add_message_notifications_failed_alarm": "addMessageNotificationsFailedAlarm",
        "add_min_number_of_messages_published_alarm": "addMinNumberOfMessagesPublishedAlarm",
    },
)
class SnsTopicMonitoringProps(SnsTopicMetricFactoryProps, BaseMonitoringProps):
    def __init__(
        self,
        *,
        topic: monocdk.aws_sns.ITopic,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_max_number_of_messages_published_alarm: typing.Optional[typing.Mapping[builtins.str, HighMessagesPublishedThreshold]] = None,
        add_message_notifications_failed_alarm: typing.Optional[typing.Mapping[builtins.str, NotificationsFailedThreshold]] = None,
        add_min_number_of_messages_published_alarm: typing.Optional[typing.Mapping[builtins.str, LowMessagesPublishedThreshold]] = None,
    ) -> None:
        '''
        :param topic: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_max_number_of_messages_published_alarm: 
        :param add_message_notifications_failed_alarm: 
        :param add_min_number_of_messages_published_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "topic": topic,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_max_number_of_messages_published_alarm is not None:
            self._values["add_max_number_of_messages_published_alarm"] = add_max_number_of_messages_published_alarm
        if add_message_notifications_failed_alarm is not None:
            self._values["add_message_notifications_failed_alarm"] = add_message_notifications_failed_alarm
        if add_min_number_of_messages_published_alarm is not None:
            self._values["add_min_number_of_messages_published_alarm"] = add_min_number_of_messages_published_alarm

    @builtins.property
    def topic(self) -> monocdk.aws_sns.ITopic:
        '''
        :stability: experimental
        '''
        result = self._values.get("topic")
        assert result is not None, "Required property 'topic' is missing"
        return typing.cast(monocdk.aws_sns.ITopic, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_max_number_of_messages_published_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HighMessagesPublishedThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_max_number_of_messages_published_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HighMessagesPublishedThreshold]], result)

    @builtins.property
    def add_message_notifications_failed_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, NotificationsFailedThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_message_notifications_failed_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, NotificationsFailedThreshold]], result)

    @builtins.property
    def add_min_number_of_messages_published_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LowMessagesPublishedThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_min_number_of_messages_published_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LowMessagesPublishedThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsTopicMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SqsQueueMonitoringProps",
    jsii_struct_bases=[
        SqsQueueMetricFactoryProps, BaseMonitoringProps, BaseSqsQueueAlarms
    ],
    name_mapping={
        "queue": "queue",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_queue_max_incoming_messages_alarm": "addQueueMaxIncomingMessagesAlarm",
        "add_queue_max_message_age_alarm": "addQueueMaxMessageAgeAlarm",
        "add_queue_max_size_alarm": "addQueueMaxSizeAlarm",
        "add_queue_max_time_to_drain_messages_alarm": "addQueueMaxTimeToDrainMessagesAlarm",
        "add_queue_min_incoming_messages_alarm": "addQueueMinIncomingMessagesAlarm",
        "add_queue_min_size_alarm": "addQueueMinSizeAlarm",
    },
)
class SqsQueueMonitoringProps(
    SqsQueueMetricFactoryProps,
    BaseMonitoringProps,
    BaseSqsQueueAlarms,
):
    def __init__(
        self,
        *,
        queue: monocdk.aws_sqs.IQueue,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        add_queue_max_time_to_drain_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]] = None,
        add_queue_min_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]] = None,
        add_queue_min_size_alarm: typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]] = None,
    ) -> None:
        '''
        :param queue: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_queue_max_incoming_messages_alarm: 
        :param add_queue_max_message_age_alarm: 
        :param add_queue_max_size_alarm: 
        :param add_queue_max_time_to_drain_messages_alarm: 
        :param add_queue_min_incoming_messages_alarm: 
        :param add_queue_min_size_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "queue": queue,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_queue_max_incoming_messages_alarm is not None:
            self._values["add_queue_max_incoming_messages_alarm"] = add_queue_max_incoming_messages_alarm
        if add_queue_max_message_age_alarm is not None:
            self._values["add_queue_max_message_age_alarm"] = add_queue_max_message_age_alarm
        if add_queue_max_size_alarm is not None:
            self._values["add_queue_max_size_alarm"] = add_queue_max_size_alarm
        if add_queue_max_time_to_drain_messages_alarm is not None:
            self._values["add_queue_max_time_to_drain_messages_alarm"] = add_queue_max_time_to_drain_messages_alarm
        if add_queue_min_incoming_messages_alarm is not None:
            self._values["add_queue_min_incoming_messages_alarm"] = add_queue_min_incoming_messages_alarm
        if add_queue_min_size_alarm is not None:
            self._values["add_queue_min_size_alarm"] = add_queue_min_size_alarm

    @builtins.property
    def queue(self) -> monocdk.aws_sqs.IQueue:
        '''
        :stability: experimental
        '''
        result = self._values.get("queue")
        assert result is not None, "Required property 'queue' is missing"
        return typing.cast(monocdk.aws_sqs.IQueue, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_queue_max_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]], result)

    @builtins.property
    def add_queue_max_message_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_message_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]], result)

    @builtins.property
    def add_queue_max_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]], result)

    @builtins.property
    def add_queue_max_time_to_drain_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_time_to_drain_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]], result)

    @builtins.property
    def add_queue_min_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_min_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]], result)

    @builtins.property
    def add_queue_min_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_min_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqsQueueMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.SqsQueueMonitoringWithDlqProps",
    jsii_struct_bases=[SqsQueueMonitoringProps, BaseDlqAlarms],
    name_mapping={
        "queue": "queue",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_queue_max_incoming_messages_alarm": "addQueueMaxIncomingMessagesAlarm",
        "add_queue_max_message_age_alarm": "addQueueMaxMessageAgeAlarm",
        "add_queue_max_size_alarm": "addQueueMaxSizeAlarm",
        "add_queue_max_time_to_drain_messages_alarm": "addQueueMaxTimeToDrainMessagesAlarm",
        "add_queue_min_incoming_messages_alarm": "addQueueMinIncomingMessagesAlarm",
        "add_queue_min_size_alarm": "addQueueMinSizeAlarm",
        "add_dead_letter_queue_max_incoming_messages_alarm": "addDeadLetterQueueMaxIncomingMessagesAlarm",
        "add_dead_letter_queue_max_message_age_alarm": "addDeadLetterQueueMaxMessageAgeAlarm",
        "add_dead_letter_queue_max_size_alarm": "addDeadLetterQueueMaxSizeAlarm",
        "dead_letter_queue": "deadLetterQueue",
        "add_dead_letter_queue_to_summary_dashboard": "addDeadLetterQueueToSummaryDashboard",
    },
)
class SqsQueueMonitoringWithDlqProps(SqsQueueMonitoringProps, BaseDlqAlarms):
    def __init__(
        self,
        *,
        queue: monocdk.aws_sqs.IQueue,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        add_queue_max_time_to_drain_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]] = None,
        add_queue_min_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]] = None,
        add_queue_min_size_alarm: typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]] = None,
        add_dead_letter_queue_max_incoming_messages_alarm: typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]] = None,
        add_dead_letter_queue_max_message_age_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]] = None,
        add_dead_letter_queue_max_size_alarm: typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]] = None,
        dead_letter_queue: monocdk.aws_sqs.IQueue,
        add_dead_letter_queue_to_summary_dashboard: typing.Optional[builtins.bool] = None,
    ) -> None:
        '''
        :param queue: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_queue_max_incoming_messages_alarm: 
        :param add_queue_max_message_age_alarm: 
        :param add_queue_max_size_alarm: 
        :param add_queue_max_time_to_drain_messages_alarm: 
        :param add_queue_min_incoming_messages_alarm: 
        :param add_queue_min_size_alarm: 
        :param add_dead_letter_queue_max_incoming_messages_alarm: 
        :param add_dead_letter_queue_max_message_age_alarm: 
        :param add_dead_letter_queue_max_size_alarm: 
        :param dead_letter_queue: 
        :param add_dead_letter_queue_to_summary_dashboard: (experimental) Indicates whether the DLQ monitoring should be added to summary dashboard. Default: true

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "queue": queue,
            "dead_letter_queue": dead_letter_queue,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_queue_max_incoming_messages_alarm is not None:
            self._values["add_queue_max_incoming_messages_alarm"] = add_queue_max_incoming_messages_alarm
        if add_queue_max_message_age_alarm is not None:
            self._values["add_queue_max_message_age_alarm"] = add_queue_max_message_age_alarm
        if add_queue_max_size_alarm is not None:
            self._values["add_queue_max_size_alarm"] = add_queue_max_size_alarm
        if add_queue_max_time_to_drain_messages_alarm is not None:
            self._values["add_queue_max_time_to_drain_messages_alarm"] = add_queue_max_time_to_drain_messages_alarm
        if add_queue_min_incoming_messages_alarm is not None:
            self._values["add_queue_min_incoming_messages_alarm"] = add_queue_min_incoming_messages_alarm
        if add_queue_min_size_alarm is not None:
            self._values["add_queue_min_size_alarm"] = add_queue_min_size_alarm
        if add_dead_letter_queue_max_incoming_messages_alarm is not None:
            self._values["add_dead_letter_queue_max_incoming_messages_alarm"] = add_dead_letter_queue_max_incoming_messages_alarm
        if add_dead_letter_queue_max_message_age_alarm is not None:
            self._values["add_dead_letter_queue_max_message_age_alarm"] = add_dead_letter_queue_max_message_age_alarm
        if add_dead_letter_queue_max_size_alarm is not None:
            self._values["add_dead_letter_queue_max_size_alarm"] = add_dead_letter_queue_max_size_alarm
        if add_dead_letter_queue_to_summary_dashboard is not None:
            self._values["add_dead_letter_queue_to_summary_dashboard"] = add_dead_letter_queue_to_summary_dashboard

    @builtins.property
    def queue(self) -> monocdk.aws_sqs.IQueue:
        '''
        :stability: experimental
        '''
        result = self._values.get("queue")
        assert result is not None, "Required property 'queue' is missing"
        return typing.cast(monocdk.aws_sqs.IQueue, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_queue_max_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]], result)

    @builtins.property
    def add_queue_max_message_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_message_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]], result)

    @builtins.property
    def add_queue_max_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]], result)

    @builtins.property
    def add_queue_max_time_to_drain_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_max_time_to_drain_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxTimeToDrainThreshold]], result)

    @builtins.property
    def add_queue_min_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_min_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinIncomingMessagesCountThreshold]], result)

    @builtins.property
    def add_queue_min_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_queue_min_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinMessageCountThreshold]], result)

    @builtins.property
    def add_dead_letter_queue_max_incoming_messages_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_max_incoming_messages_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxIncomingMessagesCountThreshold]], result)

    @builtins.property
    def add_dead_letter_queue_max_message_age_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_max_message_age_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxMessageAgeThreshold]], result)

    @builtins.property
    def add_dead_letter_queue_max_size_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_max_size_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MaxMessageCountThreshold]], result)

    @builtins.property
    def dead_letter_queue(self) -> monocdk.aws_sqs.IQueue:
        '''
        :stability: experimental
        '''
        result = self._values.get("dead_letter_queue")
        assert result is not None, "Required property 'dead_letter_queue' is missing"
        return typing.cast(monocdk.aws_sqs.IQueue, result)

    @builtins.property
    def add_dead_letter_queue_to_summary_dashboard(
        self,
    ) -> typing.Optional[builtins.bool]:
        '''(experimental) Indicates whether the DLQ monitoring should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_dead_letter_queue_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqsQueueMonitoringWithDlqProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionActivityMonitoringProps",
    jsii_struct_bases=[StepFunctionActivityMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "activity": "activity",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_duration_p50_alarm": "addDurationP50Alarm",
        "add_duration_p90_alarm": "addDurationP90Alarm",
        "add_duration_p99_alarm": "addDurationP99Alarm",
        "add_failed_activities_count_alarm": "addFailedActivitiesCountAlarm",
        "add_failed_activities_rate_alarm": "addFailedActivitiesRateAlarm",
        "add_timed_out_activities_count_alarm": "addTimedOutActivitiesCountAlarm",
    },
)
class StepFunctionActivityMonitoringProps(
    StepFunctionActivityMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        activity: monocdk.aws_stepfunctions.IActivity,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_activities_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_activities_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_activities_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
    ) -> None:
        '''
        :param activity: 
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_activities_count_alarm: 
        :param add_failed_activities_rate_alarm: 
        :param add_timed_out_activities_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "activity": activity,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_duration_p50_alarm is not None:
            self._values["add_duration_p50_alarm"] = add_duration_p50_alarm
        if add_duration_p90_alarm is not None:
            self._values["add_duration_p90_alarm"] = add_duration_p90_alarm
        if add_duration_p99_alarm is not None:
            self._values["add_duration_p99_alarm"] = add_duration_p99_alarm
        if add_failed_activities_count_alarm is not None:
            self._values["add_failed_activities_count_alarm"] = add_failed_activities_count_alarm
        if add_failed_activities_rate_alarm is not None:
            self._values["add_failed_activities_rate_alarm"] = add_failed_activities_rate_alarm
        if add_timed_out_activities_count_alarm is not None:
            self._values["add_timed_out_activities_count_alarm"] = add_timed_out_activities_count_alarm

    @builtins.property
    def activity(self) -> monocdk.aws_stepfunctions.IActivity:
        '''
        :stability: experimental
        '''
        result = self._values.get("activity")
        assert result is not None, "Required property 'activity' is missing"
        return typing.cast(monocdk.aws_stepfunctions.IActivity, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_duration_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_failed_activities_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_activities_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_failed_activities_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_activities_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_timed_out_activities_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_timed_out_activities_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionActivityMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionLambdaIntegrationMonitoringProps",
    jsii_struct_bases=[
        StepFunctionLambdaIntegrationMetricFactoryProps, BaseMonitoringProps
    ],
    name_mapping={
        "lambda_function": "lambdaFunction",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_duration_p50_alarm": "addDurationP50Alarm",
        "add_duration_p90_alarm": "addDurationP90Alarm",
        "add_duration_p99_alarm": "addDurationP99Alarm",
        "add_failed_functions_count_alarm": "addFailedFunctionsCountAlarm",
        "add_failed_functions_rate_alarm": "addFailedFunctionsRateAlarm",
        "add_timed_out_functions_count_alarm": "addTimedOutFunctionsCountAlarm",
    },
)
class StepFunctionLambdaIntegrationMonitoringProps(
    StepFunctionLambdaIntegrationMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        lambda_function: monocdk.aws_lambda.IFunction,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_functions_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_functions_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_functions_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
    ) -> None:
        '''
        :param lambda_function: 
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_functions_count_alarm: 
        :param add_failed_functions_rate_alarm: 
        :param add_timed_out_functions_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "lambda_function": lambda_function,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_duration_p50_alarm is not None:
            self._values["add_duration_p50_alarm"] = add_duration_p50_alarm
        if add_duration_p90_alarm is not None:
            self._values["add_duration_p90_alarm"] = add_duration_p90_alarm
        if add_duration_p99_alarm is not None:
            self._values["add_duration_p99_alarm"] = add_duration_p99_alarm
        if add_failed_functions_count_alarm is not None:
            self._values["add_failed_functions_count_alarm"] = add_failed_functions_count_alarm
        if add_failed_functions_rate_alarm is not None:
            self._values["add_failed_functions_rate_alarm"] = add_failed_functions_rate_alarm
        if add_timed_out_functions_count_alarm is not None:
            self._values["add_timed_out_functions_count_alarm"] = add_timed_out_functions_count_alarm

    @builtins.property
    def lambda_function(self) -> monocdk.aws_lambda.IFunction:
        '''
        :stability: experimental
        '''
        result = self._values.get("lambda_function")
        assert result is not None, "Required property 'lambda_function' is missing"
        return typing.cast(monocdk.aws_lambda.IFunction, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_duration_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_failed_functions_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_functions_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_failed_functions_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_functions_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_timed_out_functions_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_timed_out_functions_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionLambdaIntegrationMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionMonitoringProps",
    jsii_struct_bases=[StepFunctionMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "state_machine": "stateMachine",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_aborted_execution_count_alarm": "addAbortedExecutionCountAlarm",
        "add_duration_p50_alarm": "addDurationP50Alarm",
        "add_duration_p90_alarm": "addDurationP90Alarm",
        "add_duration_p99_alarm": "addDurationP99Alarm",
        "add_failed_execution_count_alarm": "addFailedExecutionCountAlarm",
        "add_failed_execution_rate_alarm": "addFailedExecutionRateAlarm",
        "add_min_started_execution_count_alarm": "addMinStartedExecutionCountAlarm",
        "add_throttled_execution_count_alarm": "addThrottledExecutionCountAlarm",
        "add_timed_out_execution_count_alarm": "addTimedOutExecutionCountAlarm",
    },
)
class StepFunctionMonitoringProps(StepFunctionMetricFactoryProps, BaseMonitoringProps):
    def __init__(
        self,
        *,
        state_machine: monocdk.aws_stepfunctions.IStateMachine,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_aborted_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_execution_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_min_started_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, MinRunningTaskCountThreshold]] = None,
        add_throttled_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_timed_out_execution_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
    ) -> None:
        '''
        :param state_machine: 
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_aborted_execution_count_alarm: 
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_execution_count_alarm: 
        :param add_failed_execution_rate_alarm: 
        :param add_min_started_execution_count_alarm: (experimental) Add minimum started execution count alarm for the stepfunctions.
        :param add_throttled_execution_count_alarm: 
        :param add_timed_out_execution_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "state_machine": state_machine,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_aborted_execution_count_alarm is not None:
            self._values["add_aborted_execution_count_alarm"] = add_aborted_execution_count_alarm
        if add_duration_p50_alarm is not None:
            self._values["add_duration_p50_alarm"] = add_duration_p50_alarm
        if add_duration_p90_alarm is not None:
            self._values["add_duration_p90_alarm"] = add_duration_p90_alarm
        if add_duration_p99_alarm is not None:
            self._values["add_duration_p99_alarm"] = add_duration_p99_alarm
        if add_failed_execution_count_alarm is not None:
            self._values["add_failed_execution_count_alarm"] = add_failed_execution_count_alarm
        if add_failed_execution_rate_alarm is not None:
            self._values["add_failed_execution_rate_alarm"] = add_failed_execution_rate_alarm
        if add_min_started_execution_count_alarm is not None:
            self._values["add_min_started_execution_count_alarm"] = add_min_started_execution_count_alarm
        if add_throttled_execution_count_alarm is not None:
            self._values["add_throttled_execution_count_alarm"] = add_throttled_execution_count_alarm
        if add_timed_out_execution_count_alarm is not None:
            self._values["add_timed_out_execution_count_alarm"] = add_timed_out_execution_count_alarm

    @builtins.property
    def state_machine(self) -> monocdk.aws_stepfunctions.IStateMachine:
        '''
        :stability: experimental
        '''
        result = self._values.get("state_machine")
        assert result is not None, "Required property 'state_machine' is missing"
        return typing.cast(monocdk.aws_stepfunctions.IStateMachine, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_aborted_execution_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_aborted_execution_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_duration_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_failed_execution_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_execution_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_failed_execution_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_execution_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_min_started_execution_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, MinRunningTaskCountThreshold]]:
        '''(experimental) Add minimum started execution count alarm for the stepfunctions.

        :stability: experimental
        '''
        result = self._values.get("add_min_started_execution_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, MinRunningTaskCountThreshold]], result)

    @builtins.property
    def add_throttled_execution_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_throttled_execution_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_timed_out_execution_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_timed_out_execution_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.StepFunctionServiceIntegrationMonitoringProps",
    jsii_struct_bases=[
        StepFunctionServiceIntegrationMetricFactoryProps, BaseMonitoringProps
    ],
    name_mapping={
        "service_integration_resource_arn": "serviceIntegrationResourceArn",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add_duration_p50_alarm": "addDurationP50Alarm",
        "add_duration_p90_alarm": "addDurationP90Alarm",
        "add_duration_p99_alarm": "addDurationP99Alarm",
        "add_failed_service_integrations_count_alarm": "addFailedServiceIntegrationsCountAlarm",
        "add_failed_service_integrations_rate_alarm": "addFailedServiceIntegrationsRateAlarm",
        "add_timed_out_service_integrations_count_alarm": "addTimedOutServiceIntegrationsCountAlarm",
    },
)
class StepFunctionServiceIntegrationMonitoringProps(
    StepFunctionServiceIntegrationMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        service_integration_resource_arn: builtins.str,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add_duration_p50_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p90_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_duration_p99_alarm: typing.Optional[typing.Mapping[builtins.str, DurationThreshold]] = None,
        add_failed_service_integrations_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add_failed_service_integrations_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_timed_out_service_integrations_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
    ) -> None:
        '''
        :param service_integration_resource_arn: 
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add_duration_p50_alarm: 
        :param add_duration_p90_alarm: 
        :param add_duration_p99_alarm: 
        :param add_failed_service_integrations_count_alarm: 
        :param add_failed_service_integrations_rate_alarm: 
        :param add_timed_out_service_integrations_count_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "service_integration_resource_arn": service_integration_resource_arn,
        }
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add_duration_p50_alarm is not None:
            self._values["add_duration_p50_alarm"] = add_duration_p50_alarm
        if add_duration_p90_alarm is not None:
            self._values["add_duration_p90_alarm"] = add_duration_p90_alarm
        if add_duration_p99_alarm is not None:
            self._values["add_duration_p99_alarm"] = add_duration_p99_alarm
        if add_failed_service_integrations_count_alarm is not None:
            self._values["add_failed_service_integrations_count_alarm"] = add_failed_service_integrations_count_alarm
        if add_failed_service_integrations_rate_alarm is not None:
            self._values["add_failed_service_integrations_rate_alarm"] = add_failed_service_integrations_rate_alarm
        if add_timed_out_service_integrations_count_alarm is not None:
            self._values["add_timed_out_service_integrations_count_alarm"] = add_timed_out_service_integrations_count_alarm

    @builtins.property
    def service_integration_resource_arn(self) -> builtins.str:
        '''
        :stability: experimental
        '''
        result = self._values.get("service_integration_resource_arn")
        assert result is not None, "Required property 'service_integration_resource_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add_duration_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_duration_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, DurationThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_duration_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, DurationThreshold]], result)

    @builtins.property
    def add_failed_service_integrations_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_service_integrations_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add_failed_service_integrations_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_failed_service_integrations_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_timed_out_service_integrations_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_timed_out_service_integrations_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StepFunctionServiceIntegrationMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ApiGatewayMonitoringProps",
    jsii_struct_bases=[ApiGatewayMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "api": "api",
        "api_method": "apiMethod",
        "api_resource": "apiResource",
        "api_stage": "apiStage",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add4_xx_error_count_alarm": "add4XXErrorCountAlarm",
        "add4_xx_error_rate_alarm": "add4XXErrorRateAlarm",
        "add5_xx_fault_count_alarm": "add5XXFaultCountAlarm",
        "add5_xx_fault_rate_alarm": "add5XXFaultRateAlarm",
        "add_high_tps_alarm": "addHighTpsAlarm",
        "add_latency_p50_alarm": "addLatencyP50Alarm",
        "add_latency_p90_alarm": "addLatencyP90Alarm",
        "add_latency_p99_alarm": "addLatencyP99Alarm",
        "add_low_tps_alarm": "addLowTpsAlarm",
    },
)
class ApiGatewayMonitoringProps(ApiGatewayMetricFactoryProps, BaseMonitoringProps):
    def __init__(
        self,
        *,
        api: monocdk.aws_apigateway.RestApiBase,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add4_xx_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4_xx_error_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5_xx_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5_xx_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
    ) -> None:
        '''
        :param api: (experimental) API to monitor (cannot use IRestApi, since it does not provide API name).
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: prod
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add4_xx_error_count_alarm: 
        :param add4_xx_error_rate_alarm: 
        :param add5_xx_fault_count_alarm: 
        :param add5_xx_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "api": api,
        }
        if api_method is not None:
            self._values["api_method"] = api_method
        if api_resource is not None:
            self._values["api_resource"] = api_resource
        if api_stage is not None:
            self._values["api_stage"] = api_stage
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add4_xx_error_count_alarm is not None:
            self._values["add4_xx_error_count_alarm"] = add4_xx_error_count_alarm
        if add4_xx_error_rate_alarm is not None:
            self._values["add4_xx_error_rate_alarm"] = add4_xx_error_rate_alarm
        if add5_xx_fault_count_alarm is not None:
            self._values["add5_xx_fault_count_alarm"] = add5_xx_fault_count_alarm
        if add5_xx_fault_rate_alarm is not None:
            self._values["add5_xx_fault_rate_alarm"] = add5_xx_fault_rate_alarm
        if add_high_tps_alarm is not None:
            self._values["add_high_tps_alarm"] = add_high_tps_alarm
        if add_latency_p50_alarm is not None:
            self._values["add_latency_p50_alarm"] = add_latency_p50_alarm
        if add_latency_p90_alarm is not None:
            self._values["add_latency_p90_alarm"] = add_latency_p90_alarm
        if add_latency_p99_alarm is not None:
            self._values["add_latency_p99_alarm"] = add_latency_p99_alarm
        if add_low_tps_alarm is not None:
            self._values["add_low_tps_alarm"] = add_low_tps_alarm

    @builtins.property
    def api(self) -> monocdk.aws_apigateway.RestApiBase:
        '''(experimental) API to monitor (cannot use IRestApi, since it does not provide API name).

        :stability: experimental
        '''
        result = self._values.get("api")
        assert result is not None, "Required property 'api' is missing"
        return typing.cast(monocdk.aws_apigateway.RestApiBase, result)

    @builtins.property
    def api_method(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_method")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_resource(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_resource")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_stage(self) -> typing.Optional[builtins.str]:
        '''
        :default: prod

        :stability: experimental
        '''
        result = self._values.get("api_stage")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add4_xx_error_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add4_xx_error_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add4_xx_error_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add4_xx_error_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add5_xx_fault_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add5_xx_fault_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add5_xx_fault_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add5_xx_fault_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_high_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_high_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]], result)

    @builtins.property
    def add_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_low_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_low_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.ApiGatewayV2HttpApiMonitoringProps",
    jsii_struct_bases=[ApiGatewayV2HttpApiMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "api": "api",
        "api_method": "apiMethod",
        "api_resource": "apiResource",
        "api_stage": "apiStage",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "rate_computation_method": "rateComputationMethod",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "add4xx_count_alarm": "add4xxCountAlarm",
        "add4xx_rate_alarm": "add4xxRateAlarm",
        "add5xx_count_alarm": "add5xxCountAlarm",
        "add5xx_rate_alarm": "add5xxRateAlarm",
        "add_high_tps_alarm": "addHighTpsAlarm",
        "add_integration_latency_p50_alarm": "addIntegrationLatencyP50Alarm",
        "add_integration_latency_p90_alarm": "addIntegrationLatencyP90Alarm",
        "add_integration_latency_p99_alarm": "addIntegrationLatencyP99Alarm",
        "add_latency_p50_alarm": "addLatencyP50Alarm",
        "add_latency_p90_alarm": "addLatencyP90Alarm",
        "add_latency_p99_alarm": "addLatencyP99Alarm",
        "add_low_tps_alarm": "addLowTpsAlarm",
    },
)
class ApiGatewayV2HttpApiMonitoringProps(
    ApiGatewayV2HttpApiMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        api: monocdk.aws_apigatewayv2.IHttpApi,
        api_method: typing.Optional[builtins.str] = None,
        api_resource: typing.Optional[builtins.str] = None,
        api_stage: typing.Optional[builtins.str] = None,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        add4xx_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4xx_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5xx_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5xx_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_integration_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_integration_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_integration_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
    ) -> None:
        '''
        :param api: 
        :param api_method: (experimental) On undefined value is not set in dimensions.
        :param api_resource: (experimental) On undefined value is not set in dimensions.
        :param api_stage: Default: $default
        :param fill_tps_with_zeroes: Default: true
        :param rate_computation_method: Default: average
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param add4xx_count_alarm: 
        :param add4xx_rate_alarm: 
        :param add5xx_count_alarm: 
        :param add5xx_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_integration_latency_p50_alarm: 
        :param add_integration_latency_p90_alarm: 
        :param add_integration_latency_p99_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "api": api,
        }
        if api_method is not None:
            self._values["api_method"] = api_method
        if api_resource is not None:
            self._values["api_resource"] = api_resource
        if api_stage is not None:
            self._values["api_stage"] = api_stage
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if add4xx_count_alarm is not None:
            self._values["add4xx_count_alarm"] = add4xx_count_alarm
        if add4xx_rate_alarm is not None:
            self._values["add4xx_rate_alarm"] = add4xx_rate_alarm
        if add5xx_count_alarm is not None:
            self._values["add5xx_count_alarm"] = add5xx_count_alarm
        if add5xx_rate_alarm is not None:
            self._values["add5xx_rate_alarm"] = add5xx_rate_alarm
        if add_high_tps_alarm is not None:
            self._values["add_high_tps_alarm"] = add_high_tps_alarm
        if add_integration_latency_p50_alarm is not None:
            self._values["add_integration_latency_p50_alarm"] = add_integration_latency_p50_alarm
        if add_integration_latency_p90_alarm is not None:
            self._values["add_integration_latency_p90_alarm"] = add_integration_latency_p90_alarm
        if add_integration_latency_p99_alarm is not None:
            self._values["add_integration_latency_p99_alarm"] = add_integration_latency_p99_alarm
        if add_latency_p50_alarm is not None:
            self._values["add_latency_p50_alarm"] = add_latency_p50_alarm
        if add_latency_p90_alarm is not None:
            self._values["add_latency_p90_alarm"] = add_latency_p90_alarm
        if add_latency_p99_alarm is not None:
            self._values["add_latency_p99_alarm"] = add_latency_p99_alarm
        if add_low_tps_alarm is not None:
            self._values["add_low_tps_alarm"] = add_low_tps_alarm

    @builtins.property
    def api(self) -> monocdk.aws_apigatewayv2.IHttpApi:
        '''
        :stability: experimental
        '''
        result = self._values.get("api")
        assert result is not None, "Required property 'api' is missing"
        return typing.cast(monocdk.aws_apigatewayv2.IHttpApi, result)

    @builtins.property
    def api_method(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_method")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_resource(self) -> typing.Optional[builtins.str]:
        '''(experimental) On undefined value is not set in dimensions.

        :stability: experimental
        '''
        result = self._values.get("api_resource")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_stage(self) -> typing.Optional[builtins.str]:
        '''
        :default: $default

        :stability: experimental
        '''
        result = self._values.get("api_stage")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''
        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''
        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def add4xx_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add4xx_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add4xx_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add4xx_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add5xx_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add5xx_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add5xx_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add5xx_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_high_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_high_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]], result)

    @builtins.property
    def add_integration_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_integration_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_integration_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_integration_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_integration_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_integration_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_low_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_low_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayV2HttpApiMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AppSyncMonitoringProps",
    jsii_struct_bases=[BaseMonitoringProps, AppSyncMetricFactoryProps],
    name_mapping={
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
        "api": "api",
        "fill_tps_with_zeroes": "fillTpsWithZeroes",
        "rate_computation_method": "rateComputationMethod",
        "add4_xx_error_count_alarm": "add4XXErrorCountAlarm",
        "add4_xx_error_rate_alarm": "add4XXErrorRateAlarm",
        "add5_xx_fault_count_alarm": "add5XXFaultCountAlarm",
        "add5_xx_fault_rate_alarm": "add5XXFaultRateAlarm",
        "add_high_tps_alarm": "addHighTpsAlarm",
        "add_latency_p50_alarm": "addLatencyP50Alarm",
        "add_latency_p90_alarm": "addLatencyP90Alarm",
        "add_latency_p99_alarm": "addLatencyP99Alarm",
        "add_low_tps_alarm": "addLowTpsAlarm",
    },
)
class AppSyncMonitoringProps(BaseMonitoringProps, AppSyncMetricFactoryProps):
    def __init__(
        self,
        *,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
        api: monocdk.aws_appsync.GraphqlApi,
        fill_tps_with_zeroes: typing.Optional[builtins.bool] = None,
        rate_computation_method: typing.Optional[RateComputationMethod] = None,
        add4_xx_error_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add4_xx_error_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add5_xx_fault_count_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]] = None,
        add5_xx_fault_rate_alarm: typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]] = None,
        add_high_tps_alarm: typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]] = None,
        add_latency_p50_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p90_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_latency_p99_alarm: typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]] = None,
        add_low_tps_alarm: typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]] = None,
    ) -> None:
        '''
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.
        :param api: (experimental) the GraphQL API to monitor.
        :param fill_tps_with_zeroes: (experimental) whether the TPS should be filled with zeroes. Default: true
        :param rate_computation_method: (experimental) method to compute TPS. Default: average
        :param add4_xx_error_count_alarm: 
        :param add4_xx_error_rate_alarm: 
        :param add5_xx_fault_count_alarm: 
        :param add5_xx_fault_rate_alarm: 
        :param add_high_tps_alarm: 
        :param add_latency_p50_alarm: 
        :param add_latency_p90_alarm: 
        :param add_latency_p99_alarm: 
        :param add_low_tps_alarm: 

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "api": api,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms
        if fill_tps_with_zeroes is not None:
            self._values["fill_tps_with_zeroes"] = fill_tps_with_zeroes
        if rate_computation_method is not None:
            self._values["rate_computation_method"] = rate_computation_method
        if add4_xx_error_count_alarm is not None:
            self._values["add4_xx_error_count_alarm"] = add4_xx_error_count_alarm
        if add4_xx_error_rate_alarm is not None:
            self._values["add4_xx_error_rate_alarm"] = add4_xx_error_rate_alarm
        if add5_xx_fault_count_alarm is not None:
            self._values["add5_xx_fault_count_alarm"] = add5_xx_fault_count_alarm
        if add5_xx_fault_rate_alarm is not None:
            self._values["add5_xx_fault_rate_alarm"] = add5_xx_fault_rate_alarm
        if add_high_tps_alarm is not None:
            self._values["add_high_tps_alarm"] = add_high_tps_alarm
        if add_latency_p50_alarm is not None:
            self._values["add_latency_p50_alarm"] = add_latency_p50_alarm
        if add_latency_p90_alarm is not None:
            self._values["add_latency_p90_alarm"] = add_latency_p90_alarm
        if add_latency_p99_alarm is not None:
            self._values["add_latency_p99_alarm"] = add_latency_p99_alarm
        if add_low_tps_alarm is not None:
            self._values["add_low_tps_alarm"] = add_low_tps_alarm

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    @builtins.property
    def api(self) -> monocdk.aws_appsync.GraphqlApi:
        '''(experimental) the GraphQL API to monitor.

        :stability: experimental
        '''
        result = self._values.get("api")
        assert result is not None, "Required property 'api' is missing"
        return typing.cast(monocdk.aws_appsync.GraphqlApi, result)

    @builtins.property
    def fill_tps_with_zeroes(self) -> typing.Optional[builtins.bool]:
        '''(experimental) whether the TPS should be filled with zeroes.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("fill_tps_with_zeroes")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def rate_computation_method(self) -> typing.Optional[RateComputationMethod]:
        '''(experimental) method to compute TPS.

        :default: average

        :stability: experimental
        '''
        result = self._values.get("rate_computation_method")
        return typing.cast(typing.Optional[RateComputationMethod], result)

    @builtins.property
    def add4_xx_error_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add4_xx_error_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add4_xx_error_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add4_xx_error_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add5_xx_fault_count_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add5_xx_fault_count_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorCountThreshold]], result)

    @builtins.property
    def add5_xx_fault_rate_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add5_xx_fault_rate_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, ErrorRateThreshold]], result)

    @builtins.property
    def add_high_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_high_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, HighTpsThreshold]], result)

    @builtins.property
    def add_latency_p50_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p50_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p90_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p90_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_latency_p99_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_latency_p99_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LatencyThreshold]], result)

    @builtins.property
    def add_low_tps_alarm(
        self,
    ) -> typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("add_low_tps_alarm")
        return typing.cast(typing.Optional[typing.Mapping[builtins.str, LowTpsThreshold]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppSyncMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-monitoring-constructs.AutoScalingGroupMonitoringProps",
    jsii_struct_bases=[AutoScalingGroupMetricFactoryProps, BaseMonitoringProps],
    name_mapping={
        "auto_scaling_group": "autoScalingGroup",
        "alarm_friendly_name": "alarmFriendlyName",
        "human_readable_name": "humanReadableName",
        "local_alarm_name_prefix_override": "localAlarmNamePrefixOverride",
        "add_to_alarm_dashboard": "addToAlarmDashboard",
        "add_to_detail_dashboard": "addToDetailDashboard",
        "add_to_summary_dashboard": "addToSummaryDashboard",
        "use_created_alarms": "useCreatedAlarms",
    },
)
class AutoScalingGroupMonitoringProps(
    AutoScalingGroupMetricFactoryProps,
    BaseMonitoringProps,
):
    def __init__(
        self,
        *,
        auto_scaling_group: monocdk.aws_autoscaling.IAutoScalingGroup,
        alarm_friendly_name: typing.Optional[builtins.str] = None,
        human_readable_name: typing.Optional[builtins.str] = None,
        local_alarm_name_prefix_override: typing.Optional[builtins.str] = None,
        add_to_alarm_dashboard: typing.Optional[builtins.bool] = None,
        add_to_detail_dashboard: typing.Optional[builtins.bool] = None,
        add_to_summary_dashboard: typing.Optional[builtins.bool] = None,
        use_created_alarms: typing.Optional[IAlarmConsumer] = None,
    ) -> None:
        '''
        :param auto_scaling_group: 
        :param alarm_friendly_name: (experimental) Plain name, used in naming alarms. This unique among other resources, and respect the AWS CDK restriction posed on alarm names. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens. Default: derives name from the construct itself
        :param human_readable_name: (experimental) Human-readable name is a freeform string, used as a caption or description. There are no limitations on what it can be. Default: use alarmFriendlyName
        :param local_alarm_name_prefix_override: (experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value. The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.
        :param add_to_alarm_dashboard: (experimental) Flag indicating if the widgets should be added to alarm dashboard. Default: true
        :param add_to_detail_dashboard: (experimental) Flag indicating if the widgets should be added to detailed dashboard. Default: true
        :param add_to_summary_dashboard: (experimental) Flag indicating if the widgets should be added to summary dashboard. Default: true
        :param use_created_alarms: (experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        self._values: typing.Dict[str, typing.Any] = {
            "auto_scaling_group": auto_scaling_group,
        }
        if alarm_friendly_name is not None:
            self._values["alarm_friendly_name"] = alarm_friendly_name
        if human_readable_name is not None:
            self._values["human_readable_name"] = human_readable_name
        if local_alarm_name_prefix_override is not None:
            self._values["local_alarm_name_prefix_override"] = local_alarm_name_prefix_override
        if add_to_alarm_dashboard is not None:
            self._values["add_to_alarm_dashboard"] = add_to_alarm_dashboard
        if add_to_detail_dashboard is not None:
            self._values["add_to_detail_dashboard"] = add_to_detail_dashboard
        if add_to_summary_dashboard is not None:
            self._values["add_to_summary_dashboard"] = add_to_summary_dashboard
        if use_created_alarms is not None:
            self._values["use_created_alarms"] = use_created_alarms

    @builtins.property
    def auto_scaling_group(self) -> monocdk.aws_autoscaling.IAutoScalingGroup:
        '''
        :stability: experimental
        '''
        result = self._values.get("auto_scaling_group")
        assert result is not None, "Required property 'auto_scaling_group' is missing"
        return typing.cast(monocdk.aws_autoscaling.IAutoScalingGroup, result)

    @builtins.property
    def alarm_friendly_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Plain name, used in naming alarms.

        This unique among other resources, and respect the AWS CDK restriction posed on alarm names.
        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :default: derives name from the construct itself

        :stability: experimental
        '''
        result = self._values.get("alarm_friendly_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def human_readable_name(self) -> typing.Optional[builtins.str]:
        '''(experimental) Human-readable name is a freeform string, used as a caption or description.

        There are no limitations on what it can be.

        :default: use alarmFriendlyName

        :stability: experimental
        '''
        result = self._values.get("human_readable_name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def local_alarm_name_prefix_override(self) -> typing.Optional[builtins.str]:
        '''(experimental) If this is defined, the local alarm name prefix used in naming alarms for the construct will be set to this value.

        The length must be 1 - 255 characters and although the validation rules are undocumented, we recommend using ASCII and hyphens.

        :see: AlarmNamingStrategy for more details on alarm name prefixes
        :stability: experimental
        '''
        result = self._values.get("local_alarm_name_prefix_override")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def add_to_alarm_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to alarm dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_alarm_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_detail_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to detailed dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_detail_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def add_to_summary_dashboard(self) -> typing.Optional[builtins.bool]:
        '''(experimental) Flag indicating if the widgets should be added to summary dashboard.

        :default: true

        :stability: experimental
        '''
        result = self._values.get("add_to_summary_dashboard")
        return typing.cast(typing.Optional[builtins.bool], result)

    @builtins.property
    def use_created_alarms(self) -> typing.Optional[IAlarmConsumer]:
        '''(experimental) Calls provided function to process all alarms created.

        :stability: experimental
        '''
        result = self._values.get("use_created_alarms")
        return typing.cast(typing.Optional[IAlarmConsumer], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoScalingGroupMonitoringProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultAlarmAnnotationStrategy(
    FillingAlarmAnnotationStrategy,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DefaultAlarmAnnotationStrategy",
):
    '''(experimental) Default annotation strategy that returns the built-in alarm annotation.

    :stability: experimental
    '''

    def __init__(self) -> None:
        '''
        :stability: experimental
        '''
        jsii.create(self.__class__, self, [])

    @jsii.member(jsii_name="createAnnotationToFill")
    def _create_annotation_to_fill(
        self,
        *,
        alarm: monocdk.aws_cloudwatch.Alarm,
        comparison_operator: monocdk.aws_cloudwatch.ComparisonOperator,
        datapoints_to_alarm: jsii.Number,
        evaluation_periods: jsii.Number,
        fill_alarm_range: builtins.bool,
        metric: typing.Union[monocdk.aws_cloudwatch.Metric, monocdk.aws_cloudwatch.MathExpression],
        threshold: jsii.Number,
        action: IAlarmActionStrategy,
        custom_params: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
        custom_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
        dedupe_string: typing.Optional[builtins.str] = None,
        disambiguator: typing.Optional[builtins.str] = None,
    ) -> monocdk.aws_cloudwatch.HorizontalAnnotation:
        '''
        :param alarm: 
        :param comparison_operator: 
        :param datapoints_to_alarm: 
        :param evaluation_periods: 
        :param fill_alarm_range: 
        :param metric: 
        :param threshold: 
        :param action: 
        :param custom_params: 
        :param custom_tags: 
        :param dedupe_string: 
        :param disambiguator: 

        :stability: experimental
        '''
        props = AlarmAnnotationStrategyProps(
            alarm=alarm,
            comparison_operator=comparison_operator,
            datapoints_to_alarm=datapoints_to_alarm,
            evaluation_periods=evaluation_periods,
            fill_alarm_range=fill_alarm_range,
            metric=metric,
            threshold=threshold,
            action=action,
            custom_params=custom_params,
            custom_tags=custom_tags,
            dedupe_string=dedupe_string,
            disambiguator=disambiguator,
        )

        return typing.cast(monocdk.aws_cloudwatch.HorizontalAnnotation, jsii.invoke(self, "createAnnotationToFill", [props]))


class DoNotModifyDedupeString(
    ExtendDedupeString,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-monitoring-constructs.DoNotModifyDedupeString",
):
    '''(experimental) Default dedupe strategy - does not add any prefix nor suffix.

    :stability: experimental
    '''

    def __init__(
        self,
        prefix: typing.Optional[builtins.str] = None,
        suffix: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param prefix: -
        :param suffix: -

        :stability: experimental
        '''
        jsii.create(self.__class__, self, [prefix, suffix])


__all__ = [
    "AddAlarmProps",
    "AddCompositeAlarmProps",
    "AgeAlarmFactory",
    "AlarmActionStrategyProps",
    "AlarmAnnotationStrategyProps",
    "AlarmFactory",
    "AlarmFactoryDefaults",
    "AlarmFactoryProps",
    "AlarmMatrixWidget",
    "AlarmMatrixWidgetProps",
    "AlarmMetadata",
    "AlarmNamingInput",
    "AlarmNamingStrategy",
    "AlarmSummaryMatrixWidget",
    "AlarmSummaryMatrixWidgetPropertiesJson",
    "AlarmSummaryMatrixWidgetProps",
    "AlarmWithAnnotation",
    "AnomalyDetectingAlarmFactory",
    "AnomalyDetectionMathExpression",
    "AnomalyDetectionThreshold",
    "ApiGatewayMetricFactory",
    "ApiGatewayMetricFactoryProps",
    "ApiGatewayMonitoring",
    "ApiGatewayMonitoringProps",
    "ApiGatewayV2HttpApiMetricFactory",
    "ApiGatewayV2HttpApiMetricFactoryProps",
    "ApiGatewayV2HttpApiMonitoring",
    "ApiGatewayV2HttpApiMonitoringProps",
    "AppSyncMetricFactory",
    "AppSyncMetricFactoryProps",
    "AppSyncMonitoring",
    "AppSyncMonitoringProps",
    "ApplicationLoadBalancerMetricFactory",
    "ApplicationLoadBalancerMetricFactoryProps",
    "AutoScalingGroupMetricFactory",
    "AutoScalingGroupMetricFactoryProps",
    "AutoScalingGroupMonitoring",
    "AutoScalingGroupMonitoringProps",
    "AvailabilityThreshold",
    "AwsConsoleUrlFactory",
    "AwsConsoleUrlFactoryProps",
    "AxisPosition",
    "BaseDlqAlarms",
    "BaseEc2ServiceAlarms",
    "BaseFargateServiceAlarms",
    "BaseMonitoringProps",
    "BaseServiceMetricFactory",
    "BaseServiceMetricFactoryProps",
    "BaseSqsQueueAlarms",
    "BillingMetricFactory",
    "BillingMonitoring",
    "BitmapDashboard",
    "BitmapWidgetRenderingSupport",
    "CapacityType",
    "CertificateManagerMetricFactory",
    "CertificateManagerMetricFactoryProps",
    "CertificateManagerMonitoring",
    "CertificateManagerMonitoringProps",
    "CloudFrontDistributionMetricFactory",
    "CloudFrontDistributionMetricFactoryProps",
    "CloudFrontDistributionMonitoring",
    "CloudFrontDistributionMonitoringProps",
    "CodeBuildProjectMetricFactory",
    "CodeBuildProjectMetricFactoryProps",
    "CodeBuildProjectMonitoring",
    "CodeBuildProjectMonitoringProps",
    "CompositeAlarmOperator",
    "ConsumedCapacityThreshold",
    "CustomAlarmFactory",
    "CustomAlarmThreshold",
    "CustomEc2ServiceMonitoringProps",
    "CustomFargateServiceMonitoringProps",
    "CustomMetricGroup",
    "CustomMetricGroupWithAnnotations",
    "CustomMetricSearch",
    "CustomMetricWithAlarm",
    "CustomMetricWithAnomalyDetection",
    "CustomMonitoring",
    "CustomMonitoringProps",
    "CustomThreshold",
    "CustomWidget",
    "CustomWidgetProps",
    "DashboardRenderingPreference",
    "DashboardWithBitmapCopy",
    "DaysSinceUpdateThreshold",
    "DaysToExpiryThreshold",
    "DefaultAlarmAnnotationStrategy",
    "DefaultDashboardFactory",
    "DefaultWidgetFactory",
    "DoNotModifyDedupeString",
    "DurationThreshold",
    "DynamoAlarmFactory",
    "DynamoTableGlobalSecondaryIndexMetricFactory",
    "DynamoTableGlobalSecondaryIndexMetricFactoryProps",
    "DynamoTableGlobalSecondaryIndexMonitoring",
    "DynamoTableGlobalSecondaryIndexMonitoringProps",
    "DynamoTableMetricFactory",
    "DynamoTableMetricFactoryProps",
    "DynamoTableMonitoring",
    "DynamoTableMonitoringProps",
    "EC2MetricFactory",
    "EC2Monitoring",
    "EC2MonitoringProps",
    "Ec2ApplicationLoadBalancerMonitoringProps",
    "Ec2NetworkLoadBalancerMonitoringProps",
    "Ec2ServiceMonitoring",
    "Ec2ServiceMonitoringProps",
    "ElastiCacheAlarmFactory",
    "ElastiCacheClusterMetricFactory",
    "ElastiCacheClusterMetricFactoryProps",
    "ElastiCacheClusterMonitoring",
    "ElastiCacheClusterMonitoringProps",
    "ElastiCacheClusterType",
    "ElasticsearchClusterStatus",
    "ErrorAlarmFactory",
    "ErrorCountThreshold",
    "ErrorRateThreshold",
    "ErrorType",
    "ExtendDedupeString",
    "FargateApplicationLoadBalancerMonitoringProps",
    "FargateNetworkLoadBalancerMonitoringProps",
    "FargateServiceMonitoring",
    "FargateServiceMonitoringProps",
    "FillingAlarmAnnotationStrategy",
    "FullRestartCountThreshold",
    "GlueJobMetricFactory",
    "GlueJobMonitoring",
    "GlueJobMonitoringProps",
    "GraphWidgetType",
    "HeaderLevel",
    "HeaderWidget",
    "HealthyTaskCountThreshold",
    "HealthyTaskPercentThreshold",
    "HighMessagesPublishedThreshold",
    "HighTpsThreshold",
    "IAlarmActionStrategy",
    "IAlarmAnnotationStrategy",
    "IAlarmConsumer",
    "IAlarmDedupeStringProcessor",
    "IDashboardFactory",
    "IDashboardFactoryProps",
    "IDashboardSegment",
    "ILoadBalancerMetricFactory",
    "IWidgetFactory",
    "KeyValueTableWidget",
    "KinesisAlarmFactory",
    "KinesisDataAnalyticsAlarmFactory",
    "KinesisDataAnalyticsMetricFactory",
    "KinesisDataAnalyticsMetricFactoryProps",
    "KinesisDataAnalyticsMonitoring",
    "KinesisDataAnalyticsMonitoringProps",
    "KinesisDataStreamMetricFactory",
    "KinesisDataStreamMetricFactoryProps",
    "KinesisDataStreamMonitoring",
    "KinesisDataStreamMonitoringProps",
    "KinesisFirehoseMetricFactory",
    "KinesisFirehoseMetricFactoryProps",
    "KinesisFirehoseMonitoring",
    "KinesisFirehoseMonitoringProps",
    "LambdaFunctionEnhancedMetricFactory",
    "LambdaFunctionMetricFactory",
    "LambdaFunctionMetricFactoryProps",
    "LambdaFunctionMonitoring",
    "LambdaFunctionMonitoringProps",
    "LatencyAlarmFactory",
    "LatencyThreshold",
    "LatencyType",
    "LogLevel",
    "LogLevelAlarmFactory",
    "LogLevelCountThreshold",
    "LogMonitoring",
    "LogMonitoringProps",
    "LowMessagesPublishedThreshold",
    "LowTpsThreshold",
    "MaxAgeThreshold",
    "MaxDowntimeThreshold",
    "MaxIncomingMessagesCountThreshold",
    "MaxItemsCountThreshold",
    "MaxIteratorAgeThreshold",
    "MaxMessageAgeThreshold",
    "MaxMessageCountThreshold",
    "MaxTimeToDrainThreshold",
    "MaxUsedSwapMemoryThreshold",
    "MetricFactory",
    "MetricFactoryDefaults",
    "MetricFactoryProps",
    "MetricStatistic",
    "MinFreeableMemoryThreshold",
    "MinIncomingMessagesCountThreshold",
    "MinMessageCountThreshold",
    "MinProcessedBytesThreshold",
    "MinRunningTaskCountThreshold",
    "Monitoring",
    "MonitoringDashboardsOverrideProps",
    "MonitoringDashboardsProps",
    "MonitoringFacade",
    "MonitoringFacadeProps",
    "MonitoringHeaderWidget",
    "MonitoringHeaderWidgetProps",
    "MonitoringNamingStrategy",
    "MonitoringScope",
    "MultipleAlarmActionStrategy",
    "NameResolutionInput",
    "NetworkLoadBalancerMetricFactory",
    "NetworkLoadBalancerMetricFactoryProps",
    "NetworkLoadBalancerMonitoring",
    "NetworkLoadBalancerMonitoringProps",
    "NoopAlarmActionStrategy",
    "NotificationsFailedThreshold",
    "OpenSearchBackportedMetrics",
    "OpenSearchClusterAlarmFactory",
    "OpenSearchClusterAutomatedSnapshotFailureThreshold",
    "OpenSearchClusterIndexWritesBlockedThreshold",
    "OpenSearchClusterMetricFactory",
    "OpenSearchClusterMetricFactoryProps",
    "OpenSearchClusterMonitoring",
    "OpenSearchClusterMonitoringProps",
    "OpenSearchClusterNodesThreshold",
    "OpenSearchClusterStatus",
    "OpenSearchClusterStatusCustomization",
    "OpenSearchKmsKeyErrorThreshold",
    "OpenSearchKmsKeyInaccessibleThreshold",
    "QueueAlarmFactory",
    "QueueProcessingEc2ServiceMonitoringProps",
    "QueueProcessingFargateServiceMonitoringProps",
    "RateComputationMethod",
    "RdsClusterMetricFactory",
    "RdsClusterMetricFactoryProps",
    "RdsClusterMonitoring",
    "RdsClusterMonitoringProps",
    "RecordsFailedThreshold",
    "RecordsThrottledThreshold",
    "RedshiftClusterMetricFactory",
    "RedshiftClusterMetricFactoryProps",
    "RedshiftClusterMonitoring",
    "RedshiftClusterMonitoringProps",
    "RunningTaskCountThreshold",
    "RunningTaskRateThreshold",
    "S3BucketMetricFactory",
    "S3BucketMetricFactoryProps",
    "S3BucketMonitoring",
    "S3BucketMonitoringProps",
    "SecretsManagerMetricsPublisher",
    "SecretsManagerSecretMetricFactory",
    "SecretsManagerSecretMetricFactoryProps",
    "SecretsManagerSecretMonitoring",
    "SecretsManagerSecretMonitoringProps",
    "SimpleEc2ServiceMonitoringProps",
    "SimpleFargateServiceMonitoringProps",
    "SingleWidgetDashboardSegment",
    "SnsAlarmActionStrategy",
    "SnsAlarmActionStrategyProps",
    "SnsTopicMetricFactory",
    "SnsTopicMetricFactoryProps",
    "SnsTopicMonitoring",
    "SnsTopicMonitoringProps",
    "SqsQueueMetricFactory",
    "SqsQueueMetricFactoryProps",
    "SqsQueueMonitoring",
    "SqsQueueMonitoringProps",
    "SqsQueueMonitoringWithDlq",
    "SqsQueueMonitoringWithDlqProps",
    "StepFunctionActivityMetricFactory",
    "StepFunctionActivityMetricFactoryProps",
    "StepFunctionActivityMonitoring",
    "StepFunctionActivityMonitoringProps",
    "StepFunctionLambdaIntegrationMetricFactory",
    "StepFunctionLambdaIntegrationMetricFactoryProps",
    "StepFunctionLambdaIntegrationMonitoring",
    "StepFunctionLambdaIntegrationMonitoringProps",
    "StepFunctionMetricFactory",
    "StepFunctionMetricFactoryProps",
    "StepFunctionMonitoring",
    "StepFunctionMonitoringProps",
    "StepFunctionServiceIntegrationMetricFactory",
    "StepFunctionServiceIntegrationMetricFactoryProps",
    "StepFunctionServiceIntegrationMonitoring",
    "StepFunctionServiceIntegrationMonitoringProps",
    "StorageType",
    "TaskHealthAlarmFactory",
    "ThrottledEventsThreshold",
    "ThroughputAlarmFactory",
    "TopicAlarmFactory",
    "TpsAlarmFactory",
    "UnhealthyTaskCountThreshold",
    "UsageAlarmFactory",
    "UsageCountThreshold",
    "UsageThreshold",
    "UsageType",
    "UserProvidedNames",
    "XaxrMathExpression",
    "XaxrMathExpressionProps",
]

publication.publish()
